
#include <math.h>
#include <utility>
#include <map>
#include <ptv.h>
#include <DofT.h>
#include <ScalarFunction.h>

using namespace std; 



/* ------------- order 1 ---------------*/


  
void matrix_factory_stiffness_2D_order1 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[3];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00+x0;  dof1[1]=G10+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G01+x0;  dof2[1]=y0+G11;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[3][3];
  A[0][0]=((Jinv01*Jinv01)/2.0+Jinv01*Jinv00+(Jinv11*Jinv11)/2.0+Jinv10*Jinv11+(Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[0][1]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[0][2]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[1][0]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[1][1]=((Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[1][2]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[2][0]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[2][1]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[2][2]=((Jinv01*Jinv01)/2.0+(Jinv11*Jinv11)/2.0)*D;
  int nbf = 3;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 2 ---------------*/


  
void matrix_factory_stiffness_2D_order2 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[6];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/2.0+x0;  dof1[1]=G10/2.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G00+x0;  dof2[1]=G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=G01/2.0+x0;  dof3[1]=y0+G11/2.0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G01/2.0+G00/2.0+x0;  dof4[1]=G10/2.0+y0+G11/2.0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01+x0;  dof5[1]=y0+G11;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[6][6];
  A[0][0]=(Jinv11*Jinv10+(Jinv01*Jinv01)/2.0+(Jinv00*Jinv00)/2.0+(Jinv11*Jinv11)/2.0+(Jinv10*Jinv10)/2.0+Jinv01*Jinv00)*D;
  A[0][1]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00)-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[0][2]=(Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0+(Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0)*D;
  A[0][3]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01)-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[0][4]=(0.0)*D;
  A[0][5]=(Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0+(Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0)*D;
  A[1][0]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00)-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[1][1]=((4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00)+(4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00)*D;
  A[1][2]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00)-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[1][3]=((4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*Jinv01*Jinv00)*D;
  A[1][4]=(-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01)-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00)*D;
  A[1][5]=(0.0)*D;
  A[2][0]=(Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0+(Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0)*D;
  A[2][1]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00)-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[2][2]=((Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=((2.0/3.0)*Jinv11*Jinv10+(2.0/3.0)*Jinv01*Jinv00)*D;
  A[2][5]=(-Jinv11*Jinv10/6.0-Jinv01*Jinv00/6.0)*D;
  A[3][0]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01)-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[3][1]=((4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*Jinv01*Jinv00)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00)+(4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00)*D;
  A[3][4]=(-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00)-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00)*D;
  A[3][5]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01)-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[4][0]=(0.0)*D;
  A[4][1]=(-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01)-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00)*D;
  A[4][2]=((2.0/3.0)*Jinv11*Jinv10+(2.0/3.0)*Jinv01*Jinv00)*D;
  A[4][3]=(-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00)-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00)*D;
  A[4][4]=((4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00)+(4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00)*D;
  A[4][5]=((2.0/3.0)*Jinv11*Jinv10+(2.0/3.0)*Jinv01*Jinv00)*D;
  A[5][0]=(Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0+(Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0)*D;
  A[5][1]=(0.0)*D;
  A[5][2]=(-Jinv11*Jinv10/6.0-Jinv01*Jinv00/6.0)*D;
  A[5][3]=(-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01)-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00)*D;
  A[5][4]=((2.0/3.0)*Jinv11*Jinv10+(2.0/3.0)*Jinv01*Jinv00)*D;
  A[5][5]=((Jinv01*Jinv01)/2.0+(Jinv11*Jinv11)/2.0)*D;
  int nbf = 6;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 3 ---------------*/


  
void matrix_factory_stiffness_2D_order3 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[10];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/3.0+x0;  dof1[1]=G10/3.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=(2.0/3.0)*G00+x0;  dof2[1]=(2.0/3.0)*G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=G00+x0;  dof3[1]=G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G01/3.0+x0;  dof4[1]=y0+G11/3.0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01/3.0+G00/3.0+x0;  dof5[1]=G10/3.0+y0+G11/3.0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/3.0+(2.0/3.0)*G00+x0;  dof6[1]=(2.0/3.0)*G10+y0+G11/3.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=(2.0/3.0)*G01+x0;  dof7[1]=y0+(2.0/3.0)*G11;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=(2.0/3.0)*G01+G00/3.0+x0;  dof8[1]=G10/3.0+y0+(2.0/3.0)*G11;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01+x0;  dof9[1]=y0+G11;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[10][10];
  A[0][0]=((17.0/40.0)*(Jinv11*Jinv11)+(17.0/20.0)*Jinv01*Jinv00+(17.0/20.0)*Jinv11*Jinv10+(17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10)+(17.0/40.0)*(Jinv01*Jinv01))*D;
  A[0][1]=((3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[0][2]=((3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00+(3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[0][3]=(-(7.0/80.0)*Jinv01*Jinv00-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10))*D;
  A[0][4]=(-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01))*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[0][7]=((27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00+(3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[0][8]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[0][9]=(-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01))*D;
  A[1][0]=((3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[1][1]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[1][2]=(-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[1][3]=((3.0/10.0)*Jinv01*Jinv00+(3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[1][4]=((27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10)*D;
  A[1][5]=(-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01))*D;
  A[1][6]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[1][7]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[1][8]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[1][9]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[2][0]=((3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00+(3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[2][1]=(-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[2][2]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[2][3]=(-(57.0/80.0)*Jinv01*Jinv00-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10))*D;
  A[2][4]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[2][5]=((81.0/40.0)*Jinv01*Jinv00+(81.0/40.0)*Jinv11*Jinv10)*D;
  A[2][6]=(-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[2][7]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[2][8]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[2][9]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[3][0]=(-(7.0/80.0)*Jinv01*Jinv00-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][1]=((3.0/10.0)*Jinv01*Jinv00+(3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][2]=(-(57.0/80.0)*Jinv01*Jinv00-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10))*D;
  A[3][3]=((17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10))*D;
  A[3][4]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][5]=(0.0)*D;
  A[3][6]=((57.0/80.0)*Jinv01*Jinv00+(57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][7]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][8]=(-(3.0/10.0)*Jinv01*Jinv00-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[3][9]=((7.0/80.0)*Jinv01*Jinv00+(7.0/80.0)*Jinv11*Jinv10)*D;
  A[4][0]=(-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01))*D;
  A[4][1]=((27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10)*D;
  A[4][2]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[4][3]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[4][4]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[4][5]=(-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10))*D;
  A[4][6]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[4][7]=(-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01))*D;
  A[4][8]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[4][9]=((27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00+(3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01))*D;
  A[5][2]=((81.0/40.0)*Jinv01*Jinv00+(81.0/40.0)*Jinv11*Jinv10)*D;
  A[5][3]=(0.0)*D;
  A[5][4]=(-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10))*D;
  A[5][5]=((81.0/20.0)*(Jinv11*Jinv11)+(81.0/20.0)*Jinv01*Jinv00+(81.0/20.0)*Jinv11*Jinv10+(81.0/20.0)*(Jinv00*Jinv00)+(81.0/20.0)*(Jinv10*Jinv10)+(81.0/20.0)*(Jinv01*Jinv01))*D;
  A[5][6]=(-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10))*D;
  A[5][7]=((81.0/40.0)*Jinv01*Jinv00+(81.0/40.0)*Jinv11*Jinv10)*D;
  A[5][8]=(-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01))*D;
  A[5][9]=(0.0)*D;
  A[6][0]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[6][1]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[6][2]=(-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[6][3]=((57.0/80.0)*Jinv01*Jinv00+(57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[6][4]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[6][5]=(-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10))*D;
  A[6][6]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[6][7]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[6][8]=(-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00+(27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[6][9]=((3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[7][0]=((27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00+(3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[7][1]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[7][2]=(-(27.0/80.0)*Jinv01*Jinv00-(27.0/80.0)*Jinv11*Jinv10)*D;
  A[7][3]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[7][4]=(-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01))*D;
  A[7][5]=((81.0/40.0)*Jinv01*Jinv00+(81.0/40.0)*Jinv11*Jinv10)*D;
  A[7][6]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[7][7]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[7][8]=(-(27.0/16.0)*Jinv01*Jinv00-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10))*D;
  A[7][9]=(-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01))*D;
  A[8][0]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[8][1]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[8][2]=((27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[8][3]=(-(3.0/10.0)*Jinv01*Jinv00-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[8][4]=((27.0/80.0)*Jinv01*Jinv00+(27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10))*D;
  A[8][5]=(-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01))*D;
  A[8][6]=(-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00+(27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[8][7]=(-(27.0/16.0)*Jinv01*Jinv00-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10))*D;
  A[8][8]=((27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00+(27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01))*D;
  A[8][9]=((3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00+(57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][0]=(-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][1]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][2]=(-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][3]=((7.0/80.0)*Jinv01*Jinv00+(7.0/80.0)*Jinv11*Jinv10)*D;
  A[9][4]=((27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00+(3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][5]=(0.0)*D;
  A[9][6]=((3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][7]=(-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01))*D;
  A[9][8]=((3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00+(57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01))*D;
  A[9][9]=((17.0/40.0)*(Jinv11*Jinv11)+(17.0/40.0)*(Jinv01*Jinv01))*D;
  int nbf = 10;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 4 ---------------*/


  
void matrix_factory_stiffness_2D_order4 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[15];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/4.0+x0;  dof1[1]=G10/4.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G00/2.0+x0;  dof2[1]=G10/2.0+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=(3.0/4.0)*G00+x0;  dof3[1]=(3.0/4.0)*G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G00+x0;  dof4[1]=G10+y0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01/4.0+x0;  dof5[1]=y0+G11/4.0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/4.0+G00/4.0+x0;  dof6[1]=G10/4.0+y0+G11/4.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=G01/4.0+G00/2.0+x0;  dof7[1]=G10/2.0+y0+G11/4.0;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=G01/4.0+(3.0/4.0)*G00+x0;  dof8[1]=(3.0/4.0)*G10+y0+G11/4.0;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01/2.0+x0;  dof9[1]=y0+G11/2.0;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

  double dof10[2];
  dof10[0]=G01/2.0+G00/4.0+x0;  dof10[1]=G10/4.0+y0+G11/2.0;
  ptv pdof10(2,dof10);
  iidof[10] = dof.insert_dof(element,10,pdof10);

  double dof11[2];
  dof11[0]=G01/2.0+G00/2.0+x0;  dof11[1]=G10/2.0+y0+G11/2.0;
  ptv pdof11(2,dof11);
  iidof[11] = dof.insert_dof(element,11,pdof11);

  double dof12[2];
  dof12[0]=(3.0/4.0)*G01+x0;  dof12[1]=y0+(3.0/4.0)*G11;
  ptv pdof12(2,dof12);
  iidof[12] = dof.insert_dof(element,12,pdof12);

  double dof13[2];
  dof13[0]=(3.0/4.0)*G01+G00/4.0+x0;  dof13[1]=G10/4.0+y0+(3.0/4.0)*G11;
  ptv pdof13(2,dof13);
  iidof[13] = dof.insert_dof(element,13,pdof13);

  double dof14[2];
  dof14[0]=G01+x0;  dof14[1]=y0+G11;
  ptv pdof14(2,dof14);
  iidof[14] = dof.insert_dof(element,14,pdof14);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[15][15];
  A[0][0]=((47.0/126.0)*(Jinv01*Jinv01)+(47.0/63.0)*Jinv01*Jinv00+(47.0/126.0)*(Jinv11*Jinv11)+(47.0/63.0)*Jinv10*Jinv11+(47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10))*D;
  A[0][1]=((8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv01*Jinv00+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv10*Jinv11-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10))*D;
  A[0][2]=((8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv10*Jinv11+(442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10))*D;
  A[0][3]=(-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv01*Jinv00-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv10*Jinv11-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10))*D;
  A[0][4]=((107.0/1890.0)*Jinv01*Jinv00+(107.0/1890.0)*Jinv10*Jinv11+(107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10))*D;
  A[0][5]=(-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv01*Jinv00-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv10*Jinv11+(8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10))*D;
  A[0][6]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][7]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][8]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][9]=((442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv01*Jinv00+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][10]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][11]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][12]=(-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv01*Jinv00-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv10*Jinv11-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][13]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[0][14]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv01*Jinv00+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv10*Jinv11)*D;
  A[1][0]=((8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv01*Jinv00+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv10*Jinv11-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10))*D;
  A[1][1]=((64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv01*Jinv00+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv10*Jinv11+(64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10))*D;
  A[1][2]=(-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv01*Jinv00-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv10*Jinv11-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10))*D;
  A[1][3]=((64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv01*Jinv00+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv10*Jinv11+(64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10))*D;
  A[1][4]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][5]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][6]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv01*Jinv00-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][7]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][8]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv01*Jinv00-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][9]=((32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv01*Jinv00+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][10]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][11]=(-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv01*Jinv00-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[1][12]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[1][13]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[1][14]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[2][0]=((8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv10*Jinv11+(442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10))*D;
  A[2][1]=(-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv01*Jinv00-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv10*Jinv11-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10))*D;
  A[2][2]=((772.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv01*Jinv00+(772.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv10*Jinv11+(932.0/315.0)*(Jinv00*Jinv00)+(932.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][3]=(-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv01*Jinv00-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv10*Jinv11-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10))*D;
  A[2][4]=((134.0/315.0)*Jinv01*Jinv00+(134.0/315.0)*Jinv10*Jinv11+(442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10))*D;
  A[2][5]=(-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv10*Jinv11+(32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][6]=((128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][7]=(-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv01*Jinv00-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][8]=((16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv01*Jinv00+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv10*Jinv11+(32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][9]=((16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv01*Jinv00+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv10*Jinv11+(16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][10]=((128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][11]=((124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv01*Jinv00+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv10*Jinv11+(16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10))*D;
  A[2][12]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11)*D;
  A[2][13]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv01*Jinv00-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv10*Jinv11)*D;
  A[2][14]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[3][0]=(-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv01*Jinv00-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv10*Jinv11-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][1]=((64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv01*Jinv00+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv10*Jinv11+(64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10))*D;
  A[3][2]=(-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv01*Jinv00-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv10*Jinv11-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10))*D;
  A[3][3]=((1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv01*Jinv00+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv10*Jinv11+(64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10))*D;
  A[3][4]=(-(736.0/945.0)*Jinv01*Jinv00-(736.0/945.0)*Jinv10*Jinv11-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10))*D;
  A[3][5]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][6]=(-(128.0/189.0)*Jinv01*Jinv00-(128.0/189.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][7]=((2432.0/945.0)*Jinv01*Jinv00+(2432.0/945.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][8]=(-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv01*Jinv00-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][9]=((16.0/189.0)*Jinv01*Jinv00+(16.0/189.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][10]=(-(128.0/189.0)*Jinv01*Jinv00-(128.0/189.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][11]=((16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv01*Jinv00+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[3][12]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[3][13]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[3][14]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[4][0]=((107.0/1890.0)*Jinv01*Jinv00+(107.0/1890.0)*Jinv10*Jinv11+(107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10))*D;
  A[4][1]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10))*D;
  A[4][2]=((134.0/315.0)*Jinv01*Jinv00+(134.0/315.0)*Jinv10*Jinv11+(442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10))*D;
  A[4][3]=(-(736.0/945.0)*Jinv01*Jinv00-(736.0/945.0)*Jinv10*Jinv11-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10))*D;
  A[4][4]=((47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10))*D;
  A[4][5]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][6]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][7]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][8]=((736.0/945.0)*Jinv01*Jinv00+(736.0/945.0)*Jinv10*Jinv11+(8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10))*D;
  A[4][9]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][10]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][11]=(-(134.0/315.0)*Jinv01*Jinv00-(134.0/315.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][12]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][13]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[4][14]=(-(107.0/1890.0)*Jinv01*Jinv00-(107.0/1890.0)*Jinv10*Jinv11)*D;
  A[5][0]=(-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv01*Jinv00-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv10*Jinv11+(8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10))*D;
  A[5][1]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[5][2]=(-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv10*Jinv11+(32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[5][3]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[5][4]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[5][5]=((64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv01*Jinv00+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv10*Jinv11+(64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10))*D;
  A[5][6]=((128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv10*Jinv11-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10))*D;
  A[5][7]=((128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[5][8]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10))*D;
  A[5][9]=(-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv01*Jinv00-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv10*Jinv11-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10))*D;
  A[5][10]=((128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[5][11]=(-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv10*Jinv11-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10))*D;
  A[5][12]=((64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv01*Jinv00+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv10*Jinv11+(64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[5][13]=(-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv10*Jinv11-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[5][14]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[6][0]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[6][1]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv01*Jinv00-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[6][2]=((128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[6][3]=(-(128.0/189.0)*Jinv01*Jinv00-(128.0/189.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[6][4]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[6][5]=((128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv10*Jinv11-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10))*D;
  A[6][6]=((256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv01*Jinv00+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv10*Jinv11+(256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10))*D;
  A[6][7]=(-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv01*Jinv00-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv10*Jinv11-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10))*D;
  A[6][8]=((128.0/189.0)*Jinv01*Jinv00+(128.0/189.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[6][9]=(-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[6][10]=(-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv01*Jinv00-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv10*Jinv11-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[6][11]=((128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[6][12]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv10*Jinv11)*D;
  A[6][13]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv10*Jinv11)*D;
  A[6][14]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[7][0]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[7][1]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[7][2]=(-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv01*Jinv00-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[7][3]=((2432.0/945.0)*Jinv01*Jinv00+(2432.0/945.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[7][4]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[7][5]=((128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[7][6]=(-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv01*Jinv00-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv10*Jinv11-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10))*D;
  A[7][7]=((256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv01*Jinv00+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv10*Jinv11+(256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10))*D;
  A[7][8]=(-(2432.0/945.0)*Jinv01*Jinv00-(2432.0/945.0)*Jinv10*Jinv11-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10))*D;
  A[7][9]=(-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[7][10]=(-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv01*Jinv00-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv10*Jinv11-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[7][11]=(-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv01*Jinv00-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[7][12]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv10*Jinv11)*D;
  A[7][13]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv10*Jinv11)*D;
  A[7][14]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[8][0]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][1]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv01*Jinv00-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[8][2]=((16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv01*Jinv00+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv10*Jinv11+(32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[8][3]=(-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv01*Jinv00-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv10*Jinv11-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[8][4]=((736.0/945.0)*Jinv01*Jinv00+(736.0/945.0)*Jinv10*Jinv11+(8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10))*D;
  A[8][5]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10))*D;
  A[8][6]=((128.0/189.0)*Jinv01*Jinv00+(128.0/189.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[8][7]=(-(2432.0/945.0)*Jinv01*Jinv00-(2432.0/945.0)*Jinv10*Jinv11-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10))*D;
  A[8][8]=((1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv01*Jinv00+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv10*Jinv11+(64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10))*D;
  A[8][9]=(-(16.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*Jinv10*Jinv11-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10))*D;
  A[8][10]=((128.0/189.0)*Jinv01*Jinv00+(128.0/189.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[8][11]=(-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv01*Jinv00-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv10*Jinv11-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10))*D;
  A[8][12]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][13]=((64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv01*Jinv00+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv10*Jinv11+(64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][14]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv01*Jinv00-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[9][0]=((442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv01*Jinv00+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][1]=((32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv01*Jinv00+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[9][2]=((16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv01*Jinv00+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv10*Jinv11+(16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][3]=((16.0/189.0)*Jinv01*Jinv00+(16.0/189.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[9][4]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][5]=(-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv01*Jinv00-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv10*Jinv11-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][6]=(-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][7]=(-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][8]=(-(16.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*Jinv10*Jinv11-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10))*D;
  A[9][9]=((932.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv01*Jinv00+(932.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv10*Jinv11+(772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][10]=(-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv10*Jinv11-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10))*D;
  A[9][11]=((16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv01*Jinv00+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv10*Jinv11+(124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10))*D;
  A[9][12]=(-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv01*Jinv00-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv10*Jinv11-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[9][13]=((32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv01*Jinv00+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv10*Jinv11+(16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[9][14]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv01*Jinv00+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv10*Jinv11)*D;
  A[10][0]=(-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv01*Jinv00-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv10*Jinv11-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[10][1]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[10][2]=((128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv10*Jinv11-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10))*D;
  A[10][3]=(-(128.0/189.0)*Jinv01*Jinv00-(128.0/189.0)*Jinv10*Jinv11+(128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10))*D;
  A[10][4]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[10][5]=((128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[10][6]=(-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv01*Jinv00-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv10*Jinv11-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[10][7]=(-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv01*Jinv00-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv10*Jinv11-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[10][8]=((128.0/189.0)*Jinv01*Jinv00+(128.0/189.0)*Jinv10*Jinv11+(256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10))*D;
  A[10][9]=(-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv01*Jinv00-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv10*Jinv11-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10))*D;
  A[10][10]=((256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv01*Jinv00+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv10*Jinv11+(256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10))*D;
  A[10][11]=((128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv10*Jinv11-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10))*D;
  A[10][12]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv10*Jinv11)*D;
  A[10][13]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv01*Jinv00-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv10*Jinv11)*D;
  A[10][14]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[11][0]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[11][1]=(-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv01*Jinv00-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[11][2]=((124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv01*Jinv00+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv10*Jinv11+(16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][3]=((16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv01*Jinv00+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv10*Jinv11-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10))*D;
  A[11][4]=(-(134.0/315.0)*Jinv01*Jinv00-(134.0/315.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[11][5]=(-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv10*Jinv11-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10))*D;
  A[11][6]=((128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][7]=(-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv01*Jinv00-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv10*Jinv11+(128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][8]=(-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv01*Jinv00-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv10*Jinv11-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][9]=((16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv01*Jinv00+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv10*Jinv11+(124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][10]=((128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv01*Jinv00+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv10*Jinv11-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10))*D;
  A[11][11]=((772.0/315.0)*(Jinv01*Jinv01)+(68.0/35.0)*Jinv01*Jinv00+(772.0/315.0)*(Jinv11*Jinv11)+(68.0/35.0)*Jinv10*Jinv11+(772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10))*D;
  A[11][12]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv10*Jinv11+(16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[11][13]=(-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv01*Jinv00-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv10*Jinv11-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[11][14]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv10*Jinv11)*D;
  A[12][0]=(-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv01*Jinv00-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv10*Jinv11-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[12][1]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[12][2]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11)*D;
  A[12][3]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[12][4]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[12][5]=((64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv01*Jinv00+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv10*Jinv11+(64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[12][6]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv10*Jinv11)*D;
  A[12][7]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv10*Jinv11)*D;
  A[12][8]=(-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*Jinv10*Jinv11-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[12][9]=(-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv01*Jinv00-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv10*Jinv11-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[12][10]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv01*Jinv00+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv10*Jinv11)*D;
  A[12][11]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv01*Jinv00-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv10*Jinv11+(16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[12][12]=((64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv01*Jinv00+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv10*Jinv11+(1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10))*D;
  A[12][13]=(-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv10*Jinv11-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10))*D;
  A[12][14]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv01*Jinv00-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv10*Jinv11)*D;
  A[13][0]=((8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv10*Jinv11+(8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[13][1]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[13][2]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv01*Jinv00-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv10*Jinv11)*D;
  A[13][3]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[13][4]=((64.0/315.0)*Jinv01*Jinv00+(64.0/315.0)*Jinv10*Jinv11-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[13][5]=(-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv10*Jinv11-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[13][6]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv10*Jinv11)*D;
  A[13][7]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv01*Jinv00+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv10*Jinv11)*D;
  A[13][8]=((64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv01*Jinv00+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv10*Jinv11+(64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10))*D;
  A[13][9]=((32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv01*Jinv00+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv10*Jinv11+(16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[13][10]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv01*Jinv00-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv10*Jinv11)*D;
  A[13][11]=(-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv01*Jinv00-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv10*Jinv11-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10))*D;
  A[13][12]=(-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv01*Jinv00-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv10*Jinv11-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10))*D;
  A[13][13]=((64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv01*Jinv00+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv10*Jinv11+(1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10))*D;
  A[13][14]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv01*Jinv00+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv10*Jinv11)*D;
  A[14][0]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv01*Jinv00+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv10*Jinv11)*D;
  A[14][1]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][2]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][3]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][4]=(-(107.0/1890.0)*Jinv01*Jinv00-(107.0/1890.0)*Jinv10*Jinv11)*D;
  A[14][5]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv01*Jinv00-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv10*Jinv11)*D;
  A[14][6]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][7]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][8]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv01*Jinv00-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv10*Jinv11)*D;
  A[14][9]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv01*Jinv00+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv10*Jinv11)*D;
  A[14][10]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][11]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv01*Jinv00+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv10*Jinv11)*D;
  A[14][12]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv01*Jinv00-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv10*Jinv11)*D;
  A[14][13]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv01*Jinv00+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv10*Jinv11)*D;
  A[14][14]=((47.0/126.0)*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11))*D;
  int nbf = 15;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 5 ---------------*/


  
void matrix_factory_stiffness_2D_order5 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[21];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/5.0+x0;  dof1[1]=G10/5.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=(2.0/5.0)*G00+x0;  dof2[1]=(2.0/5.0)*G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=(3.0/5.0)*G00+x0;  dof3[1]=(3.0/5.0)*G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=(4.0/5.0)*G00+x0;  dof4[1]=(4.0/5.0)*G10+y0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G00+x0;  dof5[1]=G10+y0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/5.0+x0;  dof6[1]=y0+G11/5.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=G01/5.0+G00/5.0+x0;  dof7[1]=G10/5.0+y0+G11/5.0;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=G01/5.0+(2.0/5.0)*G00+x0;  dof8[1]=(2.0/5.0)*G10+y0+G11/5.0;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01/5.0+(3.0/5.0)*G00+x0;  dof9[1]=(3.0/5.0)*G10+y0+G11/5.0;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

  double dof10[2];
  dof10[0]=G01/5.0+(4.0/5.0)*G00+x0;  dof10[1]=(4.0/5.0)*G10+y0+G11/5.0;
  ptv pdof10(2,dof10);
  iidof[10] = dof.insert_dof(element,10,pdof10);

  double dof11[2];
  dof11[0]=(2.0/5.0)*G01+x0;  dof11[1]=y0+(2.0/5.0)*G11;
  ptv pdof11(2,dof11);
  iidof[11] = dof.insert_dof(element,11,pdof11);

  double dof12[2];
  dof12[0]=(2.0/5.0)*G01+G00/5.0+x0;  dof12[1]=G10/5.0+y0+(2.0/5.0)*G11;
  ptv pdof12(2,dof12);
  iidof[12] = dof.insert_dof(element,12,pdof12);

  double dof13[2];
  dof13[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  dof13[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  ptv pdof13(2,dof13);
  iidof[13] = dof.insert_dof(element,13,pdof13);

  double dof14[2];
  dof14[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  dof14[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  ptv pdof14(2,dof14);
  iidof[14] = dof.insert_dof(element,14,pdof14);

  double dof15[2];
  dof15[0]=(3.0/5.0)*G01+x0;  dof15[1]=y0+(3.0/5.0)*G11;
  ptv pdof15(2,dof15);
  iidof[15] = dof.insert_dof(element,15,pdof15);

  double dof16[2];
  dof16[0]=(3.0/5.0)*G01+G00/5.0+x0;  dof16[1]=G10/5.0+y0+(3.0/5.0)*G11;
  ptv pdof16(2,dof16);
  iidof[16] = dof.insert_dof(element,16,pdof16);

  double dof17[2];
  dof17[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  dof17[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  ptv pdof17(2,dof17);
  iidof[17] = dof.insert_dof(element,17,pdof17);

  double dof18[2];
  dof18[0]=(4.0/5.0)*G01+x0;  dof18[1]=y0+(4.0/5.0)*G11;
  ptv pdof18(2,dof18);
  iidof[18] = dof.insert_dof(element,18,pdof18);

  double dof19[2];
  dof19[0]=(4.0/5.0)*G01+G00/5.0+x0;  dof19[1]=G10/5.0+y0+(4.0/5.0)*G11;
  ptv pdof19(2,dof19);
  iidof[19] = dof.insert_dof(element,19,pdof19);

  double dof20[2];
  dof20[0]=G01+x0;  dof20[1]=y0+G11;
  ptv pdof20(2,dof20);
  iidof[20] = dof.insert_dof(element,20,pdof20);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[21][21];
  A[0][0]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/48384.0)*(Jinv11*Jinv11)+(16567.0/24192.0)*Jinv10*Jinv11+(16567.0/24192.0)*Jinv01*Jinv00+(16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][1]=((725.0/3584.0)*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv11*Jinv11)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[0][2]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv11*Jinv11)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[0][3]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv11*Jinv11)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][4]=((1975.0/48384.0)*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv11*Jinv11)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][5]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][6]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv11*Jinv11)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[0][7]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[0][8]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][9]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][10]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][11]=((14375.0/24192.0)*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv11*Jinv11)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[0][12]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][13]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][14]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[0][15]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv11*Jinv11)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][16]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][17]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[0][18]=((29375.0/145152.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv11*Jinv11)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][19]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][20]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*(Jinv11*Jinv11)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[1][0]=((725.0/3584.0)*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv11*Jinv11)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[1][1]=((6875.0/3456.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv11*Jinv11)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[1][2]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv11*Jinv11)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][3]=((59375.0/72576.0)*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv11*Jinv11)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[1][4]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[1][5]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][6]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[1][7]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv11*Jinv11)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[1][8]=((115625.0/96768.0)*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv11*Jinv11)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][9]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv11*Jinv11)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[1][10]=((49375.0/145152.0)*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv11*Jinv11)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[1][11]=((11875.0/41472.0)*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv11*Jinv11)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][12]=((3125.0/2304.0)*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv11*Jinv11)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[1][13]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv11*Jinv11)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][14]=((3125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv11*Jinv11)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[1][15]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv11*Jinv11)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[1][16]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv11*Jinv11)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[1][17]=((38125.0/290304.0)*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[1][18]=((14375.0/72576.0)*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[1][19]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*(Jinv11*Jinv11)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[1][20]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[2][0]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv11*Jinv11)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[2][1]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv11*Jinv11)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][2]=((10625.0/3456.0)*(Jinv01*Jinv01)+(10625.0/3456.0)*(Jinv11*Jinv11)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[2][3]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[2][4]=((8125.0/9072.0)*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv11*Jinv11)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[2][5]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][6]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv11*Jinv11)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[2][7]=((53125.0/72576.0)*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv11*Jinv11)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][8]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv11*Jinv11)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[2][9]=((146875.0/72576.0)*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv11*Jinv11)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][10]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv11*Jinv11)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][11]=((625.0/6048.0)*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[2][12]=((3125.0/8064.0)*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv11*Jinv11)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][13]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[2][14]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv11*Jinv11)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][15]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv11*Jinv11)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[2][16]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[2][17]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[2][18]=((8125.0/72576.0)*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[2][19]=((38125.0/290304.0)*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv11*Jinv11)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[2][20]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[3][0]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv11*Jinv11)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][1]=((59375.0/72576.0)*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv11*Jinv11)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[3][2]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[3][3]=((89375.0/24192.0)*(Jinv01*Jinv01)+(89375.0/24192.0)*(Jinv11*Jinv11)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[3][4]=(-(625.0/448.0)*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv11*Jinv11)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][5]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[3][6]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][8]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[3][9]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv11*Jinv11)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][10]=((625.0/448.0)*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv11*Jinv11)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[3][11]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][12]=((3125.0/72576.0)*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv11*Jinv11)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[3][13]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][14]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[3][15]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[3][16]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[3][17]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv11*Jinv11)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[3][18]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[3][19]=((3125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv11*Jinv11)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[3][20]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[4][0]=((1975.0/48384.0)*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv11*Jinv11)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[4][1]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][2]=((8125.0/9072.0)*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv11*Jinv11)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[4][3]=(-(625.0/448.0)*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv11*Jinv11)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][4]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[4][5]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[4][6]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][7]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[4][8]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][9]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[4][10]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[4][11]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][12]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][13]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[4][14]=((625.0/448.0)*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv11*Jinv11)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][15]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[4][16]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[4][17]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv11*Jinv11)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[4][18]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[4][19]=((49375.0/145152.0)*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv11*Jinv11)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[4][20]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[5][0]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][1]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][2]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][3]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[5][4]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[5][5]=((16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[5][6]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[5][7]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][8]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][9]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[5][10]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[5][11]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[5][12]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][13]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][14]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[5][15]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[5][16]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][17]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][18]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[5][19]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[5][20]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[6][0]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv11*Jinv11)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[6][1]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[6][2]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv11*Jinv11)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[6][3]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][4]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][5]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[6][6]=((6875.0/3456.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv11*Jinv11)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[6][7]=((8125.0/16128.0)*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv11*Jinv11)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][8]=((4375.0/20736.0)*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv11*Jinv11)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[6][9]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv11*Jinv11)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][10]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[6][11]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv11*Jinv11)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][12]=((14375.0/290304.0)*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv11*Jinv11)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[6][13]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv11*Jinv11)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[6][14]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][15]=((11875.0/6048.0)*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv11*Jinv11)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][16]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv11*Jinv11)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][17]=((8125.0/72576.0)*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv11*Jinv11)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[6][18]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][19]=((14375.0/72576.0)*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv11*Jinv11)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][20]=((29375.0/145152.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv11*Jinv11)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00)*D;
  A[7][0]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][1]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv11*Jinv11)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[7][2]=((53125.0/72576.0)*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv11*Jinv11)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][3]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][4]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[7][5]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[7][6]=((8125.0/16128.0)*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv11*Jinv11)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[7][7]=((128125.0/18144.0)*(Jinv01*Jinv01)+(128125.0/18144.0)*(Jinv11*Jinv11)+(3125.0/504.0)*Jinv10*Jinv11+(3125.0/504.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[7][8]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv11*Jinv11)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[7][9]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[7][10]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[7][11]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][12]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv11*Jinv11)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[7][13]=((34375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv11*Jinv11)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[7][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[7][15]=((49375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv11*Jinv11)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[7][16]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[7][17]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[7][18]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv11*Jinv11)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[7][19]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv11*Jinv11)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[7][20]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[8][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][1]=((115625.0/96768.0)*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv11*Jinv11)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][2]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv11*Jinv11)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[8][3]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[8][4]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][5]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][6]=((4375.0/20736.0)*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv11*Jinv11)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[8][7]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv11*Jinv11)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[8][8]=((209375.0/24192.0)*(Jinv01*Jinv01)+(209375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(34375.0/3456.0)*(Jinv00*Jinv00)+(34375.0/3456.0)*(Jinv10*Jinv10))*D;
  A[8][9]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv11*Jinv11)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[8][10]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[8][11]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv11*Jinv11)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[8][12]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv11*Jinv11)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[8][13]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[8][14]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[8][15]=((11875.0/36288.0)*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv11*Jinv11)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[8][16]=((34375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[8][17]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[8][18]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv11*Jinv11)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00)*D;
  A[8][19]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv11*Jinv11)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00)*D;
  A[8][20]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[9][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[9][1]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv11*Jinv11)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[9][2]=((146875.0/72576.0)*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv11*Jinv11)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][3]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv11*Jinv11)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][4]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[9][5]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][6]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv11*Jinv11)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[9][7]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[9][8]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv11*Jinv11)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[9][9]=((71875.0/9072.0)*(Jinv01*Jinv01)+(71875.0/9072.0)*(Jinv11*Jinv11)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[9][10]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[9][11]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv11*Jinv11)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[9][12]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[9][13]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv11*Jinv11)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[9][14]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv11*Jinv11)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][15]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv11*Jinv11)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[9][16]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[9][17]=((146875.0/72576.0)*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv11*Jinv11)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[9][18]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv11*Jinv11)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[9][19]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv11*Jinv11)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[9][20]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[10][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][1]=((49375.0/145152.0)*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv11*Jinv11)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[10][2]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv11*Jinv11)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][3]=((625.0/448.0)*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv11*Jinv11)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[10][4]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[10][5]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[10][6]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][7]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][8]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[10][9]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][10]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[10][11]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][12]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[10][13]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[10][14]=(-(625.0/448.0)*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][15]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[10][16]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[10][17]=((8125.0/9072.0)*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv11*Jinv11)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[10][18]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][19]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv11*Jinv11)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][20]=((1975.0/48384.0)*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv11*Jinv11)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00)*D;
  A[11][0]=((14375.0/24192.0)*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv11*Jinv11)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[11][1]=((11875.0/41472.0)*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv11*Jinv11)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][2]=((625.0/6048.0)*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[11][3]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[11][4]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[11][5]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[11][6]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv11*Jinv11)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][7]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[11][8]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv11*Jinv11)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[11][9]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv11*Jinv11)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[11][10]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][11]=((11875.0/2688.0)*(Jinv01*Jinv01)+(11875.0/2688.0)*(Jinv11*Jinv11)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[11][12]=((625.0/145152.0)*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv11*Jinv11)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][13]=((11875.0/36288.0)*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv11*Jinv11)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[11][14]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][15]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][16]=((49375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv11*Jinv11)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[11][17]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv11*Jinv11)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][18]=((11875.0/6048.0)*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv11*Jinv11)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[11][19]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv11*Jinv11)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[11][20]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv11*Jinv11)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00)*D;
  A[12][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[12][1]=((3125.0/2304.0)*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv11*Jinv11)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[12][2]=((3125.0/8064.0)*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv11*Jinv11)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[12][3]=((3125.0/72576.0)*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv11*Jinv11)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[12][4]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[12][5]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][6]=((14375.0/290304.0)*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv11*Jinv11)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[12][7]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv11*Jinv11)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[12][8]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv11*Jinv11)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[12][9]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[12][10]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[12][11]=((625.0/145152.0)*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv11*Jinv11)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[12][12]=((34375.0/3456.0)*(Jinv01*Jinv01)+(34375.0/3456.0)*(Jinv11*Jinv11)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[12][13]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[12][14]=((3125.0/72576.0)*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv11*Jinv11)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[12][15]=((625.0/145152.0)*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv11*Jinv11)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][16]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv11*Jinv11)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[12][17]=((3125.0/8064.0)*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv11*Jinv11)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][18]=((14375.0/290304.0)*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv11*Jinv11)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[12][19]=((3125.0/2304.0)*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv11*Jinv11)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[12][20]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[13][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][1]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv11*Jinv11)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[13][2]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[13][3]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[13][4]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[13][5]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[13][6]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv11*Jinv11)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[13][7]=((34375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv11*Jinv11)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[13][8]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[13][9]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv11*Jinv11)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[13][10]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[13][11]=((11875.0/36288.0)*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv11*Jinv11)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[13][12]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[13][13]=((209375.0/24192.0)*(Jinv01*Jinv01)+(209375.0/24192.0)*(Jinv11*Jinv11)+(59375.0/8064.0)*Jinv10*Jinv11+(59375.0/8064.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[13][14]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[13][15]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv11*Jinv11)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][16]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv11*Jinv11)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[13][17]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv11*Jinv11)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][18]=((4375.0/20736.0)*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv11*Jinv11)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[13][19]=((115625.0/96768.0)*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv11*Jinv11)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[13][20]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[14][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[14][1]=((3125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv11*Jinv11)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][2]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv11*Jinv11)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][3]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[14][4]=((625.0/448.0)*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv11*Jinv11)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[14][5]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[14][6]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[14][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[14][8]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[14][9]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv11*Jinv11)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][10]=(-(625.0/448.0)*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[14][11]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[14][12]=((3125.0/72576.0)*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv11*Jinv11)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[14][13]=((146875.0/145152.0)*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv11*Jinv11)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[14][14]=((89375.0/24192.0)*(Jinv01*Jinv01)+(89375.0/24192.0)*(Jinv11*Jinv11)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[14][15]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[14][16]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][17]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv11*Jinv11)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[14][18]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[14][19]=((59375.0/72576.0)*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv11*Jinv11)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[14][20]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv11*Jinv11)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00)*D;
  A[15][0]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv11*Jinv11)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[15][1]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv11*Jinv11)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[15][2]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv11*Jinv11)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[15][3]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[15][4]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[15][5]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[15][6]=((11875.0/6048.0)*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv11*Jinv11)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][7]=((49375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv11*Jinv11)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[15][8]=((11875.0/36288.0)*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv11*Jinv11)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][9]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv11*Jinv11)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[15][10]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[15][11]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][12]=((625.0/145152.0)*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv11*Jinv11)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][13]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv11*Jinv11)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][14]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv11*Jinv11)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[15][15]=((11875.0/2688.0)*(Jinv01*Jinv01)+(11875.0/2688.0)*(Jinv11*Jinv11)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[15][16]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv11*Jinv11)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[15][17]=((625.0/6048.0)*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][18]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv11*Jinv11)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[15][19]=((11875.0/41472.0)*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv11*Jinv11)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[15][20]=((14375.0/24192.0)*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv11*Jinv11)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00)*D;
  A[16][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[16][1]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv11*Jinv11)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[16][2]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[16][3]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[16][4]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[16][5]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[16][6]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv11*Jinv11)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][7]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[16][8]=((34375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[16][9]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[16][10]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][11]=((49375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv11*Jinv11)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][12]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv11*Jinv11)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][13]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv11*Jinv11)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][15]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv11*Jinv11)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[16][16]=((128125.0/18144.0)*(Jinv01*Jinv01)+(128125.0/18144.0)*(Jinv11*Jinv11)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(71875.0/9072.0)*(Jinv00*Jinv00)+(71875.0/9072.0)*(Jinv10*Jinv10))*D;
  A[16][17]=((53125.0/72576.0)*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv11*Jinv11)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[16][18]=((8125.0/16128.0)*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv11*Jinv11)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00)*D;
  A[16][19]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv11*Jinv11)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00)*D;
  A[16][20]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[17][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[17][1]=((38125.0/290304.0)*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[17][2]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[17][3]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv11*Jinv11)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[17][4]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv11*Jinv11)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[17][5]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[17][6]=((8125.0/72576.0)*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv11*Jinv11)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[17][7]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[17][8]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv11*Jinv11)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[17][9]=((146875.0/72576.0)*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv11*Jinv11)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[17][10]=((8125.0/9072.0)*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv11*Jinv11)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[17][11]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv11*Jinv11)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[17][12]=((3125.0/8064.0)*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv11*Jinv11)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[17][13]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv11*Jinv11)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[17][14]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv11*Jinv11)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[17][15]=((625.0/6048.0)*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[17][16]=((53125.0/72576.0)*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv11*Jinv11)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[17][17]=((10625.0/3456.0)*(Jinv01*Jinv01)+(10625.0/3456.0)*(Jinv11*Jinv11)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[17][18]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv11*Jinv11)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[17][19]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[17][20]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv11*Jinv11)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00)*D;
  A[18][0]=((29375.0/145152.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv11*Jinv11)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[18][1]=((14375.0/72576.0)*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[18][2]=((8125.0/72576.0)*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[18][3]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[18][4]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[18][5]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[18][6]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[18][7]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv11*Jinv11)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[18][8]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv11*Jinv11)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00)*D;
  A[18][9]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv11*Jinv11)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[18][10]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[18][11]=((11875.0/6048.0)*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv11*Jinv11)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[18][12]=((14375.0/290304.0)*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv11*Jinv11)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[18][13]=((4375.0/20736.0)*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv11*Jinv11)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[18][14]=((6875.0/96768.0)*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv11*Jinv11)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[18][15]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv11*Jinv11)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[18][16]=((8125.0/16128.0)*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv11*Jinv11)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00)*D;
  A[18][17]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv11*Jinv11)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[18][18]=((6875.0/3456.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[18][19]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[18][20]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv11*Jinv11)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00)*D;
  A[19][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[19][1]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*(Jinv11*Jinv11)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[19][2]=((38125.0/290304.0)*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv11*Jinv11)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[19][3]=((3125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv11*Jinv11)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00)*D;
  A[19][4]=((49375.0/145152.0)*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv11*Jinv11)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[19][5]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[19][6]=((14375.0/72576.0)*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv11*Jinv11)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[19][7]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv11*Jinv11)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[19][8]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv11*Jinv11)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00)*D;
  A[19][9]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv11*Jinv11)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00)*D;
  A[19][10]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv11*Jinv11)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[19][11]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv11*Jinv11)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[19][12]=((3125.0/2304.0)*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv11*Jinv11)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[19][13]=((115625.0/96768.0)*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv11*Jinv11)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00)*D;
  A[19][14]=((59375.0/72576.0)*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv11*Jinv11)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[19][15]=((11875.0/41472.0)*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv11*Jinv11)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[19][16]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv11*Jinv11)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00)*D;
  A[19][17]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[19][18]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[19][19]=((6875.0/3456.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[19][20]=((725.0/3584.0)*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv11*Jinv11)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00)*D;
  A[20][0]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*(Jinv11*Jinv11)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[20][1]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[20][2]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[20][3]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[20][4]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[20][5]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[20][6]=((29375.0/145152.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv11*Jinv11)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00)*D;
  A[20][7]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[20][8]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[20][9]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[20][10]=((1975.0/48384.0)*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv11*Jinv11)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00)*D;
  A[20][11]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv11*Jinv11)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00)*D;
  A[20][12]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[20][13]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[20][14]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv11*Jinv11)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00)*D;
  A[20][15]=((14375.0/24192.0)*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv11*Jinv11)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00)*D;
  A[20][16]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[20][17]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv11*Jinv11)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00)*D;
  A[20][18]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv11*Jinv11)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00)*D;
  A[20][19]=((725.0/3584.0)*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv11*Jinv11)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00)*D;
  A[20][20]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/48384.0)*(Jinv11*Jinv11))*D;
  int nbf = 21;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 1 ---------------*/


 
using namespace std; 
  
void matrix_factory_stiffness_2D_with_M_order1 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[3];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00+x0;  dof1[1]=G10+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G01+x0;  dof2[1]=y0+G11;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[3][3];
  A[0][0]=(Jinv00*M01*Jinv10/2.0+M10*Jinv11*Jinv01/2.0+Jinv00*M10*Jinv11/2.0+M01*Jinv10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+Jinv00*M00*Jinv01+Jinv11*Jinv10*M11+(Jinv00*Jinv00)*M00/2.0+M01*Jinv11*Jinv01/2.0+M00*(Jinv01*Jinv01)/2.0+(Jinv10*Jinv10)*M11/2.0+Jinv00*M10*Jinv10/2.0+M10*Jinv10*Jinv01/2.0+Jinv00*M01*Jinv11/2.0)*D;
  A[0][1]=(-Jinv00*M01*Jinv10/2.0-Jinv00*M00*Jinv01/2.0-Jinv11*Jinv10*M11/2.0-(Jinv00*Jinv00)*M00/2.0-(Jinv10*Jinv10)*M11/2.0-Jinv00*M10*Jinv10/2.0-M10*Jinv10*Jinv01/2.0-Jinv00*M01*Jinv11/2.0)*D;
  A[0][2]=(-M10*Jinv11*Jinv01/2.0-Jinv00*M10*Jinv11/2.0-M01*Jinv10*Jinv01/2.0-(Jinv11*Jinv11)*M11/2.0-Jinv00*M00*Jinv01/2.0-Jinv11*Jinv10*M11/2.0-M01*Jinv11*Jinv01/2.0-M00*(Jinv01*Jinv01)/2.0)*D;
  A[1][0]=(-Jinv00*M01*Jinv10/2.0-Jinv00*M10*Jinv11/2.0-M01*Jinv10*Jinv01/2.0-Jinv00*M00*Jinv01/2.0-Jinv11*Jinv10*M11/2.0-(Jinv00*Jinv00)*M00/2.0-(Jinv10*Jinv10)*M11/2.0-Jinv00*M10*Jinv10/2.0)*D;
  A[1][1]=(Jinv00*M01*Jinv10/2.0+(Jinv00*Jinv00)*M00/2.0+(Jinv10*Jinv10)*M11/2.0+Jinv00*M10*Jinv10/2.0)*D;
  A[1][2]=(Jinv00*M10*Jinv11/2.0+M01*Jinv10*Jinv01/2.0+Jinv00*M00*Jinv01/2.0+Jinv11*Jinv10*M11/2.0)*D;
  A[2][0]=(-M10*Jinv11*Jinv01/2.0-(Jinv11*Jinv11)*M11/2.0-Jinv00*M00*Jinv01/2.0-Jinv11*Jinv10*M11/2.0-M01*Jinv11*Jinv01/2.0-M00*(Jinv01*Jinv01)/2.0-M10*Jinv10*Jinv01/2.0-Jinv00*M01*Jinv11/2.0)*D;
  A[2][1]=(Jinv00*M00*Jinv01/2.0+Jinv11*Jinv10*M11/2.0+M10*Jinv10*Jinv01/2.0+Jinv00*M01*Jinv11/2.0)*D;
  A[2][2]=(M10*Jinv11*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+M01*Jinv11*Jinv01/2.0+M00*(Jinv01*Jinv01)/2.0)*D;
  int nbf = 3;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 2 ---------------*/


 
using namespace std; 
  
void matrix_factory_stiffness_2D_with_M_order2 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[6];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/2.0+x0;  dof1[1]=G10/2.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G00+x0;  dof2[1]=G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=G01/2.0+x0;  dof3[1]=y0+G11/2.0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G01/2.0+G00/2.0+x0;  dof4[1]=G10/2.0+y0+G11/2.0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01+x0;  dof5[1]=y0+G11;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[6][6];
  A[0][0]=(M10*Jinv11*Jinv01/2.0+M10*Jinv10*Jinv00/2.0+M01*Jinv10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+Jinv11*Jinv10*M11+M00*(Jinv00*Jinv00)/2.0+M00*Jinv01*Jinv00+M01*Jinv11*Jinv00/2.0+M01*Jinv11*Jinv01/2.0+M00*(Jinv01*Jinv01)/2.0+(Jinv10*Jinv10)*M11/2.0+M01*Jinv10*Jinv00/2.0+M10*Jinv10*Jinv01/2.0+M10*Jinv11*Jinv00/2.0)*D;
  A[0][1]=(-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*(Jinv00*Jinv00)-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[0][2]=(M10*Jinv10*Jinv00/6.0+Jinv11*Jinv10*M11/6.0+M00*(Jinv00*Jinv00)/6.0+M00*Jinv01*Jinv00/6.0+M01*Jinv11*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+M01*Jinv10*Jinv00/6.0+M10*Jinv10*Jinv01/6.0)*D;
  A[0][3]=(-(2.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*M01*Jinv10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv01-(2.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[0][4]=(0.0)*D;
  A[0][5]=(M10*Jinv11*Jinv01/6.0+M01*Jinv10*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+Jinv11*Jinv10*M11/6.0+M00*Jinv01*Jinv00/6.0+M01*Jinv11*Jinv01/6.0+M00*(Jinv01*Jinv01)/6.0+M10*Jinv11*Jinv00/6.0)*D;
  A[1][0]=(-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*M01*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*(Jinv00*Jinv00)-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[1][1]=((4.0/3.0)*M10*Jinv11*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(2.0/3.0)*M01*Jinv10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*M00*(Jinv00*Jinv00)+(4.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(4.0/3.0)*M01*Jinv11*Jinv01+(4.0/3.0)*M00*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv10*Jinv10)*M11+(4.0/3.0)*M01*Jinv10*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[1][2]=(-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*(Jinv00*Jinv00)-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[1][3]=((2.0/3.0)*M01*Jinv10*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[1][4]=(-(4.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*M01*Jinv10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(4.0/3.0)*M01*Jinv11*Jinv01-(4.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[1][5]=(0.0)*D;
  A[2][0]=(M10*Jinv10*Jinv00/6.0+M01*Jinv10*Jinv01/6.0+Jinv11*Jinv10*M11/6.0+M00*(Jinv00*Jinv00)/6.0+M00*Jinv01*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+M01*Jinv10*Jinv00/6.0+M10*Jinv11*Jinv00/6.0)*D;
  A[2][1]=(-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*M01*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*(Jinv00*Jinv00)-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[2][2]=(M10*Jinv10*Jinv00/2.0+M00*(Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)*M11/2.0+M01*Jinv10*Jinv00/2.0)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=((2.0/3.0)*M01*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[2][5]=(-M01*Jinv10*Jinv01/6.0-Jinv11*Jinv10*M11/6.0-M00*Jinv01*Jinv00/6.0-M10*Jinv11*Jinv00/6.0)*D;
  A[3][0]=(-(2.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv01-(2.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[3][1]=((2.0/3.0)*M01*Jinv10*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((4.0/3.0)*M10*Jinv11*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(2.0/3.0)*M01*Jinv10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*M00*(Jinv00*Jinv00)+(4.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(4.0/3.0)*M01*Jinv11*Jinv01+(4.0/3.0)*M00*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv10*Jinv10)*M11+(4.0/3.0)*M01*Jinv10*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[3][4]=(-(4.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*M01*Jinv10*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*M00*(Jinv00*Jinv00)-(4.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(4.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[3][5]=(-(2.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*M01*Jinv10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv01-(2.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[4][0]=(0.0)*D;
  A[4][1]=(-(4.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*M01*Jinv10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(4.0/3.0)*M01*Jinv11*Jinv01-(4.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[4][2]=((2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[4][3]=(-(4.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*M01*Jinv10*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*M00*(Jinv00*Jinv00)-(4.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(4.0/3.0)*M01*Jinv10*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[4][4]=((4.0/3.0)*M10*Jinv11*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(2.0/3.0)*M01*Jinv10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*M00*(Jinv00*Jinv00)+(4.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(4.0/3.0)*M01*Jinv11*Jinv01+(4.0/3.0)*M00*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv10*Jinv10)*M11+(4.0/3.0)*M01*Jinv10*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[4][5]=((2.0/3.0)*M01*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M10*Jinv11*Jinv00)*D;
  A[5][0]=(M10*Jinv11*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+Jinv11*Jinv10*M11/6.0+M00*Jinv01*Jinv00/6.0+M01*Jinv11*Jinv00/6.0+M01*Jinv11*Jinv01/6.0+M00*(Jinv01*Jinv01)/6.0+M10*Jinv10*Jinv01/6.0)*D;
  A[5][1]=(0.0)*D;
  A[5][2]=(-Jinv11*Jinv10*M11/6.0-M00*Jinv01*Jinv00/6.0-M01*Jinv11*Jinv00/6.0-M10*Jinv10*Jinv01/6.0)*D;
  A[5][3]=(-(2.0/3.0)*M10*Jinv11*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*M00*Jinv01*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv00-(2.0/3.0)*M01*Jinv11*Jinv01-(2.0/3.0)*M00*(Jinv01*Jinv01)-(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[5][4]=((2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*M00*Jinv01*Jinv00+(2.0/3.0)*M01*Jinv11*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01)*D;
  A[5][5]=(M10*Jinv11*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+M01*Jinv11*Jinv01/2.0+M00*(Jinv01*Jinv01)/2.0)*D;
  int nbf = 6;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 3 ---------------*/


 
using namespace std; 
  
void matrix_factory_stiffness_2D_with_M_order3 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[10];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/3.0+x0;  dof1[1]=G10/3.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=(2.0/3.0)*G00+x0;  dof2[1]=(2.0/3.0)*G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=G00+x0;  dof3[1]=G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G01/3.0+x0;  dof4[1]=y0+G11/3.0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01/3.0+G00/3.0+x0;  dof5[1]=G10/3.0+y0+G11/3.0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/3.0+(2.0/3.0)*G00+x0;  dof6[1]=(2.0/3.0)*G10+y0+G11/3.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=(2.0/3.0)*G01+x0;  dof7[1]=y0+(2.0/3.0)*G11;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=(2.0/3.0)*G01+G00/3.0+x0;  dof8[1]=G10/3.0+y0+(2.0/3.0)*G11;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01+x0;  dof9[1]=y0+G11;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[10][10];
  A[0][0]=((17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/20.0)*Jinv01*Jinv00*M00+(17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*M01*Jinv00*Jinv11+(17.0/40.0)*Jinv10*M10*Jinv00+(17.0/40.0)*Jinv01*M10*Jinv11+(17.0/20.0)*Jinv10*Jinv11*M11+(17.0/40.0)*Jinv10*M01*Jinv00+(17.0/40.0)*Jinv01*M01*Jinv11+(17.0/40.0)*Jinv10*Jinv01*M10+(17.0/40.0)*(Jinv11*Jinv11)*M11+(17.0/40.0)*M10*Jinv00*Jinv11+(17.0/40.0)*Jinv10*Jinv01*M01+(17.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][1]=(-(27.0/40.0)*(Jinv10*Jinv10)*M11-(51.0/80.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv00*Jinv11-(27.0/40.0)*Jinv10*M10*Jinv00+(3.0/80.0)*Jinv01*M10*Jinv11-(51.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv10*M01*Jinv00+(3.0/80.0)*Jinv01*M01*Jinv11-(27.0/40.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M01-(27.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][2]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/8.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(3.0/80.0)*Jinv01*M10*Jinv11+(3.0/8.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(3.0/80.0)*Jinv01*M01*Jinv11+(27.0/80.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][3]=(-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv01*Jinv00*M00-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*Jinv10*M10*Jinv00-(7.0/80.0)*Jinv10*Jinv11*M11-(7.0/80.0)*Jinv10*M01*Jinv00-(7.0/80.0)*Jinv10*Jinv01*M10-(7.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][4]=((3.0/80.0)*(Jinv10*Jinv10)*M11-(51.0/80.0)*Jinv01*Jinv00*M00-(27.0/40.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00-(27.0/40.0)*Jinv01*M10*Jinv11-(51.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00-(27.0/40.0)*Jinv01*M01*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M10-(27.0/40.0)*(Jinv11*Jinv11)*M11-(27.0/40.0)*M10*Jinv00*Jinv11-(27.0/40.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/40.0)*Jinv01*Jinv00*M00-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/40.0)*Jinv10*Jinv11*M11-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M10-(3.0/80.0)*(Jinv11*Jinv11)*M11-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M01-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][7]=((3.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/8.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv01*M10*Jinv11+(3.0/8.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00+(27.0/80.0)*Jinv01*M01*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][8]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/40.0)*Jinv01*Jinv00*M00-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/40.0)*Jinv10*Jinv11*M11-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M10-(3.0/80.0)*(Jinv11*Jinv11)*M11-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M01-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[0][9]=(-(7.0/80.0)*Jinv01*Jinv00*M00-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*Jinv01*M10*Jinv11-(7.0/80.0)*Jinv10*Jinv11*M11-(7.0/80.0)*Jinv01*M01*Jinv11-(7.0/80.0)*(Jinv11*Jinv11)*M11-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[1][0]=(-(27.0/40.0)*(Jinv10*Jinv10)*M11-(51.0/80.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv00*Jinv11-(27.0/40.0)*Jinv10*M10*Jinv00+(3.0/80.0)*Jinv01*M10*Jinv11-(51.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv10*M01*Jinv00+(3.0/80.0)*Jinv01*M01*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11-(27.0/40.0)*M10*Jinv00*Jinv11-(27.0/40.0)*Jinv10*Jinv01*M01-(27.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[1][1]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[1][2]=(-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*Jinv01*Jinv00*M00-(27.0/80.0)*(Jinv01*Jinv01)*M00-(189.0/160.0)*M01*Jinv00*Jinv11-(27.0/20.0)*Jinv10*M10*Jinv00-(27.0/80.0)*Jinv01*M10*Jinv11-(27.0/20.0)*Jinv10*Jinv11*M11-(27.0/20.0)*Jinv10*M01*Jinv00-(27.0/80.0)*Jinv01*M01*Jinv11-(189.0/160.0)*Jinv10*Jinv01*M10-(27.0/80.0)*(Jinv11*Jinv11)*M11-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01-(27.0/20.0)*(Jinv00*Jinv00)*M00)*D;
  A[1][3]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv01*Jinv00*M00+(3.0/10.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(3.0/10.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(3.0/10.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[1][4]=((27.0/16.0)*Jinv01*Jinv00*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01)*D;
  A[1][5]=(-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv01*M10*Jinv11-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv01*M01*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/40.0)*(Jinv11*Jinv11)*M11-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[1][6]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[1][7]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[1][8]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[1][9]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[2][0]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/8.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(3.0/80.0)*Jinv01*M10*Jinv11+(3.0/8.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(3.0/80.0)*Jinv01*M01*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[2][1]=(-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*Jinv01*Jinv00*M00-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/20.0)*Jinv10*M10*Jinv00-(27.0/80.0)*Jinv01*M10*Jinv11-(27.0/20.0)*Jinv10*Jinv11*M11-(27.0/20.0)*Jinv10*M01*Jinv00-(27.0/80.0)*Jinv01*M01*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/80.0)*(Jinv11*Jinv11)*M11-(189.0/160.0)*M10*Jinv00*Jinv11-(189.0/160.0)*Jinv10*Jinv01*M01-(27.0/20.0)*(Jinv00*Jinv00)*M00)*D;
  A[2][2]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[2][3]=(-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv01*Jinv00*M00-(57.0/80.0)*M01*Jinv00*Jinv11-(27.0/40.0)*Jinv10*M10*Jinv00-(57.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv10*M01*Jinv00-(57.0/80.0)*Jinv10*Jinv01*M10-(27.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[2][4]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[2][5]=((81.0/40.0)*Jinv01*Jinv00*M00+(81.0/80.0)*M01*Jinv00*Jinv11+(81.0/40.0)*Jinv10*Jinv11*M11+(81.0/80.0)*Jinv10*Jinv01*M10+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[2][6]=(-(27.0/16.0)*Jinv01*Jinv00*M00-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/16.0)*Jinv01*M10*Jinv11-(27.0/16.0)*Jinv10*Jinv11*M11-(27.0/16.0)*Jinv01*M01*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M10-(27.0/16.0)*(Jinv11*Jinv11)*M11-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M01)*D;
  A[2][7]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[2][8]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[2][9]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[3][0]=(-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv01*Jinv00*M00-(7.0/80.0)*Jinv10*M10*Jinv00-(7.0/80.0)*Jinv10*Jinv11*M11-(7.0/80.0)*Jinv10*M01*Jinv00-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*Jinv10*Jinv01*M01-(7.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][1]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv01*Jinv00*M00+(27.0/80.0)*Jinv10*M10*Jinv00+(3.0/10.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/10.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][2]=(-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv01*Jinv00*M00-(27.0/40.0)*Jinv10*M10*Jinv00-(57.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv10*M01*Jinv00-(57.0/80.0)*M10*Jinv00*Jinv11-(57.0/80.0)*Jinv10*Jinv01*M01-(27.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][3]=((17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/40.0)*Jinv10*M10*Jinv00+(17.0/40.0)*Jinv10*M01*Jinv00+(17.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][4]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][5]=(0.0)*D;
  A[3][6]=((3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv01*Jinv00*M00+(3.0/80.0)*Jinv10*M10*Jinv00+(57.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00+(57.0/80.0)*M10*Jinv00*Jinv11+(57.0/80.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][7]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][8]=((3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv01*Jinv00*M00+(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/10.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/10.0)*M10*Jinv00*Jinv11-(3.0/10.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[3][9]=((7.0/80.0)*Jinv01*Jinv00*M00+(7.0/80.0)*Jinv10*Jinv11*M11+(7.0/80.0)*M10*Jinv00*Jinv11+(7.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[4][0]=((3.0/80.0)*(Jinv10*Jinv10)*M11-(51.0/80.0)*Jinv01*Jinv00*M00-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00-(27.0/40.0)*Jinv01*M10*Jinv11-(51.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00-(27.0/40.0)*Jinv01*M01*Jinv11-(27.0/40.0)*Jinv10*Jinv01*M10-(27.0/40.0)*(Jinv11*Jinv11)*M11+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][1]=((27.0/16.0)*Jinv01*Jinv00*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01)*D;
  A[4][2]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[4][3]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][4]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][5]=(-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv10*M10*Jinv00-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv10*M01*Jinv00-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01-(81.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][6]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][7]=(-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*Jinv01*Jinv00*M00-(27.0/20.0)*(Jinv01*Jinv01)*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*M10*Jinv00-(27.0/20.0)*Jinv01*M10*Jinv11-(27.0/20.0)*Jinv10*Jinv11*M11-(27.0/80.0)*Jinv10*M01*Jinv00-(27.0/20.0)*Jinv01*M01*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/20.0)*(Jinv11*Jinv11)*M11-(189.0/160.0)*M10*Jinv00*Jinv11-(189.0/160.0)*Jinv10*Jinv01*M01-(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][8]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[4][9]=((3.0/10.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*Jinv01*M10*Jinv11+(3.0/10.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/80.0)*(Jinv11*Jinv11)*M11+(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/10.0)*Jinv10*Jinv01*M01)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv01*M10*Jinv11-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv01*M01*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/40.0)*(Jinv11*Jinv11)*M11-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[5][2]=((81.0/40.0)*Jinv01*Jinv00*M00+(81.0/80.0)*M01*Jinv00*Jinv11+(81.0/40.0)*Jinv10*Jinv11*M11+(81.0/80.0)*Jinv10*Jinv01*M10+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[5][3]=(0.0)*D;
  A[5][4]=(-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv10*M10*Jinv00-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv10*M01*Jinv00-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01-(81.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[5][5]=((81.0/20.0)*(Jinv10*Jinv10)*M11+(81.0/20.0)*Jinv01*Jinv00*M00+(81.0/20.0)*(Jinv01*Jinv01)*M00+(81.0/40.0)*M01*Jinv00*Jinv11+(81.0/20.0)*Jinv10*M10*Jinv00+(81.0/20.0)*Jinv01*M10*Jinv11+(81.0/20.0)*Jinv10*Jinv11*M11+(81.0/20.0)*Jinv10*M01*Jinv00+(81.0/20.0)*Jinv01*M01*Jinv11+(81.0/40.0)*Jinv10*Jinv01*M10+(81.0/20.0)*(Jinv11*Jinv11)*M11+(81.0/40.0)*M10*Jinv00*Jinv11+(81.0/40.0)*Jinv10*Jinv01*M01+(81.0/20.0)*(Jinv00*Jinv00)*M00)*D;
  A[5][6]=(-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv10*M10*Jinv00-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv10*M01*Jinv00-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01-(81.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[5][7]=((81.0/40.0)*Jinv01*Jinv00*M00+(81.0/80.0)*M01*Jinv00*Jinv11+(81.0/40.0)*Jinv10*Jinv11*M11+(81.0/80.0)*Jinv10*Jinv01*M10+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[5][8]=(-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv01*M10*Jinv11-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv01*M01*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/40.0)*(Jinv11*Jinv11)*M11-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[5][9]=(0.0)*D;
  A[6][0]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/40.0)*Jinv01*Jinv00*M00-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/40.0)*Jinv10*Jinv11*M11-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M10-(3.0/80.0)*(Jinv11*Jinv11)*M11-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M01-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][1]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[6][2]=(-(27.0/16.0)*Jinv01*Jinv00*M00-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/16.0)*Jinv01*M10*Jinv11-(27.0/16.0)*Jinv10*Jinv11*M11-(27.0/16.0)*Jinv01*M01*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M10-(27.0/16.0)*(Jinv11*Jinv11)*M11-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M01)*D;
  A[6][3]=((3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv01*Jinv00*M00+(57.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00+(57.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00+(57.0/80.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][4]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][5]=(-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv10*M10*Jinv00-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv10*M01*Jinv00-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01-(81.0/40.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][6]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][7]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][8]=(-(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/40.0)*Jinv01*Jinv00*M00-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*M10*Jinv00-(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/40.0)*Jinv10*Jinv11*M11-(27.0/80.0)*Jinv10*M01*Jinv00-(27.0/80.0)*Jinv01*M01*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01-(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[6][9]=(-(3.0/10.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/10.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv01*M01*Jinv11+(3.0/80.0)*(Jinv11*Jinv11)*M11-(3.0/10.0)*M10*Jinv00*Jinv11-(3.0/10.0)*Jinv10*Jinv01*M01)*D;
  A[7][0]=((3.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/8.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv01*M10*Jinv11+(3.0/8.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/80.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*Jinv10*Jinv01*M01+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][1]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[7][2]=(-(27.0/80.0)*Jinv01*Jinv00*M00-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*Jinv11*M11-(27.0/160.0)*Jinv10*Jinv01*M10-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[7][3]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][4]=(-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*Jinv01*Jinv00*M00-(27.0/20.0)*(Jinv01*Jinv01)*M00-(189.0/160.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*M10*Jinv00-(27.0/20.0)*Jinv01*M10*Jinv11-(27.0/20.0)*Jinv10*Jinv11*M11-(27.0/80.0)*Jinv10*M01*Jinv00-(27.0/20.0)*Jinv01*M01*Jinv11-(189.0/160.0)*Jinv10*Jinv01*M10-(27.0/20.0)*(Jinv11*Jinv11)*M11-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01-(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][5]=((81.0/40.0)*Jinv01*Jinv00*M00+(81.0/80.0)*M01*Jinv00*Jinv11+(81.0/40.0)*Jinv10*Jinv11*M11+(81.0/80.0)*Jinv10*Jinv01*M10+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[7][6]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][7]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][8]=(-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv01*Jinv00*M00-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/16.0)*Jinv10*M10*Jinv00-(27.0/16.0)*Jinv10*Jinv11*M11-(27.0/16.0)*Jinv10*M01*Jinv00-(27.0/32.0)*Jinv10*Jinv01*M10-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M01-(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[7][9]=(-(57.0/80.0)*Jinv01*Jinv00*M00-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*Jinv01*M10*Jinv11-(57.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv01*M01*Jinv11-(27.0/40.0)*(Jinv11*Jinv11)*M11-(57.0/80.0)*M10*Jinv00*Jinv11-(57.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[8][0]=(-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/40.0)*Jinv01*Jinv00*M00-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/40.0)*Jinv10*Jinv11*M11-(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M10-(3.0/80.0)*(Jinv11*Jinv11)*M11-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*Jinv10*Jinv01*M01-(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][1]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[8][2]=((27.0/80.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01)*D;
  A[8][3]=((3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv01*Jinv00*M00-(3.0/10.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv10*M10*Jinv00-(3.0/10.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv10*M01*Jinv00-(3.0/10.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][4]=((27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv01*Jinv00*M00+(27.0/160.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv10*M10*Jinv00+(27.0/80.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv10*M01*Jinv00+(27.0/160.0)*Jinv10*Jinv01*M10+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/160.0)*Jinv10*Jinv01*M01+(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][5]=(-(81.0/40.0)*Jinv01*Jinv00*M00-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/40.0)*Jinv01*M10*Jinv11-(81.0/40.0)*Jinv10*Jinv11*M11-(81.0/40.0)*Jinv01*M01*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M10-(81.0/40.0)*(Jinv11*Jinv11)*M11-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[8][6]=(-(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/40.0)*Jinv01*Jinv00*M00-(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/80.0)*Jinv10*M10*Jinv00-(27.0/80.0)*Jinv01*M10*Jinv11+(27.0/40.0)*Jinv10*Jinv11*M11-(27.0/80.0)*Jinv10*M01*Jinv00-(27.0/80.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10-(27.0/80.0)*(Jinv11*Jinv11)*M11-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*Jinv10*Jinv01*M01-(27.0/80.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][7]=(-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv01*Jinv00*M00-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/16.0)*Jinv10*M10*Jinv00-(27.0/16.0)*Jinv10*Jinv11*M11-(27.0/16.0)*Jinv10*M01*Jinv00-(27.0/32.0)*Jinv10*Jinv01*M10-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/32.0)*Jinv10*Jinv01*M01-(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][8]=((27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*Jinv01*Jinv00*M00+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/32.0)*M01*Jinv00*Jinv11+(27.0/16.0)*Jinv10*M10*Jinv00+(27.0/16.0)*Jinv01*M10*Jinv11+(27.0/16.0)*Jinv10*Jinv11*M11+(27.0/16.0)*Jinv10*M01*Jinv00+(27.0/16.0)*Jinv01*M01*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M10+(27.0/16.0)*(Jinv11*Jinv11)*M11+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*Jinv10*Jinv01*M01+(27.0/16.0)*(Jinv00*Jinv00)*M00)*D;
  A[8][9]=((57.0/80.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*Jinv01*M10*Jinv11+(57.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv01*M01*Jinv11+(3.0/80.0)*(Jinv11*Jinv11)*M11+(57.0/80.0)*M10*Jinv00*Jinv11+(57.0/80.0)*Jinv10*Jinv01*M01)*D;
  A[9][0]=(-(7.0/80.0)*Jinv01*Jinv00*M00-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*Jinv01*M10*Jinv11-(7.0/80.0)*Jinv10*Jinv11*M11-(7.0/80.0)*Jinv01*M01*Jinv11-(7.0/80.0)*Jinv10*Jinv01*M10-(7.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][1]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][2]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][3]=((7.0/80.0)*Jinv01*Jinv00*M00+(7.0/80.0)*M01*Jinv00*Jinv11+(7.0/80.0)*Jinv10*Jinv11*M11+(7.0/80.0)*Jinv10*Jinv01*M10)*D;
  A[9][4]=((3.0/10.0)*Jinv01*Jinv00*M00+(27.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/10.0)*M01*Jinv00*Jinv11+(27.0/80.0)*Jinv01*M10*Jinv11+(3.0/10.0)*Jinv10*Jinv11*M11+(27.0/80.0)*Jinv01*M01*Jinv11+(3.0/10.0)*Jinv10*Jinv01*M10+(27.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][5]=(0.0)*D;
  A[9][6]=(-(3.0/10.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/10.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv01*M10*Jinv11-(3.0/10.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv01*M01*Jinv11-(3.0/10.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][7]=(-(57.0/80.0)*Jinv01*Jinv00*M00-(27.0/40.0)*(Jinv01*Jinv01)*M00-(57.0/80.0)*M01*Jinv00*Jinv11-(27.0/40.0)*Jinv01*M10*Jinv11-(57.0/80.0)*Jinv10*Jinv11*M11-(27.0/40.0)*Jinv01*M01*Jinv11-(57.0/80.0)*Jinv10*Jinv01*M10-(27.0/40.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][8]=((57.0/80.0)*Jinv01*Jinv00*M00+(3.0/80.0)*(Jinv01*Jinv01)*M00+(57.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*Jinv01*M10*Jinv11+(57.0/80.0)*Jinv10*Jinv11*M11+(3.0/80.0)*Jinv01*M01*Jinv11+(57.0/80.0)*Jinv10*Jinv01*M10+(3.0/80.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][9]=((17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*Jinv01*M10*Jinv11+(17.0/40.0)*Jinv01*M01*Jinv11+(17.0/40.0)*(Jinv11*Jinv11)*M11)*D;
  int nbf = 10;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 4 ---------------*/


 
using namespace std; 
  
void matrix_factory_stiffness_2D_with_M_order4 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[15];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/4.0+x0;  dof1[1]=G10/4.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=G00/2.0+x0;  dof2[1]=G10/2.0+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=(3.0/4.0)*G00+x0;  dof3[1]=(3.0/4.0)*G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=G00+x0;  dof4[1]=G10+y0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G01/4.0+x0;  dof5[1]=y0+G11/4.0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/4.0+G00/4.0+x0;  dof6[1]=G10/4.0+y0+G11/4.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=G01/4.0+G00/2.0+x0;  dof7[1]=G10/2.0+y0+G11/4.0;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=G01/4.0+(3.0/4.0)*G00+x0;  dof8[1]=(3.0/4.0)*G10+y0+G11/4.0;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01/2.0+x0;  dof9[1]=y0+G11/2.0;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

  double dof10[2];
  dof10[0]=G01/2.0+G00/4.0+x0;  dof10[1]=G10/4.0+y0+G11/2.0;
  ptv pdof10(2,dof10);
  iidof[10] = dof.insert_dof(element,10,pdof10);

  double dof11[2];
  dof11[0]=G01/2.0+G00/2.0+x0;  dof11[1]=G10/2.0+y0+G11/2.0;
  ptv pdof11(2,dof11);
  iidof[11] = dof.insert_dof(element,11,pdof11);

  double dof12[2];
  dof12[0]=(3.0/4.0)*G01+x0;  dof12[1]=y0+(3.0/4.0)*G11;
  ptv pdof12(2,dof12);
  iidof[12] = dof.insert_dof(element,12,pdof12);

  double dof13[2];
  dof13[0]=(3.0/4.0)*G01+G00/4.0+x0;  dof13[1]=G10/4.0+y0+(3.0/4.0)*G11;
  ptv pdof13(2,dof13);
  iidof[13] = dof.insert_dof(element,13,pdof13);

  double dof14[2];
  dof14[0]=G01+x0;  dof14[1]=y0+G11;
  ptv pdof14(2,dof14);
  iidof[14] = dof.insert_dof(element,14,pdof14);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[15][15];
  A[0][0]=((47.0/63.0)*Jinv00*M00*Jinv01+(47.0/126.0)*M10*Jinv11*Jinv01+(47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*M01*Jinv10*Jinv01+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*Jinv00*M10*Jinv11+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/63.0)*Jinv11*Jinv10*M11+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv10*Jinv10)*M11+(47.0/126.0)*Jinv00*M01*Jinv11+(47.0/126.0)*M01*Jinv11*Jinv01+(47.0/126.0)*Jinv00*M10*Jinv10+(47.0/126.0)*M10*Jinv10*Jinv01)*D;
  A[0][1]=(-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M10*Jinv11*Jinv01-(88.0/135.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*M01*Jinv10*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M10*Jinv11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[0][2]=((482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(442.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[0][3]=(-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv11*Jinv01-(232.0/945.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*M01*Jinv10*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[0][4]=((107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11+(107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*Jinv00*M10*Jinv10+(107.0/1890.0)*M10*Jinv10*Jinv01)*D;
  A[0][5]=(-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M10*Jinv11*Jinv01+(8.0/63.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*M01*Jinv10*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M10*Jinv11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[0][6]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][7]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][8]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][9]=((482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*M01*Jinv10*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][10]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][11]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][12]=(-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M10*Jinv11*Jinv01-(8.0/189.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*M01*Jinv10*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][13]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[0][14]=((107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*M01*Jinv10*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*M01*Jinv11*Jinv01)*D;
  A[1][0]=(-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M10*Jinv11*Jinv01-(88.0/135.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*M01*Jinv10*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M10*Jinv11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[1][1]=((1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*M10*Jinv11*Jinv01+(64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*M01*Jinv10*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[1][2]=(-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*M10*Jinv11*Jinv01-(368.0/189.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[1][3]=((64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*M01*Jinv10*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[1][4]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/315.0)*Jinv00*M01*Jinv11-(232.0/945.0)*Jinv00*M10*Jinv10-(64.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[1][5]=((64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/35.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01)*D;
  A[1][6]=(-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*M01*Jinv10*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[1][7]=((128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[1][8]=(-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*M01*Jinv10*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[1][9]=(-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[1][10]=((128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[1][11]=(-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*M01*Jinv10*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[1][12]=((64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01+(32.0/315.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[1][13]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*M01*Jinv10*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[1][14]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[2][0]=((482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(442.0/945.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[2][1]=(-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*M10*Jinv11*Jinv01-(368.0/189.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*M01*Jinv10*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[2][2]=((932.0/315.0)*Jinv00*M00*Jinv01+(772.0/315.0)*M10*Jinv11*Jinv01+(932.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*M01*Jinv10*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(932.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M00*(Jinv01*Jinv01)+(932.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M01*Jinv11*Jinv01+(932.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][3]=(-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*M10*Jinv11*Jinv01-(368.0/189.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*M01*Jinv10*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[2][4]=((134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11+(134.0/315.0)*Jinv00*M01*Jinv11+(442.0/945.0)*Jinv00*M10*Jinv10+(134.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][5]=(-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[2][6]=((992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11+(496.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][7]=(-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*M01*Jinv10*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[2][8]=((176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*M10*Jinv11*Jinv01+(32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*M01*Jinv10*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[2][9]=(-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*M10*Jinv11*Jinv01+(16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*M01*Jinv10*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)*M11-(46.0/315.0)*Jinv00*M10*Jinv11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][10]=(-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][11]=((124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*M10*Jinv11*Jinv01+(16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*M01*Jinv10*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[2][12]=((16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[2][13]=(-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*M10*Jinv11*Jinv01-(8.0/189.0)*M01*Jinv10*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[2][14]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[3][0]=(-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv11*Jinv01-(232.0/945.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*M01*Jinv10*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[3][1]=((64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*M01*Jinv10*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[3][2]=(-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*M10*Jinv11*Jinv01-(368.0/189.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*M01*Jinv10*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[3][3]=((1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*M01*Jinv10*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[3][4]=(-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11-(736.0/945.0)*Jinv00*M01*Jinv11-(88.0/135.0)*Jinv00*M10*Jinv10-(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[3][5]=((64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*M01*Jinv10*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[3][6]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*M01*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[3][7]=((2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*M01*Jinv10*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[3][8]=(-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*M01*Jinv10*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[3][9]=((16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[3][10]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*M01*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[3][11]=((16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*M01*Jinv10*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)*M11+(8.0/27.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[3][12]=((64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M01*Jinv10*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[3][13]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv11*Jinv01-(32.0/315.0)*M01*Jinv10*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[3][14]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[4][0]=((107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*M01*Jinv10*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11+(107.0/1890.0)*Jinv00*M10*Jinv10)*D;
  A[4][1]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/315.0)*M01*Jinv10*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv11-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M10*Jinv10)*D;
  A[4][2]=((134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*(Jinv00*Jinv00)*M00+(134.0/315.0)*M01*Jinv10*Jinv01+(134.0/315.0)*Jinv00*M10*Jinv11+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M10*Jinv10)*D;
  A[4][3]=(-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*(Jinv00*Jinv00)*M00-(736.0/945.0)*M01*Jinv10*Jinv01-(736.0/945.0)*Jinv00*M10*Jinv11-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M10*Jinv10)*D;
  A[4][4]=((47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/126.0)*(Jinv10*Jinv10)*M11+(47.0/126.0)*Jinv00*M10*Jinv10)*D;
  A[4][5]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][6]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][7]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][8]=((736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*M01*Jinv10*Jinv01+(736.0/945.0)*Jinv00*M10*Jinv11+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M10*Jinv10)*D;
  A[4][9]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][10]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][11]=(-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00-(134.0/315.0)*M01*Jinv10*Jinv01-(134.0/315.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][12]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][13]=((64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*(Jinv00*Jinv00)*M00+(64.0/315.0)*M01*Jinv10*Jinv01+(64.0/315.0)*Jinv00*M10*Jinv11-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[4][14]=(-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*M01*Jinv10*Jinv01-(107.0/1890.0)*Jinv00*M10*Jinv11-(107.0/1890.0)*Jinv11*Jinv10*M11)*D;
  A[5][0]=(-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M10*Jinv11*Jinv01+(8.0/63.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*M01*Jinv10*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M10*Jinv11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[5][1]=((64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/35.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01)*D;
  A[5][2]=(-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[5][3]=((64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*M01*Jinv10*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[5][4]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[5][5]=((1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*M10*Jinv11*Jinv01+(64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*M01*Jinv10*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[5][6]=(-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[5][7]=((128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[5][8]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[5][9]=(-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*M10*Jinv11*Jinv01-(208.0/315.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*M01*Jinv10*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[5][10]=((128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[5][11]=(-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[5][12]=((64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/189.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*M01*Jinv10*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[5][13]=(-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[5][14]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M10*Jinv11*Jinv01-(64.0/315.0)*M01*Jinv10*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[6][0]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[6][1]=(-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*M01*Jinv10*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[6][2]=((992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11+(496.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[6][3]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*M01*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[6][4]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[6][5]=(-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[6][6]=((256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*M01*Jinv10*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01)*D;
  A[6][7]=(-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*M01*Jinv10*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[6][8]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*M01*Jinv10*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[6][9]=((992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[6][10]=(-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*M01*Jinv10*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[6][11]=((32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01)*D;
  A[6][12]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[6][13]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(64.0/189.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[6][14]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[7][0]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[7][1]=((128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[7][2]=(-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*M01*Jinv10*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[7][3]=((2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*M01*Jinv10*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[7][4]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[7][5]=((128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[7][6]=(-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*M01*Jinv10*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[7][7]=((256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*M01*Jinv10*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01)*D;
  A[7][8]=(-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*M01*Jinv10*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[7][9]=(-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[7][10]=((256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*M01*Jinv10*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/105.0)*Jinv00*M10*Jinv11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[7][11]=(-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*M01*Jinv10*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)*M11-(368.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[7][12]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[7][13]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(64.0/189.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[7][14]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[8][0]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[8][1]=(-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*M01*Jinv10*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[8][2]=((176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*M10*Jinv11*Jinv01+(32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*M01*Jinv10*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[8][3]=(-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*M10*Jinv11*Jinv01-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*M01*Jinv10*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[8][4]=((736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M01*Jinv11+(8.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[8][5]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[8][6]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*M01*Jinv10*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[8][7]=(-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*M01*Jinv10*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[8][8]=((1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*M01*Jinv10*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[8][9]=(-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*M01*Jinv10*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[8][10]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*M01*Jinv10*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[8][11]=((496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*M10*Jinv11*Jinv01-(208.0/315.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*M01*Jinv10*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)*M11+(776.0/945.0)*Jinv00*M10*Jinv11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[8][12]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[8][13]=(-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/189.0)*(Jinv00*Jinv00)*M00-(416.0/945.0)*M01*Jinv10*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)*M11-(416.0/945.0)*Jinv00*M10*Jinv11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[8][14]=((64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv11*Jinv01+(64.0/315.0)*M01*Jinv10*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[9][0]=((482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[9][1]=(-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[9][2]=(-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*M10*Jinv11*Jinv01+(16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*M01*Jinv10*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)*M11-(46.0/315.0)*Jinv00*M10*Jinv11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[9][3]=((16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[9][4]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[9][5]=(-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*M10*Jinv11*Jinv01-(208.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*M01*Jinv10*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[9][6]=((992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[9][7]=(-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[9][8]=(-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*M01*Jinv10*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[9][9]=((932.0/315.0)*Jinv00*M00*Jinv01+(932.0/315.0)*M10*Jinv11*Jinv01+(772.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*M01*Jinv10*Jinv01+(932.0/315.0)*(Jinv11*Jinv11)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(772.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(932.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M01*Jinv11+(932.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[9][10]=(-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[9][11]=((124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*M01*Jinv10*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[9][12]=(-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*M10*Jinv11*Jinv01-(16.0/21.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*M01*Jinv10*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[9][13]=((176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv11*Jinv01+(16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*M01*Jinv10*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[9][14]=((134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M10*Jinv11*Jinv01+(134.0/315.0)*M01*Jinv10*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv00*M10*Jinv11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[10][0]=(-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*M01*Jinv10*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[10][1]=((128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[10][2]=(-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[10][3]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*M01*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[10][4]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[10][5]=((128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[10][6]=(-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*M01*Jinv10*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01)*D;
  A[10][7]=((256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*M01*Jinv10*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/105.0)*Jinv00*M10*Jinv11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[10][8]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*M01*Jinv10*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[10][9]=(-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv11*Jinv01-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*M01*Jinv10*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01)*D;
  A[10][10]=((256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*M01*Jinv10*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01)*D;
  A[10][11]=(-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[10][12]=((2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(1216.0/945.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[10][13]=(-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*M10*Jinv11*Jinv01-(1216.0/945.0)*M01*Jinv10*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M00*(Jinv01*Jinv01)-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[10][14]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[11][0]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[11][1]=(-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*M01*Jinv10*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[11][2]=((124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*M10*Jinv11*Jinv01+(16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*M01*Jinv10*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[11][3]=((16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*M10*Jinv11*Jinv01-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*M01*Jinv10*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)*M11+(8.0/27.0)*Jinv00*M10*Jinv11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[11][4]=(-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11-(134.0/315.0)*Jinv00*M01*Jinv11+(8.0/189.0)*Jinv00*M10*Jinv10-(134.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[11][5]=(-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[11][6]=((32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01)*D;
  A[11][7]=(-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*M10*Jinv11*Jinv01+(128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*M01*Jinv10*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)*M11-(368.0/315.0)*Jinv00*M10*Jinv11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[11][8]=((496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*M10*Jinv11*Jinv01-(208.0/315.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*M01*Jinv10*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[11][9]=((124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*M01*Jinv10*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[11][10]=(-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*M10*Jinv11*Jinv01-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*M01*Jinv10*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[11][11]=((68.0/35.0)*Jinv00*M00*Jinv01+(772.0/315.0)*M10*Jinv11*Jinv01+(772.0/315.0)*(Jinv00*Jinv00)*M00+(34.0/35.0)*M01*Jinv10*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)*M11+(34.0/35.0)*Jinv00*M10*Jinv11+(772.0/315.0)*Jinv00*M01*Jinv10+(68.0/35.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv10*Jinv10)*M11+(34.0/35.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(34.0/35.0)*M10*Jinv10*Jinv01)*D;
  A[11][12]=((16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[11][13]=((496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*M10*Jinv11*Jinv01-(16.0/21.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*M01*Jinv10*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)*M11+(776.0/945.0)*Jinv00*M10*Jinv11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[11][14]=(-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01-(134.0/315.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv00*M10*Jinv11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[12][0]=(-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M10*Jinv11*Jinv01-(8.0/189.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*M01*Jinv10*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][1]=((64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01+(32.0/315.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[12][2]=((16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[12][3]=((64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M01*Jinv10*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[12][4]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv10)*D;
  A[12][5]=((64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*M01*Jinv10*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][6]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[12][7]=(-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[12][8]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*M01*Jinv10*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[12][9]=(-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*M10*Jinv11*Jinv01-(16.0/21.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*M01*Jinv10*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][10]=((2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*M10*Jinv11*Jinv01+(1216.0/945.0)*M01*Jinv10*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M00*(Jinv01*Jinv01)+(1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][11]=((16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*M01*Jinv10*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01)*D;
  A[12][12]=((1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*M01*Jinv10*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][13]=(-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[12][14]=(-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M10*Jinv11*Jinv01-(736.0/945.0)*M01*Jinv10*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv00*M10*Jinv11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*M01*Jinv11*Jinv01)*D;
  A[13][0]=((16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*M01*Jinv10*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[13][1]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*M01*Jinv10*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[13][2]=(-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*M10*Jinv11*Jinv01-(8.0/189.0)*M01*Jinv10*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[13][3]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv11*Jinv01-(32.0/315.0)*M01*Jinv10*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[13][4]=((64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11+(64.0/315.0)*Jinv00*M01*Jinv11-(8.0/189.0)*Jinv00*M10*Jinv10+(64.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[13][5]=(-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01)*D;
  A[13][6]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(64.0/189.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[13][7]=((128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*M10*Jinv11*Jinv01+(64.0/189.0)*M01*Jinv10*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[13][8]=(-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*M01*Jinv10*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv10*Jinv10)*M11-(416.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10-(416.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[13][9]=((176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv11*Jinv01+(16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*M01*Jinv10*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01)*D;
  A[13][10]=(-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*M10*Jinv11*Jinv01-(1216.0/945.0)*M01*Jinv10*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M00*(Jinv01*Jinv01)-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[13][11]=((496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*M10*Jinv11*Jinv01-(16.0/21.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*M01*Jinv10*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[13][12]=(-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*M01*Jinv10*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[13][13]=((1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*M01*Jinv10*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[13][14]=((736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M10*Jinv11*Jinv01+(736.0/945.0)*M01*Jinv10*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*M01*Jinv11*Jinv01)*D;
  A[14][0]=((107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*M01*Jinv11*Jinv01+(107.0/1890.0)*M10*Jinv10*Jinv01)*D;
  A[14][1]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][2]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][3]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][4]=(-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10*M11-(107.0/1890.0)*Jinv00*M01*Jinv11-(107.0/1890.0)*M10*Jinv10*Jinv01)*D;
  A[14][5]=(-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M10*Jinv11*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M01*Jinv11*Jinv01-(64.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[14][6]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][7]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][8]=((64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv11*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M01*Jinv11*Jinv01+(64.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[14][9]=((134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M10*Jinv11*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M00*(Jinv01*Jinv01)+(134.0/315.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M01*Jinv11*Jinv01+(134.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[14][10]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][11]=(-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M00*(Jinv01*Jinv01)-(134.0/315.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M01*Jinv11*Jinv01-(134.0/315.0)*M10*Jinv10*Jinv01)*D;
  A[14][12]=(-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M10*Jinv11*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M00*(Jinv01*Jinv01)-(736.0/945.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M01*Jinv11*Jinv01-(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[14][13]=((736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M10*Jinv11*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M00*(Jinv01*Jinv01)+(736.0/945.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M01*Jinv11*Jinv01+(736.0/945.0)*M10*Jinv10*Jinv01)*D;
  A[14][14]=((47.0/126.0)*M10*Jinv11*Jinv01+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*M01*Jinv11*Jinv01)*D;
  int nbf = 15;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 5 ---------------*/


 
using namespace std; 
  
void matrix_factory_stiffness_2D_with_M_order5 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[21];
  double dof0[2];
  dof0[0]=x0;  dof0[1]=y0;
  ptv pdof0(2,dof0);
  iidof[0] = dof.insert_dof(element,0,pdof0);

  double dof1[2];
  dof1[0]=G00/5.0+x0;  dof1[1]=G10/5.0+y0;
  ptv pdof1(2,dof1);
  iidof[1] = dof.insert_dof(element,1,pdof1);

  double dof2[2];
  dof2[0]=(2.0/5.0)*G00+x0;  dof2[1]=(2.0/5.0)*G10+y0;
  ptv pdof2(2,dof2);
  iidof[2] = dof.insert_dof(element,2,pdof2);

  double dof3[2];
  dof3[0]=(3.0/5.0)*G00+x0;  dof3[1]=(3.0/5.0)*G10+y0;
  ptv pdof3(2,dof3);
  iidof[3] = dof.insert_dof(element,3,pdof3);

  double dof4[2];
  dof4[0]=(4.0/5.0)*G00+x0;  dof4[1]=(4.0/5.0)*G10+y0;
  ptv pdof4(2,dof4);
  iidof[4] = dof.insert_dof(element,4,pdof4);

  double dof5[2];
  dof5[0]=G00+x0;  dof5[1]=G10+y0;
  ptv pdof5(2,dof5);
  iidof[5] = dof.insert_dof(element,5,pdof5);

  double dof6[2];
  dof6[0]=G01/5.0+x0;  dof6[1]=y0+G11/5.0;
  ptv pdof6(2,dof6);
  iidof[6] = dof.insert_dof(element,6,pdof6);

  double dof7[2];
  dof7[0]=G01/5.0+G00/5.0+x0;  dof7[1]=G10/5.0+y0+G11/5.0;
  ptv pdof7(2,dof7);
  iidof[7] = dof.insert_dof(element,7,pdof7);

  double dof8[2];
  dof8[0]=G01/5.0+(2.0/5.0)*G00+x0;  dof8[1]=(2.0/5.0)*G10+y0+G11/5.0;
  ptv pdof8(2,dof8);
  iidof[8] = dof.insert_dof(element,8,pdof8);

  double dof9[2];
  dof9[0]=G01/5.0+(3.0/5.0)*G00+x0;  dof9[1]=(3.0/5.0)*G10+y0+G11/5.0;
  ptv pdof9(2,dof9);
  iidof[9] = dof.insert_dof(element,9,pdof9);

  double dof10[2];
  dof10[0]=G01/5.0+(4.0/5.0)*G00+x0;  dof10[1]=(4.0/5.0)*G10+y0+G11/5.0;
  ptv pdof10(2,dof10);
  iidof[10] = dof.insert_dof(element,10,pdof10);

  double dof11[2];
  dof11[0]=(2.0/5.0)*G01+x0;  dof11[1]=y0+(2.0/5.0)*G11;
  ptv pdof11(2,dof11);
  iidof[11] = dof.insert_dof(element,11,pdof11);

  double dof12[2];
  dof12[0]=(2.0/5.0)*G01+G00/5.0+x0;  dof12[1]=G10/5.0+y0+(2.0/5.0)*G11;
  ptv pdof12(2,dof12);
  iidof[12] = dof.insert_dof(element,12,pdof12);

  double dof13[2];
  dof13[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  dof13[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  ptv pdof13(2,dof13);
  iidof[13] = dof.insert_dof(element,13,pdof13);

  double dof14[2];
  dof14[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  dof14[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  ptv pdof14(2,dof14);
  iidof[14] = dof.insert_dof(element,14,pdof14);

  double dof15[2];
  dof15[0]=(3.0/5.0)*G01+x0;  dof15[1]=y0+(3.0/5.0)*G11;
  ptv pdof15(2,dof15);
  iidof[15] = dof.insert_dof(element,15,pdof15);

  double dof16[2];
  dof16[0]=(3.0/5.0)*G01+G00/5.0+x0;  dof16[1]=G10/5.0+y0+(3.0/5.0)*G11;
  ptv pdof16(2,dof16);
  iidof[16] = dof.insert_dof(element,16,pdof16);

  double dof17[2];
  dof17[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  dof17[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  ptv pdof17(2,dof17);
  iidof[17] = dof.insert_dof(element,17,pdof17);

  double dof18[2];
  dof18[0]=(4.0/5.0)*G01+x0;  dof18[1]=y0+(4.0/5.0)*G11;
  ptv pdof18(2,dof18);
  iidof[18] = dof.insert_dof(element,18,pdof18);

  double dof19[2];
  dof19[0]=(4.0/5.0)*G01+G00/5.0+x0;  dof19[1]=G10/5.0+y0+(4.0/5.0)*G11;
  ptv pdof19(2,dof19);
  iidof[19] = dof.insert_dof(element,19,pdof19);

  double dof20[2];
  dof20[0]=G01+x0;  dof20[1]=y0+G11;
  ptv pdof20(2,dof20);
  iidof[20] = dof.insert_dof(element,20,pdof20);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[21][21];
  A[0][0]=((16567.0/24192.0)*Jinv00*M00*Jinv01+(16567.0/24192.0)*Jinv11*Jinv10*M11+(16567.0/48384.0)*M10*Jinv11*Jinv01+(16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv00*M10*Jinv11+(16567.0/48384.0)*M01*Jinv10*Jinv01+(16567.0/48384.0)*(Jinv11*Jinv11)*M11+(16567.0/48384.0)*Jinv00*M01*Jinv10+(16567.0/48384.0)*Jinv00*M01*Jinv11+(16567.0/48384.0)*M00*(Jinv01*Jinv01)+(16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*M01*Jinv11*Jinv01+(16567.0/48384.0)*Jinv00*M10*Jinv10+(16567.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[0][1]=(-(16175.0/36288.0)*Jinv00*M00*Jinv01-(16175.0/36288.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*M10*Jinv11*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv00*M10*Jinv11+(725.0/3584.0)*M01*Jinv10*Jinv01+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv00*M01*Jinv10-(26875.0/41472.0)*Jinv00*M01*Jinv11+(725.0/3584.0)*M00*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M01*Jinv11*Jinv01-(26875.0/41472.0)*Jinv00*M10*Jinv10-(26875.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[0][2]=((41975.0/72576.0)*Jinv00*M00*Jinv01+(41975.0/72576.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*M10*Jinv11*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv00*M10*Jinv11-(575.0/36288.0)*M01*Jinv10*Jinv01-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv00*M01*Jinv10+(14375.0/24192.0)*Jinv00*M01*Jinv11-(575.0/36288.0)*M00*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M01*Jinv11*Jinv01+(14375.0/24192.0)*Jinv00*M10*Jinv10+(14375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[0][3]=(-(10775.0/20736.0)*Jinv00*M00*Jinv01-(10775.0/20736.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*M10*Jinv11*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv00*M10*Jinv11-(20225.0/290304.0)*M01*Jinv10*Jinv01-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv00*M01*Jinv10-(130625.0/290304.0)*Jinv00*M01*Jinv11-(20225.0/290304.0)*M00*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M01*Jinv11*Jinv01-(130625.0/290304.0)*Jinv00*M10*Jinv10-(130625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[0][4]=((8825.0/36288.0)*Jinv00*M00*Jinv01+(8825.0/36288.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*M10*Jinv11*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv00*M10*Jinv11+(1975.0/48384.0)*M01*Jinv10*Jinv01+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv00*M01*Jinv10+(29375.0/145152.0)*Jinv00*M01*Jinv11+(1975.0/48384.0)*M00*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M01*Jinv11*Jinv01+(29375.0/145152.0)*Jinv00*M10*Jinv10+(29375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[0][5]=(-(5951.0/145152.0)*Jinv00*M00*Jinv01-(5951.0/145152.0)*Jinv11*Jinv10*M11-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*Jinv00*M01*Jinv10-(5951.0/145152.0)*Jinv00*M01*Jinv11-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv00*M10*Jinv10-(5951.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[0][6]=(-(16175.0/36288.0)*Jinv00*M00*Jinv01-(16175.0/36288.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*M10*Jinv11*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv00*M10*Jinv11-(26875.0/41472.0)*M01*Jinv10*Jinv01-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv00*M01*Jinv10+(725.0/3584.0)*Jinv00*M01*Jinv11-(26875.0/41472.0)*M00*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M01*Jinv11*Jinv01+(725.0/3584.0)*Jinv00*M10*Jinv10+(725.0/3584.0)*M10*Jinv10*Jinv01)*D;
  A[0][7]=(-(15625.0/36288.0)*Jinv00*M00*Jinv01-(15625.0/36288.0)*Jinv11*Jinv10*M11-(15625.0/72576.0)*M10*Jinv11*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv00*M10*Jinv11-(15625.0/72576.0)*M01*Jinv10*Jinv01-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv00*M01*Jinv10-(15625.0/72576.0)*Jinv00*M01*Jinv11-(15625.0/72576.0)*M00*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M01*Jinv11*Jinv01-(15625.0/72576.0)*Jinv00*M10*Jinv10-(15625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[0][8]=(-(15625.0/145152.0)*Jinv00*M00*Jinv01-(15625.0/145152.0)*Jinv11*Jinv10*M11-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M10*Jinv11-(15625.0/290304.0)*M01*Jinv10*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*Jinv00*M01*Jinv11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M01*Jinv11*Jinv01-(15625.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[0][9]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[0][10]=(-(1975.0/24192.0)*Jinv00*M00*Jinv01-(1975.0/24192.0)*Jinv11*Jinv10*M11-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M10*Jinv11-(1975.0/48384.0)*M01*Jinv10*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*Jinv00*M01*Jinv11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M01*Jinv11*Jinv01-(1975.0/48384.0)*Jinv00*M10*Jinv10-(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[0][11]=((41975.0/72576.0)*Jinv00*M00*Jinv01+(41975.0/72576.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*M10*Jinv11*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv00*M10*Jinv11+(14375.0/24192.0)*M01*Jinv10*Jinv01+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv00*M01*Jinv10-(575.0/36288.0)*Jinv00*M01*Jinv11+(14375.0/24192.0)*M00*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M01*Jinv11*Jinv01-(575.0/36288.0)*Jinv00*M10*Jinv10-(575.0/36288.0)*M10*Jinv10*Jinv01)*D;
  A[0][12]=(-(15625.0/145152.0)*Jinv00*M00*Jinv01-(15625.0/145152.0)*Jinv11*Jinv10*M11-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M10*Jinv11-(15625.0/290304.0)*M01*Jinv10*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*Jinv00*M01*Jinv11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M01*Jinv11*Jinv01-(15625.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[0][13]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[0][14]=(-(175.0/2304.0)*Jinv00*M00*Jinv01-(175.0/2304.0)*Jinv11*Jinv10*M11-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M10*Jinv11-(175.0/4608.0)*M01*Jinv10*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*Jinv00*M01*Jinv11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M01*Jinv11*Jinv01-(175.0/4608.0)*Jinv00*M10*Jinv10-(175.0/4608.0)*M10*Jinv10*Jinv01)*D;
  A[0][15]=(-(10775.0/20736.0)*Jinv00*M00*Jinv01-(10775.0/20736.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*M10*Jinv11*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv00*M10*Jinv11-(130625.0/290304.0)*M01*Jinv10*Jinv01-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv00*M01*Jinv10-(20225.0/290304.0)*Jinv00*M01*Jinv11-(130625.0/290304.0)*M00*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M01*Jinv11*Jinv01-(20225.0/290304.0)*Jinv00*M10*Jinv10-(20225.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[0][16]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[0][17]=(-(175.0/2304.0)*Jinv00*M00*Jinv01-(175.0/2304.0)*Jinv11*Jinv10*M11-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M10*Jinv11-(175.0/4608.0)*M01*Jinv10*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*Jinv00*M01*Jinv11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M01*Jinv11*Jinv01-(175.0/4608.0)*Jinv00*M10*Jinv10-(175.0/4608.0)*M10*Jinv10*Jinv01)*D;
  A[0][18]=((8825.0/36288.0)*Jinv00*M00*Jinv01+(8825.0/36288.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*M10*Jinv11*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv00*M10*Jinv11+(29375.0/145152.0)*M01*Jinv10*Jinv01+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv00*M01*Jinv10+(1975.0/48384.0)*Jinv00*M01*Jinv11+(29375.0/145152.0)*M00*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M01*Jinv11*Jinv01+(1975.0/48384.0)*Jinv00*M10*Jinv10+(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[0][19]=(-(1975.0/24192.0)*Jinv00*M00*Jinv01-(1975.0/24192.0)*Jinv11*Jinv10*M11-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M10*Jinv11-(1975.0/48384.0)*M01*Jinv10*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*Jinv00*M01*Jinv11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M01*Jinv11*Jinv01-(1975.0/48384.0)*Jinv00*M10*Jinv10-(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[0][20]=(-(5951.0/145152.0)*Jinv00*M00*Jinv01-(5951.0/145152.0)*Jinv11*Jinv10*M11-(5951.0/145152.0)*M10*Jinv11*Jinv01-(5951.0/145152.0)*Jinv00*M10*Jinv11-(5951.0/145152.0)*M01*Jinv10*Jinv01-(5951.0/145152.0)*(Jinv11*Jinv11)*M11-(5951.0/145152.0)*M00*(Jinv01*Jinv01)-(5951.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[1][0]=(-(16175.0/36288.0)*Jinv00*M00*Jinv01-(16175.0/36288.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*M10*Jinv11*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv00*M10*Jinv11-(26875.0/41472.0)*M01*Jinv10*Jinv01+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv00*M01*Jinv10+(725.0/3584.0)*Jinv00*M01*Jinv11+(725.0/3584.0)*M00*(Jinv01*Jinv01)-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M01*Jinv11*Jinv01-(26875.0/41472.0)*Jinv00*M10*Jinv10+(725.0/3584.0)*M10*Jinv10*Jinv01)*D;
  A[1][1]=((29375.0/20736.0)*Jinv00*M00*Jinv01+(29375.0/20736.0)*Jinv11*Jinv10*M11+(6875.0/3456.0)*M10*Jinv11*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(29375.0/41472.0)*Jinv00*M10*Jinv11+(29375.0/41472.0)*M01*Jinv10*Jinv01+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv00*M01*Jinv10+(29375.0/41472.0)*Jinv00*M01*Jinv11+(6875.0/3456.0)*M00*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M01*Jinv11*Jinv01+(6875.0/3456.0)*Jinv00*M10*Jinv10+(29375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[1][2]=(-(14375.0/6912.0)*Jinv00*M00*Jinv01-(14375.0/6912.0)*Jinv11*Jinv10*M11-(263125.0/290304.0)*M10*Jinv11*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/41472.0)*Jinv00*M10*Jinv11-(15625.0/41472.0)*M01*Jinv10*Jinv01-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv00*M01*Jinv10-(70625.0/41472.0)*Jinv00*M01*Jinv11-(263125.0/290304.0)*M00*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M01*Jinv11*Jinv01-(745625.0/290304.0)*Jinv00*M10*Jinv10-(70625.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[1][3]=((45625.0/24192.0)*Jinv00*M00*Jinv01+(45625.0/24192.0)*Jinv11*Jinv10*M11+(59375.0/72576.0)*M10*Jinv11*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(10625.0/18144.0)*Jinv00*M10*Jinv11+(10625.0/18144.0)*M01*Jinv10*Jinv01+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv00*M01*Jinv10+(94375.0/72576.0)*Jinv00*M01*Jinv11+(59375.0/72576.0)*M00*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M01*Jinv11*Jinv01+(11875.0/6048.0)*Jinv00*M10*Jinv10+(94375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[1][4]=(-(68125.0/72576.0)*Jinv00*M00*Jinv01-(68125.0/72576.0)*Jinv11*Jinv10*M11-(49375.0/145152.0)*M10*Jinv11*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(78125.0/290304.0)*Jinv00*M10*Jinv11-(78125.0/290304.0)*M01*Jinv10*Jinv01-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv00*M01*Jinv10-(194375.0/290304.0)*Jinv00*M01*Jinv11-(49375.0/145152.0)*M00*(Jinv01*Jinv01)-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M01*Jinv11*Jinv01-(68125.0/72576.0)*Jinv00*M10*Jinv10-(194375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[1][5]=((1675.0/10368.0)*Jinv00*M00*Jinv01+(1675.0/10368.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv00*M01*Jinv10+(1675.0/10368.0)*Jinv00*M01*Jinv11+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv00*M10*Jinv10+(1675.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[1][6]=((6875.0/3456.0)*Jinv00*M00*Jinv01+(6875.0/3456.0)*Jinv11*Jinv10*M11-(11875.0/41472.0)*M10*Jinv11*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(6875.0/6912.0)*Jinv00*M10*Jinv11+(6875.0/6912.0)*M01*Jinv10*Jinv01-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv00*M01*Jinv10+(6875.0/6912.0)*Jinv00*M01*Jinv11-(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M01*Jinv11*Jinv01-(11875.0/41472.0)*Jinv00*M10*Jinv10+(6875.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[1][7]=(-(168125.0/72576.0)*Jinv00*M00*Jinv01-(168125.0/72576.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*M10*Jinv11*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(168125.0/145152.0)*Jinv00*M10*Jinv11-(168125.0/145152.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv00*M01*Jinv10-(168125.0/145152.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*M00*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M01*Jinv11*Jinv01+(8125.0/16128.0)*Jinv00*M10*Jinv10-(168125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[1][8]=((180625.0/145152.0)*Jinv00*M00*Jinv01+(180625.0/145152.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*M10*Jinv11*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(180625.0/290304.0)*Jinv00*M10*Jinv11+(180625.0/290304.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv00*M01*Jinv10+(180625.0/290304.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*M00*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M01*Jinv11*Jinv01+(14375.0/290304.0)*Jinv00*M10*Jinv10+(180625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[1][9]=(-(105625.0/72576.0)*Jinv00*M00*Jinv01-(105625.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*M10*Jinv11*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(105625.0/145152.0)*Jinv00*M10*Jinv11-(105625.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv00*M01*Jinv10-(105625.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*M00*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M01*Jinv11*Jinv01-(625.0/1344.0)*Jinv00*M10*Jinv10-(105625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[1][10]=((78125.0/145152.0)*Jinv00*M00*Jinv01+(78125.0/145152.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*M10*Jinv11*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(78125.0/290304.0)*Jinv00*M10*Jinv11+(78125.0/290304.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv00*M01*Jinv10+(78125.0/290304.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*M00*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M01*Jinv11*Jinv01+(14375.0/72576.0)*Jinv00*M10*Jinv10+(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[1][11]=(-(168125.0/145152.0)*Jinv00*M00*Jinv01-(168125.0/145152.0)*Jinv11*Jinv10*M11+(11875.0/41472.0)*M10*Jinv11*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(168125.0/290304.0)*Jinv00*M10*Jinv11-(168125.0/290304.0)*M01*Jinv10*Jinv01+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv00*M01*Jinv10-(168125.0/290304.0)*Jinv00*M01*Jinv11+(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M01*Jinv11*Jinv01-(14375.0/290304.0)*Jinv00*M10*Jinv10-(168125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[1][12]=((8125.0/5184.0)*Jinv00*M00*Jinv01+(8125.0/5184.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*M10*Jinv11*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(8125.0/10368.0)*Jinv00*M10*Jinv11+(8125.0/10368.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv00*M01*Jinv10+(8125.0/10368.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*M00*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M01*Jinv11*Jinv01+(4375.0/20736.0)*Jinv00*M10*Jinv10+(8125.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[1][13]=(-(14375.0/20736.0)*Jinv00*M00*Jinv01-(14375.0/20736.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*M10*Jinv11*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(14375.0/41472.0)*Jinv00*M10*Jinv11-(14375.0/41472.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv00*M01*Jinv10-(14375.0/41472.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*M00*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M01*Jinv11*Jinv01-(79375.0/290304.0)*Jinv00*M10*Jinv10-(14375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[1][14]=((6875.0/24192.0)*Jinv00*M00*Jinv01+(6875.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*M10*Jinv11*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(6875.0/48384.0)*Jinv00*M10*Jinv11+(6875.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv00*M01*Jinv10+(6875.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*M00*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M01*Jinv11*Jinv01+(8125.0/72576.0)*Jinv00*M10*Jinv10+(6875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[1][15]=((29375.0/48384.0)*Jinv00*M00*Jinv01+(29375.0/48384.0)*Jinv11*Jinv10*M11-(104375.0/290304.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(29375.0/96768.0)*Jinv00*M10*Jinv11+(29375.0/96768.0)*M01*Jinv10*Jinv01-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10+(29375.0/96768.0)*Jinv00*M01*Jinv11-(104375.0/290304.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10+(29375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[1][16]=(-(29375.0/36288.0)*Jinv00*M00*Jinv01-(29375.0/36288.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*M10*Jinv11*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(29375.0/72576.0)*Jinv00*M10*Jinv11-(29375.0/72576.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv00*M01*Jinv10-(29375.0/72576.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*M00*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M01*Jinv11*Jinv01-(6875.0/48384.0)*Jinv00*M10*Jinv10-(29375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[1][17]=((29375.0/145152.0)*Jinv00*M00*Jinv01+(29375.0/145152.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(29375.0/290304.0)*Jinv00*M10*Jinv11+(29375.0/290304.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10+(29375.0/290304.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10+(29375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[1][18]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*M10*Jinv11*Jinv01-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*(Jinv11*Jinv11)*M11-(6875.0/96768.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*M00*(Jinv01*Jinv01)+(14375.0/72576.0)*M01*Jinv11*Jinv01-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[1][19]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/48384.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/48384.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/48384.0)*M00*(Jinv01*Jinv01)+(6875.0/48384.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[1][20]=(-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*M01*Jinv11*Jinv01)*D;
  A[2][0]=((41975.0/72576.0)*Jinv00*M00*Jinv01+(41975.0/72576.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*M10*Jinv11*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv00*M10*Jinv11+(14375.0/24192.0)*M01*Jinv10*Jinv01-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv00*M01*Jinv10-(575.0/36288.0)*Jinv00*M01*Jinv11-(575.0/36288.0)*M00*(Jinv01*Jinv01)+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M01*Jinv11*Jinv01+(14375.0/24192.0)*Jinv00*M10*Jinv10-(575.0/36288.0)*M10*Jinv10*Jinv01)*D;
  A[2][1]=(-(14375.0/6912.0)*Jinv00*M00*Jinv01-(14375.0/6912.0)*Jinv11*Jinv10*M11-(263125.0/290304.0)*M10*Jinv11*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(70625.0/41472.0)*Jinv00*M10*Jinv11-(70625.0/41472.0)*M01*Jinv10*Jinv01-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/41472.0)*Jinv00*M01*Jinv11-(263125.0/290304.0)*M00*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M01*Jinv11*Jinv01-(745625.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[2][2]=((4375.0/1152.0)*Jinv00*M00*Jinv01+(4375.0/1152.0)*Jinv11*Jinv10*M11+(10625.0/3456.0)*M10*Jinv11*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(4375.0/2304.0)*Jinv00*M10*Jinv11+(4375.0/2304.0)*M01*Jinv10*Jinv01+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv00*M01*Jinv10+(4375.0/2304.0)*Jinv00*M01*Jinv11+(10625.0/3456.0)*M00*(Jinv01*Jinv01)+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M01*Jinv11*Jinv01+(11875.0/2688.0)*Jinv00*M10*Jinv10+(4375.0/2304.0)*M10*Jinv10*Jinv01)*D;
  A[2][3]=(-(574375.0/145152.0)*Jinv00*M00*Jinv01-(574375.0/145152.0)*Jinv11*Jinv10*M11-(261875.0/145152.0)*M10*Jinv11*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(15625.0/10752.0)*Jinv00*M10*Jinv11-(15625.0/10752.0)*M01*Jinv10*Jinv01-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv00*M01*Jinv10-(726875.0/290304.0)*Jinv00*M01*Jinv11-(261875.0/145152.0)*M00*(Jinv01*Jinv01)-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M01*Jinv11*Jinv01-(574375.0/145152.0)*Jinv00*M10*Jinv10-(726875.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[2][4]=((49375.0/24192.0)*Jinv00*M00*Jinv01+(49375.0/24192.0)*Jinv11*Jinv10*M11+(8125.0/9072.0)*M10*Jinv11*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(6875.0/10368.0)*Jinv00*M10*Jinv11+(6875.0/10368.0)*M01*Jinv10*Jinv01+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M01*Jinv11*Jinv01+(11875.0/6048.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[2][5]=(-(575.0/1512.0)*Jinv00*M00*Jinv01-(575.0/1512.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv00*M01*Jinv10-(575.0/1512.0)*Jinv00*M01*Jinv11-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv00*M10*Jinv10-(575.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[2][6]=(-(168125.0/145152.0)*Jinv00*M00*Jinv01-(168125.0/145152.0)*Jinv11*Jinv10*M11-(14375.0/290304.0)*M10*Jinv11*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(168125.0/290304.0)*Jinv00*M10*Jinv11-(168125.0/290304.0)*M01*Jinv10*Jinv01-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv00*M01*Jinv10-(168125.0/290304.0)*Jinv00*M01*Jinv11-(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M01*Jinv11*Jinv01+(11875.0/41472.0)*Jinv00*M10*Jinv10-(168125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[2][7]=((49375.0/12096.0)*Jinv00*M00*Jinv01+(49375.0/12096.0)*Jinv11*Jinv10*M11+(53125.0/72576.0)*M10*Jinv11*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/24192.0)*Jinv00*M10*Jinv11+(49375.0/24192.0)*M01*Jinv10*Jinv01+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv00*M01*Jinv10+(49375.0/24192.0)*Jinv00*M01*Jinv11+(53125.0/72576.0)*M00*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M01*Jinv11*Jinv01-(44375.0/72576.0)*Jinv00*M10*Jinv10+(49375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[2][8]=(-(233125.0/48384.0)*Jinv00*M00*Jinv01-(233125.0/48384.0)*Jinv11*Jinv10*M11-(184375.0/48384.0)*M10*Jinv11*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(233125.0/96768.0)*Jinv00*M10*Jinv11-(233125.0/96768.0)*M01*Jinv10*Jinv01-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv00*M01*Jinv10-(233125.0/96768.0)*Jinv00*M01*Jinv11-(184375.0/48384.0)*M00*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M01*Jinv11*Jinv01+(625.0/145152.0)*Jinv00*M10*Jinv10-(233125.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[2][9]=((116875.0/36288.0)*Jinv00*M00*Jinv01+(116875.0/36288.0)*Jinv11*Jinv10*M11+(146875.0/72576.0)*M10*Jinv11*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(116875.0/72576.0)*Jinv00*M10*Jinv11+(116875.0/72576.0)*M01*Jinv10*Jinv01+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv00*M01*Jinv10+(116875.0/72576.0)*Jinv00*M01*Jinv11+(146875.0/72576.0)*M00*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M01*Jinv11*Jinv01+(49375.0/72576.0)*Jinv00*M10*Jinv10+(116875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[2][10]=(-(6875.0/5184.0)*Jinv00*M00*Jinv01-(6875.0/5184.0)*Jinv11*Jinv10*M11-(8125.0/9072.0)*M10*Jinv11*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(6875.0/10368.0)*Jinv00*M10*Jinv11-(6875.0/10368.0)*M01*Jinv10*Jinv01-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv00*M01*Jinv10-(6875.0/10368.0)*Jinv00*M01*Jinv11-(8125.0/9072.0)*M00*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M01*Jinv11*Jinv01-(104375.0/290304.0)*Jinv00*M10*Jinv10-(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[2][11]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(625.0/6048.0)*M10*Jinv11*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(625.0/6048.0)*M00*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M01*Jinv11*Jinv01+(625.0/6048.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[2][12]=(-(45625.0/48384.0)*Jinv00*M00*Jinv01-(45625.0/48384.0)*Jinv11*Jinv10*M11+(3125.0/8064.0)*M10*Jinv11*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00-(45625.0/96768.0)*Jinv00*M10*Jinv11-(45625.0/96768.0)*M01*Jinv10*Jinv01+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv00*M01*Jinv10-(45625.0/96768.0)*Jinv00*M01*Jinv11+(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M01*Jinv11*Jinv01-(23125.0/72576.0)*Jinv00*M10*Jinv10-(45625.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[2][13]=((10625.0/8064.0)*Jinv00*M00*Jinv01+(10625.0/8064.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(10625.0/16128.0)*Jinv00*M10*Jinv11+(10625.0/16128.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv00*M01*Jinv10+(10625.0/16128.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(11875.0/36288.0)*Jinv00*M10*Jinv10+(10625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[2][14]=(-(45625.0/145152.0)*Jinv00*M00*Jinv01-(45625.0/145152.0)*Jinv11*Jinv10*M11-(10625.0/48384.0)*M10*Jinv11*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(45625.0/290304.0)*Jinv00*M10*Jinv11-(45625.0/290304.0)*M01*Jinv10*Jinv01-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv00*M01*Jinv10-(45625.0/290304.0)*Jinv00*M01*Jinv11-(10625.0/48384.0)*M00*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M01*Jinv11*Jinv01-(8125.0/72576.0)*Jinv00*M10*Jinv10-(45625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[2][15]=((625.0/6912.0)*Jinv00*M00*Jinv01+(625.0/6912.0)*Jinv11*Jinv10*M11-(8125.0/72576.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00+(625.0/13824.0)*Jinv00*M10*Jinv11+(625.0/13824.0)*M01*Jinv10*Jinv01-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10+(625.0/13824.0)*Jinv00*M01*Jinv11-(8125.0/72576.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10+(625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[2][16]=((625.0/3024.0)*Jinv00*M00*Jinv01+(625.0/3024.0)*Jinv11*Jinv10*M11-(3125.0/9072.0)*M10*Jinv11*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv00*M10*Jinv11+(625.0/6048.0)*M01*Jinv10*Jinv01-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv00*M01*Jinv10+(625.0/6048.0)*Jinv00*M01*Jinv11-(3125.0/9072.0)*M00*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M01*Jinv11*Jinv01+(625.0/18144.0)*Jinv00*M10*Jinv10+(625.0/6048.0)*M10*Jinv10*Jinv01)*D;
  A[2][17]=(-(14375.0/48384.0)*Jinv00*M00*Jinv01-(14375.0/48384.0)*Jinv11*Jinv10*M11-(14375.0/48384.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/96768.0)*Jinv00*M10*Jinv11-(14375.0/96768.0)*M01*Jinv10*Jinv01-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10-(14375.0/96768.0)*Jinv00*M01*Jinv11-(14375.0/48384.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10-(14375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[2][18]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*M10*Jinv11*Jinv01-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/20736.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*M00*(Jinv01*Jinv01)+(8125.0/72576.0)*M01*Jinv11*Jinv01-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[2][19]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*M10*Jinv11*Jinv01+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/20736.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*M00*(Jinv01*Jinv01)+(38125.0/290304.0)*M01*Jinv11*Jinv01+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[2][20]=(-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*M01*Jinv11*Jinv01)*D;
  A[3][0]=(-(10775.0/20736.0)*Jinv00*M00*Jinv01-(10775.0/20736.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*M10*Jinv11*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv00*M10*Jinv11-(130625.0/290304.0)*M01*Jinv10*Jinv01-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv00*M01*Jinv10-(20225.0/290304.0)*Jinv00*M01*Jinv11-(20225.0/290304.0)*M00*(Jinv01*Jinv01)-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M01*Jinv11*Jinv01-(130625.0/290304.0)*Jinv00*M10*Jinv10-(20225.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[3][1]=((45625.0/24192.0)*Jinv00*M00*Jinv01+(45625.0/24192.0)*Jinv11*Jinv10*M11+(59375.0/72576.0)*M10*Jinv11*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(94375.0/72576.0)*Jinv00*M10*Jinv11+(94375.0/72576.0)*M01*Jinv10*Jinv01+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv00*M01*Jinv10+(10625.0/18144.0)*Jinv00*M01*Jinv11+(59375.0/72576.0)*M00*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M01*Jinv11*Jinv01+(11875.0/6048.0)*Jinv00*M10*Jinv10+(10625.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[3][2]=(-(574375.0/145152.0)*Jinv00*M00*Jinv01-(574375.0/145152.0)*Jinv11*Jinv10*M11-(261875.0/145152.0)*M10*Jinv11*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(726875.0/290304.0)*Jinv00*M10*Jinv11-(726875.0/290304.0)*M01*Jinv10*Jinv01-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv00*M01*Jinv10-(15625.0/10752.0)*Jinv00*M01*Jinv11-(261875.0/145152.0)*M00*(Jinv01*Jinv01)-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M01*Jinv11*Jinv01-(574375.0/145152.0)*Jinv00*M10*Jinv10-(15625.0/10752.0)*M10*Jinv10*Jinv01)*D;
  A[3][3]=((40625.0/8064.0)*Jinv00*M00*Jinv01+(40625.0/8064.0)*Jinv11*Jinv10*M11+(89375.0/24192.0)*M10*Jinv11*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(40625.0/16128.0)*Jinv00*M10*Jinv11+(40625.0/16128.0)*M01*Jinv10*Jinv01+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv00*M01*Jinv10+(40625.0/16128.0)*Jinv00*M01*Jinv11+(89375.0/24192.0)*M00*(Jinv01*Jinv01)+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M01*Jinv11*Jinv01+(11875.0/2688.0)*Jinv00*M10*Jinv10+(40625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[3][4]=(-(221875.0/72576.0)*Jinv00*M00*Jinv01-(221875.0/72576.0)*Jinv11*Jinv10*M11-(625.0/448.0)*M10*Jinv11*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(41875.0/48384.0)*Jinv00*M10*Jinv11-(41875.0/48384.0)*M01*Jinv10*Jinv01-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv00*M01*Jinv10-(318125.0/145152.0)*Jinv00*M01*Jinv11-(625.0/448.0)*M00*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M01*Jinv11*Jinv01-(745625.0/290304.0)*Jinv00*M10*Jinv10-(318125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[3][5]=((6325.0/10368.0)*Jinv00*M00*Jinv01+(6325.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv00*M01*Jinv10+(6325.0/10368.0)*Jinv00*M01*Jinv11+(14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv00*M10*Jinv10+(6325.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[3][6]=((29375.0/48384.0)*Jinv00*M00*Jinv01+(29375.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(29375.0/96768.0)*Jinv00*M10*Jinv11+(29375.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv00*M01*Jinv10+(29375.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01-(104375.0/290304.0)*Jinv00*M10*Jinv10+(29375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[3][7]=(-(625.0/336.0)*Jinv00*M00*Jinv01-(625.0/336.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/672.0)*Jinv00*M10*Jinv11-(625.0/672.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv00*M01*Jinv10-(625.0/672.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(49375.0/72576.0)*Jinv00*M10*Jinv10-(625.0/672.0)*M10*Jinv10*Jinv01)*D;
  A[3][8]=((700625.0/145152.0)*Jinv00*M00*Jinv01+(700625.0/145152.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(700625.0/290304.0)*Jinv00*M10*Jinv11+(700625.0/290304.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv00*M01*Jinv10+(700625.0/290304.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01+(625.0/145152.0)*Jinv00*M10*Jinv10+(700625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[3][9]=(-(6875.0/1296.0)*Jinv00*M00*Jinv01-(6875.0/1296.0)*Jinv11*Jinv10*M11-(71875.0/18144.0)*M10*Jinv11*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/2592.0)*Jinv00*M10*Jinv11-(6875.0/2592.0)*M01*Jinv10*Jinv01-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/2592.0)*Jinv00*M01*Jinv11-(71875.0/18144.0)*M00*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M01*Jinv11*Jinv01-(44375.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/2592.0)*M10*Jinv10*Jinv01)*D;
  A[3][10]=((41875.0/24192.0)*Jinv00*M00*Jinv01+(41875.0/24192.0)*Jinv11*Jinv10*M11+(625.0/448.0)*M10*Jinv11*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(41875.0/48384.0)*Jinv00*M10*Jinv11+(41875.0/48384.0)*M01*Jinv10*Jinv01+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv00*M01*Jinv10+(41875.0/48384.0)*Jinv00*M01*Jinv11+(625.0/448.0)*M00*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M01*Jinv11*Jinv01+(11875.0/41472.0)*Jinv00*M10*Jinv10+(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[3][11]=((625.0/6912.0)*Jinv00*M00*Jinv01+(625.0/6912.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/13824.0)*Jinv00*M10*Jinv11+(625.0/13824.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv00*M01*Jinv10+(625.0/13824.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(8125.0/72576.0)*Jinv00*M10*Jinv10+(625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[3][12]=(-(6875.0/10368.0)*Jinv00*M00*Jinv01-(6875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/72576.0)*M10*Jinv11*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00-(6875.0/20736.0)*Jinv00*M10*Jinv11-(6875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv00*M01*Jinv10-(6875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/72576.0)*M00*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M01*Jinv11*Jinv01+(11875.0/36288.0)*Jinv00*M10*Jinv10-(6875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[3][13]=((44375.0/145152.0)*Jinv00*M00*Jinv01+(44375.0/145152.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(44375.0/290304.0)*Jinv00*M10*Jinv11+(44375.0/290304.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv00*M01*Jinv10+(44375.0/290304.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01-(23125.0/72576.0)*Jinv00*M10*Jinv10+(44375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[3][14]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11+(19375.0/72576.0)*M10*Jinv11*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/145152.0)*Jinv00*M10*Jinv11+(19375.0/145152.0)*M01*Jinv10*Jinv01+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv00*M01*Jinv10+(19375.0/145152.0)*Jinv00*M01*Jinv11+(19375.0/72576.0)*M00*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M01*Jinv11*Jinv01+(625.0/6048.0)*Jinv00*M10*Jinv10+(19375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[3][15]=((38125.0/145152.0)*Jinv00*M00*Jinv01+(38125.0/145152.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv00*M10*Jinv11+(38125.0/290304.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10+(38125.0/290304.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10+(38125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[3][16]=(-(625.0/4536.0)*Jinv00*M00*Jinv01-(625.0/4536.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(625.0/9072.0)*Jinv00*M10*Jinv11-(625.0/9072.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv00*M01*Jinv10-(625.0/9072.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(625.0/18144.0)*Jinv00*M10*Jinv10-(625.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[3][17]=(-(18125.0/145152.0)*Jinv00*M00*Jinv01-(18125.0/145152.0)*Jinv11*Jinv10*M11-(10625.0/48384.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(18125.0/290304.0)*Jinv00*M10*Jinv11-(18125.0/290304.0)*M01*Jinv10*Jinv01-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10-(18125.0/290304.0)*Jinv00*M01*Jinv11-(10625.0/48384.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10-(18125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[3][18]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(625.0/20736.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*M01*Jinv11*Jinv01-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[3][19]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*M10*Jinv11*Jinv01+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(625.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*M00*(Jinv01*Jinv01)+(3125.0/18144.0)*M01*Jinv11*Jinv01+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[3][20]=(-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*M01*Jinv11*Jinv01)*D;
  A[4][0]=((8825.0/36288.0)*Jinv00*M00*Jinv01+(8825.0/36288.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*M10*Jinv11*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv00*M10*Jinv11+(29375.0/145152.0)*M01*Jinv10*Jinv01+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv00*M01*Jinv10+(1975.0/48384.0)*Jinv00*M01*Jinv11+(1975.0/48384.0)*M00*(Jinv01*Jinv01)+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M01*Jinv11*Jinv01+(29375.0/145152.0)*Jinv00*M10*Jinv10+(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[4][1]=(-(68125.0/72576.0)*Jinv00*M00*Jinv01-(68125.0/72576.0)*Jinv11*Jinv10*M11-(49375.0/145152.0)*M10*Jinv11*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(194375.0/290304.0)*Jinv00*M10*Jinv11-(194375.0/290304.0)*M01*Jinv10*Jinv01-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv00*M01*Jinv10-(78125.0/290304.0)*Jinv00*M01*Jinv11-(49375.0/145152.0)*M00*(Jinv01*Jinv01)-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M01*Jinv11*Jinv01-(68125.0/72576.0)*Jinv00*M10*Jinv10-(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[4][2]=((49375.0/24192.0)*Jinv00*M00*Jinv01+(49375.0/24192.0)*Jinv11*Jinv10*M11+(8125.0/9072.0)*M10*Jinv11*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv00*M01*Jinv10+(6875.0/10368.0)*Jinv00*M01*Jinv11+(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M01*Jinv11*Jinv01+(11875.0/6048.0)*Jinv00*M10*Jinv10+(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[4][3]=(-(221875.0/72576.0)*Jinv00*M00*Jinv01-(221875.0/72576.0)*Jinv11*Jinv10*M11-(625.0/448.0)*M10*Jinv11*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(318125.0/145152.0)*Jinv00*M10*Jinv11-(318125.0/145152.0)*M01*Jinv10*Jinv01-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv00*M01*Jinv10-(41875.0/48384.0)*Jinv00*M01*Jinv11-(625.0/448.0)*M00*(Jinv01*Jinv01)-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M01*Jinv11*Jinv01-(745625.0/290304.0)*Jinv00*M10*Jinv10-(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[4][4]=((53125.0/20736.0)*Jinv00*M00*Jinv01+(53125.0/20736.0)*Jinv11*Jinv10*M11+(53125.0/20736.0)*M10*Jinv11*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/41472.0)*Jinv00*M10*Jinv11+(53125.0/41472.0)*M01*Jinv10*Jinv01+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv00*M01*Jinv10+(53125.0/41472.0)*Jinv00*M01*Jinv11+(53125.0/20736.0)*M00*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M01*Jinv11*Jinv01+(6875.0/3456.0)*Jinv00*M10*Jinv10+(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[4][5]=(-(123425.0/145152.0)*Jinv00*M00*Jinv01-(123425.0/145152.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv00*M01*Jinv10-(123425.0/145152.0)*Jinv00*M01*Jinv11-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv00*M10*Jinv10-(123425.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[4][6]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/96768.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[4][7]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*Jinv00*M01*Jinv10+(38125.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv00*M10*Jinv10+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[4][8]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*Jinv00*M01*Jinv10-(11875.0/20736.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv00*M10*Jinv10-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[4][9]=((120625.0/36288.0)*Jinv00*M00*Jinv01+(120625.0/36288.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*Jinv00*M10*Jinv11+(120625.0/72576.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*Jinv00*M01*Jinv10+(120625.0/72576.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv00*M10*Jinv10+(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[4][10]=(-(53125.0/20736.0)*Jinv00*M00*Jinv01-(53125.0/20736.0)*Jinv11*Jinv10*M11-(53125.0/20736.0)*M10*Jinv11*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/41472.0)*Jinv00*M10*Jinv11-(53125.0/41472.0)*M01*Jinv10*Jinv01-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv00*M01*Jinv10-(53125.0/41472.0)*Jinv00*M01*Jinv11-(53125.0/20736.0)*M00*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M01*Jinv11*Jinv01-(11875.0/41472.0)*Jinv00*M10*Jinv10-(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[4][11]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[4][12]=((10625.0/72576.0)*Jinv00*M00*Jinv01+(10625.0/72576.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*Jinv00*M10*Jinv11+(10625.0/145152.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*Jinv00*M01*Jinv10+(10625.0/145152.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv00*M10*Jinv10+(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[4][13]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*Jinv00*M01*Jinv10-(11875.0/20736.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv00*M10*Jinv10-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[4][14]=((25625.0/24192.0)*Jinv00*M00*Jinv01+(25625.0/24192.0)*Jinv11*Jinv10*M11+(625.0/448.0)*M10*Jinv11*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(25625.0/48384.0)*Jinv00*M10*Jinv11+(25625.0/48384.0)*M01*Jinv10*Jinv01+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv00*M01*Jinv10+(25625.0/48384.0)*Jinv00*M01*Jinv11+(625.0/448.0)*M00*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M01*Jinv11*Jinv01-(14375.0/290304.0)*Jinv00*M10*Jinv10+(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[4][15]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[4][16]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*Jinv00*M01*Jinv10+(38125.0/145152.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv00*M10*Jinv10+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[4][17]=(-(625.0/1344.0)*Jinv00*M00*Jinv01-(625.0/1344.0)*Jinv11*Jinv10*M11-(8125.0/9072.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/2688.0)*Jinv00*M10*Jinv11-(625.0/2688.0)*M01*Jinv10*Jinv01-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10-(625.0/2688.0)*Jinv00*M01*Jinv11-(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10-(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[4][18]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01-(6875.0/96768.0)*Jinv00*M01*Jinv11-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[4][19]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*M00*(Jinv01*Jinv01)+(49375.0/145152.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[4][20]=(-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*M01*Jinv11*Jinv01)*D;
  A[5][0]=(-(5951.0/145152.0)*Jinv00*M00*Jinv01-(5951.0/145152.0)*Jinv11*Jinv10*M11-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*Jinv00*M10*Jinv11-(5951.0/145152.0)*M01*Jinv10*Jinv01-(5951.0/145152.0)*Jinv00*M01*Jinv10-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[5][1]=((1675.0/10368.0)*Jinv00*M00*Jinv01+(1675.0/10368.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1675.0/10368.0)*Jinv00*M10*Jinv11+(1675.0/10368.0)*M01*Jinv10*Jinv01+(29375.0/145152.0)*Jinv00*M01*Jinv10+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[5][2]=(-(575.0/1512.0)*Jinv00*M00*Jinv01-(575.0/1512.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(575.0/1512.0)*Jinv00*M10*Jinv11-(575.0/1512.0)*M01*Jinv10*Jinv01-(130625.0/290304.0)*Jinv00*M01*Jinv10-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[5][3]=((6325.0/10368.0)*Jinv00*M00*Jinv01+(6325.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(6325.0/10368.0)*Jinv00*M10*Jinv11+(6325.0/10368.0)*M01*Jinv10*Jinv01+(14375.0/24192.0)*Jinv00*M01*Jinv10+(14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv00*M10*Jinv10)*D;
  A[5][4]=(-(123425.0/145152.0)*Jinv00*M00*Jinv01-(123425.0/145152.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(123425.0/145152.0)*Jinv00*M10*Jinv11-(123425.0/145152.0)*M01*Jinv10*Jinv01-(26875.0/41472.0)*Jinv00*M01*Jinv10-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv00*M10*Jinv10)*D;
  A[5][5]=((16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv00*M01*Jinv10+(16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[5][6]=(-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[5][7]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[5][8]=(-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[5][9]=(-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv00*M01*Jinv10-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv00*M10*Jinv10)*D;
  A[5][10]=((123425.0/145152.0)*Jinv00*M00*Jinv01+(123425.0/145152.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(123425.0/145152.0)*Jinv00*M10*Jinv11+(123425.0/145152.0)*M01*Jinv10*Jinv01+(725.0/3584.0)*Jinv00*M01*Jinv10+(725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv00*M10*Jinv10)*D;
  A[5][11]=(-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv00*M10*Jinv10)*D;
  A[5][12]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[5][13]=(-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[5][14]=(-(6325.0/10368.0)*Jinv00*M00*Jinv01-(6325.0/10368.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(6325.0/10368.0)*Jinv00*M10*Jinv11-(6325.0/10368.0)*M01*Jinv10*Jinv01-(575.0/36288.0)*Jinv00*M01*Jinv10-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv00*M10*Jinv10)*D;
  A[5][15]=(-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv00*M10*Jinv10)*D;
  A[5][16]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[5][17]=((575.0/1512.0)*Jinv00*M00*Jinv01+(575.0/1512.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*(Jinv00*Jinv00)*M00+(575.0/1512.0)*Jinv00*M10*Jinv11+(575.0/1512.0)*M01*Jinv10*Jinv01-(20225.0/290304.0)*Jinv00*M01*Jinv10-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[5][18]=(-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[5][19]=(-(1675.0/10368.0)*Jinv00*M00*Jinv01-(1675.0/10368.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1675.0/10368.0)*Jinv00*M10*Jinv11-(1675.0/10368.0)*M01*Jinv10*Jinv01+(1975.0/48384.0)*Jinv00*M01*Jinv10+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[5][20]=((5951.0/145152.0)*Jinv00*M00*Jinv01+(5951.0/145152.0)*Jinv11*Jinv10*M11+(5951.0/145152.0)*Jinv00*M10*Jinv11+(5951.0/145152.0)*M01*Jinv10*Jinv01)*D;
  A[6][0]=(-(16175.0/36288.0)*Jinv00*M00*Jinv01-(16175.0/36288.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*M10*Jinv11*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv00*M10*Jinv11+(725.0/3584.0)*M01*Jinv10*Jinv01-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv00*M01*Jinv10-(26875.0/41472.0)*Jinv00*M01*Jinv11-(26875.0/41472.0)*M00*(Jinv01*Jinv01)+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M01*Jinv11*Jinv01+(725.0/3584.0)*Jinv00*M10*Jinv10-(26875.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[6][1]=((6875.0/3456.0)*Jinv00*M00*Jinv01+(6875.0/3456.0)*Jinv11*Jinv10*M11-(11875.0/41472.0)*M10*Jinv11*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(6875.0/6912.0)*Jinv00*M10*Jinv11+(6875.0/6912.0)*M01*Jinv10*Jinv01-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv00*M01*Jinv10+(6875.0/6912.0)*Jinv00*M01*Jinv11-(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M01*Jinv11*Jinv01-(11875.0/41472.0)*Jinv00*M10*Jinv10+(6875.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[6][2]=(-(168125.0/145152.0)*Jinv00*M00*Jinv01-(168125.0/145152.0)*Jinv11*Jinv10*M11-(14375.0/290304.0)*M10*Jinv11*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(168125.0/290304.0)*Jinv00*M10*Jinv11-(168125.0/290304.0)*M01*Jinv10*Jinv01-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv00*M01*Jinv10-(168125.0/290304.0)*Jinv00*M01*Jinv11-(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M01*Jinv11*Jinv01+(11875.0/41472.0)*Jinv00*M10*Jinv10-(168125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[6][3]=((29375.0/48384.0)*Jinv00*M00*Jinv01+(29375.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(29375.0/96768.0)*Jinv00*M10*Jinv11+(29375.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv00*M01*Jinv10+(29375.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01-(104375.0/290304.0)*Jinv00*M10*Jinv10+(29375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[6][4]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/96768.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[6][5]=(-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[6][6]=((29375.0/20736.0)*Jinv00*M00*Jinv01+(29375.0/20736.0)*Jinv11*Jinv10*M11+(6875.0/3456.0)*M10*Jinv11*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(29375.0/41472.0)*Jinv00*M10*Jinv11+(29375.0/41472.0)*M01*Jinv10*Jinv01+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv00*M01*Jinv10+(29375.0/41472.0)*Jinv00*M01*Jinv11+(6875.0/3456.0)*M00*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M01*Jinv11*Jinv01+(6875.0/3456.0)*Jinv00*M10*Jinv10+(29375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[6][7]=(-(168125.0/72576.0)*Jinv00*M00*Jinv01-(168125.0/72576.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*M10*Jinv11*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(168125.0/145152.0)*Jinv00*M10*Jinv11-(168125.0/145152.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv00*M01*Jinv10-(168125.0/145152.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*M00*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M01*Jinv11*Jinv01-(409375.0/145152.0)*Jinv00*M10*Jinv10-(168125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[6][8]=((8125.0/5184.0)*Jinv00*M00*Jinv01+(8125.0/5184.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*M10*Jinv11*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(8125.0/10368.0)*Jinv00*M10*Jinv11+(8125.0/10368.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv00*M01*Jinv10+(8125.0/10368.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*M00*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M01*Jinv11*Jinv01+(3125.0/2304.0)*Jinv00*M10*Jinv10+(8125.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[6][9]=(-(29375.0/36288.0)*Jinv00*M00*Jinv01-(29375.0/36288.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*M10*Jinv11*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(29375.0/72576.0)*Jinv00*M10*Jinv11-(29375.0/72576.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv00*M01*Jinv10-(29375.0/72576.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*M00*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M01*Jinv11*Jinv01-(96875.0/145152.0)*Jinv00*M10*Jinv10-(29375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[6][10]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/48384.0)*Jinv00*M01*Jinv10+(6875.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv00*M10*Jinv10+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[6][11]=(-(14375.0/6912.0)*Jinv00*M00*Jinv01-(14375.0/6912.0)*Jinv11*Jinv10*M11-(745625.0/290304.0)*M10*Jinv11*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(70625.0/41472.0)*Jinv00*M10*Jinv11-(70625.0/41472.0)*M01*Jinv10*Jinv01-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/41472.0)*Jinv00*M01*Jinv11-(745625.0/290304.0)*M00*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M01*Jinv11*Jinv01-(263125.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[6][12]=((180625.0/145152.0)*Jinv00*M00*Jinv01+(180625.0/145152.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*M10*Jinv11*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(180625.0/290304.0)*Jinv00*M10*Jinv11+(180625.0/290304.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv00*M01*Jinv10+(180625.0/290304.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M01*Jinv11*Jinv01+(115625.0/96768.0)*Jinv00*M10*Jinv10+(180625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[6][13]=(-(14375.0/20736.0)*Jinv00*M00*Jinv01-(14375.0/20736.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*M10*Jinv11*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(14375.0/41472.0)*Jinv00*M10*Jinv11-(14375.0/41472.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv00*M01*Jinv10-(14375.0/41472.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*M00*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M01*Jinv11*Jinv01-(40625.0/96768.0)*Jinv00*M10*Jinv10-(14375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[6][14]=((29375.0/145152.0)*Jinv00*M00*Jinv01+(29375.0/145152.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(29375.0/290304.0)*Jinv00*M10*Jinv11+(29375.0/290304.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv00*M01*Jinv10+(29375.0/290304.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01+(38125.0/290304.0)*Jinv00*M10*Jinv10+(29375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[6][15]=((45625.0/24192.0)*Jinv00*M00*Jinv01+(45625.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/6048.0)*M10*Jinv11*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(94375.0/72576.0)*Jinv00*M10*Jinv11+(94375.0/72576.0)*M01*Jinv10*Jinv01+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv00*M01*Jinv10+(10625.0/18144.0)*Jinv00*M01*Jinv11+(11875.0/6048.0)*M00*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M01*Jinv11*Jinv01+(59375.0/72576.0)*Jinv00*M10*Jinv10+(10625.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[6][16]=(-(105625.0/72576.0)*Jinv00*M00*Jinv01-(105625.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*M10*Jinv11*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(105625.0/145152.0)*Jinv00*M10*Jinv11-(105625.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv00*M01*Jinv10-(105625.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*M00*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M01*Jinv11*Jinv01-(71875.0/72576.0)*Jinv00*M10*Jinv10-(105625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[6][17]=((6875.0/24192.0)*Jinv00*M00*Jinv01+(6875.0/24192.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(6875.0/48384.0)*Jinv00*M10*Jinv11+(6875.0/48384.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv00*M01*Jinv10+(6875.0/48384.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/18144.0)*Jinv00*M10*Jinv10+(6875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[6][18]=(-(68125.0/72576.0)*Jinv00*M00*Jinv01-(68125.0/72576.0)*Jinv11*Jinv10*M11-(68125.0/72576.0)*M10*Jinv11*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(194375.0/290304.0)*Jinv00*M10*Jinv11-(194375.0/290304.0)*M01*Jinv10*Jinv01-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv00*M01*Jinv10-(78125.0/290304.0)*Jinv00*M01*Jinv11-(68125.0/72576.0)*M00*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M01*Jinv11*Jinv01-(49375.0/145152.0)*Jinv00*M10*Jinv10-(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[6][19]=((78125.0/145152.0)*Jinv00*M00*Jinv01+(78125.0/145152.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*M10*Jinv11*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(78125.0/290304.0)*Jinv00*M10*Jinv11+(78125.0/290304.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv00*M01*Jinv10+(78125.0/290304.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*M00*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M01*Jinv11*Jinv01+(49375.0/145152.0)*Jinv00*M10*Jinv10+(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[6][20]=((1675.0/10368.0)*Jinv00*M00*Jinv01+(1675.0/10368.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*M10*Jinv11*Jinv01+(1675.0/10368.0)*Jinv00*M10*Jinv11+(1675.0/10368.0)*M01*Jinv10*Jinv01+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*M00*(Jinv01*Jinv01)+(29375.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[7][0]=(-(15625.0/36288.0)*Jinv00*M00*Jinv01-(15625.0/36288.0)*Jinv11*Jinv10*M11-(15625.0/72576.0)*M10*Jinv11*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv00*M10*Jinv11-(15625.0/72576.0)*M01*Jinv10*Jinv01-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv00*M01*Jinv10-(15625.0/72576.0)*Jinv00*M01*Jinv11-(15625.0/72576.0)*M00*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M01*Jinv11*Jinv01-(15625.0/72576.0)*Jinv00*M10*Jinv10-(15625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[7][1]=(-(168125.0/72576.0)*Jinv00*M00*Jinv01-(168125.0/72576.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*M10*Jinv11*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(168125.0/145152.0)*Jinv00*M10*Jinv11-(168125.0/145152.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv00*M01*Jinv10-(168125.0/145152.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*M00*(Jinv01*Jinv01)+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M01*Jinv11*Jinv01+(8125.0/16128.0)*Jinv00*M10*Jinv10-(168125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][2]=((49375.0/12096.0)*Jinv00*M00*Jinv01+(49375.0/12096.0)*Jinv11*Jinv10*M11+(53125.0/72576.0)*M10*Jinv11*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/24192.0)*Jinv00*M10*Jinv11+(49375.0/24192.0)*M01*Jinv10*Jinv01+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv00*M01*Jinv10+(49375.0/24192.0)*Jinv00*M01*Jinv11+(53125.0/72576.0)*M00*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M01*Jinv11*Jinv01-(44375.0/72576.0)*Jinv00*M10*Jinv10+(49375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[7][3]=(-(625.0/336.0)*Jinv00*M00*Jinv01-(625.0/336.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/672.0)*Jinv00*M10*Jinv11-(625.0/672.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv00*M01*Jinv10-(625.0/672.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(49375.0/72576.0)*Jinv00*M10*Jinv10-(625.0/672.0)*M10*Jinv10*Jinv01)*D;
  A[7][4]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*Jinv00*M01*Jinv10+(38125.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv00*M10*Jinv10+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][5]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[7][6]=(-(168125.0/72576.0)*Jinv00*M00*Jinv01-(168125.0/72576.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*M10*Jinv11*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(168125.0/145152.0)*Jinv00*M10*Jinv11-(168125.0/145152.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv00*M01*Jinv10-(168125.0/145152.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*M00*(Jinv01*Jinv01)-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M01*Jinv11*Jinv01-(409375.0/145152.0)*Jinv00*M10*Jinv10-(168125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][7]=((3125.0/504.0)*Jinv00*M00*Jinv01+(3125.0/504.0)*Jinv11*Jinv10*M11+(128125.0/18144.0)*M10*Jinv11*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(3125.0/1008.0)*Jinv00*M10*Jinv11+(3125.0/1008.0)*M01*Jinv10*Jinv01+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv00*M01*Jinv10+(3125.0/1008.0)*Jinv00*M01*Jinv11+(128125.0/18144.0)*M00*(Jinv01*Jinv01)+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M01*Jinv11*Jinv01+(128125.0/18144.0)*Jinv00*M10*Jinv10+(3125.0/1008.0)*M10*Jinv10*Jinv01)*D;
  A[7][8]=(-(221875.0/36288.0)*Jinv00*M00*Jinv01-(221875.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/1728.0)*M10*Jinv11*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(221875.0/72576.0)*Jinv00*M10*Jinv11-(221875.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv00*M01*Jinv10-(221875.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/1728.0)*M00*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M01*Jinv11*Jinv01-(21875.0/3456.0)*Jinv00*M10*Jinv10-(221875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[7][9]=((3125.0/1134.0)*Jinv00*M00*Jinv01+(3125.0/1134.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/1134.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[7][10]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*Jinv00*M01*Jinv10-(38125.0/145152.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv00*M10*Jinv10-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][11]=((49375.0/12096.0)*Jinv00*M00*Jinv01+(49375.0/12096.0)*Jinv11*Jinv10*M11-(44375.0/72576.0)*M10*Jinv11*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/24192.0)*Jinv00*M10*Jinv11+(49375.0/24192.0)*M01*Jinv10*Jinv01-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv00*M01*Jinv10+(49375.0/24192.0)*Jinv00*M01*Jinv11-(44375.0/72576.0)*M00*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M01*Jinv11*Jinv01+(53125.0/72576.0)*Jinv00*M10*Jinv10+(49375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[7][12]=(-(221875.0/36288.0)*Jinv00*M00*Jinv01-(221875.0/36288.0)*Jinv11*Jinv10*M11-(21875.0/3456.0)*M10*Jinv11*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(221875.0/72576.0)*Jinv00*M10*Jinv11-(221875.0/72576.0)*M01*Jinv10*Jinv01-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv00*M01*Jinv10-(221875.0/72576.0)*Jinv00*M01*Jinv11-(21875.0/3456.0)*M00*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M01*Jinv11*Jinv01-(3125.0/1728.0)*Jinv00*M10*Jinv10-(221875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[7][13]=((53125.0/18144.0)*Jinv00*M00*Jinv01+(53125.0/18144.0)*Jinv11*Jinv10*M11+(34375.0/24192.0)*M10*Jinv11*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(53125.0/36288.0)*Jinv00*M10*Jinv11+(53125.0/36288.0)*M01*Jinv10*Jinv01+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv00*M01*Jinv10+(53125.0/36288.0)*Jinv00*M01*Jinv11+(34375.0/24192.0)*M00*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M01*Jinv11*Jinv01+(34375.0/24192.0)*Jinv00*M10*Jinv10+(53125.0/36288.0)*M10*Jinv10*Jinv01)*D;
  A[7][14]=(-(8125.0/9072.0)*Jinv00*M00*Jinv01-(8125.0/9072.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(8125.0/18144.0)*Jinv00*M10*Jinv11-(8125.0/18144.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv00*M01*Jinv10-(8125.0/18144.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01-(3125.0/9072.0)*Jinv00*M10*Jinv10-(8125.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[7][15]=(-(625.0/336.0)*Jinv00*M00*Jinv01-(625.0/336.0)*Jinv11*Jinv10*M11+(49375.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/672.0)*Jinv00*M10*Jinv11-(625.0/672.0)*M01*Jinv10*Jinv01+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(625.0/672.0)*Jinv00*M01*Jinv11+(49375.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(625.0/672.0)*M10*Jinv10*Jinv01)*D;
  A[7][16]=((3125.0/1134.0)*Jinv00*M00*Jinv01+(3125.0/1134.0)*Jinv11*Jinv10*M11+(3125.0/1134.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(3125.0/1134.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[7][17]=(-(8125.0/9072.0)*Jinv00*M00*Jinv01-(8125.0/9072.0)*Jinv11*Jinv10*M11-(3125.0/9072.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(8125.0/18144.0)*Jinv00*M10*Jinv11-(8125.0/18144.0)*M01*Jinv10*Jinv01-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(8125.0/18144.0)*Jinv00*M01*Jinv11-(3125.0/9072.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(8125.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[7][18]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*M10*Jinv11*Jinv01+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*(Jinv11*Jinv11)*M11+(38125.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*M00*(Jinv01*Jinv01)-(625.0/1344.0)*M01*Jinv11*Jinv01+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][19]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*M10*Jinv11*Jinv01-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(38125.0/145152.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*M00*(Jinv01*Jinv01)-(96875.0/145152.0)*M01*Jinv11*Jinv01-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[7][20]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[8][0]=(-(15625.0/145152.0)*Jinv00*M00*Jinv01-(15625.0/145152.0)*Jinv11*Jinv10*M11-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M10*Jinv11-(15625.0/290304.0)*M01*Jinv10*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*Jinv00*M01*Jinv11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M01*Jinv11*Jinv01-(15625.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[8][1]=((180625.0/145152.0)*Jinv00*M00*Jinv01+(180625.0/145152.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*M10*Jinv11*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(180625.0/290304.0)*Jinv00*M10*Jinv11+(180625.0/290304.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv00*M01*Jinv10+(180625.0/290304.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*M00*(Jinv01*Jinv01)+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M01*Jinv11*Jinv01+(14375.0/290304.0)*Jinv00*M10*Jinv10+(180625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[8][2]=(-(233125.0/48384.0)*Jinv00*M00*Jinv01-(233125.0/48384.0)*Jinv11*Jinv10*M11-(184375.0/48384.0)*M10*Jinv11*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(233125.0/96768.0)*Jinv00*M10*Jinv11-(233125.0/96768.0)*M01*Jinv10*Jinv01-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv00*M01*Jinv10-(233125.0/96768.0)*Jinv00*M01*Jinv11-(184375.0/48384.0)*M00*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M01*Jinv11*Jinv01+(625.0/145152.0)*Jinv00*M10*Jinv10-(233125.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[8][3]=((700625.0/145152.0)*Jinv00*M00*Jinv01+(700625.0/145152.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(700625.0/290304.0)*Jinv00*M10*Jinv11+(700625.0/290304.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv00*M01*Jinv10+(700625.0/290304.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01+(625.0/145152.0)*Jinv00*M10*Jinv10+(700625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[8][4]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*Jinv00*M01*Jinv10-(11875.0/20736.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv00*M10*Jinv10-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[8][5]=(-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[8][6]=((8125.0/5184.0)*Jinv00*M00*Jinv01+(8125.0/5184.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*M10*Jinv11*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(8125.0/10368.0)*Jinv00*M10*Jinv11+(8125.0/10368.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv00*M01*Jinv10+(8125.0/10368.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*M00*(Jinv01*Jinv01)+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M01*Jinv11*Jinv01+(3125.0/2304.0)*Jinv00*M10*Jinv10+(8125.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[8][7]=(-(221875.0/36288.0)*Jinv00*M00*Jinv01-(221875.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/1728.0)*M10*Jinv11*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(221875.0/72576.0)*Jinv00*M10*Jinv11-(221875.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv00*M01*Jinv10-(221875.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/1728.0)*M00*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M01*Jinv11*Jinv01-(21875.0/3456.0)*Jinv00*M10*Jinv10-(221875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[8][8]=((34375.0/3456.0)*Jinv00*M00*Jinv01+(34375.0/3456.0)*Jinv11*Jinv10*M11+(209375.0/24192.0)*M10*Jinv11*Jinv01+(34375.0/3456.0)*(Jinv00*Jinv00)*M00+(34375.0/6912.0)*Jinv00*M10*Jinv11+(34375.0/6912.0)*M01*Jinv10*Jinv01+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/3456.0)*Jinv00*M01*Jinv10+(34375.0/6912.0)*Jinv00*M01*Jinv11+(209375.0/24192.0)*M00*(Jinv01*Jinv01)+(34375.0/3456.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M01*Jinv11*Jinv01+(34375.0/3456.0)*Jinv00*M10*Jinv10+(34375.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[8][9]=(-(59375.0/9072.0)*Jinv00*M00*Jinv01-(59375.0/9072.0)*Jinv11*Jinv10*M11-(146875.0/72576.0)*M10*Jinv11*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(59375.0/18144.0)*Jinv00*M10*Jinv11-(59375.0/18144.0)*M01*Jinv10*Jinv01-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv00*M01*Jinv10-(59375.0/18144.0)*Jinv00*M01*Jinv11-(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M01*Jinv11*Jinv01-(21875.0/3456.0)*Jinv00*M10*Jinv10-(59375.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[8][10]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*Jinv00*M01*Jinv10+(11875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv00*M10*Jinv10+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[8][11]=(-(45625.0/48384.0)*Jinv00*M00*Jinv01-(45625.0/48384.0)*Jinv11*Jinv10*M11-(23125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(45625.0/96768.0)*Jinv00*M10*Jinv11-(45625.0/96768.0)*M01*Jinv10*Jinv01-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv00*M01*Jinv10-(45625.0/96768.0)*Jinv00*M01*Jinv11-(23125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/8064.0)*Jinv00*M10*Jinv10-(45625.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[8][12]=((246875.0/48384.0)*Jinv00*M00*Jinv01+(246875.0/48384.0)*Jinv11*Jinv10*M11-(3125.0/8064.0)*M10*Jinv11*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(246875.0/96768.0)*Jinv00*M10*Jinv11+(246875.0/96768.0)*M01*Jinv10*Jinv01-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv00*M01*Jinv10+(246875.0/96768.0)*Jinv00*M01*Jinv11-(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M01*Jinv11*Jinv01-(3125.0/8064.0)*Jinv00*M10*Jinv10+(246875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[8][13]=(-(40625.0/6912.0)*Jinv00*M00*Jinv01-(40625.0/6912.0)*Jinv11*Jinv10*M11-(40625.0/6912.0)*M10*Jinv11*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/13824.0)*Jinv00*M10*Jinv11-(40625.0/13824.0)*M01*Jinv10*Jinv01-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv00*M01*Jinv10-(40625.0/13824.0)*Jinv00*M01*Jinv11-(40625.0/6912.0)*M00*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M01*Jinv11*Jinv01-(3125.0/8064.0)*Jinv00*M10*Jinv10-(40625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[8][14]=((11875.0/6912.0)*Jinv00*M00*Jinv01+(11875.0/6912.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(11875.0/13824.0)*Jinv00*M10*Jinv11+(11875.0/13824.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv00*M01*Jinv10+(11875.0/13824.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01+(3125.0/8064.0)*Jinv00*M10*Jinv10+(11875.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[8][15]=(-(6875.0/10368.0)*Jinv00*M00*Jinv01-(6875.0/10368.0)*Jinv11*Jinv10*M11+(11875.0/36288.0)*M10*Jinv11*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/20736.0)*Jinv00*M10*Jinv11-(6875.0/20736.0)*M01*Jinv10*Jinv01+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/20736.0)*Jinv00*M01*Jinv11+(11875.0/36288.0)*M00*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M01*Jinv11*Jinv01+(3125.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[8][16]=(-(3125.0/36288.0)*Jinv00*M00*Jinv01-(3125.0/36288.0)*Jinv11*Jinv10*M11+(34375.0/24192.0)*M10*Jinv11*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00-(3125.0/72576.0)*Jinv00*M10*Jinv11-(3125.0/72576.0)*M01*Jinv10*Jinv01+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv00*M01*Jinv10-(3125.0/72576.0)*Jinv00*M01*Jinv11+(34375.0/24192.0)*M00*(Jinv01*Jinv01)-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M01*Jinv11*Jinv01-(3125.0/36288.0)*Jinv00*M10*Jinv10-(3125.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[8][17]=((18125.0/24192.0)*Jinv00*M00*Jinv01+(18125.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(18125.0/48384.0)*Jinv00*M10*Jinv11+(18125.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv00*M01*Jinv10+(18125.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/72576.0)*Jinv00*M10*Jinv10+(18125.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[8][18]=((10625.0/72576.0)*Jinv00*M00*Jinv01+(10625.0/72576.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*M10*Jinv11*Jinv01+(10625.0/145152.0)*Jinv00*M10*Jinv11+(10625.0/145152.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*(Jinv11*Jinv11)*M11+(10625.0/145152.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*M00*(Jinv01*Jinv01)-(79375.0/290304.0)*M01*Jinv11*Jinv01+(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[8][19]=(-(10625.0/72576.0)*Jinv00*M00*Jinv01-(10625.0/72576.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*M10*Jinv11*Jinv01-(10625.0/145152.0)*Jinv00*M10*Jinv11-(10625.0/145152.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(10625.0/145152.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*M00*(Jinv01*Jinv01)-(40625.0/96768.0)*M01*Jinv11*Jinv01-(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[8][20]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[9][0]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[9][1]=(-(105625.0/72576.0)*Jinv00*M00*Jinv01-(105625.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*M10*Jinv11*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(105625.0/145152.0)*Jinv00*M10*Jinv11-(105625.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv00*M01*Jinv10-(105625.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*M00*(Jinv01*Jinv01)-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M01*Jinv11*Jinv01-(625.0/1344.0)*Jinv00*M10*Jinv10-(105625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[9][2]=((116875.0/36288.0)*Jinv00*M00*Jinv01+(116875.0/36288.0)*Jinv11*Jinv10*M11+(146875.0/72576.0)*M10*Jinv11*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(116875.0/72576.0)*Jinv00*M10*Jinv11+(116875.0/72576.0)*M01*Jinv10*Jinv01+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv00*M01*Jinv10+(116875.0/72576.0)*Jinv00*M01*Jinv11+(146875.0/72576.0)*M00*(Jinv01*Jinv01)+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M01*Jinv11*Jinv01+(49375.0/72576.0)*Jinv00*M10*Jinv10+(116875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][3]=(-(6875.0/1296.0)*Jinv00*M00*Jinv01-(6875.0/1296.0)*Jinv11*Jinv10*M11-(71875.0/18144.0)*M10*Jinv11*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/2592.0)*Jinv00*M10*Jinv11-(6875.0/2592.0)*M01*Jinv10*Jinv01-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/2592.0)*Jinv00*M01*Jinv11-(71875.0/18144.0)*M00*(Jinv01*Jinv01)-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M01*Jinv11*Jinv01-(44375.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/2592.0)*M10*Jinv10*Jinv01)*D;
  A[9][4]=((120625.0/36288.0)*Jinv00*M00*Jinv01+(120625.0/36288.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*Jinv00*M10*Jinv11+(120625.0/72576.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*Jinv00*M01*Jinv10+(120625.0/72576.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv00*M10*Jinv10+(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][5]=(-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv00*M01*Jinv10-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv00*M10*Jinv10)*D;
  A[9][6]=(-(29375.0/36288.0)*Jinv00*M00*Jinv01-(29375.0/36288.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*M10*Jinv11*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(29375.0/72576.0)*Jinv00*M10*Jinv11-(29375.0/72576.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv00*M01*Jinv10-(29375.0/72576.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*M00*(Jinv01*Jinv01)-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M01*Jinv11*Jinv01-(96875.0/145152.0)*Jinv00*M10*Jinv10-(29375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][7]=((3125.0/1134.0)*Jinv00*M00*Jinv01+(3125.0/1134.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/1134.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[9][8]=(-(59375.0/9072.0)*Jinv00*M00*Jinv01-(59375.0/9072.0)*Jinv11*Jinv10*M11-(146875.0/72576.0)*M10*Jinv11*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(59375.0/18144.0)*Jinv00*M10*Jinv11-(59375.0/18144.0)*M01*Jinv10*Jinv01-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv00*M01*Jinv10-(59375.0/18144.0)*Jinv00*M01*Jinv11-(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M01*Jinv11*Jinv01-(21875.0/3456.0)*Jinv00*M10*Jinv10-(59375.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[9][9]=((71875.0/9072.0)*Jinv00*M00*Jinv01+(71875.0/9072.0)*Jinv11*Jinv10*M11+(71875.0/9072.0)*M10*Jinv11*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(71875.0/18144.0)*Jinv00*M10*Jinv11+(71875.0/18144.0)*M01*Jinv10*Jinv01+(71875.0/9072.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv00*M01*Jinv10+(71875.0/18144.0)*Jinv00*M01*Jinv11+(71875.0/9072.0)*M00*(Jinv01*Jinv01)+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(71875.0/9072.0)*M01*Jinv11*Jinv01+(128125.0/18144.0)*Jinv00*M10*Jinv10+(71875.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[9][10]=(-(120625.0/36288.0)*Jinv00*M00*Jinv01-(120625.0/36288.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*Jinv00*M10*Jinv11-(120625.0/72576.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*Jinv00*M01*Jinv10-(120625.0/72576.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv00*M10*Jinv10-(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][11]=((625.0/3024.0)*Jinv00*M00*Jinv01+(625.0/3024.0)*Jinv11*Jinv10*M11+(625.0/18144.0)*M10*Jinv11*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv00*M10*Jinv11+(625.0/6048.0)*M01*Jinv10*Jinv01+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv00*M01*Jinv10+(625.0/6048.0)*Jinv00*M01*Jinv11+(625.0/18144.0)*M00*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M01*Jinv11*Jinv01-(3125.0/9072.0)*Jinv00*M10*Jinv10+(625.0/6048.0)*M10*Jinv10*Jinv01)*D;
  A[9][12]=(-(3125.0/36288.0)*Jinv00*M00*Jinv01-(3125.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/36288.0)*M10*Jinv11*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/72576.0)*Jinv00*M10*Jinv11-(3125.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv00*M01*Jinv10-(3125.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/36288.0)*M00*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M01*Jinv11*Jinv01+(34375.0/24192.0)*Jinv00*M10*Jinv10-(3125.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][13]=((90625.0/36288.0)*Jinv00*M00*Jinv01+(90625.0/36288.0)*Jinv11*Jinv10*M11-(146875.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00+(90625.0/72576.0)*Jinv00*M10*Jinv11+(90625.0/72576.0)*M01*Jinv10*Jinv01-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv00*M01*Jinv10+(90625.0/72576.0)*Jinv00*M01*Jinv11-(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/1728.0)*Jinv00*M10*Jinv10+(90625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[9][14]=(-(11875.0/4536.0)*Jinv00*M00*Jinv01-(11875.0/4536.0)*Jinv11*Jinv10*M11-(71875.0/18144.0)*M10*Jinv11*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(11875.0/9072.0)*Jinv00*M10*Jinv11-(11875.0/9072.0)*M01*Jinv10*Jinv01-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv00*M01*Jinv10-(11875.0/9072.0)*Jinv00*M01*Jinv11-(71875.0/18144.0)*M00*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M01*Jinv11*Jinv01+(53125.0/72576.0)*Jinv00*M10*Jinv10-(11875.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[9][15]=(-(625.0/4536.0)*Jinv00*M00*Jinv01-(625.0/4536.0)*Jinv11*Jinv10*M11+(625.0/18144.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/9072.0)*Jinv00*M10*Jinv11-(625.0/9072.0)*M01*Jinv10*Jinv01+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(625.0/9072.0)*Jinv00*M01*Jinv11+(625.0/18144.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(625.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[9][16]=(-(3125.0/4536.0)*Jinv00*M00*Jinv01-(3125.0/4536.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv00*M10*Jinv11-(3125.0/9072.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10-(3125.0/9072.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10-(3125.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[9][17]=((625.0/756.0)*Jinv00*M00*Jinv01+(625.0/756.0)*Jinv11*Jinv10*M11+(146875.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/1512.0)*Jinv00*M10*Jinv11+(625.0/1512.0)*M01*Jinv10*Jinv01+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10+(625.0/1512.0)*Jinv00*M01*Jinv11+(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10+(625.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[9][18]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*M10*Jinv11*Jinv01+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*(Jinv11*Jinv11)*M11+(38125.0/145152.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*M00*(Jinv01*Jinv01)-(6875.0/48384.0)*M01*Jinv11*Jinv01+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[9][19]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*M10*Jinv11*Jinv01-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(38125.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/72576.0)*M01*Jinv11*Jinv01-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[9][20]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[10][0]=(-(1975.0/24192.0)*Jinv00*M00*Jinv01-(1975.0/24192.0)*Jinv11*Jinv10*M11-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M10*Jinv11-(1975.0/48384.0)*M01*Jinv10*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*Jinv00*M01*Jinv11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M01*Jinv11*Jinv01-(1975.0/48384.0)*Jinv00*M10*Jinv10-(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[10][1]=((78125.0/145152.0)*Jinv00*M00*Jinv01+(78125.0/145152.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*M10*Jinv11*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(78125.0/290304.0)*Jinv00*M10*Jinv11+(78125.0/290304.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv00*M01*Jinv10+(78125.0/290304.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*M00*(Jinv01*Jinv01)+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M01*Jinv11*Jinv01+(14375.0/72576.0)*Jinv00*M10*Jinv10+(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[10][2]=(-(6875.0/5184.0)*Jinv00*M00*Jinv01-(6875.0/5184.0)*Jinv11*Jinv10*M11-(8125.0/9072.0)*M10*Jinv11*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(6875.0/10368.0)*Jinv00*M10*Jinv11-(6875.0/10368.0)*M01*Jinv10*Jinv01-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv00*M01*Jinv10-(6875.0/10368.0)*Jinv00*M01*Jinv11-(8125.0/9072.0)*M00*(Jinv01*Jinv01)-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M01*Jinv11*Jinv01-(104375.0/290304.0)*Jinv00*M10*Jinv10-(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[10][3]=((41875.0/24192.0)*Jinv00*M00*Jinv01+(41875.0/24192.0)*Jinv11*Jinv10*M11+(625.0/448.0)*M10*Jinv11*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(41875.0/48384.0)*Jinv00*M10*Jinv11+(41875.0/48384.0)*M01*Jinv10*Jinv01+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv00*M01*Jinv10+(41875.0/48384.0)*Jinv00*M01*Jinv11+(625.0/448.0)*M00*(Jinv01*Jinv01)+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M01*Jinv11*Jinv01+(11875.0/41472.0)*Jinv00*M10*Jinv10+(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[10][4]=(-(53125.0/20736.0)*Jinv00*M00*Jinv01-(53125.0/20736.0)*Jinv11*Jinv10*M11-(53125.0/20736.0)*M10*Jinv11*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/41472.0)*Jinv00*M10*Jinv11-(53125.0/41472.0)*M01*Jinv10*Jinv01-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv00*M01*Jinv10-(53125.0/41472.0)*Jinv00*M01*Jinv11-(53125.0/20736.0)*M00*(Jinv01*Jinv01)-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M01*Jinv11*Jinv01-(11875.0/41472.0)*Jinv00*M10*Jinv10-(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[10][5]=((123425.0/145152.0)*Jinv00*M00*Jinv01+(123425.0/145152.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv00*M01*Jinv10+(123425.0/145152.0)*Jinv00*M01*Jinv11+(725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv00*M10*Jinv10+(123425.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[10][6]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/48384.0)*Jinv00*M01*Jinv10+(6875.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv00*M10*Jinv10+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[10][7]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*Jinv00*M01*Jinv10-(38125.0/145152.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv00*M10*Jinv10-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[10][8]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*Jinv00*M01*Jinv10+(11875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv00*M10*Jinv10+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[10][9]=(-(120625.0/36288.0)*Jinv00*M00*Jinv01-(120625.0/36288.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*Jinv00*M10*Jinv11-(120625.0/72576.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*Jinv00*M01*Jinv10-(120625.0/72576.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv00*M10*Jinv10-(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[10][10]=((53125.0/20736.0)*Jinv00*M00*Jinv01+(53125.0/20736.0)*Jinv11*Jinv10*M11+(53125.0/20736.0)*M10*Jinv11*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/41472.0)*Jinv00*M10*Jinv11+(53125.0/41472.0)*M01*Jinv10*Jinv01+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv00*M01*Jinv10+(53125.0/41472.0)*Jinv00*M01*Jinv11+(53125.0/20736.0)*M00*(Jinv01*Jinv01)+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M01*Jinv11*Jinv01+(6875.0/3456.0)*Jinv00*M10*Jinv10+(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[10][11]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*Jinv00*M01*Jinv10+(625.0/20736.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv00*M10*Jinv10+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[10][12]=(-(10625.0/72576.0)*Jinv00*M00*Jinv01-(10625.0/72576.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*Jinv00*M10*Jinv11-(10625.0/145152.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*Jinv00*M01*Jinv10-(10625.0/145152.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv00*M10*Jinv10-(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[10][13]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*Jinv00*M01*Jinv10+(11875.0/20736.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv00*M10*Jinv10+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[10][14]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11-(625.0/448.0)*M10*Jinv11*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00+(115625.0/145152.0)*Jinv00*M10*Jinv11+(115625.0/145152.0)*M01*Jinv10*Jinv01-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv00*M01*Jinv10-(25625.0/48384.0)*Jinv00*M01*Jinv11-(625.0/448.0)*M00*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M01*Jinv11*Jinv01-(263125.0/290304.0)*Jinv00*M10*Jinv10-(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[10][15]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*Jinv00*M01*Jinv10+(625.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv00*M10*Jinv10+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[10][16]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*Jinv00*M01*Jinv10-(38125.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv00*M10*Jinv10-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[10][17]=(-(18125.0/72576.0)*Jinv00*M00*Jinv01-(18125.0/72576.0)*Jinv11*Jinv10*M11+(8125.0/9072.0)*M10*Jinv11*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/1296.0)*Jinv00*M10*Jinv11-(625.0/1296.0)*M01*Jinv10*Jinv01+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv00*M01*Jinv10+(625.0/2688.0)*Jinv00*M01*Jinv11+(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M01*Jinv11*Jinv01+(59375.0/72576.0)*Jinv00*M10*Jinv10+(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[10][18]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*Jinv00*M01*Jinv10+(6875.0/96768.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv00*M10*Jinv10+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[10][19]=((3125.0/12096.0)*Jinv00*M00*Jinv01+(3125.0/12096.0)*Jinv11*Jinv10*M11-(49375.0/145152.0)*M10*Jinv11*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(10625.0/32256.0)*Jinv00*M10*Jinv11+(10625.0/32256.0)*M01*Jinv10*Jinv01-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv00*M01*Jinv10-(6875.0/96768.0)*Jinv00*M01*Jinv11-(49375.0/145152.0)*M00*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M01*Jinv11*Jinv01-(49375.0/145152.0)*Jinv00*M10*Jinv10-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[10][20]=(-(1675.0/10368.0)*Jinv00*M00*Jinv01-(1675.0/10368.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*M10*Jinv11*Jinv01-(1675.0/10368.0)*Jinv00*M10*Jinv11-(1675.0/10368.0)*M01*Jinv10*Jinv01+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*M00*(Jinv01*Jinv01)+(1975.0/48384.0)*M01*Jinv11*Jinv01)*D;
  A[11][0]=((41975.0/72576.0)*Jinv00*M00*Jinv01+(41975.0/72576.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*M10*Jinv11*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv00*M10*Jinv11-(575.0/36288.0)*M01*Jinv10*Jinv01+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv00*M01*Jinv10+(14375.0/24192.0)*Jinv00*M01*Jinv11+(14375.0/24192.0)*M00*(Jinv01*Jinv01)-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M01*Jinv11*Jinv01-(575.0/36288.0)*Jinv00*M10*Jinv10+(14375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[11][1]=(-(168125.0/145152.0)*Jinv00*M00*Jinv01-(168125.0/145152.0)*Jinv11*Jinv10*M11+(11875.0/41472.0)*M10*Jinv11*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(168125.0/290304.0)*Jinv00*M10*Jinv11-(168125.0/290304.0)*M01*Jinv10*Jinv01+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv00*M01*Jinv10-(168125.0/290304.0)*Jinv00*M01*Jinv11+(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M01*Jinv11*Jinv01-(14375.0/290304.0)*Jinv00*M10*Jinv10-(168125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[11][2]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(625.0/6048.0)*M10*Jinv11*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(625.0/6048.0)*M00*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M01*Jinv11*Jinv01+(625.0/6048.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[11][3]=((625.0/6912.0)*Jinv00*M00*Jinv01+(625.0/6912.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/13824.0)*Jinv00*M10*Jinv11+(625.0/13824.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv00*M01*Jinv10+(625.0/13824.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(8125.0/72576.0)*Jinv00*M10*Jinv10+(625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[11][4]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[11][5]=(-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv00*M10*Jinv10)*D;
  A[11][6]=(-(14375.0/6912.0)*Jinv00*M00*Jinv01-(14375.0/6912.0)*Jinv11*Jinv10*M11-(745625.0/290304.0)*M10*Jinv11*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/41472.0)*Jinv00*M10*Jinv11-(15625.0/41472.0)*M01*Jinv10*Jinv01-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv00*M01*Jinv10-(70625.0/41472.0)*Jinv00*M01*Jinv11-(745625.0/290304.0)*M00*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M01*Jinv11*Jinv01-(263125.0/290304.0)*Jinv00*M10*Jinv10-(70625.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[11][7]=((49375.0/12096.0)*Jinv00*M00*Jinv01+(49375.0/12096.0)*Jinv11*Jinv10*M11-(44375.0/72576.0)*M10*Jinv11*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/24192.0)*Jinv00*M10*Jinv11+(49375.0/24192.0)*M01*Jinv10*Jinv01-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv00*M01*Jinv10+(49375.0/24192.0)*Jinv00*M01*Jinv11-(44375.0/72576.0)*M00*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M01*Jinv11*Jinv01+(53125.0/72576.0)*Jinv00*M10*Jinv10+(49375.0/24192.0)*M10*Jinv10*Jinv01)*D;
  A[11][8]=(-(45625.0/48384.0)*Jinv00*M00*Jinv01-(45625.0/48384.0)*Jinv11*Jinv10*M11-(23125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(45625.0/96768.0)*Jinv00*M10*Jinv11-(45625.0/96768.0)*M01*Jinv10*Jinv01-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv00*M01*Jinv10-(45625.0/96768.0)*Jinv00*M01*Jinv11-(23125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/8064.0)*Jinv00*M10*Jinv10-(45625.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[11][9]=((625.0/3024.0)*Jinv00*M00*Jinv01+(625.0/3024.0)*Jinv11*Jinv10*M11+(625.0/18144.0)*M10*Jinv11*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv00*M10*Jinv11+(625.0/6048.0)*M01*Jinv10*Jinv01+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv00*M01*Jinv10+(625.0/6048.0)*Jinv00*M01*Jinv11+(625.0/18144.0)*M00*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M01*Jinv11*Jinv01-(3125.0/9072.0)*Jinv00*M10*Jinv10+(625.0/6048.0)*M10*Jinv10*Jinv01)*D;
  A[11][10]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*Jinv00*M01*Jinv10+(625.0/20736.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv00*M10*Jinv10+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[11][11]=((4375.0/1152.0)*Jinv00*M00*Jinv01+(4375.0/1152.0)*Jinv11*Jinv10*M11+(11875.0/2688.0)*M10*Jinv11*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(4375.0/2304.0)*Jinv00*M10*Jinv11+(4375.0/2304.0)*M01*Jinv10*Jinv01+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv00*M01*Jinv10+(4375.0/2304.0)*Jinv00*M01*Jinv11+(11875.0/2688.0)*M00*(Jinv01*Jinv01)+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M01*Jinv11*Jinv01+(10625.0/3456.0)*Jinv00*M10*Jinv10+(4375.0/2304.0)*M10*Jinv10*Jinv01)*D;
  A[11][12]=(-(233125.0/48384.0)*Jinv00*M00*Jinv01-(233125.0/48384.0)*Jinv11*Jinv10*M11+(625.0/145152.0)*M10*Jinv11*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00-(233125.0/96768.0)*Jinv00*M10*Jinv11-(233125.0/96768.0)*M01*Jinv10*Jinv01+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv00*M01*Jinv10-(233125.0/96768.0)*Jinv00*M01*Jinv11+(625.0/145152.0)*M00*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M01*Jinv11*Jinv01-(184375.0/48384.0)*Jinv00*M10*Jinv10-(233125.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[11][13]=((10625.0/8064.0)*Jinv00*M00*Jinv01+(10625.0/8064.0)*Jinv11*Jinv10*M11+(11875.0/36288.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(10625.0/16128.0)*Jinv00*M10*Jinv11+(10625.0/16128.0)*M01*Jinv10*Jinv01+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(10625.0/16128.0)*Jinv00*M01*Jinv11+(11875.0/36288.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(10625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[11][14]=(-(14375.0/48384.0)*Jinv00*M00*Jinv01-(14375.0/48384.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(14375.0/96768.0)*Jinv00*M10*Jinv11-(14375.0/96768.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv00*M01*Jinv10-(14375.0/96768.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(14375.0/48384.0)*Jinv00*M10*Jinv10-(14375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[11][15]=(-(574375.0/145152.0)*Jinv00*M00*Jinv01-(574375.0/145152.0)*Jinv11*Jinv10*M11-(574375.0/145152.0)*M10*Jinv11*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(726875.0/290304.0)*Jinv00*M10*Jinv11-(726875.0/290304.0)*M01*Jinv10*Jinv01-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv00*M01*Jinv10-(15625.0/10752.0)*Jinv00*M01*Jinv11-(574375.0/145152.0)*M00*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M01*Jinv11*Jinv01-(261875.0/145152.0)*Jinv00*M10*Jinv10-(15625.0/10752.0)*M10*Jinv10*Jinv01)*D;
  A[11][16]=((116875.0/36288.0)*Jinv00*M00*Jinv01+(116875.0/36288.0)*Jinv11*Jinv10*M11+(49375.0/72576.0)*M10*Jinv11*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(116875.0/72576.0)*Jinv00*M10*Jinv11+(116875.0/72576.0)*M01*Jinv10*Jinv01+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv00*M01*Jinv10+(116875.0/72576.0)*Jinv00*M01*Jinv11+(49375.0/72576.0)*M00*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M01*Jinv11*Jinv01+(146875.0/72576.0)*Jinv00*M10*Jinv10+(116875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[11][17]=(-(45625.0/145152.0)*Jinv00*M00*Jinv01-(45625.0/145152.0)*Jinv11*Jinv10*M11-(8125.0/72576.0)*M10*Jinv11*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(45625.0/290304.0)*Jinv00*M10*Jinv11-(45625.0/290304.0)*M01*Jinv10*Jinv01-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv00*M01*Jinv10-(45625.0/290304.0)*Jinv00*M01*Jinv11-(8125.0/72576.0)*M00*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M01*Jinv11*Jinv01-(10625.0/48384.0)*Jinv00*M10*Jinv10-(45625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[11][18]=((49375.0/24192.0)*Jinv00*M00*Jinv01+(49375.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/6048.0)*M10*Jinv11*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv00*M01*Jinv10+(6875.0/10368.0)*Jinv00*M01*Jinv11+(11875.0/6048.0)*M00*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M01*Jinv11*Jinv01+(8125.0/9072.0)*Jinv00*M10*Jinv10+(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[11][19]=(-(6875.0/5184.0)*Jinv00*M00*Jinv01-(6875.0/5184.0)*Jinv11*Jinv10*M11-(104375.0/290304.0)*M10*Jinv11*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(6875.0/10368.0)*Jinv00*M10*Jinv11-(6875.0/10368.0)*M01*Jinv10*Jinv01-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv00*M01*Jinv10-(6875.0/10368.0)*Jinv00*M01*Jinv11-(104375.0/290304.0)*M00*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M01*Jinv11*Jinv01-(8125.0/9072.0)*Jinv00*M10*Jinv10-(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[11][20]=(-(575.0/1512.0)*Jinv00*M00*Jinv01-(575.0/1512.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*M10*Jinv11*Jinv01-(575.0/1512.0)*Jinv00*M10*Jinv11-(575.0/1512.0)*M01*Jinv10*Jinv01-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*M00*(Jinv01*Jinv01)-(130625.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[12][0]=(-(15625.0/145152.0)*Jinv00*M00*Jinv01-(15625.0/145152.0)*Jinv11*Jinv10*M11-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M10*Jinv11-(15625.0/290304.0)*M01*Jinv10*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*Jinv00*M01*Jinv11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M01*Jinv11*Jinv01-(15625.0/290304.0)*Jinv00*M10*Jinv10-(15625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[12][1]=((8125.0/5184.0)*Jinv00*M00*Jinv01+(8125.0/5184.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*M10*Jinv11*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(8125.0/10368.0)*Jinv00*M10*Jinv11+(8125.0/10368.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv00*M01*Jinv10+(8125.0/10368.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*M00*(Jinv01*Jinv01)+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M01*Jinv11*Jinv01+(4375.0/20736.0)*Jinv00*M10*Jinv10+(8125.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[12][2]=(-(45625.0/48384.0)*Jinv00*M00*Jinv01-(45625.0/48384.0)*Jinv11*Jinv10*M11+(3125.0/8064.0)*M10*Jinv11*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00-(45625.0/96768.0)*Jinv00*M10*Jinv11-(45625.0/96768.0)*M01*Jinv10*Jinv01+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv00*M01*Jinv10-(45625.0/96768.0)*Jinv00*M01*Jinv11+(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M01*Jinv11*Jinv01-(23125.0/72576.0)*Jinv00*M10*Jinv10-(45625.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[12][3]=(-(6875.0/10368.0)*Jinv00*M00*Jinv01-(6875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/72576.0)*M10*Jinv11*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00-(6875.0/20736.0)*Jinv00*M10*Jinv11-(6875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv00*M01*Jinv10-(6875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/72576.0)*M00*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M01*Jinv11*Jinv01+(11875.0/36288.0)*Jinv00*M10*Jinv10-(6875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[12][4]=((10625.0/72576.0)*Jinv00*M00*Jinv01+(10625.0/72576.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*Jinv00*M10*Jinv11+(10625.0/145152.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*Jinv00*M01*Jinv10+(10625.0/145152.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv00*M10*Jinv10+(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[12][5]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[12][6]=((180625.0/145152.0)*Jinv00*M00*Jinv01+(180625.0/145152.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*M10*Jinv11*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(180625.0/290304.0)*Jinv00*M10*Jinv11+(180625.0/290304.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv00*M01*Jinv10+(180625.0/290304.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M01*Jinv11*Jinv01+(115625.0/96768.0)*Jinv00*M10*Jinv10+(180625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[12][7]=(-(221875.0/36288.0)*Jinv00*M00*Jinv01-(221875.0/36288.0)*Jinv11*Jinv10*M11-(21875.0/3456.0)*M10*Jinv11*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(221875.0/72576.0)*Jinv00*M10*Jinv11-(221875.0/72576.0)*M01*Jinv10*Jinv01-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv00*M01*Jinv10-(221875.0/72576.0)*Jinv00*M01*Jinv11-(21875.0/3456.0)*M00*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M01*Jinv11*Jinv01-(3125.0/1728.0)*Jinv00*M10*Jinv10-(221875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[12][8]=((246875.0/48384.0)*Jinv00*M00*Jinv01+(246875.0/48384.0)*Jinv11*Jinv10*M11-(3125.0/8064.0)*M10*Jinv11*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(246875.0/96768.0)*Jinv00*M10*Jinv11+(246875.0/96768.0)*M01*Jinv10*Jinv01-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv00*M01*Jinv10+(246875.0/96768.0)*Jinv00*M01*Jinv11-(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M01*Jinv11*Jinv01-(3125.0/8064.0)*Jinv00*M10*Jinv10+(246875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[12][9]=(-(3125.0/36288.0)*Jinv00*M00*Jinv01-(3125.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/36288.0)*M10*Jinv11*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/72576.0)*Jinv00*M10*Jinv11-(3125.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv00*M01*Jinv10-(3125.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/36288.0)*M00*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M01*Jinv11*Jinv01+(34375.0/24192.0)*Jinv00*M10*Jinv10-(3125.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[12][10]=(-(10625.0/72576.0)*Jinv00*M00*Jinv01-(10625.0/72576.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*Jinv00*M10*Jinv11-(10625.0/145152.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*Jinv00*M01*Jinv10-(10625.0/145152.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv00*M10*Jinv10-(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[12][11]=(-(233125.0/48384.0)*Jinv00*M00*Jinv01-(233125.0/48384.0)*Jinv11*Jinv10*M11+(625.0/145152.0)*M10*Jinv11*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00-(233125.0/96768.0)*Jinv00*M10*Jinv11-(233125.0/96768.0)*M01*Jinv10*Jinv01+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv00*M01*Jinv10-(233125.0/96768.0)*Jinv00*M01*Jinv11+(625.0/145152.0)*M00*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M01*Jinv11*Jinv01-(184375.0/48384.0)*Jinv00*M10*Jinv10-(233125.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[12][12]=((34375.0/3456.0)*Jinv00*M00*Jinv01+(34375.0/3456.0)*Jinv11*Jinv10*M11+(34375.0/3456.0)*M10*Jinv11*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/6912.0)*Jinv00*M10*Jinv11+(34375.0/6912.0)*M01*Jinv10*Jinv01+(34375.0/3456.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv00*M01*Jinv10+(34375.0/6912.0)*Jinv00*M01*Jinv11+(34375.0/3456.0)*M00*(Jinv01*Jinv01)+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/3456.0)*M01*Jinv11*Jinv01+(209375.0/24192.0)*Jinv00*M10*Jinv10+(34375.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[12][13]=(-(40625.0/6912.0)*Jinv00*M00*Jinv01-(40625.0/6912.0)*Jinv11*Jinv10*M11-(3125.0/8064.0)*M10*Jinv11*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(40625.0/13824.0)*Jinv00*M10*Jinv11-(40625.0/13824.0)*M01*Jinv10*Jinv01-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv00*M01*Jinv10-(40625.0/13824.0)*Jinv00*M01*Jinv11-(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M01*Jinv11*Jinv01-(40625.0/6912.0)*Jinv00*M10*Jinv10-(40625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[12][14]=((18125.0/24192.0)*Jinv00*M00*Jinv01+(18125.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(18125.0/48384.0)*Jinv00*M10*Jinv11+(18125.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(18125.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(18125.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[12][15]=((700625.0/145152.0)*Jinv00*M00*Jinv01+(700625.0/145152.0)*Jinv11*Jinv10*M11+(625.0/145152.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(700625.0/290304.0)*Jinv00*M10*Jinv11+(700625.0/290304.0)*M01*Jinv10*Jinv01+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(700625.0/290304.0)*Jinv00*M01*Jinv11+(625.0/145152.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(700625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[12][16]=(-(59375.0/9072.0)*Jinv00*M00*Jinv01-(59375.0/9072.0)*Jinv11*Jinv10*M11-(21875.0/3456.0)*M10*Jinv11*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(59375.0/18144.0)*Jinv00*M10*Jinv11-(59375.0/18144.0)*M01*Jinv10*Jinv01-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv00*M01*Jinv10-(59375.0/18144.0)*Jinv00*M01*Jinv11-(21875.0/3456.0)*M00*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M01*Jinv11*Jinv01-(146875.0/72576.0)*Jinv00*M10*Jinv10-(59375.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[12][17]=((11875.0/6912.0)*Jinv00*M00*Jinv01+(11875.0/6912.0)*Jinv11*Jinv10*M11+(3125.0/8064.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(11875.0/13824.0)*Jinv00*M10*Jinv11+(11875.0/13824.0)*M01*Jinv10*Jinv01+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(11875.0/13824.0)*Jinv00*M01*Jinv11+(3125.0/8064.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(11875.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[12][18]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*M10*Jinv11*Jinv01-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*(Jinv11*Jinv11)*M11-(11875.0/20736.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(14375.0/290304.0)*M01*Jinv11*Jinv01-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[12][19]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*M10*Jinv11*Jinv01+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(11875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*M00*(Jinv01*Jinv01)+(3125.0/2304.0)*M01*Jinv11*Jinv01+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[12][20]=(-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[13][0]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[13][1]=(-(14375.0/20736.0)*Jinv00*M00*Jinv01-(14375.0/20736.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*M10*Jinv11*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(14375.0/41472.0)*Jinv00*M10*Jinv11-(14375.0/41472.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv00*M01*Jinv10-(14375.0/41472.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*M00*(Jinv01*Jinv01)-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M01*Jinv11*Jinv01-(79375.0/290304.0)*Jinv00*M10*Jinv10-(14375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[13][2]=((10625.0/8064.0)*Jinv00*M00*Jinv01+(10625.0/8064.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(10625.0/16128.0)*Jinv00*M10*Jinv11+(10625.0/16128.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv00*M01*Jinv10+(10625.0/16128.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(11875.0/36288.0)*Jinv00*M10*Jinv10+(10625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[13][3]=((44375.0/145152.0)*Jinv00*M00*Jinv01+(44375.0/145152.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(44375.0/290304.0)*Jinv00*M10*Jinv11+(44375.0/290304.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv00*M01*Jinv10+(44375.0/290304.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01-(23125.0/72576.0)*Jinv00*M10*Jinv10+(44375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[13][4]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*Jinv00*M01*Jinv10-(11875.0/20736.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv00*M10*Jinv10-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[13][5]=(-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv00*M01*Jinv10-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv00*M10*Jinv10)*D;
  A[13][6]=(-(14375.0/20736.0)*Jinv00*M00*Jinv01-(14375.0/20736.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*M10*Jinv11*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(14375.0/41472.0)*Jinv00*M10*Jinv11-(14375.0/41472.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv00*M01*Jinv10-(14375.0/41472.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*M00*(Jinv01*Jinv01)-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M01*Jinv11*Jinv01-(40625.0/96768.0)*Jinv00*M10*Jinv10-(14375.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[13][7]=((53125.0/18144.0)*Jinv00*M00*Jinv01+(53125.0/18144.0)*Jinv11*Jinv10*M11+(34375.0/24192.0)*M10*Jinv11*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(53125.0/36288.0)*Jinv00*M10*Jinv11+(53125.0/36288.0)*M01*Jinv10*Jinv01+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv00*M01*Jinv10+(53125.0/36288.0)*Jinv00*M01*Jinv11+(34375.0/24192.0)*M00*(Jinv01*Jinv01)+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M01*Jinv11*Jinv01+(34375.0/24192.0)*Jinv00*M10*Jinv10+(53125.0/36288.0)*M10*Jinv10*Jinv01)*D;
  A[13][8]=(-(40625.0/6912.0)*Jinv00*M00*Jinv01-(40625.0/6912.0)*Jinv11*Jinv10*M11-(40625.0/6912.0)*M10*Jinv11*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/13824.0)*Jinv00*M10*Jinv11-(40625.0/13824.0)*M01*Jinv10*Jinv01-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv00*M01*Jinv10-(40625.0/13824.0)*Jinv00*M01*Jinv11-(40625.0/6912.0)*M00*(Jinv01*Jinv01)-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M01*Jinv11*Jinv01-(3125.0/8064.0)*Jinv00*M10*Jinv10-(40625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[13][9]=((90625.0/36288.0)*Jinv00*M00*Jinv01+(90625.0/36288.0)*Jinv11*Jinv10*M11-(146875.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00+(90625.0/72576.0)*Jinv00*M10*Jinv11+(90625.0/72576.0)*M01*Jinv10*Jinv01-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv00*M01*Jinv10+(90625.0/72576.0)*Jinv00*M01*Jinv11-(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/1728.0)*Jinv00*M10*Jinv10+(90625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[13][10]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*Jinv00*M01*Jinv10+(11875.0/20736.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv00*M10*Jinv10+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[13][11]=((10625.0/8064.0)*Jinv00*M00*Jinv01+(10625.0/8064.0)*Jinv11*Jinv10*M11+(11875.0/36288.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(10625.0/16128.0)*Jinv00*M10*Jinv11+(10625.0/16128.0)*M01*Jinv10*Jinv01+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(10625.0/16128.0)*Jinv00*M01*Jinv11+(11875.0/36288.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(10625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[13][12]=(-(40625.0/6912.0)*Jinv00*M00*Jinv01-(40625.0/6912.0)*Jinv11*Jinv10*M11-(3125.0/8064.0)*M10*Jinv11*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(40625.0/13824.0)*Jinv00*M10*Jinv11-(40625.0/13824.0)*M01*Jinv10*Jinv01-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv00*M01*Jinv10-(40625.0/13824.0)*Jinv00*M01*Jinv11-(3125.0/8064.0)*M00*(Jinv01*Jinv01)-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M01*Jinv11*Jinv01-(40625.0/6912.0)*Jinv00*M10*Jinv10-(40625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[13][13]=((59375.0/8064.0)*Jinv00*M00*Jinv01+(59375.0/8064.0)*Jinv11*Jinv10*M11+(209375.0/24192.0)*M10*Jinv11*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(59375.0/16128.0)*Jinv00*M10*Jinv11+(59375.0/16128.0)*M01*Jinv10*Jinv01+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv00*M01*Jinv10+(59375.0/16128.0)*Jinv00*M01*Jinv11+(209375.0/24192.0)*M00*(Jinv01*Jinv01)+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M01*Jinv11*Jinv01+(209375.0/24192.0)*Jinv00*M10*Jinv10+(59375.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[13][14]=(-(19375.0/6912.0)*Jinv00*M00*Jinv01-(19375.0/6912.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00-(19375.0/13824.0)*Jinv00*M10*Jinv11-(19375.0/13824.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv00*M01*Jinv10-(19375.0/13824.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01-(184375.0/48384.0)*Jinv00*M10*Jinv10-(19375.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[13][15]=((44375.0/145152.0)*Jinv00*M00*Jinv01+(44375.0/145152.0)*Jinv11*Jinv10*M11-(23125.0/72576.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(44375.0/290304.0)*Jinv00*M10*Jinv11+(44375.0/290304.0)*M01*Jinv10*Jinv01-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(44375.0/290304.0)*Jinv00*M01*Jinv11-(23125.0/72576.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(44375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[13][16]=((90625.0/36288.0)*Jinv00*M00*Jinv01+(90625.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/1728.0)*M10*Jinv11*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(90625.0/72576.0)*Jinv00*M10*Jinv11+(90625.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv00*M01*Jinv10+(90625.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/1728.0)*M00*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M01*Jinv11*Jinv01-(146875.0/72576.0)*Jinv00*M10*Jinv10+(90625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[13][17]=(-(19375.0/6912.0)*Jinv00*M00*Jinv01-(19375.0/6912.0)*Jinv11*Jinv10*M11-(184375.0/48384.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(19375.0/13824.0)*Jinv00*M10*Jinv11-(19375.0/13824.0)*M01*Jinv10*Jinv01-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10-(19375.0/13824.0)*Jinv00*M01*Jinv11-(184375.0/48384.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10-(19375.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[13][18]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*M10*Jinv11*Jinv01-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/20736.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*M00*(Jinv01*Jinv01)+(4375.0/20736.0)*M01*Jinv11*Jinv01-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[13][19]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*M10*Jinv11*Jinv01+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(11875.0/20736.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*M00*(Jinv01*Jinv01)+(115625.0/96768.0)*M01*Jinv11*Jinv01+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[13][20]=(-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[14][0]=(-(175.0/2304.0)*Jinv00*M00*Jinv01-(175.0/2304.0)*Jinv11*Jinv10*M11-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M10*Jinv11-(175.0/4608.0)*M01*Jinv10*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*Jinv00*M01*Jinv11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M01*Jinv11*Jinv01-(175.0/4608.0)*Jinv00*M10*Jinv10-(175.0/4608.0)*M10*Jinv10*Jinv01)*D;
  A[14][1]=((6875.0/24192.0)*Jinv00*M00*Jinv01+(6875.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*M10*Jinv11*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(6875.0/48384.0)*Jinv00*M10*Jinv11+(6875.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv00*M01*Jinv10+(6875.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*M00*(Jinv01*Jinv01)+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M01*Jinv11*Jinv01+(8125.0/72576.0)*Jinv00*M10*Jinv10+(6875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[14][2]=(-(45625.0/145152.0)*Jinv00*M00*Jinv01-(45625.0/145152.0)*Jinv11*Jinv10*M11-(10625.0/48384.0)*M10*Jinv11*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(45625.0/290304.0)*Jinv00*M10*Jinv11-(45625.0/290304.0)*M01*Jinv10*Jinv01-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv00*M01*Jinv10-(45625.0/290304.0)*Jinv00*M01*Jinv11-(10625.0/48384.0)*M00*(Jinv01*Jinv01)-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M01*Jinv11*Jinv01-(8125.0/72576.0)*Jinv00*M10*Jinv10-(45625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[14][3]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11+(19375.0/72576.0)*M10*Jinv11*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/145152.0)*Jinv00*M10*Jinv11+(19375.0/145152.0)*M01*Jinv10*Jinv01+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv00*M01*Jinv10+(19375.0/145152.0)*Jinv00*M01*Jinv11+(19375.0/72576.0)*M00*(Jinv01*Jinv01)+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M01*Jinv11*Jinv01+(625.0/6048.0)*Jinv00*M10*Jinv10+(19375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[14][4]=((25625.0/24192.0)*Jinv00*M00*Jinv01+(25625.0/24192.0)*Jinv11*Jinv10*M11+(625.0/448.0)*M10*Jinv11*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(25625.0/48384.0)*Jinv00*M10*Jinv11+(25625.0/48384.0)*M01*Jinv10*Jinv01+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv00*M01*Jinv10+(25625.0/48384.0)*Jinv00*M01*Jinv11+(625.0/448.0)*M00*(Jinv01*Jinv01)-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M01*Jinv11*Jinv01-(14375.0/290304.0)*Jinv00*M10*Jinv10+(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[14][5]=(-(6325.0/10368.0)*Jinv00*M00*Jinv01-(6325.0/10368.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv00*M01*Jinv10-(6325.0/10368.0)*Jinv00*M01*Jinv11-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv00*M10*Jinv10-(6325.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[14][6]=((29375.0/145152.0)*Jinv00*M00*Jinv01+(29375.0/145152.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(29375.0/290304.0)*Jinv00*M10*Jinv11+(29375.0/290304.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv00*M01*Jinv10+(29375.0/290304.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01+(38125.0/290304.0)*Jinv00*M10*Jinv10+(29375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[14][7]=(-(8125.0/9072.0)*Jinv00*M00*Jinv01-(8125.0/9072.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(8125.0/18144.0)*Jinv00*M10*Jinv11-(8125.0/18144.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv00*M01*Jinv10-(8125.0/18144.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01-(3125.0/9072.0)*Jinv00*M10*Jinv10-(8125.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[14][8]=((11875.0/6912.0)*Jinv00*M00*Jinv01+(11875.0/6912.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(11875.0/13824.0)*Jinv00*M10*Jinv11+(11875.0/13824.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv00*M01*Jinv10+(11875.0/13824.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01+(3125.0/8064.0)*Jinv00*M10*Jinv10+(11875.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[14][9]=(-(11875.0/4536.0)*Jinv00*M00*Jinv01-(11875.0/4536.0)*Jinv11*Jinv10*M11-(71875.0/18144.0)*M10*Jinv11*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(11875.0/9072.0)*Jinv00*M10*Jinv11-(11875.0/9072.0)*M01*Jinv10*Jinv01-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv00*M01*Jinv10-(11875.0/9072.0)*Jinv00*M01*Jinv11-(71875.0/18144.0)*M00*(Jinv01*Jinv01)+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M01*Jinv11*Jinv01+(53125.0/72576.0)*Jinv00*M10*Jinv10-(11875.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[14][10]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11-(625.0/448.0)*M10*Jinv11*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(25625.0/48384.0)*Jinv00*M10*Jinv11-(25625.0/48384.0)*M01*Jinv10*Jinv01-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv00*M01*Jinv10+(115625.0/145152.0)*Jinv00*M01*Jinv11-(625.0/448.0)*M00*(Jinv01*Jinv01)-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M01*Jinv11*Jinv01-(263125.0/290304.0)*Jinv00*M10*Jinv10+(115625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[14][11]=(-(14375.0/48384.0)*Jinv00*M00*Jinv01-(14375.0/48384.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(14375.0/96768.0)*Jinv00*M10*Jinv11-(14375.0/96768.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv00*M01*Jinv10-(14375.0/96768.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(14375.0/48384.0)*Jinv00*M10*Jinv10-(14375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[14][12]=((18125.0/24192.0)*Jinv00*M00*Jinv01+(18125.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(18125.0/48384.0)*Jinv00*M10*Jinv11+(18125.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(18125.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(18125.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[14][13]=(-(19375.0/6912.0)*Jinv00*M00*Jinv01-(19375.0/6912.0)*Jinv11*Jinv10*M11+(146875.0/145152.0)*M10*Jinv11*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00-(19375.0/13824.0)*Jinv00*M10*Jinv11-(19375.0/13824.0)*M01*Jinv10*Jinv01+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv00*M01*Jinv10-(19375.0/13824.0)*Jinv00*M01*Jinv11+(146875.0/145152.0)*M00*(Jinv01*Jinv01)-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M01*Jinv11*Jinv01-(184375.0/48384.0)*Jinv00*M10*Jinv10-(19375.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[14][14]=((8125.0/3456.0)*Jinv00*M00*Jinv01+(8125.0/3456.0)*Jinv11*Jinv10*M11+(89375.0/24192.0)*M10*Jinv11*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(8125.0/6912.0)*Jinv00*M10*Jinv11+(8125.0/6912.0)*M01*Jinv10*Jinv01+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv00*M01*Jinv10+(8125.0/6912.0)*Jinv00*M01*Jinv11+(89375.0/24192.0)*M00*(Jinv01*Jinv01)+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M01*Jinv11*Jinv01+(10625.0/3456.0)*Jinv00*M10*Jinv10+(8125.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[14][15]=(-(18125.0/145152.0)*Jinv00*M00*Jinv01-(18125.0/145152.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(18125.0/290304.0)*Jinv00*M10*Jinv11-(18125.0/290304.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv00*M01*Jinv10-(18125.0/290304.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(10625.0/48384.0)*Jinv00*M10*Jinv10-(18125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[14][16]=((625.0/756.0)*Jinv00*M00*Jinv01+(625.0/756.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/1512.0)*Jinv00*M10*Jinv11+(625.0/1512.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv00*M01*Jinv10+(625.0/1512.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(146875.0/72576.0)*Jinv00*M10*Jinv10+(625.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[14][17]=((625.0/1792.0)*Jinv00*M00*Jinv01+(625.0/1792.0)*Jinv11*Jinv10*M11-(261875.0/145152.0)*M10*Jinv11*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00+(203125.0/290304.0)*Jinv00*M10*Jinv11+(203125.0/290304.0)*M01*Jinv10*Jinv01-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv00*M01*Jinv10-(101875.0/290304.0)*Jinv00*M01*Jinv11-(261875.0/145152.0)*M00*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M01*Jinv11*Jinv01-(261875.0/145152.0)*Jinv00*M10*Jinv10-(101875.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[14][18]=(-(625.0/1344.0)*Jinv00*M00*Jinv01-(625.0/1344.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(625.0/2688.0)*Jinv00*M10*Jinv11-(625.0/2688.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv00*M01*Jinv10-(625.0/2688.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01-(8125.0/9072.0)*Jinv00*M10*Jinv10-(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[14][19]=(-(18125.0/72576.0)*Jinv00*M00*Jinv01-(18125.0/72576.0)*Jinv11*Jinv10*M11+(59375.0/72576.0)*M10*Jinv11*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(625.0/1296.0)*Jinv00*M10*Jinv11-(625.0/1296.0)*M01*Jinv10*Jinv01+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv00*M01*Jinv10+(625.0/2688.0)*Jinv00*M01*Jinv11+(59375.0/72576.0)*M00*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M01*Jinv11*Jinv01+(8125.0/9072.0)*Jinv00*M10*Jinv10+(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[14][20]=((575.0/1512.0)*Jinv00*M00*Jinv01+(575.0/1512.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*M10*Jinv11*Jinv01+(575.0/1512.0)*Jinv00*M10*Jinv11+(575.0/1512.0)*M01*Jinv10*Jinv01-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*M00*(Jinv01*Jinv01)-(20225.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[15][0]=(-(10775.0/20736.0)*Jinv00*M00*Jinv01-(10775.0/20736.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*M10*Jinv11*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv00*M10*Jinv11-(20225.0/290304.0)*M01*Jinv10*Jinv01-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv00*M01*Jinv10-(130625.0/290304.0)*Jinv00*M01*Jinv11-(130625.0/290304.0)*M00*(Jinv01*Jinv01)-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M01*Jinv11*Jinv01-(20225.0/290304.0)*Jinv00*M10*Jinv10-(130625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][1]=((29375.0/48384.0)*Jinv00*M00*Jinv01+(29375.0/48384.0)*Jinv11*Jinv10*M11-(104375.0/290304.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(29375.0/96768.0)*Jinv00*M10*Jinv11+(29375.0/96768.0)*M01*Jinv10*Jinv01-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10+(29375.0/96768.0)*Jinv00*M01*Jinv11-(104375.0/290304.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10+(29375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[15][2]=((625.0/6912.0)*Jinv00*M00*Jinv01+(625.0/6912.0)*Jinv11*Jinv10*M11-(8125.0/72576.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00+(625.0/13824.0)*Jinv00*M10*Jinv11+(625.0/13824.0)*M01*Jinv10*Jinv01-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10+(625.0/13824.0)*Jinv00*M01*Jinv11-(8125.0/72576.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10+(625.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[15][3]=((38125.0/145152.0)*Jinv00*M00*Jinv01+(38125.0/145152.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv00*M10*Jinv11+(38125.0/290304.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10+(38125.0/290304.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10+(38125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][4]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*Jinv00*M01*Jinv10-(625.0/20736.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv00*M10*Jinv10-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[15][5]=(-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv00*M10*Jinv10)*D;
  A[15][6]=((45625.0/24192.0)*Jinv00*M00*Jinv01+(45625.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/6048.0)*M10*Jinv11*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(10625.0/18144.0)*Jinv00*M10*Jinv11+(10625.0/18144.0)*M01*Jinv10*Jinv01+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv00*M01*Jinv10+(94375.0/72576.0)*Jinv00*M01*Jinv11+(11875.0/6048.0)*M00*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M01*Jinv11*Jinv01+(59375.0/72576.0)*Jinv00*M10*Jinv10+(94375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[15][7]=(-(625.0/336.0)*Jinv00*M00*Jinv01-(625.0/336.0)*Jinv11*Jinv10*M11+(49375.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/672.0)*Jinv00*M10*Jinv11-(625.0/672.0)*M01*Jinv10*Jinv01+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(625.0/672.0)*Jinv00*M01*Jinv11+(49375.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(625.0/672.0)*M10*Jinv10*Jinv01)*D;
  A[15][8]=(-(6875.0/10368.0)*Jinv00*M00*Jinv01-(6875.0/10368.0)*Jinv11*Jinv10*M11+(11875.0/36288.0)*M10*Jinv11*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/20736.0)*Jinv00*M10*Jinv11-(6875.0/20736.0)*M01*Jinv10*Jinv01+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv00*M01*Jinv10-(6875.0/20736.0)*Jinv00*M01*Jinv11+(11875.0/36288.0)*M00*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M01*Jinv11*Jinv01+(3125.0/72576.0)*Jinv00*M10*Jinv10-(6875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[15][9]=(-(625.0/4536.0)*Jinv00*M00*Jinv01-(625.0/4536.0)*Jinv11*Jinv10*M11+(625.0/18144.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(625.0/9072.0)*Jinv00*M10*Jinv11-(625.0/9072.0)*M01*Jinv10*Jinv01+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(625.0/9072.0)*Jinv00*M01*Jinv11+(625.0/18144.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(625.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[15][10]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*Jinv00*M01*Jinv10+(625.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv00*M10*Jinv10+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[15][11]=(-(574375.0/145152.0)*Jinv00*M00*Jinv01-(574375.0/145152.0)*Jinv11*Jinv10*M11-(574375.0/145152.0)*M10*Jinv11*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(15625.0/10752.0)*Jinv00*M10*Jinv11-(15625.0/10752.0)*M01*Jinv10*Jinv01-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv00*M01*Jinv10-(726875.0/290304.0)*Jinv00*M01*Jinv11-(574375.0/145152.0)*M00*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M01*Jinv11*Jinv01-(261875.0/145152.0)*Jinv00*M10*Jinv10-(726875.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][12]=((700625.0/145152.0)*Jinv00*M00*Jinv01+(700625.0/145152.0)*Jinv11*Jinv10*M11+(625.0/145152.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(700625.0/290304.0)*Jinv00*M10*Jinv11+(700625.0/290304.0)*M01*Jinv10*Jinv01+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(700625.0/290304.0)*Jinv00*M01*Jinv11+(625.0/145152.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(700625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][13]=((44375.0/145152.0)*Jinv00*M00*Jinv01+(44375.0/145152.0)*Jinv11*Jinv10*M11-(23125.0/72576.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(44375.0/290304.0)*Jinv00*M10*Jinv11+(44375.0/290304.0)*M01*Jinv10*Jinv01-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(44375.0/290304.0)*Jinv00*M01*Jinv11-(23125.0/72576.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(44375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][14]=(-(18125.0/145152.0)*Jinv00*M00*Jinv01-(18125.0/145152.0)*Jinv11*Jinv10*M11-(625.0/36288.0)*M10*Jinv11*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(18125.0/290304.0)*Jinv00*M10*Jinv11-(18125.0/290304.0)*M01*Jinv10*Jinv01-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv00*M01*Jinv10-(18125.0/290304.0)*Jinv00*M01*Jinv11-(625.0/36288.0)*M00*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M01*Jinv11*Jinv01-(10625.0/48384.0)*Jinv00*M10*Jinv10-(18125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[15][15]=((40625.0/8064.0)*Jinv00*M00*Jinv01+(40625.0/8064.0)*Jinv11*Jinv10*M11+(11875.0/2688.0)*M10*Jinv11*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(40625.0/16128.0)*Jinv00*M10*Jinv11+(40625.0/16128.0)*M01*Jinv10*Jinv01+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv00*M01*Jinv10+(40625.0/16128.0)*Jinv00*M01*Jinv11+(11875.0/2688.0)*M00*(Jinv01*Jinv01)+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M01*Jinv11*Jinv01+(89375.0/24192.0)*Jinv00*M10*Jinv10+(40625.0/16128.0)*M10*Jinv10*Jinv01)*D;
  A[15][16]=(-(6875.0/1296.0)*Jinv00*M00*Jinv01-(6875.0/1296.0)*Jinv11*Jinv10*M11-(44375.0/72576.0)*M10*Jinv11*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(6875.0/2592.0)*Jinv00*M10*Jinv11-(6875.0/2592.0)*M01*Jinv10*Jinv01-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv00*M01*Jinv10-(6875.0/2592.0)*Jinv00*M01*Jinv11-(44375.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M01*Jinv11*Jinv01-(71875.0/18144.0)*Jinv00*M10*Jinv10-(6875.0/2592.0)*M10*Jinv10*Jinv01)*D;
  A[15][17]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11+(625.0/6048.0)*M10*Jinv11*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(19375.0/145152.0)*Jinv00*M10*Jinv11+(19375.0/145152.0)*M01*Jinv10*Jinv01+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv00*M01*Jinv10+(19375.0/145152.0)*Jinv00*M01*Jinv11+(625.0/6048.0)*M00*(Jinv01*Jinv01)+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M01*Jinv11*Jinv01+(19375.0/72576.0)*Jinv00*M10*Jinv10+(19375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[15][18]=(-(221875.0/72576.0)*Jinv00*M00*Jinv01-(221875.0/72576.0)*Jinv11*Jinv10*M11-(745625.0/290304.0)*M10*Jinv11*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(318125.0/145152.0)*Jinv00*M10*Jinv11-(318125.0/145152.0)*M01*Jinv10*Jinv01-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv00*M01*Jinv10-(41875.0/48384.0)*Jinv00*M01*Jinv11-(745625.0/290304.0)*M00*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M01*Jinv11*Jinv01-(625.0/448.0)*Jinv00*M10*Jinv10-(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[15][19]=((41875.0/24192.0)*Jinv00*M00*Jinv01+(41875.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/41472.0)*M10*Jinv11*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(41875.0/48384.0)*Jinv00*M10*Jinv11+(41875.0/48384.0)*M01*Jinv10*Jinv01+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv00*M01*Jinv10+(41875.0/48384.0)*Jinv00*M01*Jinv11+(11875.0/41472.0)*M00*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M01*Jinv11*Jinv01+(625.0/448.0)*Jinv00*M10*Jinv10+(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[15][20]=((6325.0/10368.0)*Jinv00*M00*Jinv01+(6325.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*M10*Jinv11*Jinv01+(6325.0/10368.0)*Jinv00*M10*Jinv11+(6325.0/10368.0)*M01*Jinv10*Jinv01+(14375.0/24192.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*M00*(Jinv01*Jinv01)+(14375.0/24192.0)*M01*Jinv11*Jinv01)*D;
  A[16][0]=((15625.0/72576.0)*Jinv00*M00*Jinv01+(15625.0/72576.0)*Jinv11*Jinv10*M11+(15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M10*Jinv11+(15625.0/145152.0)*M01*Jinv10*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*Jinv00*M01*Jinv11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M01*Jinv11*Jinv01+(15625.0/145152.0)*Jinv00*M10*Jinv10+(15625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[16][1]=(-(29375.0/36288.0)*Jinv00*M00*Jinv01-(29375.0/36288.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*M10*Jinv11*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(29375.0/72576.0)*Jinv00*M10*Jinv11-(29375.0/72576.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv00*M01*Jinv10-(29375.0/72576.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*M00*(Jinv01*Jinv01)-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M01*Jinv11*Jinv01-(6875.0/48384.0)*Jinv00*M10*Jinv10-(29375.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][2]=((625.0/3024.0)*Jinv00*M00*Jinv01+(625.0/3024.0)*Jinv11*Jinv10*M11-(3125.0/9072.0)*M10*Jinv11*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv00*M10*Jinv11+(625.0/6048.0)*M01*Jinv10*Jinv01-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv00*M01*Jinv10+(625.0/6048.0)*Jinv00*M01*Jinv11-(3125.0/9072.0)*M00*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M01*Jinv11*Jinv01+(625.0/18144.0)*Jinv00*M10*Jinv10+(625.0/6048.0)*M10*Jinv10*Jinv01)*D;
  A[16][3]=(-(625.0/4536.0)*Jinv00*M00*Jinv01-(625.0/4536.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(625.0/9072.0)*Jinv00*M10*Jinv11-(625.0/9072.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv00*M01*Jinv10-(625.0/9072.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(625.0/18144.0)*Jinv00*M10*Jinv10-(625.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[16][4]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*Jinv00*M01*Jinv10+(38125.0/145152.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv00*M10*Jinv10+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[16][5]=((15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv00*M01*Jinv10+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv00*M10*Jinv10)*D;
  A[16][6]=(-(105625.0/72576.0)*Jinv00*M00*Jinv01-(105625.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*M10*Jinv11*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(105625.0/145152.0)*Jinv00*M10*Jinv11-(105625.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv00*M01*Jinv10-(105625.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*M00*(Jinv01*Jinv01)-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M01*Jinv11*Jinv01-(71875.0/72576.0)*Jinv00*M10*Jinv10-(105625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[16][7]=((3125.0/1134.0)*Jinv00*M00*Jinv01+(3125.0/1134.0)*Jinv11*Jinv10*M11+(3125.0/1134.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/2268.0)*Jinv00*M10*Jinv11+(3125.0/2268.0)*M01*Jinv10*Jinv01+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(3125.0/1134.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[16][8]=(-(3125.0/36288.0)*Jinv00*M00*Jinv01-(3125.0/36288.0)*Jinv11*Jinv10*M11+(34375.0/24192.0)*M10*Jinv11*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00-(3125.0/72576.0)*Jinv00*M10*Jinv11-(3125.0/72576.0)*M01*Jinv10*Jinv01+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv00*M01*Jinv10-(3125.0/72576.0)*Jinv00*M01*Jinv11+(34375.0/24192.0)*M00*(Jinv01*Jinv01)-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M01*Jinv11*Jinv01-(3125.0/36288.0)*Jinv00*M10*Jinv10-(3125.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][9]=(-(3125.0/4536.0)*Jinv00*M00*Jinv01-(3125.0/4536.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv00*M10*Jinv11-(3125.0/9072.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv00*M01*Jinv10-(3125.0/9072.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/3024.0)*Jinv00*M10*Jinv10-(3125.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[16][10]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*Jinv00*M01*Jinv10-(38125.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv00*M10*Jinv10-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[16][11]=((116875.0/36288.0)*Jinv00*M00*Jinv01+(116875.0/36288.0)*Jinv11*Jinv10*M11+(49375.0/72576.0)*M10*Jinv11*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(116875.0/72576.0)*Jinv00*M10*Jinv11+(116875.0/72576.0)*M01*Jinv10*Jinv01+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv00*M01*Jinv10+(116875.0/72576.0)*Jinv00*M01*Jinv11+(49375.0/72576.0)*M00*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M01*Jinv11*Jinv01+(146875.0/72576.0)*Jinv00*M10*Jinv10+(116875.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][12]=(-(59375.0/9072.0)*Jinv00*M00*Jinv01-(59375.0/9072.0)*Jinv11*Jinv10*M11-(21875.0/3456.0)*M10*Jinv11*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(59375.0/18144.0)*Jinv00*M10*Jinv11-(59375.0/18144.0)*M01*Jinv10*Jinv01-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv00*M01*Jinv10-(59375.0/18144.0)*Jinv00*M01*Jinv11-(21875.0/3456.0)*M00*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M01*Jinv11*Jinv01-(146875.0/72576.0)*Jinv00*M10*Jinv10-(59375.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[16][13]=((90625.0/36288.0)*Jinv00*M00*Jinv01+(90625.0/36288.0)*Jinv11*Jinv10*M11-(3125.0/1728.0)*M10*Jinv11*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(90625.0/72576.0)*Jinv00*M10*Jinv11+(90625.0/72576.0)*M01*Jinv10*Jinv01-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv00*M01*Jinv10+(90625.0/72576.0)*Jinv00*M01*Jinv11-(3125.0/1728.0)*M00*(Jinv01*Jinv01)-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M01*Jinv11*Jinv01-(146875.0/72576.0)*Jinv00*M10*Jinv10+(90625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][14]=((625.0/756.0)*Jinv00*M00*Jinv01+(625.0/756.0)*Jinv11*Jinv10*M11-(3125.0/6048.0)*M10*Jinv11*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/1512.0)*Jinv00*M10*Jinv11+(625.0/1512.0)*M01*Jinv10*Jinv01-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv00*M01*Jinv10+(625.0/1512.0)*Jinv00*M01*Jinv11-(3125.0/6048.0)*M00*(Jinv01*Jinv01)+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M01*Jinv11*Jinv01+(146875.0/72576.0)*Jinv00*M10*Jinv10+(625.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[16][15]=(-(6875.0/1296.0)*Jinv00*M00*Jinv01-(6875.0/1296.0)*Jinv11*Jinv10*M11-(44375.0/72576.0)*M10*Jinv11*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(6875.0/2592.0)*Jinv00*M10*Jinv11-(6875.0/2592.0)*M01*Jinv10*Jinv01-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv00*M01*Jinv10-(6875.0/2592.0)*Jinv00*M01*Jinv11-(44375.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M01*Jinv11*Jinv01-(71875.0/18144.0)*Jinv00*M10*Jinv10-(6875.0/2592.0)*M10*Jinv10*Jinv01)*D;
  A[16][16]=((71875.0/9072.0)*Jinv00*M00*Jinv01+(71875.0/9072.0)*Jinv11*Jinv10*M11+(128125.0/18144.0)*M10*Jinv11*Jinv01+(71875.0/9072.0)*(Jinv00*Jinv00)*M00+(71875.0/18144.0)*Jinv00*M10*Jinv11+(71875.0/18144.0)*M01*Jinv10*Jinv01+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(71875.0/9072.0)*Jinv00*M01*Jinv10+(71875.0/18144.0)*Jinv00*M01*Jinv11+(128125.0/18144.0)*M00*(Jinv01*Jinv01)+(71875.0/9072.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M01*Jinv11*Jinv01+(71875.0/9072.0)*Jinv00*M10*Jinv10+(71875.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[16][17]=(-(11875.0/4536.0)*Jinv00*M00*Jinv01-(11875.0/4536.0)*Jinv11*Jinv10*M11+(53125.0/72576.0)*M10*Jinv11*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(11875.0/9072.0)*Jinv00*M10*Jinv11-(11875.0/9072.0)*M01*Jinv10*Jinv01+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv00*M01*Jinv10-(11875.0/9072.0)*Jinv00*M01*Jinv11+(53125.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M01*Jinv11*Jinv01-(71875.0/18144.0)*Jinv00*M10*Jinv10-(11875.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[16][18]=((120625.0/36288.0)*Jinv00*M00*Jinv01+(120625.0/36288.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*M10*Jinv11*Jinv01+(120625.0/72576.0)*Jinv00*M10*Jinv11+(120625.0/72576.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*(Jinv11*Jinv11)*M11+(120625.0/72576.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*M00*(Jinv01*Jinv01)+(8125.0/16128.0)*M01*Jinv11*Jinv01+(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][19]=(-(120625.0/36288.0)*Jinv00*M00*Jinv01-(120625.0/36288.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*M10*Jinv11*Jinv01-(120625.0/72576.0)*Jinv00*M10*Jinv11-(120625.0/72576.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*(Jinv11*Jinv11)*M11-(120625.0/72576.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*M00*(Jinv01*Jinv01)-(409375.0/145152.0)*M01*Jinv11*Jinv01-(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[16][20]=(-(15625.0/72576.0)*M10*Jinv11*Jinv01-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*M00*(Jinv01*Jinv01)-(15625.0/72576.0)*M01*Jinv11*Jinv01)*D;
  A[17][0]=(-(175.0/2304.0)*Jinv00*M00*Jinv01-(175.0/2304.0)*Jinv11*Jinv10*M11-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv00*M10*Jinv11-(175.0/4608.0)*M01*Jinv10*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv00*M01*Jinv10-(175.0/4608.0)*Jinv00*M01*Jinv11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M01*Jinv11*Jinv01-(175.0/4608.0)*Jinv00*M10*Jinv10-(175.0/4608.0)*M10*Jinv10*Jinv01)*D;
  A[17][1]=((29375.0/145152.0)*Jinv00*M00*Jinv01+(29375.0/145152.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(29375.0/290304.0)*Jinv00*M10*Jinv11+(29375.0/290304.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10+(29375.0/290304.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10+(29375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[17][2]=(-(14375.0/48384.0)*Jinv00*M00*Jinv01-(14375.0/48384.0)*Jinv11*Jinv10*M11-(14375.0/48384.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/96768.0)*Jinv00*M10*Jinv11-(14375.0/96768.0)*M01*Jinv10*Jinv01-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10-(14375.0/96768.0)*Jinv00*M01*Jinv11-(14375.0/48384.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10-(14375.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[17][3]=(-(18125.0/145152.0)*Jinv00*M00*Jinv01-(18125.0/145152.0)*Jinv11*Jinv10*M11-(10625.0/48384.0)*M10*Jinv11*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(18125.0/290304.0)*Jinv00*M10*Jinv11-(18125.0/290304.0)*M01*Jinv10*Jinv01-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv00*M01*Jinv10-(18125.0/290304.0)*Jinv00*M01*Jinv11-(10625.0/48384.0)*M00*(Jinv01*Jinv01)-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M01*Jinv11*Jinv01-(625.0/36288.0)*Jinv00*M10*Jinv10-(18125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[17][4]=(-(625.0/1344.0)*Jinv00*M00*Jinv01-(625.0/1344.0)*Jinv11*Jinv10*M11-(8125.0/9072.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/2688.0)*Jinv00*M10*Jinv11-(625.0/2688.0)*M01*Jinv10*Jinv01-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv10-(625.0/2688.0)*Jinv00*M01*Jinv11-(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv10-(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[17][5]=((575.0/1512.0)*Jinv00*M00*Jinv01+(575.0/1512.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv00*M01*Jinv10+(575.0/1512.0)*Jinv00*M01*Jinv11-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv00*M10*Jinv10+(575.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[17][6]=((6875.0/24192.0)*Jinv00*M00*Jinv01+(6875.0/24192.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*M10*Jinv11*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(6875.0/48384.0)*Jinv00*M10*Jinv11+(6875.0/48384.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv00*M01*Jinv10+(6875.0/48384.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*M00*(Jinv01*Jinv01)+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M01*Jinv11*Jinv01+(3125.0/18144.0)*Jinv00*M10*Jinv10+(6875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[17][7]=(-(8125.0/9072.0)*Jinv00*M00*Jinv01-(8125.0/9072.0)*Jinv11*Jinv10*M11-(3125.0/9072.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(8125.0/18144.0)*Jinv00*M10*Jinv11-(8125.0/18144.0)*M01*Jinv10*Jinv01-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10-(8125.0/18144.0)*Jinv00*M01*Jinv11-(3125.0/9072.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10-(8125.0/18144.0)*M10*Jinv10*Jinv01)*D;
  A[17][8]=((18125.0/24192.0)*Jinv00*M00*Jinv01+(18125.0/24192.0)*Jinv11*Jinv10*M11+(3125.0/3024.0)*M10*Jinv11*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(18125.0/48384.0)*Jinv00*M10*Jinv11+(18125.0/48384.0)*M01*Jinv10*Jinv01+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv00*M01*Jinv10+(18125.0/48384.0)*Jinv00*M01*Jinv11+(3125.0/3024.0)*M00*(Jinv01*Jinv01)+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M01*Jinv11*Jinv01+(3125.0/72576.0)*Jinv00*M10*Jinv10+(18125.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[17][9]=((625.0/756.0)*Jinv00*M00*Jinv01+(625.0/756.0)*Jinv11*Jinv10*M11+(146875.0/72576.0)*M10*Jinv11*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/1512.0)*Jinv00*M10*Jinv11+(625.0/1512.0)*M01*Jinv10*Jinv01+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv00*M01*Jinv10+(625.0/1512.0)*Jinv00*M01*Jinv11+(146875.0/72576.0)*M00*(Jinv01*Jinv01)-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M01*Jinv11*Jinv01-(3125.0/6048.0)*Jinv00*M10*Jinv10+(625.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[17][10]=(-(18125.0/72576.0)*Jinv00*M00*Jinv01-(18125.0/72576.0)*Jinv11*Jinv10*M11+(8125.0/9072.0)*M10*Jinv11*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/2688.0)*Jinv00*M10*Jinv11+(625.0/2688.0)*M01*Jinv10*Jinv01+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv00*M01*Jinv10-(625.0/1296.0)*Jinv00*M01*Jinv11+(8125.0/9072.0)*M00*(Jinv01*Jinv01)+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M01*Jinv11*Jinv01+(59375.0/72576.0)*Jinv00*M10*Jinv10-(625.0/1296.0)*M10*Jinv10*Jinv01)*D;
  A[17][11]=(-(45625.0/145152.0)*Jinv00*M00*Jinv01-(45625.0/145152.0)*Jinv11*Jinv10*M11-(8125.0/72576.0)*M10*Jinv11*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(45625.0/290304.0)*Jinv00*M10*Jinv11-(45625.0/290304.0)*M01*Jinv10*Jinv01-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv00*M01*Jinv10-(45625.0/290304.0)*Jinv00*M01*Jinv11-(8125.0/72576.0)*M00*(Jinv01*Jinv01)-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M01*Jinv11*Jinv01-(10625.0/48384.0)*Jinv00*M10*Jinv10-(45625.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[17][12]=((11875.0/6912.0)*Jinv00*M00*Jinv01+(11875.0/6912.0)*Jinv11*Jinv10*M11+(3125.0/8064.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(11875.0/13824.0)*Jinv00*M10*Jinv11+(11875.0/13824.0)*M01*Jinv10*Jinv01+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10+(11875.0/13824.0)*Jinv00*M01*Jinv11+(3125.0/8064.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10+(11875.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[17][13]=(-(19375.0/6912.0)*Jinv00*M00*Jinv01-(19375.0/6912.0)*Jinv11*Jinv10*M11-(184375.0/48384.0)*M10*Jinv11*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(19375.0/13824.0)*Jinv00*M10*Jinv11-(19375.0/13824.0)*M01*Jinv10*Jinv01-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv00*M01*Jinv10-(19375.0/13824.0)*Jinv00*M01*Jinv11-(184375.0/48384.0)*M00*(Jinv01*Jinv01)+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M01*Jinv11*Jinv01+(146875.0/145152.0)*Jinv00*M10*Jinv10-(19375.0/13824.0)*M10*Jinv10*Jinv01)*D;
  A[17][14]=((625.0/1792.0)*Jinv00*M00*Jinv01+(625.0/1792.0)*Jinv11*Jinv10*M11-(261875.0/145152.0)*M10*Jinv11*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(101875.0/290304.0)*Jinv00*M10*Jinv11-(101875.0/290304.0)*M01*Jinv10*Jinv01-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv00*M01*Jinv10+(203125.0/290304.0)*Jinv00*M01*Jinv11-(261875.0/145152.0)*M00*(Jinv01*Jinv01)-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M01*Jinv11*Jinv01-(261875.0/145152.0)*Jinv00*M10*Jinv10+(203125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[17][15]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11+(625.0/6048.0)*M10*Jinv11*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(19375.0/145152.0)*Jinv00*M10*Jinv11+(19375.0/145152.0)*M01*Jinv10*Jinv01+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv00*M01*Jinv10+(19375.0/145152.0)*Jinv00*M01*Jinv11+(625.0/6048.0)*M00*(Jinv01*Jinv01)+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M01*Jinv11*Jinv01+(19375.0/72576.0)*Jinv00*M10*Jinv10+(19375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[17][16]=(-(11875.0/4536.0)*Jinv00*M00*Jinv01-(11875.0/4536.0)*Jinv11*Jinv10*M11+(53125.0/72576.0)*M10*Jinv11*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(11875.0/9072.0)*Jinv00*M10*Jinv11-(11875.0/9072.0)*M01*Jinv10*Jinv01+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv00*M01*Jinv10-(11875.0/9072.0)*Jinv00*M01*Jinv11+(53125.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M01*Jinv11*Jinv01-(71875.0/18144.0)*Jinv00*M10*Jinv10-(11875.0/9072.0)*M10*Jinv10*Jinv01)*D;
  A[17][17]=((8125.0/3456.0)*Jinv00*M00*Jinv01+(8125.0/3456.0)*Jinv11*Jinv10*M11+(10625.0/3456.0)*M10*Jinv11*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(8125.0/6912.0)*Jinv00*M10*Jinv11+(8125.0/6912.0)*M01*Jinv10*Jinv01+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv00*M01*Jinv10+(8125.0/6912.0)*Jinv00*M01*Jinv11+(10625.0/3456.0)*M00*(Jinv01*Jinv01)+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M01*Jinv11*Jinv01+(89375.0/24192.0)*Jinv00*M10*Jinv10+(8125.0/6912.0)*M10*Jinv10*Jinv01)*D;
  A[17][18]=((25625.0/24192.0)*Jinv00*M00*Jinv01+(25625.0/24192.0)*Jinv11*Jinv10*M11-(14375.0/290304.0)*M10*Jinv11*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(25625.0/48384.0)*Jinv00*M10*Jinv11+(25625.0/48384.0)*M01*Jinv10*Jinv01-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv00*M01*Jinv10+(25625.0/48384.0)*Jinv00*M01*Jinv11-(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M01*Jinv11*Jinv01+(625.0/448.0)*Jinv00*M10*Jinv10+(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[17][19]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11-(263125.0/290304.0)*M10*Jinv11*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00+(115625.0/145152.0)*Jinv00*M10*Jinv11+(115625.0/145152.0)*M01*Jinv10*Jinv01-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv00*M01*Jinv10-(25625.0/48384.0)*Jinv00*M01*Jinv11-(263125.0/290304.0)*M00*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M01*Jinv11*Jinv01-(625.0/448.0)*Jinv00*M10*Jinv10-(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[17][20]=(-(6325.0/10368.0)*Jinv00*M00*Jinv01-(6325.0/10368.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*M10*Jinv11*Jinv01-(6325.0/10368.0)*Jinv00*M10*Jinv11-(6325.0/10368.0)*M01*Jinv10*Jinv01-(575.0/36288.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*M00*(Jinv01*Jinv01)-(575.0/36288.0)*M01*Jinv11*Jinv01)*D;
  A[18][0]=((8825.0/36288.0)*Jinv00*M00*Jinv01+(8825.0/36288.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*M10*Jinv11*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv00*M10*Jinv11+(1975.0/48384.0)*M01*Jinv10*Jinv01+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv00*M01*Jinv10+(29375.0/145152.0)*Jinv00*M01*Jinv11+(29375.0/145152.0)*M00*(Jinv01*Jinv01)+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M01*Jinv11*Jinv01+(1975.0/48384.0)*Jinv00*M10*Jinv10+(29375.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[18][1]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*M10*Jinv11*Jinv01-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*(Jinv11*Jinv11)*M11-(6875.0/96768.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*M00*(Jinv01*Jinv01)+(14375.0/72576.0)*M01*Jinv11*Jinv01-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[18][2]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(8125.0/72576.0)*M10*Jinv11*Jinv01-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/20736.0)*Jinv00*M01*Jinv11+(8125.0/72576.0)*M00*(Jinv01*Jinv01)+(8125.0/72576.0)*M01*Jinv11*Jinv01-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[18][3]=(-(625.0/10368.0)*Jinv00*M00*Jinv01-(625.0/10368.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(625.0/20736.0)*Jinv00*M10*Jinv11-(625.0/20736.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(625.0/20736.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)+(6875.0/96768.0)*M01*Jinv11*Jinv01-(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[18][4]=(-(6875.0/48384.0)*Jinv00*M00*Jinv01-(6875.0/48384.0)*Jinv11*Jinv10*M11-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01-(6875.0/96768.0)*Jinv00*M01*Jinv11-(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[18][5]=(-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv00*M10*Jinv10)*D;
  A[18][6]=(-(68125.0/72576.0)*Jinv00*M00*Jinv01-(68125.0/72576.0)*Jinv11*Jinv10*M11-(68125.0/72576.0)*M10*Jinv11*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(78125.0/290304.0)*Jinv00*M10*Jinv11-(78125.0/290304.0)*M01*Jinv10*Jinv01-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv00*M01*Jinv10-(194375.0/290304.0)*Jinv00*M01*Jinv11-(68125.0/72576.0)*M00*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M01*Jinv11*Jinv01-(49375.0/145152.0)*Jinv00*M10*Jinv10-(194375.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[18][7]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(625.0/1344.0)*M10*Jinv11*Jinv01+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(625.0/1344.0)*(Jinv11*Jinv11)*M11+(38125.0/145152.0)*Jinv00*M01*Jinv11-(625.0/1344.0)*M00*(Jinv01*Jinv01)-(625.0/1344.0)*M01*Jinv11*Jinv01+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[18][8]=((10625.0/72576.0)*Jinv00*M00*Jinv01+(10625.0/72576.0)*Jinv11*Jinv10*M11-(79375.0/290304.0)*M10*Jinv11*Jinv01+(10625.0/145152.0)*Jinv00*M10*Jinv11+(10625.0/145152.0)*M01*Jinv10*Jinv01-(79375.0/290304.0)*(Jinv11*Jinv11)*M11+(10625.0/145152.0)*Jinv00*M01*Jinv11-(79375.0/290304.0)*M00*(Jinv01*Jinv01)-(79375.0/290304.0)*M01*Jinv11*Jinv01+(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[18][9]=((38125.0/72576.0)*Jinv00*M00*Jinv01+(38125.0/72576.0)*Jinv11*Jinv10*M11-(6875.0/48384.0)*M10*Jinv11*Jinv01+(38125.0/145152.0)*Jinv00*M10*Jinv11+(38125.0/145152.0)*M01*Jinv10*Jinv01-(6875.0/48384.0)*(Jinv11*Jinv11)*M11+(38125.0/145152.0)*Jinv00*M01*Jinv11-(6875.0/48384.0)*M00*(Jinv01*Jinv01)-(6875.0/48384.0)*M01*Jinv11*Jinv01+(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[18][10]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*Jinv00*M01*Jinv10+(6875.0/96768.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv00*M10*Jinv10+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[18][11]=((49375.0/24192.0)*Jinv00*M00*Jinv01+(49375.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/6048.0)*M10*Jinv11*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(6875.0/10368.0)*Jinv00*M10*Jinv11+(6875.0/10368.0)*M01*Jinv10*Jinv01+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv00*M01*Jinv10+(3125.0/2268.0)*Jinv00*M01*Jinv11+(11875.0/6048.0)*M00*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M01*Jinv11*Jinv01+(8125.0/9072.0)*Jinv00*M10*Jinv10+(3125.0/2268.0)*M10*Jinv10*Jinv01)*D;
  A[18][12]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/290304.0)*M10*Jinv11*Jinv01-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(14375.0/290304.0)*(Jinv11*Jinv11)*M11-(11875.0/20736.0)*Jinv00*M01*Jinv11+(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(14375.0/290304.0)*M01*Jinv11*Jinv01-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[18][13]=(-(11875.0/10368.0)*Jinv00*M00*Jinv01-(11875.0/10368.0)*Jinv11*Jinv10*M11+(4375.0/20736.0)*M10*Jinv11*Jinv01-(11875.0/20736.0)*Jinv00*M10*Jinv11-(11875.0/20736.0)*M01*Jinv10*Jinv01+(4375.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/20736.0)*Jinv00*M01*Jinv11+(4375.0/20736.0)*M00*(Jinv01*Jinv01)+(4375.0/20736.0)*M01*Jinv11*Jinv01-(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[18][14]=(-(625.0/1344.0)*Jinv00*M00*Jinv01-(625.0/1344.0)*Jinv11*Jinv10*M11+(6875.0/96768.0)*M10*Jinv11*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(625.0/2688.0)*Jinv00*M10*Jinv11-(625.0/2688.0)*M01*Jinv10*Jinv01+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv00*M01*Jinv10-(625.0/2688.0)*Jinv00*M01*Jinv11+(6875.0/96768.0)*M00*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M01*Jinv11*Jinv01-(8125.0/9072.0)*Jinv00*M10*Jinv10-(625.0/2688.0)*M10*Jinv10*Jinv01)*D;
  A[18][15]=(-(221875.0/72576.0)*Jinv00*M00*Jinv01-(221875.0/72576.0)*Jinv11*Jinv10*M11-(745625.0/290304.0)*M10*Jinv11*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(41875.0/48384.0)*Jinv00*M10*Jinv11-(41875.0/48384.0)*M01*Jinv10*Jinv01-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv00*M01*Jinv10-(318125.0/145152.0)*Jinv00*M01*Jinv11-(745625.0/290304.0)*M00*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M01*Jinv11*Jinv01-(625.0/448.0)*Jinv00*M10*Jinv10-(318125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[18][16]=((120625.0/36288.0)*Jinv00*M00*Jinv01+(120625.0/36288.0)*Jinv11*Jinv10*M11+(8125.0/16128.0)*M10*Jinv11*Jinv01+(120625.0/72576.0)*Jinv00*M10*Jinv11+(120625.0/72576.0)*M01*Jinv10*Jinv01+(8125.0/16128.0)*(Jinv11*Jinv11)*M11+(120625.0/72576.0)*Jinv00*M01*Jinv11+(8125.0/16128.0)*M00*(Jinv01*Jinv01)+(8125.0/16128.0)*M01*Jinv11*Jinv01+(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[18][17]=((25625.0/24192.0)*Jinv00*M00*Jinv01+(25625.0/24192.0)*Jinv11*Jinv10*M11-(14375.0/290304.0)*M10*Jinv11*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(25625.0/48384.0)*Jinv00*M10*Jinv11+(25625.0/48384.0)*M01*Jinv10*Jinv01-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv00*M01*Jinv10+(25625.0/48384.0)*Jinv00*M01*Jinv11-(14375.0/290304.0)*M00*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M01*Jinv11*Jinv01+(625.0/448.0)*Jinv00*M10*Jinv10+(25625.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[18][18]=((53125.0/20736.0)*Jinv00*M00*Jinv01+(53125.0/20736.0)*Jinv11*Jinv10*M11+(6875.0/3456.0)*M10*Jinv11*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(53125.0/41472.0)*Jinv00*M10*Jinv11+(53125.0/41472.0)*M01*Jinv10*Jinv01+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv00*M01*Jinv10+(53125.0/41472.0)*Jinv00*M01*Jinv11+(6875.0/3456.0)*M00*(Jinv01*Jinv01)+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M01*Jinv11*Jinv01+(53125.0/20736.0)*Jinv00*M10*Jinv10+(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[18][19]=(-(53125.0/20736.0)*Jinv00*M00*Jinv01-(53125.0/20736.0)*Jinv11*Jinv10*M11-(11875.0/41472.0)*M10*Jinv11*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(53125.0/41472.0)*Jinv00*M10*Jinv11-(53125.0/41472.0)*M01*Jinv10*Jinv01-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv00*M01*Jinv10-(53125.0/41472.0)*Jinv00*M01*Jinv11-(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M01*Jinv11*Jinv01-(53125.0/20736.0)*Jinv00*M10*Jinv10-(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[18][20]=(-(123425.0/145152.0)*Jinv00*M00*Jinv01-(123425.0/145152.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*M10*Jinv11*Jinv01-(123425.0/145152.0)*Jinv00*M10*Jinv11-(123425.0/145152.0)*M01*Jinv10*Jinv01-(26875.0/41472.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*M00*(Jinv01*Jinv01)-(26875.0/41472.0)*M01*Jinv11*Jinv01)*D;
  A[19][0]=(-(1975.0/24192.0)*Jinv00*M00*Jinv01-(1975.0/24192.0)*Jinv11*Jinv10*M11-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv00*M10*Jinv11-(1975.0/48384.0)*M01*Jinv10*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv00*M01*Jinv10-(1975.0/48384.0)*Jinv00*M01*Jinv11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M01*Jinv11*Jinv01-(1975.0/48384.0)*Jinv00*M10*Jinv10-(1975.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[19][1]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(6875.0/48384.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(6875.0/48384.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv11+(6875.0/48384.0)*M00*(Jinv01*Jinv01)+(6875.0/48384.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[19][2]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(38125.0/290304.0)*M10*Jinv11*Jinv01+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/20736.0)*Jinv00*M01*Jinv11+(38125.0/290304.0)*M00*(Jinv01*Jinv01)+(38125.0/290304.0)*M01*Jinv11*Jinv01+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[19][3]=((625.0/10368.0)*Jinv00*M00*Jinv01+(625.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/18144.0)*M10*Jinv11*Jinv01+(625.0/20736.0)*Jinv00*M10*Jinv11+(625.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(625.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/18144.0)*M00*(Jinv01*Jinv01)+(3125.0/18144.0)*M01*Jinv11*Jinv01+(625.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[19][4]=((6875.0/48384.0)*Jinv00*M00*Jinv01+(6875.0/48384.0)*Jinv11*Jinv10*M11+(49375.0/145152.0)*M10*Jinv11*Jinv01+(6875.0/96768.0)*Jinv00*M10*Jinv11+(6875.0/96768.0)*M01*Jinv10*Jinv01+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv00*M01*Jinv11+(49375.0/145152.0)*M00*(Jinv01*Jinv01)+(49375.0/145152.0)*M01*Jinv11*Jinv01+(6875.0/96768.0)*M10*Jinv10*Jinv01)*D;
  A[19][5]=(-(1675.0/10368.0)*Jinv00*M00*Jinv01-(1675.0/10368.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv00*M01*Jinv10-(1675.0/10368.0)*Jinv00*M01*Jinv11+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv00*M10*Jinv10-(1675.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[19][6]=((78125.0/145152.0)*Jinv00*M00*Jinv01+(78125.0/145152.0)*Jinv11*Jinv10*M11+(14375.0/72576.0)*M10*Jinv11*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(78125.0/290304.0)*Jinv00*M10*Jinv11+(78125.0/290304.0)*M01*Jinv10*Jinv01+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv00*M01*Jinv10+(78125.0/290304.0)*Jinv00*M01*Jinv11+(14375.0/72576.0)*M00*(Jinv01*Jinv01)+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M01*Jinv11*Jinv01+(49375.0/145152.0)*Jinv00*M10*Jinv10+(78125.0/290304.0)*M10*Jinv10*Jinv01)*D;
  A[19][7]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(96875.0/145152.0)*M10*Jinv11*Jinv01-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(38125.0/145152.0)*Jinv00*M01*Jinv11-(96875.0/145152.0)*M00*(Jinv01*Jinv01)-(96875.0/145152.0)*M01*Jinv11*Jinv01-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[19][8]=(-(10625.0/72576.0)*Jinv00*M00*Jinv01-(10625.0/72576.0)*Jinv11*Jinv10*M11-(40625.0/96768.0)*M10*Jinv11*Jinv01-(10625.0/145152.0)*Jinv00*M10*Jinv11-(10625.0/145152.0)*M01*Jinv10*Jinv01-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(10625.0/145152.0)*Jinv00*M01*Jinv11-(40625.0/96768.0)*M00*(Jinv01*Jinv01)-(40625.0/96768.0)*M01*Jinv11*Jinv01-(10625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[19][9]=(-(38125.0/72576.0)*Jinv00*M00*Jinv01-(38125.0/72576.0)*Jinv11*Jinv10*M11-(71875.0/72576.0)*M10*Jinv11*Jinv01-(38125.0/145152.0)*Jinv00*M10*Jinv11-(38125.0/145152.0)*M01*Jinv10*Jinv01-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(38125.0/145152.0)*Jinv00*M01*Jinv11-(71875.0/72576.0)*M00*(Jinv01*Jinv01)-(71875.0/72576.0)*M01*Jinv11*Jinv01-(38125.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[19][10]=((3125.0/12096.0)*Jinv00*M00*Jinv01+(3125.0/12096.0)*Jinv11*Jinv10*M11-(49375.0/145152.0)*M10*Jinv11*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*Jinv00*M10*Jinv11-(6875.0/96768.0)*M01*Jinv10*Jinv01-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv00*M01*Jinv10+(10625.0/32256.0)*Jinv00*M01*Jinv11-(49375.0/145152.0)*M00*(Jinv01*Jinv01)-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M01*Jinv11*Jinv01-(49375.0/145152.0)*Jinv00*M10*Jinv10+(10625.0/32256.0)*M10*Jinv10*Jinv01)*D;
  A[19][11]=(-(6875.0/5184.0)*Jinv00*M00*Jinv01-(6875.0/5184.0)*Jinv11*Jinv10*M11-(104375.0/290304.0)*M10*Jinv11*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(6875.0/10368.0)*Jinv00*M10*Jinv11-(6875.0/10368.0)*M01*Jinv10*Jinv01-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv00*M01*Jinv10-(6875.0/10368.0)*Jinv00*M01*Jinv11-(104375.0/290304.0)*M00*(Jinv01*Jinv01)-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M01*Jinv11*Jinv01-(8125.0/9072.0)*Jinv00*M10*Jinv10-(6875.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[19][12]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(3125.0/2304.0)*M10*Jinv11*Jinv01+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(11875.0/20736.0)*Jinv00*M01*Jinv11+(3125.0/2304.0)*M00*(Jinv01*Jinv01)+(3125.0/2304.0)*M01*Jinv11*Jinv01+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[19][13]=((11875.0/10368.0)*Jinv00*M00*Jinv01+(11875.0/10368.0)*Jinv11*Jinv10*M11+(115625.0/96768.0)*M10*Jinv11*Jinv01+(11875.0/20736.0)*Jinv00*M10*Jinv11+(11875.0/20736.0)*M01*Jinv10*Jinv01+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(11875.0/20736.0)*Jinv00*M01*Jinv11+(115625.0/96768.0)*M00*(Jinv01*Jinv01)+(115625.0/96768.0)*M01*Jinv11*Jinv01+(11875.0/20736.0)*M10*Jinv10*Jinv01)*D;
  A[19][14]=(-(18125.0/72576.0)*Jinv00*M00*Jinv01-(18125.0/72576.0)*Jinv11*Jinv10*M11+(59375.0/72576.0)*M10*Jinv11*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/2688.0)*Jinv00*M10*Jinv11+(625.0/2688.0)*M01*Jinv10*Jinv01+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv00*M01*Jinv10-(625.0/1296.0)*Jinv00*M01*Jinv11+(59375.0/72576.0)*M00*(Jinv01*Jinv01)+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M01*Jinv11*Jinv01+(8125.0/9072.0)*Jinv00*M10*Jinv10-(625.0/1296.0)*M10*Jinv10*Jinv01)*D;
  A[19][15]=((41875.0/24192.0)*Jinv00*M00*Jinv01+(41875.0/24192.0)*Jinv11*Jinv10*M11+(11875.0/41472.0)*M10*Jinv11*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(41875.0/48384.0)*Jinv00*M10*Jinv11+(41875.0/48384.0)*M01*Jinv10*Jinv01+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv00*M01*Jinv10+(41875.0/48384.0)*Jinv00*M01*Jinv11+(11875.0/41472.0)*M00*(Jinv01*Jinv01)+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M01*Jinv11*Jinv01+(625.0/448.0)*Jinv00*M10*Jinv10+(41875.0/48384.0)*M10*Jinv10*Jinv01)*D;
  A[19][16]=(-(120625.0/36288.0)*Jinv00*M00*Jinv01-(120625.0/36288.0)*Jinv11*Jinv10*M11-(409375.0/145152.0)*M10*Jinv11*Jinv01-(120625.0/72576.0)*Jinv00*M10*Jinv11-(120625.0/72576.0)*M01*Jinv10*Jinv01-(409375.0/145152.0)*(Jinv11*Jinv11)*M11-(120625.0/72576.0)*Jinv00*M01*Jinv11-(409375.0/145152.0)*M00*(Jinv01*Jinv01)-(409375.0/145152.0)*M01*Jinv11*Jinv01-(120625.0/72576.0)*M10*Jinv10*Jinv01)*D;
  A[19][17]=((19375.0/72576.0)*Jinv00*M00*Jinv01+(19375.0/72576.0)*Jinv11*Jinv10*M11-(263125.0/290304.0)*M10*Jinv11*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(25625.0/48384.0)*Jinv00*M10*Jinv11-(25625.0/48384.0)*M01*Jinv10*Jinv01-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv00*M01*Jinv10+(115625.0/145152.0)*Jinv00*M01*Jinv11-(263125.0/290304.0)*M00*(Jinv01*Jinv01)-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M01*Jinv11*Jinv01-(625.0/448.0)*Jinv00*M10*Jinv10+(115625.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[19][18]=(-(53125.0/20736.0)*Jinv00*M00*Jinv01-(53125.0/20736.0)*Jinv11*Jinv10*M11-(11875.0/41472.0)*M10*Jinv11*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(53125.0/41472.0)*Jinv00*M10*Jinv11-(53125.0/41472.0)*M01*Jinv10*Jinv01-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv00*M01*Jinv10-(53125.0/41472.0)*Jinv00*M01*Jinv11-(11875.0/41472.0)*M00*(Jinv01*Jinv01)-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M01*Jinv11*Jinv01-(53125.0/20736.0)*Jinv00*M10*Jinv10-(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[19][19]=((53125.0/20736.0)*Jinv00*M00*Jinv01+(53125.0/20736.0)*Jinv11*Jinv10*M11+(6875.0/3456.0)*M10*Jinv11*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(53125.0/41472.0)*Jinv00*M10*Jinv11+(53125.0/41472.0)*M01*Jinv10*Jinv01+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv00*M01*Jinv10+(53125.0/41472.0)*Jinv00*M01*Jinv11+(6875.0/3456.0)*M00*(Jinv01*Jinv01)+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M01*Jinv11*Jinv01+(53125.0/20736.0)*Jinv00*M10*Jinv10+(53125.0/41472.0)*M10*Jinv10*Jinv01)*D;
  A[19][20]=((123425.0/145152.0)*Jinv00*M00*Jinv01+(123425.0/145152.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*M10*Jinv11*Jinv01+(123425.0/145152.0)*Jinv00*M10*Jinv11+(123425.0/145152.0)*M01*Jinv10*Jinv01+(725.0/3584.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*M00*(Jinv01*Jinv01)+(725.0/3584.0)*M01*Jinv11*Jinv01)*D;
  A[20][0]=(-(5951.0/145152.0)*Jinv00*M00*Jinv01-(5951.0/145152.0)*Jinv11*Jinv10*M11-(5951.0/145152.0)*M10*Jinv11*Jinv01-(5951.0/145152.0)*(Jinv11*Jinv11)*M11-(5951.0/145152.0)*Jinv00*M01*Jinv11-(5951.0/145152.0)*M00*(Jinv01*Jinv01)-(5951.0/145152.0)*M01*Jinv11*Jinv01-(5951.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[20][1]=(-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*M01*Jinv11*Jinv01)*D;
  A[20][2]=(-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*M01*Jinv11*Jinv01)*D;
  A[20][3]=(-(175.0/4608.0)*M10*Jinv11*Jinv01-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*M00*(Jinv01*Jinv01)-(175.0/4608.0)*M01*Jinv11*Jinv01)*D;
  A[20][4]=(-(1975.0/48384.0)*M10*Jinv11*Jinv01-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*M00*(Jinv01*Jinv01)-(1975.0/48384.0)*M01*Jinv11*Jinv01)*D;
  A[20][5]=((5951.0/145152.0)*Jinv00*M00*Jinv01+(5951.0/145152.0)*Jinv11*Jinv10*M11+(5951.0/145152.0)*Jinv00*M01*Jinv11+(5951.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[20][6]=((1675.0/10368.0)*Jinv00*M00*Jinv01+(1675.0/10368.0)*Jinv11*Jinv10*M11+(29375.0/145152.0)*M10*Jinv11*Jinv01+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1675.0/10368.0)*Jinv00*M01*Jinv11+(29375.0/145152.0)*M00*(Jinv01*Jinv01)+(29375.0/145152.0)*M01*Jinv11*Jinv01+(1675.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[20][7]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[20][8]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[20][9]=((15625.0/145152.0)*M10*Jinv11*Jinv01+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*M00*(Jinv01*Jinv01)+(15625.0/145152.0)*M01*Jinv11*Jinv01)*D;
  A[20][10]=(-(1675.0/10368.0)*Jinv00*M00*Jinv01-(1675.0/10368.0)*Jinv11*Jinv10*M11+(1975.0/48384.0)*M10*Jinv11*Jinv01+(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1675.0/10368.0)*Jinv00*M01*Jinv11+(1975.0/48384.0)*M00*(Jinv01*Jinv01)+(1975.0/48384.0)*M01*Jinv11*Jinv01-(1675.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[20][11]=(-(575.0/1512.0)*Jinv00*M00*Jinv01-(575.0/1512.0)*Jinv11*Jinv10*M11-(130625.0/290304.0)*M10*Jinv11*Jinv01-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(575.0/1512.0)*Jinv00*M01*Jinv11-(130625.0/290304.0)*M00*(Jinv01*Jinv01)-(130625.0/290304.0)*M01*Jinv11*Jinv01-(575.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[20][12]=(-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[20][13]=(-(15625.0/290304.0)*M10*Jinv11*Jinv01-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*M00*(Jinv01*Jinv01)-(15625.0/290304.0)*M01*Jinv11*Jinv01)*D;
  A[20][14]=((575.0/1512.0)*Jinv00*M00*Jinv01+(575.0/1512.0)*Jinv11*Jinv10*M11-(20225.0/290304.0)*M10*Jinv11*Jinv01-(20225.0/290304.0)*(Jinv11*Jinv11)*M11+(575.0/1512.0)*Jinv00*M01*Jinv11-(20225.0/290304.0)*M00*(Jinv01*Jinv01)-(20225.0/290304.0)*M01*Jinv11*Jinv01+(575.0/1512.0)*M10*Jinv10*Jinv01)*D;
  A[20][15]=((6325.0/10368.0)*Jinv00*M00*Jinv01+(6325.0/10368.0)*Jinv11*Jinv10*M11+(14375.0/24192.0)*M10*Jinv11*Jinv01+(14375.0/24192.0)*(Jinv11*Jinv11)*M11+(6325.0/10368.0)*Jinv00*M01*Jinv11+(14375.0/24192.0)*M00*(Jinv01*Jinv01)+(14375.0/24192.0)*M01*Jinv11*Jinv01+(6325.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[20][16]=(-(15625.0/72576.0)*M10*Jinv11*Jinv01-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*M00*(Jinv01*Jinv01)-(15625.0/72576.0)*M01*Jinv11*Jinv01)*D;
  A[20][17]=(-(6325.0/10368.0)*Jinv00*M00*Jinv01-(6325.0/10368.0)*Jinv11*Jinv10*M11-(575.0/36288.0)*M10*Jinv11*Jinv01-(575.0/36288.0)*(Jinv11*Jinv11)*M11-(6325.0/10368.0)*Jinv00*M01*Jinv11-(575.0/36288.0)*M00*(Jinv01*Jinv01)-(575.0/36288.0)*M01*Jinv11*Jinv01-(6325.0/10368.0)*M10*Jinv10*Jinv01)*D;
  A[20][18]=(-(123425.0/145152.0)*Jinv00*M00*Jinv01-(123425.0/145152.0)*Jinv11*Jinv10*M11-(26875.0/41472.0)*M10*Jinv11*Jinv01-(26875.0/41472.0)*(Jinv11*Jinv11)*M11-(123425.0/145152.0)*Jinv00*M01*Jinv11-(26875.0/41472.0)*M00*(Jinv01*Jinv01)-(26875.0/41472.0)*M01*Jinv11*Jinv01-(123425.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[20][19]=((123425.0/145152.0)*Jinv00*M00*Jinv01+(123425.0/145152.0)*Jinv11*Jinv10*M11+(725.0/3584.0)*M10*Jinv11*Jinv01+(725.0/3584.0)*(Jinv11*Jinv11)*M11+(123425.0/145152.0)*Jinv00*M01*Jinv11+(725.0/3584.0)*M00*(Jinv01*Jinv01)+(725.0/3584.0)*M01*Jinv11*Jinv01+(123425.0/145152.0)*M10*Jinv10*Jinv01)*D;
  A[20][20]=((16567.0/48384.0)*M10*Jinv11*Jinv01+(16567.0/48384.0)*(Jinv11*Jinv11)*M11+(16567.0/48384.0)*M00*(Jinv01*Jinv01)+(16567.0/48384.0)*M01*Jinv11*Jinv01)*D;
  int nbf = 21;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}
