
#include <math.h>
#include <utility>
#include <map>
#include <ptv.h>
#include <DofT.h>
#include <ScalarFunction.h>

using namespace std; 



/* ------------- order 1 ---------------*/


  
void matrix_factory_vector_stiffness_2D_order1 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[6];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00+x0;  idof2[1]=G10+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00+x0;  idof3[1]=G10+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G01+x0;  idof4[1]=y0+G11;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G01+x0;  idof5[1]=y0+G11;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[6][6];
  A[0][0]=((Jinv01*Jinv01)/2.0+Jinv01*Jinv00+(Jinv11*Jinv11)/2.0+Jinv10*Jinv11+(Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[0][5]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((Jinv01*Jinv01)/2.0+Jinv01*Jinv00+(Jinv11*Jinv11)/2.0+Jinv10*Jinv11+(Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[2][0]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[2][5]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-Jinv01*Jinv00/2.0-Jinv10*Jinv11/2.0-(Jinv00*Jinv00)/2.0-(Jinv10*Jinv10)/2.0)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((Jinv00*Jinv00)/2.0+(Jinv10*Jinv10)/2.0)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[4][0]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((Jinv01*Jinv01)/2.0+(Jinv11*Jinv11)/2.0)*D;
  A[4][5]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(Jinv01*Jinv01)/2.0-Jinv01*Jinv00/2.0-(Jinv11*Jinv11)/2.0-Jinv10*Jinv11/2.0)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(Jinv01*Jinv00/2.0+Jinv10*Jinv11/2.0)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((Jinv01*Jinv01)/2.0+(Jinv11*Jinv11)/2.0)*D;
  int nbf = 6;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 2 ---------------*/


  
void matrix_factory_vector_stiffness_2D_order2 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[12];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/2.0+x0;  idof2[1]=G10/2.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/2.0+x0;  idof3[1]=G10/2.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G00+x0;  idof4[1]=G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G00+x0;  idof5[1]=G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=G01/2.0+x0;  idof6[1]=y0+G11/2.0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=G01/2.0+x0;  idof7[1]=y0+G11/2.0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G01/2.0+G00/2.0+x0;  idof8[1]=G10/2.0+y0+G11/2.0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G01/2.0+G00/2.0+x0;  idof9[1]=G10/2.0+y0+G11/2.0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01+x0;  idof10[1]=y0+G11;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01+x0;  idof11[1]=y0+G11;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[12][12];
  A[0][0]=((Jinv11*Jinv11)/2.0+(Jinv10*Jinv10)/2.0+Jinv01*Jinv00+Jinv11*Jinv10+(Jinv01*Jinv01)/2.0+(Jinv00*Jinv00)/2.0)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[0][3]=(0.0)*D;
  A[0][4]=((Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[0][7]=(0.0)*D;
  A[0][8]=(0.0)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=((Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0)*D;
  A[0][11]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((Jinv11*Jinv11)/2.0+(Jinv10*Jinv10)/2.0+Jinv01*Jinv00+Jinv11*Jinv10+(Jinv01*Jinv01)/2.0+(Jinv00*Jinv00)/2.0)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[1][4]=(0.0)*D;
  A[1][5]=((Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[1][8]=(0.0)*D;
  A[1][9]=(0.0)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=((Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0)*D;
  A[2][0]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01))*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(0.0)*D;
  A[2][11]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01))*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(0.0)*D;
  A[4][0]=((Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)/2.0)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(0.0)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=(-Jinv01*Jinv00/6.0-Jinv11*Jinv10/6.0)*D;
  A[4][11]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=((Jinv10*Jinv10)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv00*Jinv00)/6.0)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(2.0/3.0)*(Jinv10*Jinv10)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv00*Jinv00))*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)/2.0)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(0.0)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=(-Jinv01*Jinv00/6.0-Jinv11*Jinv10/6.0)*D;
  A[6][0]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(0.0)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[6][11]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(0.0)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[8][0]=(0.0)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01))*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[8][9]=(0.0)*D;
  A[8][10]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[8][11]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=(0.0)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(4.0/3.0)*(Jinv11*Jinv11)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv01*Jinv01))*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(4.0/3.0)*(Jinv10*Jinv10)-(4.0/3.0)*Jinv01*Jinv00-(4.0/3.0)*Jinv11*Jinv10-(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((4.0/3.0)*(Jinv11*Jinv11)+(4.0/3.0)*(Jinv10*Jinv10)+(4.0/3.0)*Jinv01*Jinv00+(4.0/3.0)*Jinv11*Jinv10+(4.0/3.0)*(Jinv01*Jinv01)+(4.0/3.0)*(Jinv00*Jinv00))*D;
  A[9][10]=(0.0)*D;
  A[9][11]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[10][0]=((Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(0.0)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(-Jinv01*Jinv00/6.0-Jinv11*Jinv10/6.0)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[10][7]=(0.0)*D;
  A[10][8]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((Jinv11*Jinv11)/2.0+(Jinv01*Jinv01)/2.0)*D;
  A[10][11]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=((Jinv11*Jinv11)/6.0+Jinv01*Jinv00/6.0+Jinv11*Jinv10/6.0+(Jinv01*Jinv01)/6.0)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(0.0)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-Jinv01*Jinv00/6.0-Jinv11*Jinv10/6.0)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(-(2.0/3.0)*(Jinv11*Jinv11)-(2.0/3.0)*Jinv01*Jinv00-(2.0/3.0)*Jinv11*Jinv10-(2.0/3.0)*(Jinv01*Jinv01))*D;
  A[11][8]=(0.0)*D;
  A[11][9]=((2.0/3.0)*Jinv01*Jinv00+(2.0/3.0)*Jinv11*Jinv10)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((Jinv11*Jinv11)/2.0+(Jinv01*Jinv01)/2.0)*D;
  int nbf = 12;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 3 ---------------*/


  
void matrix_factory_vector_stiffness_2D_order3 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[20];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/3.0+x0;  idof2[1]=G10/3.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/3.0+x0;  idof3[1]=G10/3.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=(2.0/3.0)*G00+x0;  idof4[1]=(2.0/3.0)*G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=(2.0/3.0)*G00+x0;  idof5[1]=(2.0/3.0)*G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=G00+x0;  idof6[1]=G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=G00+x0;  idof7[1]=G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G01/3.0+x0;  idof8[1]=y0+G11/3.0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G01/3.0+x0;  idof9[1]=y0+G11/3.0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01/3.0+G00/3.0+x0;  idof10[1]=G10/3.0+y0+G11/3.0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01/3.0+G00/3.0+x0;  idof11[1]=G10/3.0+y0+G11/3.0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/3.0+(2.0/3.0)*G00+x0;  idof12[1]=(2.0/3.0)*G10+y0+G11/3.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/3.0+(2.0/3.0)*G00+x0;  idof13[1]=(2.0/3.0)*G10+y0+G11/3.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=(2.0/3.0)*G01+x0;  idof14[1]=y0+(2.0/3.0)*G11;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=(2.0/3.0)*G01+x0;  idof15[1]=y0+(2.0/3.0)*G11;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=(2.0/3.0)*G01+G00/3.0+x0;  idof16[1]=G10/3.0+y0+(2.0/3.0)*G11;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=(2.0/3.0)*G01+G00/3.0+x0;  idof17[1]=G10/3.0+y0+(2.0/3.0)*G11;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01+x0;  idof18[1]=y0+G11;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01+x0;  idof19[1]=y0+G11;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[20][20];
  A[0][0]=((17.0/20.0)*Jinv11*Jinv10+(17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10)+(17.0/40.0)*(Jinv01*Jinv01)+(17.0/40.0)*(Jinv11*Jinv11)+(17.0/20.0)*Jinv01*Jinv00)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=((3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=(-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(0.0)*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=((3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01)-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[0][19]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((17.0/20.0)*Jinv11*Jinv10+(17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10)+(17.0/40.0)*(Jinv01*Jinv01)+(17.0/40.0)*(Jinv11*Jinv11)+(17.0/20.0)*Jinv01*Jinv00)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=((3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=(-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=(0.0)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=((3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01)-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[2][0]=(-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[2][11]=(0.0)*D;
  A[2][12]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[2][19]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-(51.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[4][0]=((3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01)-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[4][19]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=((3.0/8.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/20.0)*(Jinv00*Jinv00)-(27.0/20.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01)-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[6][0]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10))*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(0.0)*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[6][15]=(0.0)*D;
  A[6][16]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=((7.0/80.0)*Jinv11*Jinv10+(7.0/80.0)*Jinv01*Jinv00)*D;
  A[6][19]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((17.0/40.0)*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10))*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(0.0)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[7][16]=(0.0)*D;
  A[7][17]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=((7.0/80.0)*Jinv11*Jinv10+(7.0/80.0)*Jinv01*Jinv00)*D;
  A[8][0]=(-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[8][9]=(0.0)*D;
  A[8][10]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[8][11]=(0.0)*D;
  A[8][12]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01)-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[8][15]=(0.0)*D;
  A[8][16]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[8][19]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=(-(51.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(51.0/80.0)*Jinv01*Jinv00)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[9][10]=(0.0)*D;
  A[9][11]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[9][12]=(0.0)*D;
  A[9][13]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01)-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[9][16]=(0.0)*D;
  A[9][17]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[10][0]=(0.0)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(0.0)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((81.0/20.0)*Jinv11*Jinv10+(81.0/20.0)*(Jinv00*Jinv00)+(81.0/20.0)*(Jinv10*Jinv10)+(81.0/20.0)*(Jinv01*Jinv01)+(81.0/20.0)*(Jinv11*Jinv11)+(81.0/20.0)*Jinv01*Jinv00)*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(0.0)*D;
  A[10][19]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(0.0)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(0.0)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((81.0/20.0)*Jinv11*Jinv10+(81.0/20.0)*(Jinv00*Jinv00)+(81.0/20.0)*(Jinv10*Jinv10)+(81.0/20.0)*(Jinv01*Jinv01)+(81.0/20.0)*(Jinv11*Jinv11)+(81.0/20.0)*Jinv01*Jinv00)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(0.0)*D;
  A[12][0]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01)-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[12][13]=(0.0)*D;
  A[12][14]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[12][15]=(0.0)*D;
  A[12][16]=((27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00)*D;
  A[12][17]=(0.0)*D;
  A[12][18]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[12][19]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv01*Jinv01)-(27.0/16.0)*(Jinv11*Jinv11)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv00*Jinv00)-(81.0/40.0)*(Jinv10*Jinv10)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[13][14]=(0.0)*D;
  A[13][15]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[13][16]=(0.0)*D;
  A[13][17]=((27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00)*D;
  A[13][18]=(0.0)*D;
  A[13][19]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[14][0]=((3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01)-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[14][17]=(0.0)*D;
  A[14][18]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[14][19]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=((3.0/8.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/8.0)*Jinv01*Jinv00)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(-(27.0/80.0)*Jinv11*Jinv10-(27.0/80.0)*Jinv01*Jinv00)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=(-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10))*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-(27.0/20.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/20.0)*(Jinv01*Jinv01)-(27.0/20.0)*(Jinv11*Jinv11)-(27.0/20.0)*Jinv01*Jinv00)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((81.0/40.0)*Jinv11*Jinv10+(81.0/40.0)*Jinv01*Jinv00)*D;
  A[15][12]=(0.0)*D;
  A[15][13]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[16][0]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00)*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[16][17]=(0.0)*D;
  A[16][18]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[16][19]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=(-(3.0/40.0)*Jinv11*Jinv10-(3.0/80.0)*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11)-(3.0/40.0)*Jinv01*Jinv00)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=((27.0/80.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)+(27.0/80.0)*Jinv01*Jinv00)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(81.0/40.0)*Jinv11*Jinv10-(81.0/40.0)*(Jinv01*Jinv01)-(81.0/40.0)*(Jinv11*Jinv11)-(81.0/40.0)*Jinv01*Jinv00)*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((27.0/40.0)*Jinv11*Jinv10-(27.0/80.0)*(Jinv00*Jinv00)-(27.0/80.0)*(Jinv10*Jinv10)-(27.0/80.0)*(Jinv01*Jinv01)-(27.0/80.0)*(Jinv11*Jinv11)+(27.0/40.0)*Jinv01*Jinv00)*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(27.0/16.0)*Jinv11*Jinv10-(27.0/16.0)*(Jinv00*Jinv00)-(27.0/16.0)*(Jinv10*Jinv10)-(27.0/16.0)*Jinv01*Jinv00)*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((27.0/16.0)*Jinv11*Jinv10+(27.0/16.0)*(Jinv00*Jinv00)+(27.0/16.0)*(Jinv10*Jinv10)+(27.0/16.0)*(Jinv01*Jinv01)+(27.0/16.0)*(Jinv11*Jinv11)+(27.0/16.0)*Jinv01*Jinv00)*D;
  A[17][18]=(0.0)*D;
  A[17][19]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[18][0]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01)-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[18][3]=(0.0)*D;
  A[18][4]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[18][5]=(0.0)*D;
  A[18][6]=((7.0/80.0)*Jinv11*Jinv10+(7.0/80.0)*Jinv01*Jinv00)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(0.0)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[18][13]=(0.0)*D;
  A[18][14]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((17.0/40.0)*(Jinv01*Jinv01)+(17.0/40.0)*(Jinv11*Jinv11))*D;
  A[18][19]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=(-(7.0/80.0)*Jinv11*Jinv10-(7.0/80.0)*(Jinv01*Jinv01)-(7.0/80.0)*(Jinv11*Jinv11)-(7.0/80.0)*Jinv01*Jinv00)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[19][4]=(0.0)*D;
  A[19][5]=(-(3.0/80.0)*(Jinv01*Jinv01)-(3.0/80.0)*(Jinv11*Jinv11))*D;
  A[19][6]=(0.0)*D;
  A[19][7]=((7.0/80.0)*Jinv11*Jinv10+(7.0/80.0)*Jinv01*Jinv00)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((3.0/10.0)*Jinv11*Jinv10+(27.0/80.0)*(Jinv01*Jinv01)+(27.0/80.0)*(Jinv11*Jinv11)+(3.0/10.0)*Jinv01*Jinv00)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(0.0)*D;
  A[19][12]=(0.0)*D;
  A[19][13]=(-(3.0/10.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)-(3.0/10.0)*Jinv01*Jinv00)*D;
  A[19][14]=(0.0)*D;
  A[19][15]=(-(57.0/80.0)*Jinv11*Jinv10-(27.0/40.0)*(Jinv01*Jinv01)-(27.0/40.0)*(Jinv11*Jinv11)-(57.0/80.0)*Jinv01*Jinv00)*D;
  A[19][16]=(0.0)*D;
  A[19][17]=((57.0/80.0)*Jinv11*Jinv10+(3.0/80.0)*(Jinv01*Jinv01)+(3.0/80.0)*(Jinv11*Jinv11)+(57.0/80.0)*Jinv01*Jinv00)*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((17.0/40.0)*(Jinv01*Jinv01)+(17.0/40.0)*(Jinv11*Jinv11))*D;
  int nbf = 20;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 4 ---------------*/


  
void matrix_factory_vector_stiffness_2D_order4 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[30];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/4.0+x0;  idof2[1]=G10/4.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/4.0+x0;  idof3[1]=G10/4.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G00/2.0+x0;  idof4[1]=G10/2.0+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G00/2.0+x0;  idof5[1]=G10/2.0+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=(3.0/4.0)*G00+x0;  idof6[1]=(3.0/4.0)*G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=(3.0/4.0)*G00+x0;  idof7[1]=(3.0/4.0)*G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G00+x0;  idof8[1]=G10+y0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G00+x0;  idof9[1]=G10+y0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01/4.0+x0;  idof10[1]=y0+G11/4.0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01/4.0+x0;  idof11[1]=y0+G11/4.0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/4.0+G00/4.0+x0;  idof12[1]=G10/4.0+y0+G11/4.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/4.0+G00/4.0+x0;  idof13[1]=G10/4.0+y0+G11/4.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=G01/4.0+G00/2.0+x0;  idof14[1]=G10/2.0+y0+G11/4.0;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=G01/4.0+G00/2.0+x0;  idof15[1]=G10/2.0+y0+G11/4.0;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=G01/4.0+(3.0/4.0)*G00+x0;  idof16[1]=(3.0/4.0)*G10+y0+G11/4.0;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=G01/4.0+(3.0/4.0)*G00+x0;  idof17[1]=(3.0/4.0)*G10+y0+G11/4.0;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01/2.0+x0;  idof18[1]=y0+G11/2.0;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01/2.0+x0;  idof19[1]=y0+G11/2.0;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

  double idof20[3];
  idof20[0]=G01/2.0+G00/4.0+x0;  idof20[1]=G10/4.0+y0+G11/2.0;
  idof20[2] = 0.0;
  ptv ipdof20(3,idof20);
  iidof[20] = dof.insert_dof(element,20,ipdof20);

  double idof21[3];
  idof21[0]=G01/2.0+G00/4.0+x0;  idof21[1]=G10/4.0+y0+G11/2.0;
  idof21[2] = 1.0;
  ptv ipdof21(3,idof21);
  iidof[21] = dof.insert_dof(element,21,ipdof21);

  double idof22[3];
  idof22[0]=G01/2.0+G00/2.0+x0;  idof22[1]=G10/2.0+y0+G11/2.0;
  idof22[2] = 0.0;
  ptv ipdof22(3,idof22);
  iidof[22] = dof.insert_dof(element,22,ipdof22);

  double idof23[3];
  idof23[0]=G01/2.0+G00/2.0+x0;  idof23[1]=G10/2.0+y0+G11/2.0;
  idof23[2] = 1.0;
  ptv ipdof23(3,idof23);
  iidof[23] = dof.insert_dof(element,23,ipdof23);

  double idof24[3];
  idof24[0]=(3.0/4.0)*G01+x0;  idof24[1]=y0+(3.0/4.0)*G11;
  idof24[2] = 0.0;
  ptv ipdof24(3,idof24);
  iidof[24] = dof.insert_dof(element,24,ipdof24);

  double idof25[3];
  idof25[0]=(3.0/4.0)*G01+x0;  idof25[1]=y0+(3.0/4.0)*G11;
  idof25[2] = 1.0;
  ptv ipdof25(3,idof25);
  iidof[25] = dof.insert_dof(element,25,ipdof25);

  double idof26[3];
  idof26[0]=(3.0/4.0)*G01+G00/4.0+x0;  idof26[1]=G10/4.0+y0+(3.0/4.0)*G11;
  idof26[2] = 0.0;
  ptv ipdof26(3,idof26);
  iidof[26] = dof.insert_dof(element,26,ipdof26);

  double idof27[3];
  idof27[0]=(3.0/4.0)*G01+G00/4.0+x0;  idof27[1]=G10/4.0+y0+(3.0/4.0)*G11;
  idof27[2] = 1.0;
  ptv ipdof27(3,idof27);
  iidof[27] = dof.insert_dof(element,27,ipdof27);

  double idof28[3];
  idof28[0]=G01+x0;  idof28[1]=y0+G11;
  idof28[2] = 0.0;
  ptv ipdof28(3,idof28);
  iidof[28] = dof.insert_dof(element,28,ipdof28);

  double idof29[3];
  idof29[0]=G01+x0;  idof29[1]=y0+G11;
  idof29[2] = 1.0;
  ptv ipdof29(3,idof29);
  iidof[29] = dof.insert_dof(element,29,ipdof29);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[30][30];
  A[0][0]=((47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10)+(47.0/126.0)*(Jinv01*Jinv01)+(47.0/63.0)*Jinv00*Jinv01+(47.0/126.0)*(Jinv11*Jinv11)+(47.0/63.0)*Jinv11*Jinv10)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)+(8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=((107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[0][19]=(0.0)*D;
  A[0][20]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[0][21]=(0.0)*D;
  A[0][22]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[0][23]=(0.0)*D;
  A[0][24]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[0][25]=(0.0)*D;
  A[0][26]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[0][27]=(0.0)*D;
  A[0][28]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[0][29]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10)+(47.0/126.0)*(Jinv01*Jinv01)+(47.0/63.0)*Jinv00*Jinv01+(47.0/126.0)*(Jinv11*Jinv11)+(47.0/63.0)*Jinv11*Jinv10)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)+(8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=((107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[1][20]=(0.0)*D;
  A[1][21]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[1][22]=(0.0)*D;
  A[1][23]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[1][24]=(0.0)*D;
  A[1][25]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[1][26]=(0.0)*D;
  A[1][27]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[1][28]=(0.0)*D;
  A[1][29]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[2][0]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)+(8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv11*Jinv10)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv11*Jinv10)*D;
  A[2][11]=(0.0)*D;
  A[2][12]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[2][19]=(0.0)*D;
  A[2][20]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[2][21]=(0.0)*D;
  A[2][22]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[2][23]=(0.0)*D;
  A[2][24]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[2][25]=(0.0)*D;
  A[2][26]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[2][27]=(0.0)*D;
  A[2][28]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[2][29]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)+(8.0/63.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv11*Jinv10)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv11*Jinv10)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[3][20]=(0.0)*D;
  A[3][21]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[3][22]=(0.0)*D;
  A[3][23]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[3][24]=(0.0)*D;
  A[3][25]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[3][26]=(0.0)*D;
  A[3][27]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[3][28]=(0.0)*D;
  A[3][29]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[4][0]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((932.0/315.0)*(Jinv00*Jinv00)+(932.0/315.0)*(Jinv10*Jinv10)+(772.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv00*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv11*Jinv10)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(134.0/315.0)*Jinv00*Jinv01+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv11*Jinv10)*D;
  A[4][19]=(0.0)*D;
  A[4][20]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[4][21]=(0.0)*D;
  A[4][22]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[4][23]=(0.0)*D;
  A[4][24]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[4][25]=(0.0)*D;
  A[4][26]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[4][27]=(0.0)*D;
  A[4][28]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[4][29]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((932.0/315.0)*(Jinv00*Jinv00)+(932.0/315.0)*(Jinv10*Jinv10)+(772.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv00*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv11*Jinv10)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(134.0/315.0)*Jinv00*Jinv01+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv11*Jinv10)*D;
  A[5][20]=(0.0)*D;
  A[5][21]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[5][22]=(0.0)*D;
  A[5][23]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[5][24]=(0.0)*D;
  A[5][25]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[5][26]=(0.0)*D;
  A[5][27]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[5][28]=(0.0)*D;
  A[5][29]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[6][0]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)-(736.0/945.0)*Jinv00*Jinv01-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(2432.0/945.0)*Jinv00*Jinv01+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[6][15]=(0.0)*D;
  A[6][16]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/189.0)*Jinv00*Jinv01+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[6][19]=(0.0)*D;
  A[6][20]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[6][21]=(0.0)*D;
  A[6][22]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[6][23]=(0.0)*D;
  A[6][24]=((64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[6][25]=(0.0)*D;
  A[6][26]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[6][27]=(0.0)*D;
  A[6][28]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[6][29]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(8.0/189.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((64.0/63.0)*(Jinv00*Jinv00)+(64.0/63.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(368.0/189.0)*(Jinv00*Jinv00)-(368.0/189.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)-(736.0/945.0)*Jinv00*Jinv01-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(2432.0/945.0)*Jinv00*Jinv01+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[7][16]=(0.0)*D;
  A[7][17]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/189.0)*Jinv00*Jinv01+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[7][20]=(0.0)*D;
  A[7][21]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[7][22]=(0.0)*D;
  A[7][23]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[7][24]=(0.0)*D;
  A[7][25]=((64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[7][26]=(0.0)*D;
  A[7][27]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[7][28]=(0.0)*D;
  A[7][29]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[8][0]=((107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(134.0/315.0)*Jinv00*Jinv01+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)-(736.0/945.0)*Jinv00*Jinv01-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10))*D;
  A[8][9]=(0.0)*D;
  A[8][10]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][11]=(0.0)*D;
  A[8][12]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][15]=(0.0)*D;
  A[8][16]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)+(736.0/945.0)*Jinv00*Jinv01+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][19]=(0.0)*D;
  A[8][20]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][21]=(0.0)*D;
  A[8][22]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)-(134.0/315.0)*Jinv00*Jinv01-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[8][23]=(0.0)*D;
  A[8][24]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[8][25]=(0.0)*D;
  A[8][26]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[8][27]=(0.0)*D;
  A[8][28]=(-(107.0/1890.0)*Jinv00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[8][29]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=((107.0/1890.0)*(Jinv00*Jinv00)+(107.0/1890.0)*(Jinv10*Jinv10)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(232.0/945.0)*(Jinv00*Jinv00)-(232.0/945.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((442.0/945.0)*(Jinv00*Jinv00)+(442.0/945.0)*(Jinv10*Jinv10)+(134.0/315.0)*Jinv00*Jinv01+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(88.0/135.0)*(Jinv00*Jinv00)-(88.0/135.0)*(Jinv10*Jinv10)-(736.0/945.0)*Jinv00*Jinv01-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((47.0/126.0)*(Jinv00*Jinv00)+(47.0/126.0)*(Jinv10*Jinv10))*D;
  A[9][10]=(0.0)*D;
  A[9][11]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][12]=(0.0)*D;
  A[9][13]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][16]=(0.0)*D;
  A[9][17]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)+(736.0/945.0)*Jinv00*Jinv01+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][20]=(0.0)*D;
  A[9][21]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][22]=(0.0)*D;
  A[9][23]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)-(134.0/315.0)*Jinv00*Jinv01-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[9][24]=(0.0)*D;
  A[9][25]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[9][26]=(0.0)*D;
  A[9][27]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[9][28]=(0.0)*D;
  A[9][29]=(-(107.0/1890.0)*Jinv00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[10][0]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv11*Jinv10)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv11*Jinv10)*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[10][19]=(0.0)*D;
  A[10][20]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[10][21]=(0.0)*D;
  A[10][22]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[10][23]=(0.0)*D;
  A[10][24]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[10][25]=(0.0)*D;
  A[10][26]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[10][27]=(0.0)*D;
  A[10][28]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[10][29]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)-(88.0/135.0)*(Jinv01*Jinv01)-(496.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(496.0/945.0)*Jinv11*Jinv10)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/35.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/35.0)*Jinv11*Jinv10)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1472.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1472.0/945.0)*Jinv11*Jinv10)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[11][20]=(0.0)*D;
  A[11][21]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[11][22]=(0.0)*D;
  A[11][23]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[11][24]=(0.0)*D;
  A[11][25]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[11][26]=(0.0)*D;
  A[11][27]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[11][28]=(0.0)*D;
  A[11][29]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[12][0]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[12][13]=(0.0)*D;
  A[12][14]=(-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[12][15]=(0.0)*D;
  A[12][16]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[12][17]=(0.0)*D;
  A[12][18]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[12][19]=(0.0)*D;
  A[12][20]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[12][21]=(0.0)*D;
  A[12][22]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv11*Jinv10)*D;
  A[12][23]=(0.0)*D;
  A[12][24]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[12][25]=(0.0)*D;
  A[12][26]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[12][27]=(0.0)*D;
  A[12][28]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[12][29]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(256.0/105.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)-(2176.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(2176.0/945.0)*Jinv11*Jinv10)*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[13][14]=(0.0)*D;
  A[13][15]=(-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[13][16]=(0.0)*D;
  A[13][17]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[13][18]=(0.0)*D;
  A[13][19]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[13][20]=(0.0)*D;
  A[13][21]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[13][22]=(0.0)*D;
  A[13][23]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv11*Jinv10)*D;
  A[13][24]=(0.0)*D;
  A[13][25]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[13][26]=(0.0)*D;
  A[13][27]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[13][28]=(0.0)*D;
  A[13][29]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][0]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(2432.0/945.0)*Jinv00*Jinv01+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=(-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)-(2432.0/945.0)*Jinv00*Jinv01-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[14][17]=(0.0)*D;
  A[14][18]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[14][19]=(0.0)*D;
  A[14][20]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv11*Jinv10)*D;
  A[14][21]=(0.0)*D;
  A[14][22]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[14][23]=(0.0)*D;
  A[14][24]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[14][25]=(0.0)*D;
  A[14][26]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[14][27]=(0.0)*D;
  A[14][28]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[14][29]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(2432.0/945.0)*Jinv00*Jinv01+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[15][12]=(0.0)*D;
  A[15][13]=(-(256.0/63.0)*(Jinv00*Jinv00)-(256.0/63.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)-(2432.0/945.0)*Jinv00*Jinv01-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[15][20]=(0.0)*D;
  A[15][21]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv11*Jinv10)*D;
  A[15][22]=(0.0)*D;
  A[15][23]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[15][24]=(0.0)*D;
  A[15][25]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[15][26]=(0.0)*D;
  A[15][27]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[15][28]=(0.0)*D;
  A[15][29]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[16][0]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)+(736.0/945.0)*Jinv00*Jinv01+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)-(2432.0/945.0)*Jinv00*Jinv01-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[16][17]=(0.0)*D;
  A[16][18]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(16.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[16][19]=(0.0)*D;
  A[16][20]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[16][21]=(0.0)*D;
  A[16][22]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[16][23]=(0.0)*D;
  A[16][24]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[16][25]=(0.0)*D;
  A[16][26]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv11*Jinv10)*D;
  A[16][27]=(0.0)*D;
  A[16][28]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[16][29]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=((32.0/315.0)*(Jinv00*Jinv00)+(32.0/315.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=(-(128.0/945.0)*(Jinv00*Jinv00)-(128.0/945.0)*(Jinv10*Jinv10)-(1984.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(1984.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=((8.0/63.0)*(Jinv00*Jinv00)+(8.0/63.0)*(Jinv10*Jinv10)+(736.0/945.0)*Jinv00*Jinv01+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(64.0/315.0)*(Jinv00*Jinv00)-(64.0/315.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(256.0/105.0)*(Jinv00*Jinv00)-(256.0/105.0)*(Jinv10*Jinv10)-(2432.0/945.0)*Jinv00*Jinv01-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((64.0/35.0)*(Jinv00*Jinv00)+(64.0/35.0)*(Jinv10*Jinv10)+(1984.0/945.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(1984.0/945.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[17][18]=(0.0)*D;
  A[17][19]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(16.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[17][20]=(0.0)*D;
  A[17][21]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[17][22]=(0.0)*D;
  A[17][23]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[17][24]=(0.0)*D;
  A[17][25]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[17][26]=(0.0)*D;
  A[17][27]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv11*Jinv10)*D;
  A[17][28]=(0.0)*D;
  A[17][29]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[18][0]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[18][3]=(0.0)*D;
  A[18][4]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv11*Jinv10)*D;
  A[18][5]=(0.0)*D;
  A[18][6]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/189.0)*Jinv00*Jinv01+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[18][13]=(0.0)*D;
  A[18][14]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(16.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10)+(932.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv00*Jinv01+(932.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv11*Jinv10)*D;
  A[18][19]=(0.0)*D;
  A[18][20]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[18][21]=(0.0)*D;
  A[18][22]=((124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[18][23]=(0.0)*D;
  A[18][24]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[18][25]=(0.0)*D;
  A[18][26]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[18][27]=(0.0)*D;
  A[18][28]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[18][29]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(442.0/945.0)*(Jinv01*Jinv01)+(482.0/945.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(482.0/945.0)*Jinv11*Jinv10)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)-(688.0/945.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)-(688.0/945.0)*Jinv11*Jinv10)*D;
  A[19][4]=(0.0)*D;
  A[19][5]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)-(92.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)-(92.0/315.0)*Jinv11*Jinv10)*D;
  A[19][6]=(0.0)*D;
  A[19][7]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/189.0)*Jinv00*Jinv01+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1744.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1744.0/945.0)*Jinv11*Jinv10)*D;
  A[19][12]=(0.0)*D;
  A[19][13]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)+(992.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)+(992.0/315.0)*Jinv11*Jinv10)*D;
  A[19][14]=(0.0)*D;
  A[19][15]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[19][16]=(0.0)*D;
  A[19][17]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(16.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10)+(932.0/315.0)*(Jinv01*Jinv01)+(932.0/315.0)*Jinv00*Jinv01+(932.0/315.0)*(Jinv11*Jinv11)+(932.0/315.0)*Jinv11*Jinv10)*D;
  A[19][20]=(0.0)*D;
  A[19][21]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[19][22]=(0.0)*D;
  A[19][23]=((124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[19][24]=(0.0)*D;
  A[19][25]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[19][26]=(0.0)*D;
  A[19][27]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[19][28]=(0.0)*D;
  A[19][29]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[20][0]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[20][1]=(0.0)*D;
  A[20][2]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[20][3]=(0.0)*D;
  A[20][4]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[20][5]=(0.0)*D;
  A[20][6]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[20][9]=(0.0)*D;
  A[20][10]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[20][11]=(0.0)*D;
  A[20][12]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[20][13]=(0.0)*D;
  A[20][14]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv11*Jinv10)*D;
  A[20][15]=(0.0)*D;
  A[20][16]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[20][17]=(0.0)*D;
  A[20][18]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[20][19]=(0.0)*D;
  A[20][20]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[20][21]=(0.0)*D;
  A[20][22]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[20][23]=(0.0)*D;
  A[20][24]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[20][25]=(0.0)*D;
  A[20][26]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[20][27]=(0.0)*D;
  A[20][28]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[20][29]=(0.0)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10)-(16.0/189.0)*(Jinv01*Jinv01)-(32.0/189.0)*Jinv00*Jinv01-(16.0/189.0)*(Jinv11*Jinv11)-(32.0/189.0)*Jinv11*Jinv10)*D;
  A[21][2]=(0.0)*D;
  A[21][3]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)+(256.0/315.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(-(32.0/315.0)*(Jinv00*Jinv00)-(32.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(32.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(32.0/315.0)*Jinv11*Jinv10)*D;
  A[21][6]=(0.0)*D;
  A[21][7]=((128.0/945.0)*(Jinv00*Jinv00)+(128.0/945.0)*(Jinv10*Jinv10)-(128.0/189.0)*Jinv00*Jinv01-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[21][8]=(0.0)*D;
  A[21][9]=(-(16.0/189.0)*(Jinv00*Jinv00)-(16.0/189.0)*(Jinv10*Jinv10))*D;
  A[21][10]=(0.0)*D;
  A[21][11]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/945.0)*(Jinv01*Jinv01)+(128.0/135.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(128.0/135.0)*Jinv11*Jinv10)*D;
  A[21][12]=(0.0)*D;
  A[21][13]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/63.0)*(Jinv01*Jinv01)-(256.0/63.0)*Jinv00*Jinv01-(256.0/63.0)*(Jinv11*Jinv11)-(256.0/63.0)*Jinv11*Jinv10)*D;
  A[21][14]=(0.0)*D;
  A[21][15]=(-(256.0/315.0)*(Jinv00*Jinv00)-(256.0/315.0)*(Jinv10*Jinv10)-(256.0/315.0)*(Jinv01*Jinv01)+(256.0/105.0)*Jinv00*Jinv01-(256.0/315.0)*(Jinv11*Jinv11)+(256.0/105.0)*Jinv11*Jinv10)*D;
  A[21][16]=(0.0)*D;
  A[21][17]=((256.0/315.0)*(Jinv00*Jinv00)+(256.0/315.0)*(Jinv10*Jinv10)+(128.0/189.0)*Jinv00*Jinv01+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[21][18]=(0.0)*D;
  A[21][19]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)-(32.0/315.0)*(Jinv01*Jinv01)-(352.0/105.0)*Jinv00*Jinv01-(32.0/315.0)*(Jinv11*Jinv11)-(352.0/105.0)*Jinv11*Jinv10)*D;
  A[21][20]=(0.0)*D;
  A[21][21]=((256.0/45.0)*(Jinv00*Jinv00)+(256.0/45.0)*(Jinv10*Jinv10)+(256.0/45.0)*(Jinv01*Jinv01)+(256.0/45.0)*Jinv00*Jinv01+(256.0/45.0)*(Jinv11*Jinv11)+(256.0/45.0)*Jinv11*Jinv10)*D;
  A[21][22]=(0.0)*D;
  A[21][23]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[21][24]=(0.0)*D;
  A[21][25]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[21][26]=(0.0)*D;
  A[21][27]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[21][28]=(0.0)*D;
  A[21][29]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[22][0]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[22][1]=(0.0)*D;
  A[22][2]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[22][3]=(0.0)*D;
  A[22][4]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[22][5]=(0.0)*D;
  A[22][6]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[22][7]=(0.0)*D;
  A[22][8]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)-(134.0/315.0)*Jinv00*Jinv01-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[22][9]=(0.0)*D;
  A[22][10]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[22][11]=(0.0)*D;
  A[22][12]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv11*Jinv10)*D;
  A[22][13]=(0.0)*D;
  A[22][14]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[22][15]=(0.0)*D;
  A[22][16]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[22][17]=(0.0)*D;
  A[22][18]=((124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[22][19]=(0.0)*D;
  A[22][20]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[22][21]=(0.0)*D;
  A[22][22]=((772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10)+(772.0/315.0)*(Jinv01*Jinv01)+(68.0/35.0)*Jinv00*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)+(68.0/35.0)*Jinv11*Jinv10)*D;
  A[22][23]=(0.0)*D;
  A[22][24]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[22][25]=(0.0)*D;
  A[22][26]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[22][27]=(0.0)*D;
  A[22][28]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[22][29]=(0.0)*D;
  A[23][0]=(0.0)*D;
  A[23][1]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[23][2]=(0.0)*D;
  A[23][3]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)-(16.0/105.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[23][4]=(0.0)*D;
  A[23][5]=((16.0/315.0)*(Jinv00*Jinv00)+(16.0/315.0)*(Jinv10*Jinv10)+(124.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(124.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(-(64.0/945.0)*(Jinv00*Jinv00)-(64.0/945.0)*(Jinv10*Jinv10)+(16.0/21.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01+(16.0/21.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[23][8]=(0.0)*D;
  A[23][9]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)-(134.0/315.0)*Jinv00*Jinv01-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(-(16.0/105.0)*(Jinv00*Jinv00)-(16.0/105.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)-(208.0/945.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)-(208.0/945.0)*Jinv11*Jinv10)*D;
  A[23][12]=(0.0)*D;
  A[23][13]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)+(32.0/35.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)+(32.0/35.0)*Jinv11*Jinv10)*D;
  A[23][14]=(0.0)*D;
  A[23][15]=((128.0/315.0)*(Jinv00*Jinv00)+(128.0/315.0)*(Jinv10*Jinv10)-(128.0/45.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01-(128.0/45.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[23][16]=(0.0)*D;
  A[23][17]=(-(208.0/315.0)*(Jinv00*Jinv00)-(208.0/315.0)*(Jinv10*Jinv10)-(16.0/21.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(16.0/21.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[23][18]=(0.0)*D;
  A[23][19]=((124.0/315.0)*(Jinv00*Jinv00)+(124.0/315.0)*(Jinv10*Jinv10)+(16.0/315.0)*(Jinv01*Jinv01)+(124.0/315.0)*Jinv00*Jinv01+(16.0/315.0)*(Jinv11*Jinv11)+(124.0/315.0)*Jinv11*Jinv10)*D;
  A[23][20]=(0.0)*D;
  A[23][21]=(-(128.0/45.0)*(Jinv00*Jinv00)-(128.0/45.0)*(Jinv10*Jinv10)+(128.0/315.0)*(Jinv01*Jinv01)-(736.0/315.0)*Jinv00*Jinv01+(128.0/315.0)*(Jinv11*Jinv11)-(736.0/315.0)*Jinv11*Jinv10)*D;
  A[23][22]=(0.0)*D;
  A[23][23]=((772.0/315.0)*(Jinv00*Jinv00)+(772.0/315.0)*(Jinv10*Jinv10)+(772.0/315.0)*(Jinv01*Jinv01)+(68.0/35.0)*Jinv00*Jinv01+(772.0/315.0)*(Jinv11*Jinv11)+(68.0/35.0)*Jinv11*Jinv10)*D;
  A[23][24]=(0.0)*D;
  A[23][25]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[23][26]=(0.0)*D;
  A[23][27]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[23][28]=(0.0)*D;
  A[23][29]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[24][0]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[24][1]=(0.0)*D;
  A[24][2]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[24][3]=(0.0)*D;
  A[24][4]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[24][5]=(0.0)*D;
  A[24][6]=((64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[24][7]=(0.0)*D;
  A[24][8]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[24][9]=(0.0)*D;
  A[24][10]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[24][11]=(0.0)*D;
  A[24][12]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[24][13]=(0.0)*D;
  A[24][14]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[24][15]=(0.0)*D;
  A[24][16]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[24][17]=(0.0)*D;
  A[24][18]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[24][19]=(0.0)*D;
  A[24][20]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[24][21]=(0.0)*D;
  A[24][22]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[24][23]=(0.0)*D;
  A[24][24]=((1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[24][25]=(0.0)*D;
  A[24][26]=(-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[24][27]=(0.0)*D;
  A[24][28]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[24][29]=(0.0)*D;
  A[25][0]=(0.0)*D;
  A[25][1]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)-(232.0/945.0)*(Jinv01*Jinv01)-(272.0/945.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(272.0/945.0)*Jinv11*Jinv10)*D;
  A[25][2]=(0.0)*D;
  A[25][3]=(-(128.0/945.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[25][4]=(0.0)*D;
  A[25][5]=(-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[25][6]=(0.0)*D;
  A[25][7]=((64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[25][8]=(0.0)*D;
  A[25][9]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10))*D;
  A[25][10]=(0.0)*D;
  A[25][11]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/63.0)*(Jinv01*Jinv01)+(64.0/63.0)*Jinv00*Jinv01+(64.0/63.0)*(Jinv11*Jinv11)+(64.0/63.0)*Jinv11*Jinv10)*D;
  A[25][12]=(0.0)*D;
  A[25][13]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[25][14]=(0.0)*D;
  A[25][15]=((128.0/945.0)*(Jinv01*Jinv01)-(128.0/189.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)-(128.0/189.0)*Jinv11*Jinv10)*D;
  A[25][16]=(0.0)*D;
  A[25][17]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[25][18]=(0.0)*D;
  A[25][19]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(368.0/189.0)*(Jinv01*Jinv01)-(1936.0/945.0)*Jinv00*Jinv01-(368.0/189.0)*(Jinv11*Jinv11)-(1936.0/945.0)*Jinv11*Jinv10)*D;
  A[25][20]=(0.0)*D;
  A[25][21]=((128.0/945.0)*(Jinv01*Jinv01)+(2432.0/945.0)*Jinv00*Jinv01+(128.0/945.0)*(Jinv11*Jinv11)+(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[25][22]=(0.0)*D;
  A[25][23]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)-(64.0/945.0)*(Jinv01*Jinv01)+(16.0/27.0)*Jinv00*Jinv01-(64.0/945.0)*(Jinv11*Jinv11)+(16.0/27.0)*Jinv11*Jinv10)*D;
  A[25][24]=(0.0)*D;
  A[25][25]=((1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[25][26]=(0.0)*D;
  A[25][27]=(-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[25][28]=(0.0)*D;
  A[25][29]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[26][0]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[26][1]=(0.0)*D;
  A[26][2]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[26][3]=(0.0)*D;
  A[26][4]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[26][5]=(0.0)*D;
  A[26][6]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[26][7]=(0.0)*D;
  A[26][8]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[26][9]=(0.0)*D;
  A[26][10]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[26][11]=(0.0)*D;
  A[26][12]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[26][13]=(0.0)*D;
  A[26][14]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[26][15]=(0.0)*D;
  A[26][16]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv11*Jinv10)*D;
  A[26][17]=(0.0)*D;
  A[26][18]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[26][19]=(0.0)*D;
  A[26][20]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[26][21]=(0.0)*D;
  A[26][22]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[26][23]=(0.0)*D;
  A[26][24]=(-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[26][25]=(0.0)*D;
  A[26][26]=((1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[26][27]=(0.0)*D;
  A[26][28]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[26][29]=(0.0)*D;
  A[27][0]=(0.0)*D;
  A[27][1]=((8.0/189.0)*(Jinv00*Jinv00)+(8.0/189.0)*(Jinv10*Jinv10)+(8.0/189.0)*(Jinv01*Jinv01)+(16.0/189.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)+(16.0/189.0)*Jinv11*Jinv10)*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(-(64.0/315.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/315.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[27][4]=(0.0)*D;
  A[27][5]=(-(16.0/105.0)*(Jinv01*Jinv01)-(16.0/189.0)*Jinv00*Jinv01-(16.0/105.0)*(Jinv11*Jinv11)-(16.0/189.0)*Jinv11*Jinv10)*D;
  A[27][6]=(0.0)*D;
  A[27][7]=(-(64.0/189.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(64.0/189.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[27][8]=(0.0)*D;
  A[27][9]=(-(8.0/189.0)*(Jinv00*Jinv00)-(8.0/189.0)*(Jinv10*Jinv10)+(64.0/315.0)*Jinv00*Jinv01+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(-(64.0/189.0)*(Jinv00*Jinv00)-(64.0/189.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(64.0/135.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(64.0/135.0)*Jinv11*Jinv10)*D;
  A[27][12]=(0.0)*D;
  A[27][13]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[27][14]=(0.0)*D;
  A[27][15]=((256.0/315.0)*(Jinv01*Jinv01)+(128.0/189.0)*Jinv00*Jinv01+(256.0/315.0)*(Jinv11*Jinv11)+(128.0/189.0)*Jinv11*Jinv10)*D;
  A[27][16]=(0.0)*D;
  A[27][17]=((64.0/189.0)*(Jinv00*Jinv00)+(64.0/189.0)*(Jinv10*Jinv10)+(64.0/189.0)*(Jinv01*Jinv01)-(64.0/189.0)*Jinv00*Jinv01+(64.0/189.0)*(Jinv11*Jinv11)-(64.0/189.0)*Jinv11*Jinv10)*D;
  A[27][18]=(0.0)*D;
  A[27][19]=((16.0/21.0)*(Jinv00*Jinv00)+(16.0/21.0)*(Jinv10*Jinv10)+(32.0/315.0)*(Jinv01*Jinv01)+(176.0/189.0)*Jinv00*Jinv01+(32.0/315.0)*(Jinv11*Jinv11)+(176.0/189.0)*Jinv11*Jinv10)*D;
  A[27][20]=(0.0)*D;
  A[27][21]=(-(256.0/105.0)*(Jinv01*Jinv01)-(2432.0/945.0)*Jinv00*Jinv01-(256.0/105.0)*(Jinv11*Jinv11)-(2432.0/945.0)*Jinv11*Jinv10)*D;
  A[27][22]=(0.0)*D;
  A[27][23]=(-(16.0/21.0)*(Jinv00*Jinv00)-(16.0/21.0)*(Jinv10*Jinv10)-(208.0/315.0)*(Jinv01*Jinv01)+(496.0/945.0)*Jinv00*Jinv01-(208.0/315.0)*(Jinv11*Jinv11)+(496.0/945.0)*Jinv11*Jinv10)*D;
  A[27][24]=(0.0)*D;
  A[27][25]=(-(1984.0/945.0)*(Jinv00*Jinv00)-(1984.0/945.0)*(Jinv10*Jinv10)-(128.0/945.0)*(Jinv01*Jinv01)-(1984.0/945.0)*Jinv00*Jinv01-(128.0/945.0)*(Jinv11*Jinv11)-(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[27][26]=(0.0)*D;
  A[27][27]=((1984.0/945.0)*(Jinv00*Jinv00)+(1984.0/945.0)*(Jinv10*Jinv10)+(64.0/35.0)*(Jinv01*Jinv01)+(1984.0/945.0)*Jinv00*Jinv01+(64.0/35.0)*(Jinv11*Jinv11)+(1984.0/945.0)*Jinv11*Jinv10)*D;
  A[27][28]=(0.0)*D;
  A[27][29]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[28][0]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[28][1]=(0.0)*D;
  A[28][2]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][3]=(0.0)*D;
  A[28][4]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][5]=(0.0)*D;
  A[28][6]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][7]=(0.0)*D;
  A[28][8]=(-(107.0/1890.0)*Jinv00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[28][9]=(0.0)*D;
  A[28][10]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[28][11]=(0.0)*D;
  A[28][12]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][13]=(0.0)*D;
  A[28][14]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][15]=(0.0)*D;
  A[28][16]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[28][17]=(0.0)*D;
  A[28][18]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[28][19]=(0.0)*D;
  A[28][20]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[28][21]=(0.0)*D;
  A[28][22]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[28][23]=(0.0)*D;
  A[28][24]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[28][25]=(0.0)*D;
  A[28][26]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[28][27]=(0.0)*D;
  A[28][28]=((47.0/126.0)*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11))*D;
  A[28][29]=(0.0)*D;
  A[29][0]=(0.0)*D;
  A[29][1]=((107.0/1890.0)*(Jinv01*Jinv01)+(107.0/1890.0)*Jinv00*Jinv01+(107.0/1890.0)*(Jinv11*Jinv11)+(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[29][2]=(0.0)*D;
  A[29][3]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][4]=(0.0)*D;
  A[29][5]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][6]=(0.0)*D;
  A[29][7]=((8.0/189.0)*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][8]=(0.0)*D;
  A[29][9]=(-(107.0/1890.0)*Jinv00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10)*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(-(232.0/945.0)*(Jinv01*Jinv01)-(64.0/315.0)*Jinv00*Jinv01-(232.0/945.0)*(Jinv11*Jinv11)-(64.0/315.0)*Jinv11*Jinv10)*D;
  A[29][12]=(0.0)*D;
  A[29][13]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][14]=(0.0)*D;
  A[29][15]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][16]=(0.0)*D;
  A[29][17]=(-(8.0/189.0)*(Jinv01*Jinv01)+(64.0/315.0)*Jinv00*Jinv01-(8.0/189.0)*(Jinv11*Jinv11)+(64.0/315.0)*Jinv11*Jinv10)*D;
  A[29][18]=(0.0)*D;
  A[29][19]=((442.0/945.0)*(Jinv01*Jinv01)+(134.0/315.0)*Jinv00*Jinv01+(442.0/945.0)*(Jinv11*Jinv11)+(134.0/315.0)*Jinv11*Jinv10)*D;
  A[29][20]=(0.0)*D;
  A[29][21]=(-(16.0/189.0)*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11))*D;
  A[29][22]=(0.0)*D;
  A[29][23]=((8.0/189.0)*(Jinv01*Jinv01)-(134.0/315.0)*Jinv00*Jinv01+(8.0/189.0)*(Jinv11*Jinv11)-(134.0/315.0)*Jinv11*Jinv10)*D;
  A[29][24]=(0.0)*D;
  A[29][25]=(-(88.0/135.0)*(Jinv01*Jinv01)-(736.0/945.0)*Jinv00*Jinv01-(88.0/135.0)*(Jinv11*Jinv11)-(736.0/945.0)*Jinv11*Jinv10)*D;
  A[29][26]=(0.0)*D;
  A[29][27]=((8.0/63.0)*(Jinv01*Jinv01)+(736.0/945.0)*Jinv00*Jinv01+(8.0/63.0)*(Jinv11*Jinv11)+(736.0/945.0)*Jinv11*Jinv10)*D;
  A[29][28]=(0.0)*D;
  A[29][29]=((47.0/126.0)*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11))*D;
  int nbf = 30;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 5 ---------------*/


  
void matrix_factory_vector_stiffness_2D_order5 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double pp0[2], double pp1[2], double pp2[2]){
  
  
  
  
  //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  

  int    iidof[42];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/5.0+x0;  idof2[1]=G10/5.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/5.0+x0;  idof3[1]=G10/5.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=(2.0/5.0)*G00+x0;  idof4[1]=(2.0/5.0)*G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=(2.0/5.0)*G00+x0;  idof5[1]=(2.0/5.0)*G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=(3.0/5.0)*G00+x0;  idof6[1]=(3.0/5.0)*G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=(3.0/5.0)*G00+x0;  idof7[1]=(3.0/5.0)*G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=(4.0/5.0)*G00+x0;  idof8[1]=(4.0/5.0)*G10+y0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=(4.0/5.0)*G00+x0;  idof9[1]=(4.0/5.0)*G10+y0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G00+x0;  idof10[1]=G10+y0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G00+x0;  idof11[1]=G10+y0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/5.0+x0;  idof12[1]=y0+G11/5.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/5.0+x0;  idof13[1]=y0+G11/5.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=G01/5.0+G00/5.0+x0;  idof14[1]=G10/5.0+y0+G11/5.0;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=G01/5.0+G00/5.0+x0;  idof15[1]=G10/5.0+y0+G11/5.0;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=G01/5.0+(2.0/5.0)*G00+x0;  idof16[1]=(2.0/5.0)*G10+y0+G11/5.0;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=G01/5.0+(2.0/5.0)*G00+x0;  idof17[1]=(2.0/5.0)*G10+y0+G11/5.0;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01/5.0+(3.0/5.0)*G00+x0;  idof18[1]=(3.0/5.0)*G10+y0+G11/5.0;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01/5.0+(3.0/5.0)*G00+x0;  idof19[1]=(3.0/5.0)*G10+y0+G11/5.0;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

  double idof20[3];
  idof20[0]=G01/5.0+(4.0/5.0)*G00+x0;  idof20[1]=(4.0/5.0)*G10+y0+G11/5.0;
  idof20[2] = 0.0;
  ptv ipdof20(3,idof20);
  iidof[20] = dof.insert_dof(element,20,ipdof20);

  double idof21[3];
  idof21[0]=G01/5.0+(4.0/5.0)*G00+x0;  idof21[1]=(4.0/5.0)*G10+y0+G11/5.0;
  idof21[2] = 1.0;
  ptv ipdof21(3,idof21);
  iidof[21] = dof.insert_dof(element,21,ipdof21);

  double idof22[3];
  idof22[0]=(2.0/5.0)*G01+x0;  idof22[1]=y0+(2.0/5.0)*G11;
  idof22[2] = 0.0;
  ptv ipdof22(3,idof22);
  iidof[22] = dof.insert_dof(element,22,ipdof22);

  double idof23[3];
  idof23[0]=(2.0/5.0)*G01+x0;  idof23[1]=y0+(2.0/5.0)*G11;
  idof23[2] = 1.0;
  ptv ipdof23(3,idof23);
  iidof[23] = dof.insert_dof(element,23,ipdof23);

  double idof24[3];
  idof24[0]=(2.0/5.0)*G01+G00/5.0+x0;  idof24[1]=G10/5.0+y0+(2.0/5.0)*G11;
  idof24[2] = 0.0;
  ptv ipdof24(3,idof24);
  iidof[24] = dof.insert_dof(element,24,ipdof24);

  double idof25[3];
  idof25[0]=(2.0/5.0)*G01+G00/5.0+x0;  idof25[1]=G10/5.0+y0+(2.0/5.0)*G11;
  idof25[2] = 1.0;
  ptv ipdof25(3,idof25);
  iidof[25] = dof.insert_dof(element,25,ipdof25);

  double idof26[3];
  idof26[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof26[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof26[2] = 0.0;
  ptv ipdof26(3,idof26);
  iidof[26] = dof.insert_dof(element,26,ipdof26);

  double idof27[3];
  idof27[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof27[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof27[2] = 1.0;
  ptv ipdof27(3,idof27);
  iidof[27] = dof.insert_dof(element,27,ipdof27);

  double idof28[3];
  idof28[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  idof28[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof28[2] = 0.0;
  ptv ipdof28(3,idof28);
  iidof[28] = dof.insert_dof(element,28,ipdof28);

  double idof29[3];
  idof29[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  idof29[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof29[2] = 1.0;
  ptv ipdof29(3,idof29);
  iidof[29] = dof.insert_dof(element,29,ipdof29);

  double idof30[3];
  idof30[0]=(3.0/5.0)*G01+x0;  idof30[1]=y0+(3.0/5.0)*G11;
  idof30[2] = 0.0;
  ptv ipdof30(3,idof30);
  iidof[30] = dof.insert_dof(element,30,ipdof30);

  double idof31[3];
  idof31[0]=(3.0/5.0)*G01+x0;  idof31[1]=y0+(3.0/5.0)*G11;
  idof31[2] = 1.0;
  ptv ipdof31(3,idof31);
  iidof[31] = dof.insert_dof(element,31,ipdof31);

  double idof32[3];
  idof32[0]=(3.0/5.0)*G01+G00/5.0+x0;  idof32[1]=G10/5.0+y0+(3.0/5.0)*G11;
  idof32[2] = 0.0;
  ptv ipdof32(3,idof32);
  iidof[32] = dof.insert_dof(element,32,ipdof32);

  double idof33[3];
  idof33[0]=(3.0/5.0)*G01+G00/5.0+x0;  idof33[1]=G10/5.0+y0+(3.0/5.0)*G11;
  idof33[2] = 1.0;
  ptv ipdof33(3,idof33);
  iidof[33] = dof.insert_dof(element,33,ipdof33);

  double idof34[3];
  idof34[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof34[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  idof34[2] = 0.0;
  ptv ipdof34(3,idof34);
  iidof[34] = dof.insert_dof(element,34,ipdof34);

  double idof35[3];
  idof35[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof35[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  idof35[2] = 1.0;
  ptv ipdof35(3,idof35);
  iidof[35] = dof.insert_dof(element,35,ipdof35);

  double idof36[3];
  idof36[0]=(4.0/5.0)*G01+x0;  idof36[1]=y0+(4.0/5.0)*G11;
  idof36[2] = 0.0;
  ptv ipdof36(3,idof36);
  iidof[36] = dof.insert_dof(element,36,ipdof36);

  double idof37[3];
  idof37[0]=(4.0/5.0)*G01+x0;  idof37[1]=y0+(4.0/5.0)*G11;
  idof37[2] = 1.0;
  ptv ipdof37(3,idof37);
  iidof[37] = dof.insert_dof(element,37,ipdof37);

  double idof38[3];
  idof38[0]=(4.0/5.0)*G01+G00/5.0+x0;  idof38[1]=G10/5.0+y0+(4.0/5.0)*G11;
  idof38[2] = 0.0;
  ptv ipdof38(3,idof38);
  iidof[38] = dof.insert_dof(element,38,ipdof38);

  double idof39[3];
  idof39[0]=(4.0/5.0)*G01+G00/5.0+x0;  idof39[1]=G10/5.0+y0+(4.0/5.0)*G11;
  idof39[2] = 1.0;
  ptv ipdof39(3,idof39);
  iidof[39] = dof.insert_dof(element,39,ipdof39);

  double idof40[3];
  idof40[0]=G01+x0;  idof40[1]=y0+G11;
  idof40[2] = 0.0;
  ptv ipdof40(3,idof40);
  iidof[40] = dof.insert_dof(element,40,ipdof40);

  double idof41[3];
  idof41[0]=G01+x0;  idof41[1]=y0+G11;
  idof41[2] = 1.0;
  ptv ipdof41(3,idof41);
  iidof[41] = dof.insert_dof(element,41,ipdof41);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[42][42];
  A[0][0]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/24192.0)*Jinv10*Jinv11+(16567.0/24192.0)*Jinv01*Jinv00+(16567.0/48384.0)*(Jinv11*Jinv11)+(16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][1]=(0.0)*D;
  A[0][2]=((725.0/3584.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11)-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(-(575.0/36288.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11)+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11)-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][7]=(0.0)*D;
  A[0][8]=((1975.0/48384.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11)+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[0][13]=(0.0)*D;
  A[0][14]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[0][15]=(0.0)*D;
  A[0][16]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][17]=(0.0)*D;
  A[0][18]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][19]=(0.0)*D;
  A[0][20]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][21]=(0.0)*D;
  A[0][22]=((14375.0/24192.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11)-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[0][23]=(0.0)*D;
  A[0][24]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][25]=(0.0)*D;
  A[0][26]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][27]=(0.0)*D;
  A[0][28]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[0][29]=(0.0)*D;
  A[0][30]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11)-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[0][31]=(0.0)*D;
  A[0][32]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[0][33]=(0.0)*D;
  A[0][34]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[0][35]=(0.0)*D;
  A[0][36]=((29375.0/145152.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11)+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][37]=(0.0)*D;
  A[0][38]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[0][39]=(0.0)*D;
  A[0][40]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv11*Jinv11))*D;
  A[0][41]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/24192.0)*Jinv10*Jinv11+(16567.0/24192.0)*Jinv01*Jinv00+(16567.0/48384.0)*(Jinv11*Jinv11)+(16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[1][2]=(0.0)*D;
  A[1][3]=((725.0/3584.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11)-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[1][4]=(0.0)*D;
  A[1][5]=(-(575.0/36288.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11)+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11)-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][8]=(0.0)*D;
  A[1][9]=((1975.0/48384.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][10]=(0.0)*D;
  A[1][11]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11)+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[1][14]=(0.0)*D;
  A[1][15]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[1][16]=(0.0)*D;
  A[1][17]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][18]=(0.0)*D;
  A[1][19]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][20]=(0.0)*D;
  A[1][21]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[1][22]=(0.0)*D;
  A[1][23]=((14375.0/24192.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11)-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[1][24]=(0.0)*D;
  A[1][25]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][26]=(0.0)*D;
  A[1][27]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][28]=(0.0)*D;
  A[1][29]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[1][30]=(0.0)*D;
  A[1][31]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11)-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[1][32]=(0.0)*D;
  A[1][33]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[1][34]=(0.0)*D;
  A[1][35]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[1][36]=(0.0)*D;
  A[1][37]=((29375.0/145152.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11)+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[1][38]=(0.0)*D;
  A[1][39]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[1][40]=(0.0)*D;
  A[1][41]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv11*Jinv11))*D;
  A[2][0]=((725.0/3584.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11)-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((6875.0/3456.0)*(Jinv01*Jinv01)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((59375.0/72576.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][9]=(0.0)*D;
  A[2][10]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[2][11]=(0.0)*D;
  A[2][12]=(-(11875.0/41472.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[2][13]=(0.0)*D;
  A[2][14]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11)+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[2][15]=(0.0)*D;
  A[2][16]=((115625.0/96768.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11)+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11)-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[2][19]=(0.0)*D;
  A[2][20]=((49375.0/145152.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11)+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][21]=(0.0)*D;
  A[2][22]=((11875.0/41472.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][23]=(0.0)*D;
  A[2][24]=((3125.0/2304.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11)+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[2][25]=(0.0)*D;
  A[2][26]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11)-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[2][27]=(0.0)*D;
  A[2][28]=((3125.0/18144.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11)+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[2][29]=(0.0)*D;
  A[2][30]=(-(104375.0/290304.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[2][31]=(0.0)*D;
  A[2][32]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[2][33]=(0.0)*D;
  A[2][34]=((38125.0/290304.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[2][35]=(0.0)*D;
  A[2][36]=((14375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11))*D;
  A[2][37]=(0.0)*D;
  A[2][38]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[2][39]=(0.0)*D;
  A[2][40]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[2][41]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=((725.0/3584.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11)-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((6875.0/3456.0)*(Jinv01*Jinv01)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((59375.0/72576.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][10]=(0.0)*D;
  A[3][11]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[3][12]=(0.0)*D;
  A[3][13]=(-(11875.0/41472.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[3][14]=(0.0)*D;
  A[3][15]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11)+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[3][16]=(0.0)*D;
  A[3][17]=((115625.0/96768.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11)+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11)-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[3][20]=(0.0)*D;
  A[3][21]=((49375.0/145152.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11)+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][22]=(0.0)*D;
  A[3][23]=((11875.0/41472.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][24]=(0.0)*D;
  A[3][25]=((3125.0/2304.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11)+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[3][26]=(0.0)*D;
  A[3][27]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11)-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[3][28]=(0.0)*D;
  A[3][29]=((3125.0/18144.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11)+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[3][30]=(0.0)*D;
  A[3][31]=(-(104375.0/290304.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[3][32]=(0.0)*D;
  A[3][33]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[3][34]=(0.0)*D;
  A[3][35]=((38125.0/290304.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[3][36]=(0.0)*D;
  A[3][37]=((14375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11))*D;
  A[3][38]=(0.0)*D;
  A[3][39]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[3][40]=(0.0)*D;
  A[3][41]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[4][0]=(-(575.0/36288.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11)+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((10625.0/3456.0)*(Jinv01*Jinv01)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv11*Jinv11)+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((8125.0/9072.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[4][9]=(0.0)*D;
  A[4][10]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[4][13]=(0.0)*D;
  A[4][14]=((53125.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][15]=(0.0)*D;
  A[4][16]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[4][17]=(0.0)*D;
  A[4][18]=((146875.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][19]=(0.0)*D;
  A[4][20]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[4][21]=(0.0)*D;
  A[4][22]=((625.0/6048.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[4][23]=(0.0)*D;
  A[4][24]=((3125.0/8064.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][25]=(0.0)*D;
  A[4][26]=((3125.0/3024.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[4][27]=(0.0)*D;
  A[4][28]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[4][29]=(0.0)*D;
  A[4][30]=(-(8125.0/72576.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[4][31]=(0.0)*D;
  A[4][32]=(-(3125.0/9072.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[4][33]=(0.0)*D;
  A[4][34]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[4][35]=(0.0)*D;
  A[4][36]=((8125.0/72576.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11))*D;
  A[4][37]=(0.0)*D;
  A[4][38]=((38125.0/290304.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11))*D;
  A[4][39]=(0.0)*D;
  A[4][40]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[4][41]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(575.0/36288.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11)+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(263125.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((10625.0/3456.0)*(Jinv01*Jinv01)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv11*Jinv11)+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((8125.0/9072.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[5][10]=(0.0)*D;
  A[5][11]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[5][14]=(0.0)*D;
  A[5][15]=((53125.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[5][16]=(0.0)*D;
  A[5][17]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[5][18]=(0.0)*D;
  A[5][19]=((146875.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[5][20]=(0.0)*D;
  A[5][21]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[5][22]=(0.0)*D;
  A[5][23]=((625.0/6048.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[5][24]=(0.0)*D;
  A[5][25]=((3125.0/8064.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[5][26]=(0.0)*D;
  A[5][27]=((3125.0/3024.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[5][28]=(0.0)*D;
  A[5][29]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[5][30]=(0.0)*D;
  A[5][31]=(-(8125.0/72576.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[5][32]=(0.0)*D;
  A[5][33]=(-(3125.0/9072.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[5][34]=(0.0)*D;
  A[5][35]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[5][36]=(0.0)*D;
  A[5][37]=((8125.0/72576.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11))*D;
  A[5][38]=(0.0)*D;
  A[5][39]=((38125.0/290304.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11))*D;
  A[5][40]=(0.0)*D;
  A[5][41]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[6][0]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11)-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((59375.0/72576.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((89375.0/24192.0)*(Jinv01*Jinv01)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv11*Jinv11)+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(625.0/448.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][9]=(0.0)*D;
  A[6][10]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[6][13]=(0.0)*D;
  A[6][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][15]=(0.0)*D;
  A[6][16]=((146875.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[6][17]=(0.0)*D;
  A[6][18]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][19]=(0.0)*D;
  A[6][20]=((625.0/448.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[6][21]=(0.0)*D;
  A[6][22]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][23]=(0.0)*D;
  A[6][24]=((3125.0/72576.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[6][25]=(0.0)*D;
  A[6][26]=((146875.0/145152.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[6][27]=(0.0)*D;
  A[6][28]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[6][29]=(0.0)*D;
  A[6][30]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[6][31]=(0.0)*D;
  A[6][32]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[6][33]=(0.0)*D;
  A[6][34]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[6][35]=(0.0)*D;
  A[6][36]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11))*D;
  A[6][37]=(0.0)*D;
  A[6][38]=((3125.0/18144.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11))*D;
  A[6][39]=(0.0)*D;
  A[6][40]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[6][41]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(20225.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11)-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((59375.0/72576.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(261875.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(574375.0/145152.0)*(Jinv00*Jinv00)-(574375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((89375.0/24192.0)*(Jinv01*Jinv01)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv11*Jinv11)+(11875.0/2688.0)*(Jinv00*Jinv00)+(11875.0/2688.0)*(Jinv10*Jinv10))*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(625.0/448.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[7][10]=(0.0)*D;
  A[7][11]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[7][14]=(0.0)*D;
  A[7][15]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][16]=(0.0)*D;
  A[7][17]=((146875.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[7][18]=(0.0)*D;
  A[7][19]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][20]=(0.0)*D;
  A[7][21]=((625.0/448.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[7][22]=(0.0)*D;
  A[7][23]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][24]=(0.0)*D;
  A[7][25]=((3125.0/72576.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[7][26]=(0.0)*D;
  A[7][27]=((146875.0/145152.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[7][28]=(0.0)*D;
  A[7][29]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[7][30]=(0.0)*D;
  A[7][31]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[7][32]=(0.0)*D;
  A[7][33]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[7][34]=(0.0)*D;
  A[7][35]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[7][36]=(0.0)*D;
  A[7][37]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11))*D;
  A[7][38]=(0.0)*D;
  A[7][39]=((3125.0/18144.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11))*D;
  A[7][40]=(0.0)*D;
  A[7][41]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[8][0]=((1975.0/48384.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((8125.0/9072.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(625.0/448.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[8][9]=(0.0)*D;
  A[8][10]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[8][11]=(0.0)*D;
  A[8][12]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[8][13]=(0.0)*D;
  A[8][14]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[8][15]=(0.0)*D;
  A[8][16]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[8][19]=(0.0)*D;
  A[8][20]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[8][21]=(0.0)*D;
  A[8][22]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[8][23]=(0.0)*D;
  A[8][24]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][25]=(0.0)*D;
  A[8][26]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[8][27]=(0.0)*D;
  A[8][28]=((625.0/448.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[8][29]=(0.0)*D;
  A[8][30]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[8][31]=(0.0)*D;
  A[8][32]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[8][33]=(0.0)*D;
  A[8][34]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[8][35]=(0.0)*D;
  A[8][36]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[8][37]=(0.0)*D;
  A[8][38]=((49375.0/145152.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[8][39]=(0.0)*D;
  A[8][40]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[8][41]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=((1975.0/48384.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11)+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(49375.0/145152.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(68125.0/72576.0)*(Jinv00*Jinv00)-(68125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((8125.0/9072.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(11875.0/6048.0)*(Jinv00*Jinv00)+(11875.0/6048.0)*(Jinv10*Jinv10))*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(625.0/448.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(745625.0/290304.0)*(Jinv00*Jinv00)-(745625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[9][10]=(0.0)*D;
  A[9][11]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[9][12]=(0.0)*D;
  A[9][13]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][14]=(0.0)*D;
  A[9][15]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[9][16]=(0.0)*D;
  A[9][17]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[9][20]=(0.0)*D;
  A[9][21]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[9][22]=(0.0)*D;
  A[9][23]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[9][24]=(0.0)*D;
  A[9][25]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[9][26]=(0.0)*D;
  A[9][27]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[9][28]=(0.0)*D;
  A[9][29]=((625.0/448.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[9][30]=(0.0)*D;
  A[9][31]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[9][32]=(0.0)*D;
  A[9][33]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[9][34]=(0.0)*D;
  A[9][35]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[9][36]=(0.0)*D;
  A[9][37]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[9][38]=(0.0)*D;
  A[9][39]=((49375.0/145152.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[9][40]=(0.0)*D;
  A[9][41]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[10][0]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][1]=(0.0)*D;
  A[10][2]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][5]=(0.0)*D;
  A[10][6]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[10][7]=(0.0)*D;
  A[10][8]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[10][19]=(0.0)*D;
  A[10][20]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[10][21]=(0.0)*D;
  A[10][22]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[10][23]=(0.0)*D;
  A[10][24]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][25]=(0.0)*D;
  A[10][26]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][27]=(0.0)*D;
  A[10][28]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[10][29]=(0.0)*D;
  A[10][30]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[10][31]=(0.0)*D;
  A[10][32]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[10][33]=(0.0)*D;
  A[10][34]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[10][35]=(0.0)*D;
  A[10][36]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][37]=(0.0)*D;
  A[10][38]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[10][39]=(0.0)*D;
  A[10][40]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[10][41]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv00*Jinv00)-(5951.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][2]=(0.0)*D;
  A[11][3]=((1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv00*Jinv00)+(29375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv00*Jinv00)-(130625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][6]=(0.0)*D;
  A[11][7]=((6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv00*Jinv00)+(14375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[11][8]=(0.0)*D;
  A[11][9]=(-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv00*Jinv00)-(26875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((16567.0/48384.0)*(Jinv00*Jinv00)+(16567.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[11][20]=(0.0)*D;
  A[11][21]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[11][22]=(0.0)*D;
  A[11][23]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[11][24]=(0.0)*D;
  A[11][25]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][26]=(0.0)*D;
  A[11][27]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][28]=(0.0)*D;
  A[11][29]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[11][30]=(0.0)*D;
  A[11][31]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[11][32]=(0.0)*D;
  A[11][33]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[11][34]=(0.0)*D;
  A[11][35]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[11][36]=(0.0)*D;
  A[11][37]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][38]=(0.0)*D;
  A[11][39]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[11][40]=(0.0)*D;
  A[11][41]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[12][0]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11)+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[12][1]=(0.0)*D;
  A[12][2]=(-(11875.0/41472.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[12][7]=(0.0)*D;
  A[12][8]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((6875.0/3456.0)*(Jinv01*Jinv01)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[12][13]=(0.0)*D;
  A[12][14]=((8125.0/16128.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11)-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][15]=(0.0)*D;
  A[12][16]=((4375.0/20736.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11)+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[12][17]=(0.0)*D;
  A[12][18]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11)-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][19]=(0.0)*D;
  A[12][20]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[12][21]=(0.0)*D;
  A[12][22]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[12][23]=(0.0)*D;
  A[12][24]=((14375.0/290304.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11)+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[12][25]=(0.0)*D;
  A[12][26]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11)-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[12][27]=(0.0)*D;
  A[12][28]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[12][29]=(0.0)*D;
  A[12][30]=((11875.0/6048.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[12][31]=(0.0)*D;
  A[12][32]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11)-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[12][33]=(0.0)*D;
  A[12][34]=((8125.0/72576.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[12][35]=(0.0)*D;
  A[12][36]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][37]=(0.0)*D;
  A[12][38]=((14375.0/72576.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[12][39]=(0.0)*D;
  A[12][40]=((29375.0/145152.0)*(Jinv01*Jinv01)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[12][41]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(16175.0/36288.0)*Jinv10*Jinv11-(16175.0/36288.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11)+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[13][2]=(0.0)*D;
  A[13][3]=(-(11875.0/41472.0)*(Jinv01*Jinv01)+(6875.0/3456.0)*Jinv10*Jinv11+(6875.0/3456.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(14375.0/290304.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[13][8]=(0.0)*D;
  A[13][9]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((6875.0/3456.0)*(Jinv01*Jinv01)+(29375.0/20736.0)*Jinv10*Jinv11+(29375.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[13][14]=(0.0)*D;
  A[13][15]=((8125.0/16128.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11)-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][16]=(0.0)*D;
  A[13][17]=((4375.0/20736.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11)+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[13][18]=(0.0)*D;
  A[13][19]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11)-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][20]=(0.0)*D;
  A[13][21]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[13][22]=(0.0)*D;
  A[13][23]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[13][24]=(0.0)*D;
  A[13][25]=((14375.0/290304.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11)+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[13][26]=(0.0)*D;
  A[13][27]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11)-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[13][28]=(0.0)*D;
  A[13][29]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[13][30]=(0.0)*D;
  A[13][31]=((11875.0/6048.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[13][32]=(0.0)*D;
  A[13][33]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11)-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[13][34]=(0.0)*D;
  A[13][35]=((8125.0/72576.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[13][36]=(0.0)*D;
  A[13][37]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][38]=(0.0)*D;
  A[13][39]=((14375.0/72576.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[13][40]=(0.0)*D;
  A[13][41]=((29375.0/145152.0)*(Jinv01*Jinv01)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[14][0]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11)+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[14][3]=(0.0)*D;
  A[14][4]=((53125.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][5]=(0.0)*D;
  A[14][6]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][7]=(0.0)*D;
  A[14][8]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[14][11]=(0.0)*D;
  A[14][12]=((8125.0/16128.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11)-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((128125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/504.0)*Jinv10*Jinv11+(3125.0/504.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv11*Jinv11)+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[14][17]=(0.0)*D;
  A[14][18]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[14][19]=(0.0)*D;
  A[14][20]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[14][21]=(0.0)*D;
  A[14][22]=(-(44375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[14][23]=(0.0)*D;
  A[14][24]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[14][25]=(0.0)*D;
  A[14][26]=((34375.0/24192.0)*(Jinv01*Jinv01)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[14][27]=(0.0)*D;
  A[14][28]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[14][29]=(0.0)*D;
  A[14][30]=((49375.0/72576.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[14][31]=(0.0)*D;
  A[14][32]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[14][33]=(0.0)*D;
  A[14][34]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[14][35]=(0.0)*D;
  A[14][36]=(-(625.0/1344.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11))*D;
  A[14][37]=(0.0)*D;
  A[14][38]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11))*D;
  A[14][39]=(0.0)*D;
  A[14][40]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[14][41]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/36288.0)*Jinv10*Jinv11-(15625.0/36288.0)*Jinv01*Jinv00-(15625.0/72576.0)*(Jinv11*Jinv11)-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][2]=(0.0)*D;
  A[15][3]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11)+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[15][4]=(0.0)*D;
  A[15][5]=((53125.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][6]=(0.0)*D;
  A[15][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][8]=(0.0)*D;
  A[15][9]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][12]=(0.0)*D;
  A[15][13]=((8125.0/16128.0)*(Jinv01*Jinv01)-(168125.0/72576.0)*Jinv10*Jinv11-(168125.0/72576.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11)-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((128125.0/18144.0)*(Jinv01*Jinv01)+(3125.0/504.0)*Jinv10*Jinv11+(3125.0/504.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv11*Jinv11)+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[15][18]=(0.0)*D;
  A[15][19]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[15][20]=(0.0)*D;
  A[15][21]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[15][22]=(0.0)*D;
  A[15][23]=(-(44375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[15][24]=(0.0)*D;
  A[15][25]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[15][26]=(0.0)*D;
  A[15][27]=((34375.0/24192.0)*(Jinv01*Jinv01)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[15][28]=(0.0)*D;
  A[15][29]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[15][30]=(0.0)*D;
  A[15][31]=((49375.0/72576.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[15][32]=(0.0)*D;
  A[15][33]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[15][34]=(0.0)*D;
  A[15][35]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[15][36]=(0.0)*D;
  A[15][37]=(-(625.0/1344.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11))*D;
  A[15][38]=(0.0)*D;
  A[15][39]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11))*D;
  A[15][40]=(0.0)*D;
  A[15][41]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[16][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[16][1]=(0.0)*D;
  A[16][2]=((115625.0/96768.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11)+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[16][3]=(0.0)*D;
  A[16][4]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[16][5]=(0.0)*D;
  A[16][6]=((146875.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[16][7]=(0.0)*D;
  A[16][8]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((4375.0/20736.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11)+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((209375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/3456.0)*(Jinv00*Jinv00)+(34375.0/3456.0)*(Jinv10*Jinv10))*D;
  A[16][17]=(0.0)*D;
  A[16][18]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[16][19]=(0.0)*D;
  A[16][20]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[16][21]=(0.0)*D;
  A[16][22]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[16][23]=(0.0)*D;
  A[16][24]=(-(3125.0/8064.0)*(Jinv01*Jinv01)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[16][25]=(0.0)*D;
  A[16][26]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[16][27]=(0.0)*D;
  A[16][28]=((146875.0/145152.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[16][29]=(0.0)*D;
  A[16][30]=((11875.0/36288.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][31]=(0.0)*D;
  A[16][32]=((34375.0/24192.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[16][33]=(0.0)*D;
  A[16][34]=((3125.0/3024.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[16][35]=(0.0)*D;
  A[16][36]=(-(79375.0/290304.0)*(Jinv01*Jinv01)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[16][37]=(0.0)*D;
  A[16][38]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[16][39]=(0.0)*D;
  A[16][40]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[16][41]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[17][2]=(0.0)*D;
  A[17][3]=((115625.0/96768.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11)+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[17][4]=(0.0)*D;
  A[17][5]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[17][6]=(0.0)*D;
  A[17][7]=((146875.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(625.0/145152.0)*(Jinv00*Jinv00)+(625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[17][8]=(0.0)*D;
  A[17][9]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv00*Jinv00)+(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((4375.0/20736.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11)+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(3125.0/1728.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((209375.0/24192.0)*(Jinv01*Jinv01)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/3456.0)*(Jinv00*Jinv00)+(34375.0/3456.0)*(Jinv10*Jinv10))*D;
  A[17][18]=(0.0)*D;
  A[17][19]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[17][20]=(0.0)*D;
  A[17][21]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[17][22]=(0.0)*D;
  A[17][23]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[17][24]=(0.0)*D;
  A[17][25]=(-(3125.0/8064.0)*(Jinv01*Jinv01)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[17][26]=(0.0)*D;
  A[17][27]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[17][28]=(0.0)*D;
  A[17][29]=((146875.0/145152.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[17][30]=(0.0)*D;
  A[17][31]=((11875.0/36288.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[17][32]=(0.0)*D;
  A[17][33]=((34375.0/24192.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[17][34]=(0.0)*D;
  A[17][35]=((3125.0/3024.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[17][36]=(0.0)*D;
  A[17][37]=(-(79375.0/290304.0)*(Jinv01*Jinv01)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[17][38]=(0.0)*D;
  A[17][39]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[17][40]=(0.0)*D;
  A[17][41]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[18][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11)-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[18][3]=(0.0)*D;
  A[18][4]=((146875.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[18][5]=(0.0)*D;
  A[18][6]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[18][11]=(0.0)*D;
  A[18][12]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11)-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[18][13]=(0.0)*D;
  A[18][14]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[18][15]=(0.0)*D;
  A[18][16]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((71875.0/9072.0)*(Jinv01*Jinv01)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(71875.0/9072.0)*(Jinv11*Jinv11)+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[18][19]=(0.0)*D;
  A[18][20]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[18][21]=(0.0)*D;
  A[18][22]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[18][23]=(0.0)*D;
  A[18][24]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[18][25]=(0.0)*D;
  A[18][26]=(-(146875.0/72576.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[18][27]=(0.0)*D;
  A[18][28]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[18][29]=(0.0)*D;
  A[18][30]=((625.0/18144.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[18][31]=(0.0)*D;
  A[18][32]=((3125.0/3024.0)*(Jinv01*Jinv01)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[18][33]=(0.0)*D;
  A[18][34]=((146875.0/72576.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[18][35]=(0.0)*D;
  A[18][36]=(-(6875.0/48384.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[18][37]=(0.0)*D;
  A[18][38]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11))*D;
  A[18][39]=(0.0)*D;
  A[18][40]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[18][41]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11)-(625.0/1344.0)*(Jinv00*Jinv00)-(625.0/1344.0)*(Jinv10*Jinv10))*D;
  A[19][4]=(0.0)*D;
  A[19][5]=((146875.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)+(49375.0/72576.0)*(Jinv00*Jinv00)+(49375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[19][6]=(0.0)*D;
  A[19][7]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)-(44375.0/72576.0)*(Jinv00*Jinv00)-(44375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv00*Jinv00)+(8125.0/16128.0)*(Jinv10*Jinv10))*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(-(15625.0/72576.0)*(Jinv00*Jinv00)-(15625.0/72576.0)*(Jinv10*Jinv10))*D;
  A[19][12]=(0.0)*D;
  A[19][13]=(-(6875.0/48384.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11)-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[19][14]=(0.0)*D;
  A[19][15]=((3125.0/3024.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/1134.0)*(Jinv00*Jinv00)+(3125.0/1134.0)*(Jinv10*Jinv10))*D;
  A[19][16]=(0.0)*D;
  A[19][17]=(-(146875.0/72576.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(21875.0/3456.0)*(Jinv00*Jinv00)-(21875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((71875.0/9072.0)*(Jinv01*Jinv01)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(71875.0/9072.0)*(Jinv11*Jinv11)+(128125.0/18144.0)*(Jinv00*Jinv00)+(128125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[19][20]=(0.0)*D;
  A[19][21]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[19][22]=(0.0)*D;
  A[19][23]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[19][24]=(0.0)*D;
  A[19][25]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[19][26]=(0.0)*D;
  A[19][27]=(-(146875.0/72576.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[19][28]=(0.0)*D;
  A[19][29]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[19][30]=(0.0)*D;
  A[19][31]=((625.0/18144.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[19][32]=(0.0)*D;
  A[19][33]=((3125.0/3024.0)*(Jinv01*Jinv01)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[19][34]=(0.0)*D;
  A[19][35]=((146875.0/72576.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[19][36]=(0.0)*D;
  A[19][37]=(-(6875.0/48384.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[19][38]=(0.0)*D;
  A[19][39]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11))*D;
  A[19][40]=(0.0)*D;
  A[19][41]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[20][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[20][1]=(0.0)*D;
  A[20][2]=((49375.0/145152.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11)+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[20][3]=(0.0)*D;
  A[20][4]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[20][5]=(0.0)*D;
  A[20][6]=((625.0/448.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[20][9]=(0.0)*D;
  A[20][10]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[20][11]=(0.0)*D;
  A[20][12]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[20][13]=(0.0)*D;
  A[20][14]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[20][15]=(0.0)*D;
  A[20][16]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[20][17]=(0.0)*D;
  A[20][18]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[20][19]=(0.0)*D;
  A[20][20]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[20][21]=(0.0)*D;
  A[20][22]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[20][23]=(0.0)*D;
  A[20][24]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[20][25]=(0.0)*D;
  A[20][26]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[20][27]=(0.0)*D;
  A[20][28]=(-(625.0/448.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[20][29]=(0.0)*D;
  A[20][30]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[20][31]=(0.0)*D;
  A[20][32]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[20][33]=(0.0)*D;
  A[20][34]=((8125.0/9072.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[20][35]=(0.0)*D;
  A[20][36]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[20][37]=(0.0)*D;
  A[20][38]=(-(49375.0/145152.0)*(Jinv01*Jinv01)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[20][39]=(0.0)*D;
  A[20][40]=((1975.0/48384.0)*(Jinv01*Jinv01)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[20][41]=(0.0)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[21][2]=(0.0)*D;
  A[21][3]=((49375.0/145152.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11)+(14375.0/72576.0)*(Jinv00*Jinv00)+(14375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)-(104375.0/290304.0)*(Jinv00*Jinv00)-(104375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[21][6]=(0.0)*D;
  A[21][7]=((625.0/448.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)+(11875.0/41472.0)*(Jinv00*Jinv00)+(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[21][8]=(0.0)*D;
  A[21][9]=(-(53125.0/20736.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(53125.0/20736.0)*(Jinv11*Jinv11)-(11875.0/41472.0)*(Jinv00*Jinv00)-(11875.0/41472.0)*(Jinv10*Jinv10))*D;
  A[21][10]=(0.0)*D;
  A[21][11]=((123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv00*Jinv00)+(725.0/3584.0)*(Jinv10*Jinv10))*D;
  A[21][12]=(0.0)*D;
  A[21][13]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv00*Jinv00)+(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[21][14]=(0.0)*D;
  A[21][15]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv00*Jinv00)-(96875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[21][16]=(0.0)*D;
  A[21][17]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv00*Jinv00)+(3125.0/2304.0)*(Jinv10*Jinv10))*D;
  A[21][18]=(0.0)*D;
  A[21][19]=(-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv00*Jinv00)-(409375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[21][20]=(0.0)*D;
  A[21][21]=((53125.0/20736.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(53125.0/20736.0)*(Jinv11*Jinv11)+(6875.0/3456.0)*(Jinv00*Jinv00)+(6875.0/3456.0)*(Jinv10*Jinv10))*D;
  A[21][22]=(0.0)*D;
  A[21][23]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[21][24]=(0.0)*D;
  A[21][25]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[21][26]=(0.0)*D;
  A[21][27]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[21][28]=(0.0)*D;
  A[21][29]=(-(625.0/448.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[21][30]=(0.0)*D;
  A[21][31]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[21][32]=(0.0)*D;
  A[21][33]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[21][34]=(0.0)*D;
  A[21][35]=((8125.0/9072.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[21][36]=(0.0)*D;
  A[21][37]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[21][38]=(0.0)*D;
  A[21][39]=(-(49375.0/145152.0)*(Jinv01*Jinv01)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[21][40]=(0.0)*D;
  A[21][41]=((1975.0/48384.0)*(Jinv01*Jinv01)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[22][0]=((14375.0/24192.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11)-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[22][1]=(0.0)*D;
  A[22][2]=((11875.0/41472.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[22][3]=(0.0)*D;
  A[22][4]=((625.0/6048.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[22][5]=(0.0)*D;
  A[22][6]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[22][7]=(0.0)*D;
  A[22][8]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[22][9]=(0.0)*D;
  A[22][10]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[22][11]=(0.0)*D;
  A[22][12]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[22][13]=(0.0)*D;
  A[22][14]=(-(44375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[22][15]=(0.0)*D;
  A[22][16]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[22][17]=(0.0)*D;
  A[22][18]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[22][19]=(0.0)*D;
  A[22][20]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[22][21]=(0.0)*D;
  A[22][22]=((11875.0/2688.0)*(Jinv01*Jinv01)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv11*Jinv11)+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[22][23]=(0.0)*D;
  A[22][24]=((625.0/145152.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[22][25]=(0.0)*D;
  A[22][26]=((11875.0/36288.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[22][27]=(0.0)*D;
  A[22][28]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[22][29]=(0.0)*D;
  A[22][30]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[22][31]=(0.0)*D;
  A[22][32]=((49375.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[22][33]=(0.0)*D;
  A[22][34]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[22][35]=(0.0)*D;
  A[22][36]=((11875.0/6048.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[22][37]=(0.0)*D;
  A[22][38]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[22][39]=(0.0)*D;
  A[22][40]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[22][41]=(0.0)*D;
  A[23][0]=(0.0)*D;
  A[23][1]=((14375.0/24192.0)*(Jinv01*Jinv01)+(41975.0/72576.0)*Jinv10*Jinv11+(41975.0/72576.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11)-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[23][2]=(0.0)*D;
  A[23][3]=((11875.0/41472.0)*(Jinv01*Jinv01)-(168125.0/145152.0)*Jinv10*Jinv11-(168125.0/145152.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[23][4]=(0.0)*D;
  A[23][5]=((625.0/6048.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[23][8]=(0.0)*D;
  A[23][9]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[23][12]=(0.0)*D;
  A[23][13]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(14375.0/6912.0)*Jinv10*Jinv11-(14375.0/6912.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[23][14]=(0.0)*D;
  A[23][15]=(-(44375.0/72576.0)*(Jinv01*Jinv01)+(49375.0/12096.0)*Jinv10*Jinv11+(49375.0/12096.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[23][16]=(0.0)*D;
  A[23][17]=(-(23125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[23][18]=(0.0)*D;
  A[23][19]=((625.0/18144.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[23][20]=(0.0)*D;
  A[23][21]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[23][22]=(0.0)*D;
  A[23][23]=((11875.0/2688.0)*(Jinv01*Jinv01)+(4375.0/1152.0)*Jinv10*Jinv11+(4375.0/1152.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv11*Jinv11)+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[23][24]=(0.0)*D;
  A[23][25]=((625.0/145152.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[23][26]=(0.0)*D;
  A[23][27]=((11875.0/36288.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[23][28]=(0.0)*D;
  A[23][29]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[23][30]=(0.0)*D;
  A[23][31]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[23][32]=(0.0)*D;
  A[23][33]=((49375.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[23][34]=(0.0)*D;
  A[23][35]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[23][36]=(0.0)*D;
  A[23][37]=((11875.0/6048.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[23][38]=(0.0)*D;
  A[23][39]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[23][40]=(0.0)*D;
  A[23][41]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[24][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[24][1]=(0.0)*D;
  A[24][2]=((3125.0/2304.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11)+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[24][3]=(0.0)*D;
  A[24][4]=((3125.0/8064.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[24][5]=(0.0)*D;
  A[24][6]=((3125.0/72576.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[24][7]=(0.0)*D;
  A[24][8]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[24][9]=(0.0)*D;
  A[24][10]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[24][11]=(0.0)*D;
  A[24][12]=((14375.0/290304.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11)+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[24][13]=(0.0)*D;
  A[24][14]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[24][15]=(0.0)*D;
  A[24][16]=(-(3125.0/8064.0)*(Jinv01*Jinv01)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[24][17]=(0.0)*D;
  A[24][18]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[24][19]=(0.0)*D;
  A[24][20]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[24][21]=(0.0)*D;
  A[24][22]=((625.0/145152.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[24][23]=(0.0)*D;
  A[24][24]=((34375.0/3456.0)*(Jinv01*Jinv01)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(34375.0/3456.0)*(Jinv11*Jinv11)+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[24][25]=(0.0)*D;
  A[24][26]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[24][27]=(0.0)*D;
  A[24][28]=((3125.0/72576.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[24][29]=(0.0)*D;
  A[24][30]=((625.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[24][31]=(0.0)*D;
  A[24][32]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[24][33]=(0.0)*D;
  A[24][34]=((3125.0/8064.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[24][35]=(0.0)*D;
  A[24][36]=((14375.0/290304.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[24][37]=(0.0)*D;
  A[24][38]=((3125.0/2304.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11))*D;
  A[24][39]=(0.0)*D;
  A[24][40]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[24][41]=(0.0)*D;
  A[25][0]=(0.0)*D;
  A[25][1]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/145152.0)*Jinv10*Jinv11-(15625.0/145152.0)*Jinv01*Jinv00-(15625.0/290304.0)*(Jinv11*Jinv11)-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[25][2]=(0.0)*D;
  A[25][3]=((3125.0/2304.0)*(Jinv01*Jinv01)+(8125.0/5184.0)*Jinv10*Jinv11+(8125.0/5184.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11)+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[25][4]=(0.0)*D;
  A[25][5]=((3125.0/8064.0)*(Jinv01*Jinv01)-(45625.0/48384.0)*Jinv10*Jinv11-(45625.0/48384.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[25][6]=(0.0)*D;
  A[25][7]=((3125.0/72576.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[25][8]=(0.0)*D;
  A[25][9]=((10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[25][10]=(0.0)*D;
  A[25][11]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[25][12]=(0.0)*D;
  A[25][13]=((14375.0/290304.0)*(Jinv01*Jinv01)+(180625.0/145152.0)*Jinv10*Jinv11+(180625.0/145152.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11)+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[25][14]=(0.0)*D;
  A[25][15]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(221875.0/36288.0)*Jinv10*Jinv11-(221875.0/36288.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[25][16]=(0.0)*D;
  A[25][17]=(-(3125.0/8064.0)*(Jinv01*Jinv01)+(246875.0/48384.0)*Jinv10*Jinv11+(246875.0/48384.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[25][18]=(0.0)*D;
  A[25][19]=(-(3125.0/36288.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00-(3125.0/36288.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[25][20]=(0.0)*D;
  A[25][21]=(-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[25][22]=(0.0)*D;
  A[25][23]=((625.0/145152.0)*(Jinv01*Jinv01)-(233125.0/48384.0)*Jinv10*Jinv11-(233125.0/48384.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[25][24]=(0.0)*D;
  A[25][25]=((34375.0/3456.0)*(Jinv01*Jinv01)+(34375.0/3456.0)*Jinv10*Jinv11+(34375.0/3456.0)*Jinv01*Jinv00+(34375.0/3456.0)*(Jinv11*Jinv11)+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[25][26]=(0.0)*D;
  A[25][27]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[25][28]=(0.0)*D;
  A[25][29]=((3125.0/72576.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[25][30]=(0.0)*D;
  A[25][31]=((625.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[25][32]=(0.0)*D;
  A[25][33]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[25][34]=(0.0)*D;
  A[25][35]=((3125.0/8064.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[25][36]=(0.0)*D;
  A[25][37]=((14375.0/290304.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[25][38]=(0.0)*D;
  A[25][39]=((3125.0/2304.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11))*D;
  A[25][40]=(0.0)*D;
  A[25][41]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[26][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[26][1]=(0.0)*D;
  A[26][2]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11)-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[26][3]=(0.0)*D;
  A[26][4]=((3125.0/3024.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[26][5]=(0.0)*D;
  A[26][6]=((146875.0/145152.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[26][7]=(0.0)*D;
  A[26][8]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[26][9]=(0.0)*D;
  A[26][10]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[26][11]=(0.0)*D;
  A[26][12]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11)-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[26][13]=(0.0)*D;
  A[26][14]=((34375.0/24192.0)*(Jinv01*Jinv01)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[26][15]=(0.0)*D;
  A[26][16]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[26][17]=(0.0)*D;
  A[26][18]=(-(146875.0/72576.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[26][19]=(0.0)*D;
  A[26][20]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[26][21]=(0.0)*D;
  A[26][22]=((11875.0/36288.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[26][23]=(0.0)*D;
  A[26][24]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[26][25]=(0.0)*D;
  A[26][26]=((209375.0/24192.0)*(Jinv01*Jinv01)+(59375.0/8064.0)*Jinv10*Jinv11+(59375.0/8064.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv11*Jinv11)+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[26][27]=(0.0)*D;
  A[26][28]=((146875.0/145152.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[26][29]=(0.0)*D;
  A[26][30]=(-(23125.0/72576.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[26][31]=(0.0)*D;
  A[26][32]=(-(3125.0/1728.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[26][33]=(0.0)*D;
  A[26][34]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[26][35]=(0.0)*D;
  A[26][36]=((4375.0/20736.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11))*D;
  A[26][37]=(0.0)*D;
  A[26][38]=((115625.0/96768.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[26][39]=(0.0)*D;
  A[26][40]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[26][41]=(0.0)*D;
  A[27][0]=(0.0)*D;
  A[27][1]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11)-(79375.0/290304.0)*(Jinv00*Jinv00)-(79375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[27][4]=(0.0)*D;
  A[27][5]=((3125.0/3024.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(11875.0/36288.0)*(Jinv00*Jinv00)+(11875.0/36288.0)*(Jinv10*Jinv10))*D;
  A[27][6]=(0.0)*D;
  A[27][7]=((146875.0/145152.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(23125.0/72576.0)*(Jinv00*Jinv00)-(23125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[27][8]=(0.0)*D;
  A[27][9]=(-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv00*Jinv00)+(4375.0/20736.0)*(Jinv10*Jinv10))*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(-(15625.0/290304.0)*(Jinv00*Jinv00)-(15625.0/290304.0)*(Jinv10*Jinv10))*D;
  A[27][12]=(0.0)*D;
  A[27][13]=(-(79375.0/290304.0)*(Jinv01*Jinv01)-(14375.0/20736.0)*Jinv10*Jinv11-(14375.0/20736.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11)-(40625.0/96768.0)*(Jinv00*Jinv00)-(40625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[27][14]=(0.0)*D;
  A[27][15]=((34375.0/24192.0)*(Jinv01*Jinv01)+(53125.0/18144.0)*Jinv10*Jinv11+(53125.0/18144.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)+(34375.0/24192.0)*(Jinv00*Jinv00)+(34375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[27][16]=(0.0)*D;
  A[27][17]=(-(40625.0/6912.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(40625.0/6912.0)*(Jinv11*Jinv11)-(3125.0/8064.0)*(Jinv00*Jinv00)-(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[27][18]=(0.0)*D;
  A[27][19]=(-(146875.0/72576.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/1728.0)*(Jinv00*Jinv00)-(3125.0/1728.0)*(Jinv10*Jinv10))*D;
  A[27][20]=(0.0)*D;
  A[27][21]=((11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv00*Jinv00)+(115625.0/96768.0)*(Jinv10*Jinv10))*D;
  A[27][22]=(0.0)*D;
  A[27][23]=((11875.0/36288.0)*(Jinv01*Jinv01)+(10625.0/8064.0)*Jinv10*Jinv11+(10625.0/8064.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[27][24]=(0.0)*D;
  A[27][25]=(-(3125.0/8064.0)*(Jinv01*Jinv01)-(40625.0/6912.0)*Jinv10*Jinv11-(40625.0/6912.0)*Jinv01*Jinv00-(3125.0/8064.0)*(Jinv11*Jinv11)-(40625.0/6912.0)*(Jinv00*Jinv00)-(40625.0/6912.0)*(Jinv10*Jinv10))*D;
  A[27][26]=(0.0)*D;
  A[27][27]=((209375.0/24192.0)*(Jinv01*Jinv01)+(59375.0/8064.0)*Jinv10*Jinv11+(59375.0/8064.0)*Jinv01*Jinv00+(209375.0/24192.0)*(Jinv11*Jinv11)+(209375.0/24192.0)*(Jinv00*Jinv00)+(209375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[27][28]=(0.0)*D;
  A[27][29]=((146875.0/145152.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[27][30]=(0.0)*D;
  A[27][31]=(-(23125.0/72576.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[27][32]=(0.0)*D;
  A[27][33]=(-(3125.0/1728.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[27][34]=(0.0)*D;
  A[27][35]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[27][36]=(0.0)*D;
  A[27][37]=((4375.0/20736.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11))*D;
  A[27][38]=(0.0)*D;
  A[27][39]=((115625.0/96768.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[27][40]=(0.0)*D;
  A[27][41]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[28][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[28][1]=(0.0)*D;
  A[28][2]=((3125.0/18144.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11)+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[28][3]=(0.0)*D;
  A[28][4]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[28][5]=(0.0)*D;
  A[28][6]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[28][7]=(0.0)*D;
  A[28][8]=((625.0/448.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[28][9]=(0.0)*D;
  A[28][10]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[28][11]=(0.0)*D;
  A[28][12]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[28][13]=(0.0)*D;
  A[28][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[28][15]=(0.0)*D;
  A[28][16]=((146875.0/145152.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[28][17]=(0.0)*D;
  A[28][18]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[28][19]=(0.0)*D;
  A[28][20]=(-(625.0/448.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[28][21]=(0.0)*D;
  A[28][22]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[28][23]=(0.0)*D;
  A[28][24]=((3125.0/72576.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[28][25]=(0.0)*D;
  A[28][26]=((146875.0/145152.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[28][27]=(0.0)*D;
  A[28][28]=((89375.0/24192.0)*(Jinv01*Jinv01)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv11*Jinv11)+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[28][29]=(0.0)*D;
  A[28][30]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[28][31]=(0.0)*D;
  A[28][32]=(-(3125.0/6048.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[28][33]=(0.0)*D;
  A[28][34]=(-(261875.0/145152.0)*(Jinv01*Jinv01)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[28][35]=(0.0)*D;
  A[28][36]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[28][37]=(0.0)*D;
  A[28][38]=((59375.0/72576.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[28][39]=(0.0)*D;
  A[28][40]=(-(20225.0/290304.0)*(Jinv01*Jinv01)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11))*D;
  A[28][41]=(0.0)*D;
  A[29][0]=(0.0)*D;
  A[29][1]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[29][2]=(0.0)*D;
  A[29][3]=((3125.0/18144.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11)+(8125.0/72576.0)*(Jinv00*Jinv00)+(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[29][4]=(0.0)*D;
  A[29][5]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(8125.0/72576.0)*(Jinv00*Jinv00)-(8125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[29][6]=(0.0)*D;
  A[29][7]=((19375.0/72576.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(19375.0/72576.0)*(Jinv11*Jinv11)+(625.0/6048.0)*(Jinv00*Jinv00)+(625.0/6048.0)*(Jinv10*Jinv10))*D;
  A[29][8]=(0.0)*D;
  A[29][9]=((625.0/448.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00+(625.0/448.0)*(Jinv11*Jinv11)-(14375.0/290304.0)*(Jinv00*Jinv00)-(14375.0/290304.0)*(Jinv10*Jinv10))*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv00*Jinv00)-(575.0/36288.0)*(Jinv10*Jinv10))*D;
  A[29][12]=(0.0)*D;
  A[29][13]=((6875.0/96768.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)+(38125.0/290304.0)*(Jinv00*Jinv00)+(38125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[29][14]=(0.0)*D;
  A[29][15]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)-(3125.0/9072.0)*(Jinv00*Jinv00)-(3125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[29][16]=(0.0)*D;
  A[29][17]=((146875.0/145152.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)+(3125.0/8064.0)*(Jinv00*Jinv00)+(3125.0/8064.0)*(Jinv10*Jinv10))*D;
  A[29][18]=(0.0)*D;
  A[29][19]=(-(71875.0/18144.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00-(71875.0/18144.0)*(Jinv11*Jinv11)+(53125.0/72576.0)*(Jinv00*Jinv00)+(53125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[29][20]=(0.0)*D;
  A[29][21]=(-(625.0/448.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(625.0/448.0)*(Jinv11*Jinv11)-(263125.0/290304.0)*(Jinv00*Jinv00)-(263125.0/290304.0)*(Jinv10*Jinv10))*D;
  A[29][22]=(0.0)*D;
  A[29][23]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(14375.0/48384.0)*(Jinv00*Jinv00)-(14375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[29][24]=(0.0)*D;
  A[29][25]=((3125.0/72576.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[29][26]=(0.0)*D;
  A[29][27]=((146875.0/145152.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00+(146875.0/145152.0)*(Jinv11*Jinv11)-(184375.0/48384.0)*(Jinv00*Jinv00)-(184375.0/48384.0)*(Jinv10*Jinv10))*D;
  A[29][28]=(0.0)*D;
  A[29][29]=((89375.0/24192.0)*(Jinv01*Jinv01)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(89375.0/24192.0)*(Jinv11*Jinv11)+(10625.0/3456.0)*(Jinv00*Jinv00)+(10625.0/3456.0)*(Jinv10*Jinv10))*D;
  A[29][30]=(0.0)*D;
  A[29][31]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[29][32]=(0.0)*D;
  A[29][33]=(-(3125.0/6048.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[29][34]=(0.0)*D;
  A[29][35]=(-(261875.0/145152.0)*(Jinv01*Jinv01)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[29][36]=(0.0)*D;
  A[29][37]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[29][38]=(0.0)*D;
  A[29][39]=((59375.0/72576.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[29][40]=(0.0)*D;
  A[29][41]=(-(20225.0/290304.0)*(Jinv01*Jinv01)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11))*D;
  A[30][0]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11)-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[30][1]=(0.0)*D;
  A[30][2]=(-(104375.0/290304.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[30][3]=(0.0)*D;
  A[30][4]=(-(8125.0/72576.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[30][5]=(0.0)*D;
  A[30][6]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[30][7]=(0.0)*D;
  A[30][8]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[30][9]=(0.0)*D;
  A[30][10]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[30][11]=(0.0)*D;
  A[30][12]=((11875.0/6048.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[30][13]=(0.0)*D;
  A[30][14]=((49375.0/72576.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[30][15]=(0.0)*D;
  A[30][16]=((11875.0/36288.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[30][17]=(0.0)*D;
  A[30][18]=((625.0/18144.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[30][19]=(0.0)*D;
  A[30][20]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[30][21]=(0.0)*D;
  A[30][22]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[30][23]=(0.0)*D;
  A[30][24]=((625.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[30][25]=(0.0)*D;
  A[30][26]=(-(23125.0/72576.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[30][27]=(0.0)*D;
  A[30][28]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[30][29]=(0.0)*D;
  A[30][30]=((11875.0/2688.0)*(Jinv01*Jinv01)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv11*Jinv11)+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[30][31]=(0.0)*D;
  A[30][32]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[30][33]=(0.0)*D;
  A[30][34]=((625.0/6048.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[30][35]=(0.0)*D;
  A[30][36]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[30][37]=(0.0)*D;
  A[30][38]=((11875.0/41472.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[30][39]=(0.0)*D;
  A[30][40]=((14375.0/24192.0)*(Jinv01*Jinv01)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11))*D;
  A[30][41]=(0.0)*D;
  A[31][0]=(0.0)*D;
  A[31][1]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(10775.0/20736.0)*Jinv10*Jinv11-(10775.0/20736.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11)-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[31][2]=(0.0)*D;
  A[31][3]=(-(104375.0/290304.0)*(Jinv01*Jinv01)+(29375.0/48384.0)*Jinv10*Jinv11+(29375.0/48384.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[31][4]=(0.0)*D;
  A[31][5]=(-(8125.0/72576.0)*(Jinv01*Jinv01)+(625.0/6912.0)*Jinv10*Jinv11+(625.0/6912.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[31][6]=(0.0)*D;
  A[31][7]=(-(625.0/36288.0)*(Jinv01*Jinv01)+(38125.0/145152.0)*Jinv10*Jinv11+(38125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[31][8]=(0.0)*D;
  A[31][9]=(-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[31][10]=(0.0)*D;
  A[31][11]=(-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[31][12]=(0.0)*D;
  A[31][13]=((11875.0/6048.0)*(Jinv01*Jinv01)+(45625.0/24192.0)*Jinv10*Jinv11+(45625.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[31][14]=(0.0)*D;
  A[31][15]=((49375.0/72576.0)*(Jinv01*Jinv01)-(625.0/336.0)*Jinv10*Jinv11-(625.0/336.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[31][16]=(0.0)*D;
  A[31][17]=((11875.0/36288.0)*(Jinv01*Jinv01)-(6875.0/10368.0)*Jinv10*Jinv11-(6875.0/10368.0)*Jinv01*Jinv00+(11875.0/36288.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[31][18]=(0.0)*D;
  A[31][19]=((625.0/18144.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00+(625.0/18144.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[31][20]=(0.0)*D;
  A[31][21]=((625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[31][22]=(0.0)*D;
  A[31][23]=(-(574375.0/145152.0)*(Jinv01*Jinv01)-(574375.0/145152.0)*Jinv10*Jinv11-(574375.0/145152.0)*Jinv01*Jinv00-(574375.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[31][24]=(0.0)*D;
  A[31][25]=((625.0/145152.0)*(Jinv01*Jinv01)+(700625.0/145152.0)*Jinv10*Jinv11+(700625.0/145152.0)*Jinv01*Jinv00+(625.0/145152.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[31][26]=(0.0)*D;
  A[31][27]=(-(23125.0/72576.0)*(Jinv01*Jinv01)+(44375.0/145152.0)*Jinv10*Jinv11+(44375.0/145152.0)*Jinv01*Jinv00-(23125.0/72576.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[31][28]=(0.0)*D;
  A[31][29]=(-(625.0/36288.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(625.0/36288.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[31][30]=(0.0)*D;
  A[31][31]=((11875.0/2688.0)*(Jinv01*Jinv01)+(40625.0/8064.0)*Jinv10*Jinv11+(40625.0/8064.0)*Jinv01*Jinv00+(11875.0/2688.0)*(Jinv11*Jinv11)+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[31][32]=(0.0)*D;
  A[31][33]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[31][34]=(0.0)*D;
  A[31][35]=((625.0/6048.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[31][36]=(0.0)*D;
  A[31][37]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[31][38]=(0.0)*D;
  A[31][39]=((11875.0/41472.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[31][40]=(0.0)*D;
  A[31][41]=((14375.0/24192.0)*(Jinv01*Jinv01)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11))*D;
  A[32][0]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[32][1]=(0.0)*D;
  A[32][2]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[32][3]=(0.0)*D;
  A[32][4]=(-(3125.0/9072.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[32][5]=(0.0)*D;
  A[32][6]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[32][7]=(0.0)*D;
  A[32][8]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[32][9]=(0.0)*D;
  A[32][10]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[32][11]=(0.0)*D;
  A[32][12]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11)-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][13]=(0.0)*D;
  A[32][14]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[32][15]=(0.0)*D;
  A[32][16]=((34375.0/24192.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[32][17]=(0.0)*D;
  A[32][18]=((3125.0/3024.0)*(Jinv01*Jinv01)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[32][19]=(0.0)*D;
  A[32][20]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][21]=(0.0)*D;
  A[32][22]=((49375.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][23]=(0.0)*D;
  A[32][24]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][25]=(0.0)*D;
  A[32][26]=(-(3125.0/1728.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][27]=(0.0)*D;
  A[32][28]=(-(3125.0/6048.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[32][29]=(0.0)*D;
  A[32][30]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[32][31]=(0.0)*D;
  A[32][32]=((128125.0/18144.0)*(Jinv01*Jinv01)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv11*Jinv11)+(71875.0/9072.0)*(Jinv00*Jinv00)+(71875.0/9072.0)*(Jinv10*Jinv10))*D;
  A[32][33]=(0.0)*D;
  A[32][34]=((53125.0/72576.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[32][35]=(0.0)*D;
  A[32][36]=((8125.0/16128.0)*(Jinv01*Jinv01)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11))*D;
  A[32][37]=(0.0)*D;
  A[32][38]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[32][39]=(0.0)*D;
  A[32][40]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[32][41]=(0.0)*D;
  A[33][0]=(0.0)*D;
  A[33][1]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/72576.0)*Jinv10*Jinv11+(15625.0/72576.0)*Jinv01*Jinv00+(15625.0/145152.0)*(Jinv11*Jinv11)+(15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[33][2]=(0.0)*D;
  A[33][3]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(29375.0/36288.0)*Jinv10*Jinv11-(29375.0/36288.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11)-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[33][4]=(0.0)*D;
  A[33][5]=(-(3125.0/9072.0)*(Jinv01*Jinv01)+(625.0/3024.0)*Jinv10*Jinv11+(625.0/3024.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[33][6]=(0.0)*D;
  A[33][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)-(625.0/4536.0)*Jinv10*Jinv11-(625.0/4536.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(625.0/18144.0)*(Jinv00*Jinv00)+(625.0/18144.0)*(Jinv10*Jinv10))*D;
  A[33][8]=(0.0)*D;
  A[33][9]=((38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv00*Jinv00)-(6875.0/48384.0)*(Jinv10*Jinv10))*D;
  A[33][10]=(0.0)*D;
  A[33][11]=((15625.0/145152.0)*(Jinv00*Jinv00)+(15625.0/145152.0)*(Jinv10*Jinv10))*D;
  A[33][12]=(0.0)*D;
  A[33][13]=(-(625.0/1344.0)*(Jinv01*Jinv01)-(105625.0/72576.0)*Jinv10*Jinv11-(105625.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11)-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][14]=(0.0)*D;
  A[33][15]=((3125.0/1134.0)*(Jinv01*Jinv01)+(3125.0/1134.0)*Jinv10*Jinv11+(3125.0/1134.0)*Jinv01*Jinv00+(3125.0/1134.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[33][16]=(0.0)*D;
  A[33][17]=((34375.0/24192.0)*(Jinv01*Jinv01)-(3125.0/36288.0)*Jinv10*Jinv11-(3125.0/36288.0)*Jinv01*Jinv00+(34375.0/24192.0)*(Jinv11*Jinv11)-(3125.0/36288.0)*(Jinv00*Jinv00)-(3125.0/36288.0)*(Jinv10*Jinv10))*D;
  A[33][18]=(0.0)*D;
  A[33][19]=((3125.0/3024.0)*(Jinv01*Jinv01)-(3125.0/4536.0)*Jinv10*Jinv11-(3125.0/4536.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/3024.0)*(Jinv00*Jinv00)+(3125.0/3024.0)*(Jinv10*Jinv10))*D;
  A[33][20]=(0.0)*D;
  A[33][21]=(-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv00*Jinv00)-(71875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][22]=(0.0)*D;
  A[33][23]=((49375.0/72576.0)*(Jinv01*Jinv01)+(116875.0/36288.0)*Jinv10*Jinv11+(116875.0/36288.0)*Jinv01*Jinv00+(49375.0/72576.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][24]=(0.0)*D;
  A[33][25]=(-(21875.0/3456.0)*(Jinv01*Jinv01)-(59375.0/9072.0)*Jinv10*Jinv11-(59375.0/9072.0)*Jinv01*Jinv00-(21875.0/3456.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][26]=(0.0)*D;
  A[33][27]=(-(3125.0/1728.0)*(Jinv01*Jinv01)+(90625.0/36288.0)*Jinv10*Jinv11+(90625.0/36288.0)*Jinv01*Jinv00-(3125.0/1728.0)*(Jinv11*Jinv11)-(146875.0/72576.0)*(Jinv00*Jinv00)-(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][28]=(0.0)*D;
  A[33][29]=(-(3125.0/6048.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00-(3125.0/6048.0)*(Jinv11*Jinv11)+(146875.0/72576.0)*(Jinv00*Jinv00)+(146875.0/72576.0)*(Jinv10*Jinv10))*D;
  A[33][30]=(0.0)*D;
  A[33][31]=(-(44375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/1296.0)*Jinv10*Jinv11-(6875.0/1296.0)*Jinv01*Jinv00-(44375.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[33][32]=(0.0)*D;
  A[33][33]=((128125.0/18144.0)*(Jinv01*Jinv01)+(71875.0/9072.0)*Jinv10*Jinv11+(71875.0/9072.0)*Jinv01*Jinv00+(128125.0/18144.0)*(Jinv11*Jinv11)+(71875.0/9072.0)*(Jinv00*Jinv00)+(71875.0/9072.0)*(Jinv10*Jinv10))*D;
  A[33][34]=(0.0)*D;
  A[33][35]=((53125.0/72576.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[33][36]=(0.0)*D;
  A[33][37]=((8125.0/16128.0)*(Jinv01*Jinv01)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11))*D;
  A[33][38]=(0.0)*D;
  A[33][39]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[33][40]=(0.0)*D;
  A[33][41]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[34][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[34][1]=(0.0)*D;
  A[34][2]=((38125.0/290304.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[34][3]=(0.0)*D;
  A[34][4]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[34][5]=(0.0)*D;
  A[34][6]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[34][7]=(0.0)*D;
  A[34][8]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[34][9]=(0.0)*D;
  A[34][10]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[34][11]=(0.0)*D;
  A[34][12]=((8125.0/72576.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[34][13]=(0.0)*D;
  A[34][14]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[34][15]=(0.0)*D;
  A[34][16]=((3125.0/3024.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[34][17]=(0.0)*D;
  A[34][18]=((146875.0/72576.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[34][19]=(0.0)*D;
  A[34][20]=((8125.0/9072.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[34][21]=(0.0)*D;
  A[34][22]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[34][23]=(0.0)*D;
  A[34][24]=((3125.0/8064.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[34][25]=(0.0)*D;
  A[34][26]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[34][27]=(0.0)*D;
  A[34][28]=(-(261875.0/145152.0)*(Jinv01*Jinv01)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[34][29]=(0.0)*D;
  A[34][30]=((625.0/6048.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[34][31]=(0.0)*D;
  A[34][32]=((53125.0/72576.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[34][33]=(0.0)*D;
  A[34][34]=((10625.0/3456.0)*(Jinv01*Jinv01)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv11*Jinv11)+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[34][35]=(0.0)*D;
  A[34][36]=(-(14375.0/290304.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[34][37]=(0.0)*D;
  A[34][38]=(-(263125.0/290304.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[34][39]=(0.0)*D;
  A[34][40]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11))*D;
  A[34][41]=(0.0)*D;
  A[35][0]=(0.0)*D;
  A[35][1]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/2304.0)*Jinv10*Jinv11-(175.0/2304.0)*Jinv01*Jinv00-(175.0/4608.0)*(Jinv11*Jinv11)-(175.0/4608.0)*(Jinv00*Jinv00)-(175.0/4608.0)*(Jinv10*Jinv10))*D;
  A[35][2]=(0.0)*D;
  A[35][3]=((38125.0/290304.0)*(Jinv01*Jinv01)+(29375.0/145152.0)*Jinv10*Jinv11+(29375.0/145152.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[35][4]=(0.0)*D;
  A[35][5]=(-(14375.0/48384.0)*(Jinv01*Jinv01)-(14375.0/48384.0)*Jinv10*Jinv11-(14375.0/48384.0)*Jinv01*Jinv00-(14375.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[35][6]=(0.0)*D;
  A[35][7]=(-(10625.0/48384.0)*(Jinv01*Jinv01)-(18125.0/145152.0)*Jinv10*Jinv11-(18125.0/145152.0)*Jinv01*Jinv00-(10625.0/48384.0)*(Jinv11*Jinv11)-(625.0/36288.0)*(Jinv00*Jinv00)-(625.0/36288.0)*(Jinv10*Jinv10))*D;
  A[35][8]=(0.0)*D;
  A[35][9]=(-(8125.0/9072.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00-(8125.0/9072.0)*(Jinv11*Jinv11)+(6875.0/96768.0)*(Jinv00*Jinv00)+(6875.0/96768.0)*(Jinv10*Jinv10))*D;
  A[35][10]=(0.0)*D;
  A[35][11]=((575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv00*Jinv00)-(20225.0/290304.0)*(Jinv10*Jinv10))*D;
  A[35][12]=(0.0)*D;
  A[35][13]=((8125.0/72576.0)*(Jinv01*Jinv01)+(6875.0/24192.0)*Jinv10*Jinv11+(6875.0/24192.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11)+(3125.0/18144.0)*(Jinv00*Jinv00)+(3125.0/18144.0)*(Jinv10*Jinv10))*D;
  A[35][14]=(0.0)*D;
  A[35][15]=(-(3125.0/9072.0)*(Jinv01*Jinv01)-(8125.0/9072.0)*Jinv10*Jinv11-(8125.0/9072.0)*Jinv01*Jinv00-(3125.0/9072.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[35][16]=(0.0)*D;
  A[35][17]=((3125.0/3024.0)*(Jinv01*Jinv01)+(18125.0/24192.0)*Jinv10*Jinv11+(18125.0/24192.0)*Jinv01*Jinv00+(3125.0/3024.0)*(Jinv11*Jinv11)+(3125.0/72576.0)*(Jinv00*Jinv00)+(3125.0/72576.0)*(Jinv10*Jinv10))*D;
  A[35][18]=(0.0)*D;
  A[35][19]=((146875.0/72576.0)*(Jinv01*Jinv01)+(625.0/756.0)*Jinv10*Jinv11+(625.0/756.0)*Jinv01*Jinv00+(146875.0/72576.0)*(Jinv11*Jinv11)-(3125.0/6048.0)*(Jinv00*Jinv00)-(3125.0/6048.0)*(Jinv10*Jinv10))*D;
  A[35][20]=(0.0)*D;
  A[35][21]=((8125.0/9072.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(8125.0/9072.0)*(Jinv11*Jinv11)+(59375.0/72576.0)*(Jinv00*Jinv00)+(59375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[35][22]=(0.0)*D;
  A[35][23]=(-(8125.0/72576.0)*(Jinv01*Jinv01)-(45625.0/145152.0)*Jinv10*Jinv11-(45625.0/145152.0)*Jinv01*Jinv00-(8125.0/72576.0)*(Jinv11*Jinv11)-(10625.0/48384.0)*(Jinv00*Jinv00)-(10625.0/48384.0)*(Jinv10*Jinv10))*D;
  A[35][24]=(0.0)*D;
  A[35][25]=((3125.0/8064.0)*(Jinv01*Jinv01)+(11875.0/6912.0)*Jinv10*Jinv11+(11875.0/6912.0)*Jinv01*Jinv00+(3125.0/8064.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[35][26]=(0.0)*D;
  A[35][27]=(-(184375.0/48384.0)*(Jinv01*Jinv01)-(19375.0/6912.0)*Jinv10*Jinv11-(19375.0/6912.0)*Jinv01*Jinv00-(184375.0/48384.0)*(Jinv11*Jinv11)+(146875.0/145152.0)*(Jinv00*Jinv00)+(146875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[35][28]=(0.0)*D;
  A[35][29]=(-(261875.0/145152.0)*(Jinv01*Jinv01)+(625.0/1792.0)*Jinv10*Jinv11+(625.0/1792.0)*Jinv01*Jinv00-(261875.0/145152.0)*(Jinv11*Jinv11)-(261875.0/145152.0)*(Jinv00*Jinv00)-(261875.0/145152.0)*(Jinv10*Jinv10))*D;
  A[35][30]=(0.0)*D;
  A[35][31]=((625.0/6048.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00+(625.0/6048.0)*(Jinv11*Jinv11)+(19375.0/72576.0)*(Jinv00*Jinv00)+(19375.0/72576.0)*(Jinv10*Jinv10))*D;
  A[35][32]=(0.0)*D;
  A[35][33]=((53125.0/72576.0)*(Jinv01*Jinv01)-(11875.0/4536.0)*Jinv10*Jinv11-(11875.0/4536.0)*Jinv01*Jinv00+(53125.0/72576.0)*(Jinv11*Jinv11)-(71875.0/18144.0)*(Jinv00*Jinv00)-(71875.0/18144.0)*(Jinv10*Jinv10))*D;
  A[35][34]=(0.0)*D;
  A[35][35]=((10625.0/3456.0)*(Jinv01*Jinv01)+(8125.0/3456.0)*Jinv10*Jinv11+(8125.0/3456.0)*Jinv01*Jinv00+(10625.0/3456.0)*(Jinv11*Jinv11)+(89375.0/24192.0)*(Jinv00*Jinv00)+(89375.0/24192.0)*(Jinv10*Jinv10))*D;
  A[35][36]=(0.0)*D;
  A[35][37]=(-(14375.0/290304.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[35][38]=(0.0)*D;
  A[35][39]=(-(263125.0/290304.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[35][40]=(0.0)*D;
  A[35][41]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11))*D;
  A[36][0]=((29375.0/145152.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11)+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[36][1]=(0.0)*D;
  A[36][2]=((14375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11))*D;
  A[36][3]=(0.0)*D;
  A[36][4]=((8125.0/72576.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11))*D;
  A[36][5]=(0.0)*D;
  A[36][6]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11))*D;
  A[36][7]=(0.0)*D;
  A[36][8]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[36][9]=(0.0)*D;
  A[36][10]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[36][11]=(0.0)*D;
  A[36][12]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[36][13]=(0.0)*D;
  A[36][14]=(-(625.0/1344.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11))*D;
  A[36][15]=(0.0)*D;
  A[36][16]=(-(79375.0/290304.0)*(Jinv01*Jinv01)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[36][17]=(0.0)*D;
  A[36][18]=(-(6875.0/48384.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[36][19]=(0.0)*D;
  A[36][20]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[36][21]=(0.0)*D;
  A[36][22]=((11875.0/6048.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[36][23]=(0.0)*D;
  A[36][24]=((14375.0/290304.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[36][25]=(0.0)*D;
  A[36][26]=((4375.0/20736.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11))*D;
  A[36][27]=(0.0)*D;
  A[36][28]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[36][29]=(0.0)*D;
  A[36][30]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[36][31]=(0.0)*D;
  A[36][32]=((8125.0/16128.0)*(Jinv01*Jinv01)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11))*D;
  A[36][33]=(0.0)*D;
  A[36][34]=(-(14375.0/290304.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[36][35]=(0.0)*D;
  A[36][36]=((6875.0/3456.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[36][37]=(0.0)*D;
  A[36][38]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[36][39]=(0.0)*D;
  A[36][40]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11))*D;
  A[36][41]=(0.0)*D;
  A[37][0]=(0.0)*D;
  A[37][1]=((29375.0/145152.0)*(Jinv01*Jinv01)+(8825.0/36288.0)*Jinv10*Jinv11+(8825.0/36288.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11)+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[37][2]=(0.0)*D;
  A[37][3]=((14375.0/72576.0)*(Jinv01*Jinv01)-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11))*D;
  A[37][4]=(0.0)*D;
  A[37][5]=((8125.0/72576.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(8125.0/72576.0)*(Jinv11*Jinv11))*D;
  A[37][6]=(0.0)*D;
  A[37][7]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/10368.0)*Jinv10*Jinv11-(625.0/10368.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11))*D;
  A[37][8]=(0.0)*D;
  A[37][9]=(-(6875.0/48384.0)*Jinv10*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00)*D;
  A[37][10]=(0.0)*D;
  A[37][11]=(-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[37][12]=(0.0)*D;
  A[37][13]=(-(68125.0/72576.0)*(Jinv01*Jinv01)-(68125.0/72576.0)*Jinv10*Jinv11-(68125.0/72576.0)*Jinv01*Jinv00-(68125.0/72576.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[37][14]=(0.0)*D;
  A[37][15]=(-(625.0/1344.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(625.0/1344.0)*(Jinv11*Jinv11))*D;
  A[37][16]=(0.0)*D;
  A[37][17]=(-(79375.0/290304.0)*(Jinv01*Jinv01)+(10625.0/72576.0)*Jinv10*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00-(79375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[37][18]=(0.0)*D;
  A[37][19]=(-(6875.0/48384.0)*(Jinv01*Jinv01)+(38125.0/72576.0)*Jinv10*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00-(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[37][20]=(0.0)*D;
  A[37][21]=((6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[37][22]=(0.0)*D;
  A[37][23]=((11875.0/6048.0)*(Jinv01*Jinv01)+(49375.0/24192.0)*Jinv10*Jinv11+(49375.0/24192.0)*Jinv01*Jinv00+(11875.0/6048.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[37][24]=(0.0)*D;
  A[37][25]=((14375.0/290304.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(14375.0/290304.0)*(Jinv11*Jinv11))*D;
  A[37][26]=(0.0)*D;
  A[37][27]=((4375.0/20736.0)*(Jinv01*Jinv01)-(11875.0/10368.0)*Jinv10*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00+(4375.0/20736.0)*(Jinv11*Jinv11))*D;
  A[37][28]=(0.0)*D;
  A[37][29]=((6875.0/96768.0)*(Jinv01*Jinv01)-(625.0/1344.0)*Jinv10*Jinv11-(625.0/1344.0)*Jinv01*Jinv00+(6875.0/96768.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[37][30]=(0.0)*D;
  A[37][31]=(-(745625.0/290304.0)*(Jinv01*Jinv01)-(221875.0/72576.0)*Jinv10*Jinv11-(221875.0/72576.0)*Jinv01*Jinv00-(745625.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[37][32]=(0.0)*D;
  A[37][33]=((8125.0/16128.0)*(Jinv01*Jinv01)+(120625.0/36288.0)*Jinv10*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00+(8125.0/16128.0)*(Jinv11*Jinv11))*D;
  A[37][34]=(0.0)*D;
  A[37][35]=(-(14375.0/290304.0)*(Jinv01*Jinv01)+(25625.0/24192.0)*Jinv10*Jinv11+(25625.0/24192.0)*Jinv01*Jinv00-(14375.0/290304.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[37][36]=(0.0)*D;
  A[37][37]=((6875.0/3456.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[37][38]=(0.0)*D;
  A[37][39]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[37][40]=(0.0)*D;
  A[37][41]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11))*D;
  A[38][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[38][1]=(0.0)*D;
  A[38][2]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[38][3]=(0.0)*D;
  A[38][4]=((38125.0/290304.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11))*D;
  A[38][5]=(0.0)*D;
  A[38][6]=((3125.0/18144.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11))*D;
  A[38][7]=(0.0)*D;
  A[38][8]=((49375.0/145152.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[38][9]=(0.0)*D;
  A[38][10]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[38][11]=(0.0)*D;
  A[38][12]=((14375.0/72576.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[38][13]=(0.0)*D;
  A[38][14]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11))*D;
  A[38][15]=(0.0)*D;
  A[38][16]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[38][17]=(0.0)*D;
  A[38][18]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11))*D;
  A[38][19]=(0.0)*D;
  A[38][20]=(-(49375.0/145152.0)*(Jinv01*Jinv01)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[38][21]=(0.0)*D;
  A[38][22]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[38][23]=(0.0)*D;
  A[38][24]=((3125.0/2304.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11))*D;
  A[38][25]=(0.0)*D;
  A[38][26]=((115625.0/96768.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[38][27]=(0.0)*D;
  A[38][28]=((59375.0/72576.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[38][29]=(0.0)*D;
  A[38][30]=((11875.0/41472.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[38][31]=(0.0)*D;
  A[38][32]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[38][33]=(0.0)*D;
  A[38][34]=(-(263125.0/290304.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[38][35]=(0.0)*D;
  A[38][36]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[38][37]=(0.0)*D;
  A[38][38]=((6875.0/3456.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[38][39]=(0.0)*D;
  A[38][40]=((725.0/3584.0)*(Jinv01*Jinv01)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11))*D;
  A[38][41]=(0.0)*D;
  A[39][0]=(0.0)*D;
  A[39][1]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/24192.0)*Jinv10*Jinv11-(1975.0/24192.0)*Jinv01*Jinv00-(1975.0/48384.0)*(Jinv11*Jinv11)-(1975.0/48384.0)*(Jinv00*Jinv00)-(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[39][2]=(0.0)*D;
  A[39][3]=((6875.0/48384.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(6875.0/48384.0)*(Jinv11*Jinv11))*D;
  A[39][4]=(0.0)*D;
  A[39][5]=((38125.0/290304.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(38125.0/290304.0)*(Jinv11*Jinv11))*D;
  A[39][6]=(0.0)*D;
  A[39][7]=((3125.0/18144.0)*(Jinv01*Jinv01)+(625.0/10368.0)*Jinv10*Jinv11+(625.0/10368.0)*Jinv01*Jinv00+(3125.0/18144.0)*(Jinv11*Jinv11))*D;
  A[39][8]=(0.0)*D;
  A[39][9]=((49375.0/145152.0)*(Jinv01*Jinv01)+(6875.0/48384.0)*Jinv10*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00+(49375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[39][10]=(0.0)*D;
  A[39][11]=(-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv00*Jinv00)+(1975.0/48384.0)*(Jinv10*Jinv10))*D;
  A[39][12]=(0.0)*D;
  A[39][13]=((14375.0/72576.0)*(Jinv01*Jinv01)+(78125.0/145152.0)*Jinv10*Jinv11+(78125.0/145152.0)*Jinv01*Jinv00+(14375.0/72576.0)*(Jinv11*Jinv11)+(49375.0/145152.0)*(Jinv00*Jinv00)+(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[39][14]=(0.0)*D;
  A[39][15]=(-(96875.0/145152.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(96875.0/145152.0)*(Jinv11*Jinv11))*D;
  A[39][16]=(0.0)*D;
  A[39][17]=(-(40625.0/96768.0)*(Jinv01*Jinv01)-(10625.0/72576.0)*Jinv10*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00-(40625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[39][18]=(0.0)*D;
  A[39][19]=(-(71875.0/72576.0)*(Jinv01*Jinv01)-(38125.0/72576.0)*Jinv10*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00-(71875.0/72576.0)*(Jinv11*Jinv11))*D;
  A[39][20]=(0.0)*D;
  A[39][21]=(-(49375.0/145152.0)*(Jinv01*Jinv01)+(3125.0/12096.0)*Jinv10*Jinv11+(3125.0/12096.0)*Jinv01*Jinv00-(49375.0/145152.0)*(Jinv11*Jinv11)-(49375.0/145152.0)*(Jinv00*Jinv00)-(49375.0/145152.0)*(Jinv10*Jinv10))*D;
  A[39][22]=(0.0)*D;
  A[39][23]=(-(104375.0/290304.0)*(Jinv01*Jinv01)-(6875.0/5184.0)*Jinv10*Jinv11-(6875.0/5184.0)*Jinv01*Jinv00-(104375.0/290304.0)*(Jinv11*Jinv11)-(8125.0/9072.0)*(Jinv00*Jinv00)-(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[39][24]=(0.0)*D;
  A[39][25]=((3125.0/2304.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(3125.0/2304.0)*(Jinv11*Jinv11))*D;
  A[39][26]=(0.0)*D;
  A[39][27]=((115625.0/96768.0)*(Jinv01*Jinv01)+(11875.0/10368.0)*Jinv10*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00+(115625.0/96768.0)*(Jinv11*Jinv11))*D;
  A[39][28]=(0.0)*D;
  A[39][29]=((59375.0/72576.0)*(Jinv01*Jinv01)-(18125.0/72576.0)*Jinv10*Jinv11-(18125.0/72576.0)*Jinv01*Jinv00+(59375.0/72576.0)*(Jinv11*Jinv11)+(8125.0/9072.0)*(Jinv00*Jinv00)+(8125.0/9072.0)*(Jinv10*Jinv10))*D;
  A[39][30]=(0.0)*D;
  A[39][31]=((11875.0/41472.0)*(Jinv01*Jinv01)+(41875.0/24192.0)*Jinv10*Jinv11+(41875.0/24192.0)*Jinv01*Jinv00+(11875.0/41472.0)*(Jinv11*Jinv11)+(625.0/448.0)*(Jinv00*Jinv00)+(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[39][32]=(0.0)*D;
  A[39][33]=(-(409375.0/145152.0)*(Jinv01*Jinv01)-(120625.0/36288.0)*Jinv10*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00-(409375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[39][34]=(0.0)*D;
  A[39][35]=(-(263125.0/290304.0)*(Jinv01*Jinv01)+(19375.0/72576.0)*Jinv10*Jinv11+(19375.0/72576.0)*Jinv01*Jinv00-(263125.0/290304.0)*(Jinv11*Jinv11)-(625.0/448.0)*(Jinv00*Jinv00)-(625.0/448.0)*(Jinv10*Jinv10))*D;
  A[39][36]=(0.0)*D;
  A[39][37]=(-(11875.0/41472.0)*(Jinv01*Jinv01)-(53125.0/20736.0)*Jinv10*Jinv11-(53125.0/20736.0)*Jinv01*Jinv00-(11875.0/41472.0)*(Jinv11*Jinv11)-(53125.0/20736.0)*(Jinv00*Jinv00)-(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[39][38]=(0.0)*D;
  A[39][39]=((6875.0/3456.0)*(Jinv01*Jinv01)+(53125.0/20736.0)*Jinv10*Jinv11+(53125.0/20736.0)*Jinv01*Jinv00+(6875.0/3456.0)*(Jinv11*Jinv11)+(53125.0/20736.0)*(Jinv00*Jinv00)+(53125.0/20736.0)*(Jinv10*Jinv10))*D;
  A[39][40]=(0.0)*D;
  A[39][41]=((725.0/3584.0)*(Jinv01*Jinv01)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11))*D;
  A[40][0]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv11*Jinv11))*D;
  A[40][1]=(0.0)*D;
  A[40][2]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[40][3]=(0.0)*D;
  A[40][4]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[40][5]=(0.0)*D;
  A[40][6]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[40][7]=(0.0)*D;
  A[40][8]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[40][9]=(0.0)*D;
  A[40][10]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[40][11]=(0.0)*D;
  A[40][12]=((29375.0/145152.0)*(Jinv01*Jinv01)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[40][13]=(0.0)*D;
  A[40][14]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[40][15]=(0.0)*D;
  A[40][16]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[40][17]=(0.0)*D;
  A[40][18]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[40][19]=(0.0)*D;
  A[40][20]=((1975.0/48384.0)*(Jinv01*Jinv01)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[40][21]=(0.0)*D;
  A[40][22]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[40][23]=(0.0)*D;
  A[40][24]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[40][25]=(0.0)*D;
  A[40][26]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[40][27]=(0.0)*D;
  A[40][28]=(-(20225.0/290304.0)*(Jinv01*Jinv01)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11))*D;
  A[40][29]=(0.0)*D;
  A[40][30]=((14375.0/24192.0)*(Jinv01*Jinv01)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11))*D;
  A[40][31]=(0.0)*D;
  A[40][32]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[40][33]=(0.0)*D;
  A[40][34]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11))*D;
  A[40][35]=(0.0)*D;
  A[40][36]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11))*D;
  A[40][37]=(0.0)*D;
  A[40][38]=((725.0/3584.0)*(Jinv01*Jinv01)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11))*D;
  A[40][39]=(0.0)*D;
  A[40][40]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/48384.0)*(Jinv11*Jinv11))*D;
  A[40][41]=(0.0)*D;
  A[41][0]=(0.0)*D;
  A[41][1]=(-(5951.0/145152.0)*(Jinv01*Jinv01)-(5951.0/145152.0)*Jinv10*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00-(5951.0/145152.0)*(Jinv11*Jinv11))*D;
  A[41][2]=(0.0)*D;
  A[41][3]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[41][4]=(0.0)*D;
  A[41][5]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[41][6]=(0.0)*D;
  A[41][7]=(-(175.0/4608.0)*(Jinv01*Jinv01)-(175.0/4608.0)*(Jinv11*Jinv11))*D;
  A[41][8]=(0.0)*D;
  A[41][9]=(-(1975.0/48384.0)*(Jinv01*Jinv01)-(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[41][10]=(0.0)*D;
  A[41][11]=((5951.0/145152.0)*Jinv10*Jinv11+(5951.0/145152.0)*Jinv01*Jinv00)*D;
  A[41][12]=(0.0)*D;
  A[41][13]=((29375.0/145152.0)*(Jinv01*Jinv01)+(1675.0/10368.0)*Jinv10*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00+(29375.0/145152.0)*(Jinv11*Jinv11))*D;
  A[41][14]=(0.0)*D;
  A[41][15]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[41][16]=(0.0)*D;
  A[41][17]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[41][18]=(0.0)*D;
  A[41][19]=((15625.0/145152.0)*(Jinv01*Jinv01)+(15625.0/145152.0)*(Jinv11*Jinv11))*D;
  A[41][20]=(0.0)*D;
  A[41][21]=((1975.0/48384.0)*(Jinv01*Jinv01)-(1675.0/10368.0)*Jinv10*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00+(1975.0/48384.0)*(Jinv11*Jinv11))*D;
  A[41][22]=(0.0)*D;
  A[41][23]=(-(130625.0/290304.0)*(Jinv01*Jinv01)-(575.0/1512.0)*Jinv10*Jinv11-(575.0/1512.0)*Jinv01*Jinv00-(130625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[41][24]=(0.0)*D;
  A[41][25]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[41][26]=(0.0)*D;
  A[41][27]=(-(15625.0/290304.0)*(Jinv01*Jinv01)-(15625.0/290304.0)*(Jinv11*Jinv11))*D;
  A[41][28]=(0.0)*D;
  A[41][29]=(-(20225.0/290304.0)*(Jinv01*Jinv01)+(575.0/1512.0)*Jinv10*Jinv11+(575.0/1512.0)*Jinv01*Jinv00-(20225.0/290304.0)*(Jinv11*Jinv11))*D;
  A[41][30]=(0.0)*D;
  A[41][31]=((14375.0/24192.0)*(Jinv01*Jinv01)+(6325.0/10368.0)*Jinv10*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00+(14375.0/24192.0)*(Jinv11*Jinv11))*D;
  A[41][32]=(0.0)*D;
  A[41][33]=(-(15625.0/72576.0)*(Jinv01*Jinv01)-(15625.0/72576.0)*(Jinv11*Jinv11))*D;
  A[41][34]=(0.0)*D;
  A[41][35]=(-(575.0/36288.0)*(Jinv01*Jinv01)-(6325.0/10368.0)*Jinv10*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00-(575.0/36288.0)*(Jinv11*Jinv11))*D;
  A[41][36]=(0.0)*D;
  A[41][37]=(-(26875.0/41472.0)*(Jinv01*Jinv01)-(123425.0/145152.0)*Jinv10*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00-(26875.0/41472.0)*(Jinv11*Jinv11))*D;
  A[41][38]=(0.0)*D;
  A[41][39]=((725.0/3584.0)*(Jinv01*Jinv01)+(123425.0/145152.0)*Jinv10*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00+(725.0/3584.0)*(Jinv11*Jinv11))*D;
  A[41][40]=(0.0)*D;
  A[41][41]=((16567.0/48384.0)*(Jinv01*Jinv01)+(16567.0/48384.0)*(Jinv11*Jinv11))*D;
  int nbf = 42;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 1 ---------------*/


 
using namespace std; 
  
void matrix_factory_vector_stiffness_2D_with_M_order1 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[6];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00+x0;  idof2[1]=G10+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00+x0;  idof3[1]=G10+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G01+x0;  idof4[1]=y0+G11;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G01+x0;  idof5[1]=y0+G11;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[6][6];
  A[0][0]=(Jinv01*M01*Jinv10/2.0+(Jinv01*Jinv01)*M00/2.0+Jinv01*Jinv00*M00+M10*Jinv00*Jinv10/2.0+Jinv01*M10*Jinv11/2.0+M01*Jinv00*Jinv11/2.0+Jinv11*M11*Jinv10+Jinv01*M01*Jinv11/2.0+M01*Jinv00*Jinv10/2.0+Jinv01*M10*Jinv10/2.0+M10*Jinv00*Jinv11/2.0+(Jinv11*Jinv11)*M11/2.0+M11*(Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)*M00/2.0)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-Jinv01*Jinv00*M00/2.0-M10*Jinv00*Jinv10/2.0-M01*Jinv00*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-M01*Jinv00*Jinv10/2.0-Jinv01*M10*Jinv10/2.0-M11*(Jinv10*Jinv10)/2.0-(Jinv00*Jinv00)*M00/2.0)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(-Jinv01*M01*Jinv10/2.0-(Jinv01*Jinv01)*M00/2.0-Jinv01*Jinv00*M00/2.0-Jinv01*M10*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-Jinv01*M01*Jinv11/2.0-M10*Jinv00*Jinv11/2.0-(Jinv11*Jinv11)*M11/2.0)*D;
  A[0][5]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=(Jinv01*M01*Jinv10/2.0+(Jinv01*Jinv01)*M00/2.0+Jinv01*Jinv00*M00+M10*Jinv00*Jinv10/2.0+Jinv01*M10*Jinv11/2.0+M01*Jinv00*Jinv11/2.0+Jinv11*M11*Jinv10+Jinv01*M01*Jinv11/2.0+M01*Jinv00*Jinv10/2.0+Jinv01*M10*Jinv10/2.0+M10*Jinv00*Jinv11/2.0+(Jinv11*Jinv11)*M11/2.0+M11*(Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)*M00/2.0)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-Jinv01*Jinv00*M00/2.0-M10*Jinv00*Jinv10/2.0-M01*Jinv00*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-M01*Jinv00*Jinv10/2.0-Jinv01*M10*Jinv10/2.0-M11*(Jinv10*Jinv10)/2.0-(Jinv00*Jinv00)*M00/2.0)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=(-Jinv01*M01*Jinv10/2.0-(Jinv01*Jinv01)*M00/2.0-Jinv01*Jinv00*M00/2.0-Jinv01*M10*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-Jinv01*M01*Jinv11/2.0-M10*Jinv00*Jinv11/2.0-(Jinv11*Jinv11)*M11/2.0)*D;
  A[2][0]=(-Jinv01*M01*Jinv10/2.0-Jinv01*Jinv00*M00/2.0-M10*Jinv00*Jinv10/2.0-Jinv11*M11*Jinv10/2.0-M01*Jinv00*Jinv10/2.0-M10*Jinv00*Jinv11/2.0-M11*(Jinv10*Jinv10)/2.0-(Jinv00*Jinv00)*M00/2.0)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=(M10*Jinv00*Jinv10/2.0+M01*Jinv00*Jinv10/2.0+M11*(Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)*M00/2.0)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(Jinv01*M01*Jinv10/2.0+Jinv01*Jinv00*M00/2.0+Jinv11*M11*Jinv10/2.0+M10*Jinv00*Jinv11/2.0)*D;
  A[2][5]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-Jinv01*M01*Jinv10/2.0-Jinv01*Jinv00*M00/2.0-M10*Jinv00*Jinv10/2.0-Jinv11*M11*Jinv10/2.0-M01*Jinv00*Jinv10/2.0-M10*Jinv00*Jinv11/2.0-M11*(Jinv10*Jinv10)/2.0-(Jinv00*Jinv00)*M00/2.0)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=(M10*Jinv00*Jinv10/2.0+M01*Jinv00*Jinv10/2.0+M11*(Jinv10*Jinv10)/2.0+(Jinv00*Jinv00)*M00/2.0)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(Jinv01*M01*Jinv10/2.0+Jinv01*Jinv00*M00/2.0+Jinv11*M11*Jinv10/2.0+M10*Jinv00*Jinv11/2.0)*D;
  A[4][0]=(-(Jinv01*Jinv01)*M00/2.0-Jinv01*Jinv00*M00/2.0-Jinv01*M10*Jinv11/2.0-M01*Jinv00*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-Jinv01*M01*Jinv11/2.0-Jinv01*M10*Jinv10/2.0-(Jinv11*Jinv11)*M11/2.0)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(Jinv01*Jinv00*M00/2.0+M01*Jinv00*Jinv11/2.0+Jinv11*M11*Jinv10/2.0+Jinv01*M10*Jinv10/2.0)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((Jinv01*Jinv01)*M00/2.0+Jinv01*M10*Jinv11/2.0+Jinv01*M01*Jinv11/2.0+(Jinv11*Jinv11)*M11/2.0)*D;
  A[4][5]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(Jinv01*Jinv01)*M00/2.0-Jinv01*Jinv00*M00/2.0-Jinv01*M10*Jinv11/2.0-M01*Jinv00*Jinv11/2.0-Jinv11*M11*Jinv10/2.0-Jinv01*M01*Jinv11/2.0-Jinv01*M10*Jinv10/2.0-(Jinv11*Jinv11)*M11/2.0)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(Jinv01*Jinv00*M00/2.0+M01*Jinv00*Jinv11/2.0+Jinv11*M11*Jinv10/2.0+Jinv01*M10*Jinv10/2.0)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((Jinv01*Jinv01)*M00/2.0+Jinv01*M10*Jinv11/2.0+Jinv01*M01*Jinv11/2.0+(Jinv11*Jinv11)*M11/2.0)*D;
  int nbf = 6;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 2 ---------------*/


 
using namespace std; 
  
void matrix_factory_vector_stiffness_2D_with_M_order2 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[12];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/2.0+x0;  idof2[1]=G10/2.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/2.0+x0;  idof3[1]=G10/2.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G00+x0;  idof4[1]=G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G00+x0;  idof5[1]=G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=G01/2.0+x0;  idof6[1]=y0+G11/2.0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=G01/2.0+x0;  idof7[1]=y0+G11/2.0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G01/2.0+G00/2.0+x0;  idof8[1]=G10/2.0+y0+G11/2.0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G01/2.0+G00/2.0+x0;  idof9[1]=G10/2.0+y0+G11/2.0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01+x0;  idof10[1]=y0+G11;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01+x0;  idof11[1]=y0+G11;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[12][12];
  A[0][0]=(Jinv11*M01*Jinv00/2.0+Jinv11*M10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+M10*Jinv10*Jinv01/2.0+Jinv10*M01*Jinv00/2.0+(Jinv10*Jinv10)*M11/2.0+Jinv10*M01*Jinv01/2.0+M10*Jinv10*Jinv00/2.0+Jinv11*Jinv10*M11+(Jinv01*Jinv01)*M00/2.0+Jinv01*M00*Jinv00+Jinv11*M10*Jinv00/2.0+Jinv11*M01*Jinv01/2.0+M00*(Jinv00*Jinv00)/2.0)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(Jinv11*M01*Jinv00/6.0+M10*Jinv10*Jinv01/6.0+Jinv10*M01*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+M10*Jinv10*Jinv00/6.0+Jinv11*Jinv10*M11/6.0+Jinv01*M00*Jinv00/6.0+M00*(Jinv00*Jinv00)/6.0)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=(0.0)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(Jinv11*M10*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+Jinv10*M01*Jinv01/6.0+Jinv11*Jinv10*M11/6.0+(Jinv01*Jinv01)*M00/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M10*Jinv00/6.0+Jinv11*M01*Jinv01/6.0)*D;
  A[0][11]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=(Jinv11*M01*Jinv00/2.0+Jinv11*M10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+M10*Jinv10*Jinv01/2.0+Jinv10*M01*Jinv00/2.0+(Jinv10*Jinv10)*M11/2.0+Jinv10*M01*Jinv01/2.0+M10*Jinv10*Jinv00/2.0+Jinv11*Jinv10*M11+(Jinv01*Jinv01)*M00/2.0+Jinv01*M00*Jinv00+Jinv11*M10*Jinv00/2.0+Jinv11*M01*Jinv01/2.0+M00*(Jinv00*Jinv00)/2.0)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[1][4]=(0.0)*D;
  A[1][5]=(Jinv11*M01*Jinv00/6.0+M10*Jinv10*Jinv01/6.0+Jinv10*M01*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+M10*Jinv10*Jinv00/6.0+Jinv11*Jinv10*M11/6.0+Jinv01*M00*Jinv00/6.0+M00*(Jinv00*Jinv00)/6.0)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=(0.0)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=(Jinv11*M10*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+Jinv10*M01*Jinv01/6.0+Jinv11*Jinv10*M11/6.0+(Jinv01*Jinv01)*M00/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M10*Jinv00/6.0+Jinv11*M01*Jinv01/6.0)*D;
  A[2][0]=(-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(4.0/3.0)*Jinv11*M10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*(Jinv01*Jinv01)*M00-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(0.0)*D;
  A[2][11]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(4.0/3.0)*Jinv11*M10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*(Jinv01*Jinv01)*M00-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(0.0)*D;
  A[4][0]=(Jinv10*M01*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+Jinv10*M01*Jinv01/6.0+M10*Jinv10*Jinv00/6.0+Jinv11*Jinv10*M11/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M10*Jinv00/6.0+M00*(Jinv00*Jinv00)/6.0)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[4][3]=(0.0)*D;
  A[4][4]=(Jinv10*M01*Jinv00/2.0+(Jinv10*Jinv10)*M11/2.0+M10*Jinv10*Jinv00/2.0+M00*(Jinv00*Jinv00)/2.0)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(0.0)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((2.0/3.0)*Jinv10*M01*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=(-Jinv10*M01*Jinv01/6.0-Jinv11*Jinv10*M11/6.0-Jinv01*M00*Jinv00/6.0-Jinv11*M10*Jinv00/6.0)*D;
  A[4][11]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(Jinv10*M01*Jinv00/6.0+(Jinv10*Jinv10)*M11/6.0+Jinv10*M01*Jinv01/6.0+M10*Jinv10*Jinv00/6.0+Jinv11*Jinv10*M11/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M10*Jinv00/6.0+M00*(Jinv00*Jinv00)/6.0)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(2.0/3.0)*Jinv10*M01*Jinv00-(2.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*M10*Jinv10*Jinv00-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[5][4]=(0.0)*D;
  A[5][5]=(Jinv10*M01*Jinv00/2.0+(Jinv10*Jinv10)*M11/2.0+M10*Jinv10*Jinv00/2.0+M00*(Jinv00*Jinv00)/2.0)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(0.0)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((2.0/3.0)*Jinv10*M01*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=(-Jinv10*M01*Jinv01/6.0-Jinv11*Jinv10*M11/6.0-Jinv01*M00*Jinv00/6.0-Jinv11*M10*Jinv00/6.0)*D;
  A[6][0]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(0.0)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(4.0/3.0)*Jinv10*M01*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*M10*Jinv10*Jinv00-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[6][11]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(0.0)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(4.0/3.0)*Jinv10*M01*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*M10*Jinv10*Jinv00-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[8][0]=(0.0)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(4.0/3.0)*Jinv11*M10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*(Jinv01*Jinv01)*M00-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(4.0/3.0)*Jinv10*M01*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*M10*Jinv10*Jinv00-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[8][9]=(0.0)*D;
  A[8][10]=((2.0/3.0)*Jinv10*M01*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[8][11]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=(0.0)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(4.0/3.0)*Jinv11*M10*Jinv01-(4.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*(Jinv01*Jinv01)*M00-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*M10*Jinv10*Jinv01-(4.0/3.0)*Jinv10*M01*Jinv00-(4.0/3.0)*(Jinv10*Jinv10)*M11-(2.0/3.0)*Jinv10*M01*Jinv01-(4.0/3.0)*M10*Jinv10*Jinv00-(4.0/3.0)*Jinv11*Jinv10*M11-(4.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv00-(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((2.0/3.0)*Jinv11*M01*Jinv00+(4.0/3.0)*Jinv11*M10*Jinv01+(4.0/3.0)*(Jinv11*Jinv11)*M11+(2.0/3.0)*M10*Jinv10*Jinv01+(4.0/3.0)*Jinv10*M01*Jinv00+(4.0/3.0)*(Jinv10*Jinv10)*M11+(2.0/3.0)*Jinv10*M01*Jinv01+(4.0/3.0)*M10*Jinv10*Jinv00+(4.0/3.0)*Jinv11*Jinv10*M11+(4.0/3.0)*(Jinv01*Jinv01)*M00+(4.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00+(4.0/3.0)*Jinv11*M01*Jinv01+(4.0/3.0)*M00*(Jinv00*Jinv00))*D;
  A[9][10]=(0.0)*D;
  A[9][11]=((2.0/3.0)*Jinv10*M01*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00+(2.0/3.0)*Jinv11*M10*Jinv00)*D;
  A[10][0]=(Jinv11*M01*Jinv00/6.0+Jinv11*M10*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+M10*Jinv10*Jinv01/6.0+Jinv11*Jinv10*M11/6.0+(Jinv01*Jinv01)*M00/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M01*Jinv01/6.0)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(0.0)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(-Jinv11*M01*Jinv00/6.0-M10*Jinv10*Jinv01/6.0-Jinv11*Jinv10*M11/6.0-Jinv01*M00*Jinv00/6.0)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=(Jinv11*M10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+(Jinv01*Jinv01)*M00/2.0+Jinv11*M01*Jinv01/2.0)*D;
  A[10][11]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(Jinv11*M01*Jinv00/6.0+Jinv11*M10*Jinv01/6.0+(Jinv11*Jinv11)*M11/6.0+M10*Jinv10*Jinv01/6.0+Jinv11*Jinv10*M11/6.0+(Jinv01*Jinv01)*M00/6.0+Jinv01*M00*Jinv00/6.0+Jinv11*M01*Jinv01/6.0)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(0.0)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-Jinv11*M01*Jinv00/6.0-M10*Jinv10*Jinv01/6.0-Jinv11*Jinv10*M11/6.0-Jinv01*M00*Jinv00/6.0)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(-(2.0/3.0)*Jinv11*M01*Jinv00-(2.0/3.0)*Jinv11*M10*Jinv01-(2.0/3.0)*(Jinv11*Jinv11)*M11-(2.0/3.0)*M10*Jinv10*Jinv01-(2.0/3.0)*Jinv11*Jinv10*M11-(2.0/3.0)*(Jinv01*Jinv01)*M00-(2.0/3.0)*Jinv01*M00*Jinv00-(2.0/3.0)*Jinv11*M01*Jinv01)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=((2.0/3.0)*Jinv11*M01*Jinv00+(2.0/3.0)*M10*Jinv10*Jinv01+(2.0/3.0)*Jinv11*Jinv10*M11+(2.0/3.0)*Jinv01*M00*Jinv00)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=(Jinv11*M10*Jinv01/2.0+(Jinv11*Jinv11)*M11/2.0+(Jinv01*Jinv01)*M00/2.0+Jinv11*M01*Jinv01/2.0)*D;
  int nbf = 12;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 3 ---------------*/


 
using namespace std; 
  
void matrix_factory_vector_stiffness_2D_with_M_order3 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[20];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/3.0+x0;  idof2[1]=G10/3.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/3.0+x0;  idof3[1]=G10/3.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=(2.0/3.0)*G00+x0;  idof4[1]=(2.0/3.0)*G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=(2.0/3.0)*G00+x0;  idof5[1]=(2.0/3.0)*G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=G00+x0;  idof6[1]=G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=G00+x0;  idof7[1]=G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G01/3.0+x0;  idof8[1]=y0+G11/3.0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G01/3.0+x0;  idof9[1]=y0+G11/3.0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01/3.0+G00/3.0+x0;  idof10[1]=G10/3.0+y0+G11/3.0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01/3.0+G00/3.0+x0;  idof11[1]=G10/3.0+y0+G11/3.0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/3.0+(2.0/3.0)*G00+x0;  idof12[1]=(2.0/3.0)*G10+y0+G11/3.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/3.0+(2.0/3.0)*G00+x0;  idof13[1]=(2.0/3.0)*G10+y0+G11/3.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=(2.0/3.0)*G01+x0;  idof14[1]=y0+(2.0/3.0)*G11;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=(2.0/3.0)*G01+x0;  idof15[1]=y0+(2.0/3.0)*G11;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=(2.0/3.0)*G01+G00/3.0+x0;  idof16[1]=G10/3.0+y0+(2.0/3.0)*G11;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=(2.0/3.0)*G01+G00/3.0+x0;  idof17[1]=G10/3.0+y0+(2.0/3.0)*G11;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01+x0;  idof18[1]=y0+G11;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01+x0;  idof19[1]=y0+G11;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[20][20];
  A[0][0]=((17.0/40.0)*M01*Jinv00*Jinv11+(17.0/40.0)*M10*Jinv10*Jinv01+(17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*M01*Jinv01*Jinv11+(17.0/40.0)*M01*Jinv10*Jinv00+(17.0/20.0)*Jinv01*M00*Jinv00+(17.0/40.0)*M10*Jinv00*Jinv11+(17.0/40.0)*M10*Jinv01*Jinv11+(17.0/40.0)*M00*(Jinv00*Jinv00)+(17.0/40.0)*M01*Jinv10*Jinv01+(17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/40.0)*M11*(Jinv11*Jinv11)+(17.0/20.0)*Jinv10*M11*Jinv11+(17.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(27.0/40.0)*M01*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(27.0/40.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=((27.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv01-(7.0/80.0)*M01*Jinv10*Jinv00-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M00*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv10*M11*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(0.0)*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=(-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*M01*Jinv01*Jinv11-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv01*Jinv11-(7.0/80.0)*M01*Jinv10*Jinv01-(7.0/80.0)*M11*(Jinv11*Jinv11)-(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[0][19]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((17.0/40.0)*M01*Jinv00*Jinv11+(17.0/40.0)*M10*Jinv10*Jinv01+(17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*M01*Jinv01*Jinv11+(17.0/40.0)*M01*Jinv10*Jinv00+(17.0/20.0)*Jinv01*M00*Jinv00+(17.0/40.0)*M10*Jinv00*Jinv11+(17.0/40.0)*M10*Jinv01*Jinv11+(17.0/40.0)*M00*(Jinv00*Jinv00)+(17.0/40.0)*M01*Jinv10*Jinv01+(17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/40.0)*M11*(Jinv11*Jinv11)+(17.0/20.0)*Jinv10*M11*Jinv11+(17.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(27.0/40.0)*M01*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(27.0/40.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=((27.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv01-(7.0/80.0)*M01*Jinv10*Jinv00-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M00*(Jinv00*Jinv00)-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv10*M11*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=(0.0)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=(-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*M01*Jinv01*Jinv11-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv01*Jinv11-(7.0/80.0)*M01*Jinv10*Jinv01-(7.0/80.0)*M11*(Jinv11*Jinv11)-(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[2][0]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(27.0/40.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(189.0/160.0)*M01*Jinv00*Jinv11-(189.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/20.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/20.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((3.0/10.0)*M01*Jinv00*Jinv11+(3.0/10.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/10.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[2][11]=(0.0)*D;
  A[2][12]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[2][19]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(27.0/40.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(189.0/160.0)*M01*Jinv00*Jinv11-(189.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/20.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/20.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((3.0/10.0)*M01*Jinv00*Jinv11+(3.0/10.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/10.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[4][0]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/20.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(189.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/20.0)*M00*(Jinv00*Jinv00)-(189.0/160.0)*M01*Jinv10*Jinv01-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(57.0/80.0)*M01*Jinv00*Jinv11-(57.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*M01*Jinv10*Jinv00-(57.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/16.0)*M01*Jinv01*Jinv11-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M10*Jinv01*Jinv11-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*M11*(Jinv11*Jinv11)-(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[4][19]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=((3.0/80.0)*M01*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/80.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/20.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(189.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/20.0)*M00*(Jinv00*Jinv00)-(189.0/160.0)*M01*Jinv10*Jinv01-(27.0/20.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(57.0/80.0)*M01*Jinv00*Jinv11-(57.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*M01*Jinv10*Jinv00-(57.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M00*(Jinv00*Jinv00)-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/16.0)*M01*Jinv01*Jinv11-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M10*Jinv01*Jinv11-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*M11*(Jinv11*Jinv11)-(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[6][0]=(-(7.0/80.0)*M01*Jinv10*Jinv00-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*M00*(Jinv00*Jinv00)-(7.0/80.0)*M01*Jinv10*Jinv01-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv10*M11*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((27.0/80.0)*M01*Jinv10*Jinv00+(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/10.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/10.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(27.0/40.0)*M01*Jinv10*Jinv00-(57.0/80.0)*Jinv01*M00*Jinv00-(57.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)-(57.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((17.0/40.0)*M01*Jinv10*Jinv00+(17.0/40.0)*M00*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(0.0)*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((3.0/80.0)*M01*Jinv10*Jinv00+(57.0/80.0)*Jinv01*M00*Jinv00+(57.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(57.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][15]=(0.0)*D;
  A[6][16]=((3.0/80.0)*M01*Jinv10*Jinv00-(3.0/10.0)*Jinv01*M00*Jinv00-(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/10.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=((7.0/80.0)*Jinv01*M00*Jinv00+(7.0/80.0)*M10*Jinv00*Jinv11+(7.0/80.0)*M01*Jinv10*Jinv01+(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[6][19]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(7.0/80.0)*M01*Jinv10*Jinv00-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv00*Jinv11-(7.0/80.0)*M00*(Jinv00*Jinv00)-(7.0/80.0)*M01*Jinv10*Jinv01-(7.0/80.0)*(Jinv10*Jinv10)*M11-(7.0/80.0)*Jinv10*M11*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((27.0/80.0)*M01*Jinv10*Jinv00+(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/10.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/10.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(3.0/10.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(27.0/40.0)*M01*Jinv10*Jinv00-(57.0/80.0)*Jinv01*M00*Jinv00-(57.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M00*(Jinv00*Jinv00)-(57.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*(Jinv10*Jinv10)*M11-(57.0/80.0)*Jinv10*M11*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((17.0/40.0)*M01*Jinv10*Jinv00+(17.0/40.0)*M00*(Jinv00*Jinv00)+(17.0/40.0)*(Jinv10*Jinv10)*M11+(17.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(0.0)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((3.0/80.0)*M01*Jinv10*Jinv00+(57.0/80.0)*Jinv01*M00*Jinv00+(57.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(57.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][16]=(0.0)*D;
  A[7][17]=((3.0/80.0)*M01*Jinv10*Jinv00-(3.0/10.0)*Jinv01*M00*Jinv00-(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/10.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=((7.0/80.0)*Jinv01*M00*Jinv00+(7.0/80.0)*M10*Jinv00*Jinv11+(7.0/80.0)*M01*Jinv10*Jinv01+(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[8][0]=(-(27.0/40.0)*M01*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[8][9]=(0.0)*D;
  A[8][10]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[8][11]=(0.0)*D;
  A[8][12]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/20.0)*(Jinv01*Jinv01)*M00-(27.0/20.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(189.0/160.0)*M10*Jinv00*Jinv11-(27.0/20.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(189.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[8][15]=(0.0)*D;
  A[8][16]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/10.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/10.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[8][19]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=(-(27.0/40.0)*M01*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00-(51.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(51.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[9][10]=(0.0)*D;
  A[9][11]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[9][12]=(0.0)*D;
  A[9][13]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/20.0)*(Jinv01*Jinv01)*M00-(27.0/20.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(189.0/160.0)*M10*Jinv00*Jinv11-(27.0/20.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(189.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[9][16]=(0.0)*D;
  A[9][17]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/10.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/10.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[10][0]=(0.0)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(0.0)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((81.0/40.0)*M01*Jinv00*Jinv11+(81.0/40.0)*M10*Jinv10*Jinv01+(81.0/20.0)*(Jinv01*Jinv01)*M00+(81.0/20.0)*M01*Jinv01*Jinv11+(81.0/20.0)*M01*Jinv10*Jinv00+(81.0/20.0)*Jinv01*M00*Jinv00+(81.0/40.0)*M10*Jinv00*Jinv11+(81.0/20.0)*M10*Jinv01*Jinv11+(81.0/20.0)*M00*(Jinv00*Jinv00)+(81.0/40.0)*M01*Jinv10*Jinv01+(81.0/20.0)*(Jinv10*Jinv10)*M11+(81.0/20.0)*M11*(Jinv11*Jinv11)+(81.0/20.0)*Jinv10*M11*Jinv11+(81.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(0.0)*D;
  A[10][19]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(0.0)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(0.0)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((81.0/40.0)*M01*Jinv00*Jinv11+(81.0/40.0)*M10*Jinv10*Jinv01+(81.0/20.0)*(Jinv01*Jinv01)*M00+(81.0/20.0)*M01*Jinv01*Jinv11+(81.0/20.0)*M01*Jinv10*Jinv00+(81.0/20.0)*Jinv01*M00*Jinv00+(81.0/40.0)*M10*Jinv00*Jinv11+(81.0/20.0)*M10*Jinv01*Jinv11+(81.0/20.0)*M00*(Jinv00*Jinv00)+(81.0/40.0)*M01*Jinv10*Jinv01+(81.0/20.0)*(Jinv10*Jinv10)*M11+(81.0/20.0)*M11*(Jinv11*Jinv11)+(81.0/20.0)*Jinv10*M11*Jinv11+(81.0/20.0)*M10*Jinv10*Jinv00)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(0.0)*D;
  A[12][0]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/16.0)*M01*Jinv01*Jinv11-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M10*Jinv01*Jinv11-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*M11*(Jinv11*Jinv11)-(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((57.0/80.0)*M01*Jinv00*Jinv11+(57.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*M01*Jinv10*Jinv00+(57.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[12][13]=(0.0)*D;
  A[12][14]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[12][15]=(0.0)*D;
  A[12][16]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/40.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/40.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[12][17]=(0.0)*D;
  A[12][18]=((3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/10.0)*Jinv01*M00*Jinv00-(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/10.0)*M01*Jinv10*Jinv01+(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[12][19]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*(Jinv01*Jinv01)*M00-(27.0/16.0)*M01*Jinv01*Jinv11-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M10*Jinv01*Jinv11-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*M11*(Jinv11*Jinv11)-(27.0/16.0)*Jinv10*M11*Jinv11)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((57.0/80.0)*M01*Jinv00*Jinv11+(57.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*M01*Jinv10*Jinv00+(57.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)*M11+(57.0/80.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*M01*Jinv10*Jinv00-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M00*(Jinv00*Jinv00)-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*(Jinv10*Jinv10)*M11-(81.0/40.0)*Jinv10*M11*Jinv11-(81.0/40.0)*M10*Jinv10*Jinv00)*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[13][14]=(0.0)*D;
  A[13][15]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[13][16]=(0.0)*D;
  A[13][17]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/40.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/40.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[13][18]=(0.0)*D;
  A[13][19]=((3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/10.0)*Jinv01*M00*Jinv00-(3.0/10.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/10.0)*M01*Jinv10*Jinv01+(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[14][0]=((27.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(-(189.0/160.0)*M01*Jinv00*Jinv11-(189.0/160.0)*M10*Jinv10*Jinv01-(27.0/20.0)*(Jinv01*Jinv01)*M00-(27.0/20.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/20.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*M01*Jinv10*Jinv00-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M00*(Jinv00*Jinv00)-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv10*M11*Jinv11-(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[14][17]=(0.0)*D;
  A[14][18]=(-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11-(57.0/80.0)*Jinv01*M00*Jinv00-(57.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11-(57.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*M11*(Jinv11*Jinv11)-(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[14][19]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=((27.0/80.0)*M01*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/80.0)*M01*Jinv10*Jinv00+(3.0/8.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/8.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(-(27.0/160.0)*M01*Jinv00*Jinv11-(27.0/160.0)*M10*Jinv10*Jinv01-(27.0/80.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=(-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-(189.0/160.0)*M01*Jinv00*Jinv11-(189.0/160.0)*M10*Jinv10*Jinv01-(27.0/20.0)*(Jinv01*Jinv01)*M00-(27.0/20.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00-(27.0/20.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/20.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/20.0)*M11*(Jinv11*Jinv11)-(27.0/20.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((81.0/80.0)*M01*Jinv00*Jinv11+(81.0/80.0)*M10*Jinv10*Jinv01+(81.0/40.0)*Jinv01*M00*Jinv00+(81.0/80.0)*M10*Jinv00*Jinv11+(81.0/80.0)*M01*Jinv10*Jinv01+(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[15][12]=(0.0)*D;
  A[15][13]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*M01*Jinv10*Jinv00-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M00*(Jinv00*Jinv00)-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv10*M11*Jinv11-(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=(-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11-(57.0/80.0)*Jinv01*M00*Jinv00-(57.0/80.0)*M10*Jinv00*Jinv11-(27.0/40.0)*M10*Jinv01*Jinv11-(57.0/80.0)*M01*Jinv10*Jinv01-(27.0/40.0)*M11*(Jinv11*Jinv11)-(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[16][0]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=(-(3.0/10.0)*M01*Jinv00*Jinv11-(3.0/10.0)*M10*Jinv10*Jinv01+(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/40.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/40.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*M01*Jinv10*Jinv00-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M00*(Jinv00*Jinv00)-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv10*M11*Jinv11-(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[16][17]=(0.0)*D;
  A[16][18]=((3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(57.0/80.0)*Jinv01*M00*Jinv00+(57.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(57.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*M11*(Jinv11*Jinv11)+(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[16][19]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=(-(3.0/80.0)*M01*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv01-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/40.0)*Jinv01*M00*Jinv00-(3.0/80.0)*M10*Jinv00*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M00*(Jinv00*Jinv00)-(3.0/80.0)*M01*Jinv10*Jinv01-(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/40.0)*Jinv10*M11*Jinv11-(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=(-(3.0/10.0)*M01*Jinv00*Jinv11-(3.0/10.0)*M10*Jinv10*Jinv01+(3.0/80.0)*M01*Jinv10*Jinv00-(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M00*(Jinv00*Jinv00)+(3.0/80.0)*(Jinv10*Jinv10)*M11-(3.0/10.0)*Jinv10*M11*Jinv11+(3.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=((27.0/160.0)*M01*Jinv00*Jinv11+(27.0/160.0)*M10*Jinv10*Jinv01+(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/80.0)*Jinv01*M00*Jinv00+(27.0/160.0)*M10*Jinv00*Jinv11+(27.0/80.0)*M00*(Jinv00*Jinv00)+(27.0/160.0)*M01*Jinv10*Jinv01+(27.0/80.0)*(Jinv10*Jinv10)*M11+(27.0/80.0)*Jinv10*M11*Jinv11+(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(81.0/80.0)*M01*Jinv00*Jinv11-(81.0/80.0)*M10*Jinv10*Jinv01-(81.0/40.0)*(Jinv01*Jinv01)*M00-(81.0/40.0)*M01*Jinv01*Jinv11-(81.0/40.0)*Jinv01*M00*Jinv00-(81.0/80.0)*M10*Jinv00*Jinv11-(81.0/40.0)*M10*Jinv01*Jinv11-(81.0/80.0)*M01*Jinv10*Jinv01-(81.0/40.0)*M11*(Jinv11*Jinv11)-(81.0/40.0)*Jinv10*M11*Jinv11)*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/80.0)*(Jinv01*Jinv01)*M00-(27.0/80.0)*M01*Jinv01*Jinv11-(27.0/80.0)*M01*Jinv10*Jinv00+(27.0/40.0)*Jinv01*M00*Jinv00-(27.0/160.0)*M10*Jinv00*Jinv11-(27.0/80.0)*M10*Jinv01*Jinv11-(27.0/80.0)*M00*(Jinv00*Jinv00)-(27.0/160.0)*M01*Jinv10*Jinv01-(27.0/80.0)*(Jinv10*Jinv10)*M11-(27.0/80.0)*M11*(Jinv11*Jinv11)+(27.0/40.0)*Jinv10*M11*Jinv11-(27.0/80.0)*M10*Jinv10*Jinv00)*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(27.0/32.0)*M01*Jinv00*Jinv11-(27.0/32.0)*M10*Jinv10*Jinv01-(27.0/16.0)*M01*Jinv10*Jinv00-(27.0/16.0)*Jinv01*M00*Jinv00-(27.0/32.0)*M10*Jinv00*Jinv11-(27.0/16.0)*M00*(Jinv00*Jinv00)-(27.0/32.0)*M01*Jinv10*Jinv01-(27.0/16.0)*(Jinv10*Jinv10)*M11-(27.0/16.0)*Jinv10*M11*Jinv11-(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((27.0/32.0)*M01*Jinv00*Jinv11+(27.0/32.0)*M10*Jinv10*Jinv01+(27.0/16.0)*(Jinv01*Jinv01)*M00+(27.0/16.0)*M01*Jinv01*Jinv11+(27.0/16.0)*M01*Jinv10*Jinv00+(27.0/16.0)*Jinv01*M00*Jinv00+(27.0/32.0)*M10*Jinv00*Jinv11+(27.0/16.0)*M10*Jinv01*Jinv11+(27.0/16.0)*M00*(Jinv00*Jinv00)+(27.0/32.0)*M01*Jinv10*Jinv01+(27.0/16.0)*(Jinv10*Jinv10)*M11+(27.0/16.0)*M11*(Jinv11*Jinv11)+(27.0/16.0)*Jinv10*M11*Jinv11+(27.0/16.0)*M10*Jinv10*Jinv00)*D;
  A[17][18]=(0.0)*D;
  A[17][19]=((3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(57.0/80.0)*Jinv01*M00*Jinv00+(57.0/80.0)*M10*Jinv00*Jinv11+(3.0/80.0)*M10*Jinv01*Jinv11+(57.0/80.0)*M01*Jinv10*Jinv01+(3.0/80.0)*M11*(Jinv11*Jinv11)+(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[18][0]=(-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv01-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*M01*Jinv01*Jinv11-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv01*Jinv11-(7.0/80.0)*M11*(Jinv11*Jinv11)-(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[18][3]=(0.0)*D;
  A[18][4]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[18][5]=(0.0)*D;
  A[18][6]=((7.0/80.0)*M01*Jinv00*Jinv11+(7.0/80.0)*M10*Jinv10*Jinv01+(7.0/80.0)*Jinv01*M00*Jinv00+(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((3.0/10.0)*M01*Jinv00*Jinv11+(3.0/10.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/10.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(0.0)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=(-(3.0/10.0)*M01*Jinv00*Jinv11-(3.0/10.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[18][13]=(0.0)*D;
  A[18][14]=(-(57.0/80.0)*M01*Jinv00*Jinv11-(57.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11-(57.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=((57.0/80.0)*M01*Jinv00*Jinv11+(57.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(57.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*M01*Jinv01*Jinv11+(17.0/40.0)*M10*Jinv01*Jinv11+(17.0/40.0)*M11*(Jinv11*Jinv11))*D;
  A[18][19]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=(-(7.0/80.0)*M01*Jinv00*Jinv11-(7.0/80.0)*M10*Jinv10*Jinv01-(7.0/80.0)*(Jinv01*Jinv01)*M00-(7.0/80.0)*M01*Jinv01*Jinv11-(7.0/80.0)*Jinv01*M00*Jinv00-(7.0/80.0)*M10*Jinv01*Jinv11-(7.0/80.0)*M11*(Jinv11*Jinv11)-(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[19][4]=(0.0)*D;
  A[19][5]=(-(3.0/80.0)*(Jinv01*Jinv01)*M00-(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/80.0)*M10*Jinv01*Jinv11-(3.0/80.0)*M11*(Jinv11*Jinv11))*D;
  A[19][6]=(0.0)*D;
  A[19][7]=((7.0/80.0)*M01*Jinv00*Jinv11+(7.0/80.0)*M10*Jinv10*Jinv01+(7.0/80.0)*Jinv01*M00*Jinv00+(7.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((3.0/10.0)*M01*Jinv00*Jinv11+(3.0/10.0)*M10*Jinv10*Jinv01+(27.0/80.0)*(Jinv01*Jinv01)*M00+(27.0/80.0)*M01*Jinv01*Jinv11+(3.0/10.0)*Jinv01*M00*Jinv00+(27.0/80.0)*M10*Jinv01*Jinv11+(27.0/80.0)*M11*(Jinv11*Jinv11)+(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(0.0)*D;
  A[19][12]=(0.0)*D;
  A[19][13]=(-(3.0/10.0)*M01*Jinv00*Jinv11-(3.0/10.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11-(3.0/10.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M11*(Jinv11*Jinv11)-(3.0/10.0)*Jinv10*M11*Jinv11)*D;
  A[19][14]=(0.0)*D;
  A[19][15]=(-(57.0/80.0)*M01*Jinv00*Jinv11-(57.0/80.0)*M10*Jinv10*Jinv01-(27.0/40.0)*(Jinv01*Jinv01)*M00-(27.0/40.0)*M01*Jinv01*Jinv11-(57.0/80.0)*Jinv01*M00*Jinv00-(27.0/40.0)*M10*Jinv01*Jinv11-(27.0/40.0)*M11*(Jinv11*Jinv11)-(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[19][16]=(0.0)*D;
  A[19][17]=((57.0/80.0)*M01*Jinv00*Jinv11+(57.0/80.0)*M10*Jinv10*Jinv01+(3.0/80.0)*(Jinv01*Jinv01)*M00+(3.0/80.0)*M01*Jinv01*Jinv11+(57.0/80.0)*Jinv01*M00*Jinv00+(3.0/80.0)*M10*Jinv01*Jinv11+(3.0/80.0)*M11*(Jinv11*Jinv11)+(57.0/80.0)*Jinv10*M11*Jinv11)*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((17.0/40.0)*(Jinv01*Jinv01)*M00+(17.0/40.0)*M01*Jinv01*Jinv11+(17.0/40.0)*M10*Jinv01*Jinv11+(17.0/40.0)*M11*(Jinv11*Jinv11))*D;
  int nbf = 20;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 4 ---------------*/


 
using namespace std; 
  
void matrix_factory_vector_stiffness_2D_with_M_order4 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[30];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/4.0+x0;  idof2[1]=G10/4.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/4.0+x0;  idof3[1]=G10/4.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=G00/2.0+x0;  idof4[1]=G10/2.0+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=G00/2.0+x0;  idof5[1]=G10/2.0+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=(3.0/4.0)*G00+x0;  idof6[1]=(3.0/4.0)*G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=(3.0/4.0)*G00+x0;  idof7[1]=(3.0/4.0)*G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=G00+x0;  idof8[1]=G10+y0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=G00+x0;  idof9[1]=G10+y0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G01/4.0+x0;  idof10[1]=y0+G11/4.0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G01/4.0+x0;  idof11[1]=y0+G11/4.0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/4.0+G00/4.0+x0;  idof12[1]=G10/4.0+y0+G11/4.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/4.0+G00/4.0+x0;  idof13[1]=G10/4.0+y0+G11/4.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=G01/4.0+G00/2.0+x0;  idof14[1]=G10/2.0+y0+G11/4.0;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=G01/4.0+G00/2.0+x0;  idof15[1]=G10/2.0+y0+G11/4.0;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=G01/4.0+(3.0/4.0)*G00+x0;  idof16[1]=(3.0/4.0)*G10+y0+G11/4.0;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=G01/4.0+(3.0/4.0)*G00+x0;  idof17[1]=(3.0/4.0)*G10+y0+G11/4.0;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01/2.0+x0;  idof18[1]=y0+G11/2.0;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01/2.0+x0;  idof19[1]=y0+G11/2.0;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

  double idof20[3];
  idof20[0]=G01/2.0+G00/4.0+x0;  idof20[1]=G10/4.0+y0+G11/2.0;
  idof20[2] = 0.0;
  ptv ipdof20(3,idof20);
  iidof[20] = dof.insert_dof(element,20,ipdof20);

  double idof21[3];
  idof21[0]=G01/2.0+G00/4.0+x0;  idof21[1]=G10/4.0+y0+G11/2.0;
  idof21[2] = 1.0;
  ptv ipdof21(3,idof21);
  iidof[21] = dof.insert_dof(element,21,ipdof21);

  double idof22[3];
  idof22[0]=G01/2.0+G00/2.0+x0;  idof22[1]=G10/2.0+y0+G11/2.0;
  idof22[2] = 0.0;
  ptv ipdof22(3,idof22);
  iidof[22] = dof.insert_dof(element,22,ipdof22);

  double idof23[3];
  idof23[0]=G01/2.0+G00/2.0+x0;  idof23[1]=G10/2.0+y0+G11/2.0;
  idof23[2] = 1.0;
  ptv ipdof23(3,idof23);
  iidof[23] = dof.insert_dof(element,23,ipdof23);

  double idof24[3];
  idof24[0]=(3.0/4.0)*G01+x0;  idof24[1]=y0+(3.0/4.0)*G11;
  idof24[2] = 0.0;
  ptv ipdof24(3,idof24);
  iidof[24] = dof.insert_dof(element,24,ipdof24);

  double idof25[3];
  idof25[0]=(3.0/4.0)*G01+x0;  idof25[1]=y0+(3.0/4.0)*G11;
  idof25[2] = 1.0;
  ptv ipdof25(3,idof25);
  iidof[25] = dof.insert_dof(element,25,ipdof25);

  double idof26[3];
  idof26[0]=(3.0/4.0)*G01+G00/4.0+x0;  idof26[1]=G10/4.0+y0+(3.0/4.0)*G11;
  idof26[2] = 0.0;
  ptv ipdof26(3,idof26);
  iidof[26] = dof.insert_dof(element,26,ipdof26);

  double idof27[3];
  idof27[0]=(3.0/4.0)*G01+G00/4.0+x0;  idof27[1]=G10/4.0+y0+(3.0/4.0)*G11;
  idof27[2] = 1.0;
  ptv ipdof27(3,idof27);
  iidof[27] = dof.insert_dof(element,27,ipdof27);

  double idof28[3];
  idof28[0]=G01+x0;  idof28[1]=y0+G11;
  idof28[2] = 0.0;
  ptv ipdof28(3,idof28);
  iidof[28] = dof.insert_dof(element,28,ipdof28);

  double idof29[3];
  idof29[0]=G01+x0;  idof29[1]=y0+G11;
  idof29[2] = 1.0;
  ptv ipdof29(3,idof29);
  iidof[29] = dof.insert_dof(element,29,ipdof29);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[30][30];
  A[0][0]=((47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*Jinv00*M01*Jinv11+(47.0/126.0)*M10*Jinv11*Jinv01+(47.0/63.0)*Jinv00*M00*Jinv01+(47.0/126.0)*Jinv00*M10*Jinv10+(47.0/126.0)*M10*Jinv10*Jinv01+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/63.0)*Jinv11*Jinv10*M11+(47.0/126.0)*M01*Jinv11*Jinv01+(47.0/126.0)*(Jinv10*Jinv10)*M11+(47.0/126.0)*Jinv00*M10*Jinv11+(47.0/126.0)*M01*Jinv10*Jinv01)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M10*Jinv11+(8.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=((107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv10+(107.0/1890.0)*M10*Jinv10*Jinv01+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M10*Jinv11-(88.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(442.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[0][19]=(0.0)*D;
  A[0][20]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][21]=(0.0)*D;
  A[0][22]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][23]=(0.0)*D;
  A[0][24]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(232.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[0][25]=(0.0)*D;
  A[0][26]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[0][27]=(0.0)*D;
  A[0][28]=((107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M01*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[0][29]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*Jinv00*M01*Jinv11+(47.0/126.0)*M10*Jinv11*Jinv01+(47.0/63.0)*Jinv00*M00*Jinv01+(47.0/126.0)*Jinv00*M10*Jinv10+(47.0/126.0)*M10*Jinv10*Jinv01+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/63.0)*Jinv11*Jinv10*M11+(47.0/126.0)*M01*Jinv11*Jinv01+(47.0/126.0)*(Jinv10*Jinv10)*M11+(47.0/126.0)*Jinv00*M10*Jinv11+(47.0/126.0)*M01*Jinv10*Jinv01)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M10*Jinv11+(8.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=((107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv10+(107.0/1890.0)*M10*Jinv10*Jinv01+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M10*Jinv11-(88.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(442.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[1][20]=(0.0)*D;
  A[1][21]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][22]=(0.0)*D;
  A[1][23]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][24]=(0.0)*D;
  A[1][25]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(232.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[1][26]=(0.0)*D;
  A[1][27]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[1][28]=(0.0)*D;
  A[1][29]=((107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M01*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[2][0]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M10*Jinv11-(88.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((64.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(64.0/315.0)*M10*Jinv10*Jinv01-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M10*Jinv11+(32.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[2][11]=(0.0)*D;
  A[2][12]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[2][19]=(0.0)*D;
  A[2][20]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[2][21]=(0.0)*D;
  A[2][22]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[2][23]=(0.0)*D;
  A[2][24]=((32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[2][25]=(0.0)*D;
  A[2][26]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[2][27]=(0.0)*D;
  A[2][28]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[2][29]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00+(8.0/63.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10+(8.0/63.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11-(88.0/135.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01-(88.0/135.0)*(Jinv10*Jinv10)*M11-(88.0/135.0)*Jinv00*M10*Jinv11-(88.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((64.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(64.0/315.0)*M10*Jinv10*Jinv01-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M10*Jinv11+(32.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[3][20]=(0.0)*D;
  A[3][21]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[3][22]=(0.0)*D;
  A[3][23]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[3][24]=(0.0)*D;
  A[3][25]=((32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[3][26]=(0.0)*D;
  A[3][27]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[3][28]=(0.0)*D;
  A[3][29]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[4][0]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(442.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(40.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((932.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M10*Jinv11*Jinv01+(932.0/315.0)*Jinv00*M00*Jinv01+(932.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01+(772.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv11*Jinv11)*M11+(932.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M01*Jinv11*Jinv01+(932.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(466.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(134.0/315.0)*Jinv00*M01*Jinv11+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(134.0/315.0)*M10*Jinv10*Jinv01+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=((32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=((32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=((16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M10*Jinv11-(46.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[4][19]=(0.0)*D;
  A[4][20]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[4][21]=(0.0)*D;
  A[4][22]=((16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(124.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[4][23]=(0.0)*D;
  A[4][24]=((8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[4][25]=(0.0)*D;
  A[4][26]=(-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[4][27]=(0.0)*D;
  A[4][28]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[4][29]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(442.0/945.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(442.0/945.0)*(Jinv10*Jinv10)*M11+(442.0/945.0)*Jinv00*M10*Jinv11+(442.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(40.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((932.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M10*Jinv11*Jinv01+(932.0/315.0)*Jinv00*M00*Jinv01+(932.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01+(772.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv11*Jinv11)*M11+(932.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M01*Jinv11*Jinv01+(932.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(466.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(134.0/315.0)*Jinv00*M01*Jinv11+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(134.0/315.0)*M10*Jinv10*Jinv01+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=((32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=((32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=((16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M10*Jinv11-(46.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[5][20]=(0.0)*D;
  A[5][21]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[5][22]=(0.0)*D;
  A[5][23]=((16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(124.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[5][24]=(0.0)*D;
  A[5][25]=((8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[5][26]=(0.0)*D;
  A[5][27]=(-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[5][28]=(0.0)*D;
  A[5][29]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[6][0]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(232.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((64.0/63.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(1496.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(736.0/945.0)*Jinv00*M01*Jinv11-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(736.0/945.0)*M10*Jinv10*Jinv01-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11)*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*Jinv00*M01*Jinv11+(2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][15]=(0.0)*D;
  A[6][16]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[6][19]=(0.0)*D;
  A[6][20]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[6][21]=(0.0)*D;
  A[6][22]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[6][23]=(0.0)*D;
  A[6][24]=((32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[6][25]=(0.0)*D;
  A[6][26]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[6][27]=(0.0)*D;
  A[6][28]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[6][29]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11-(232.0/945.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01-(232.0/945.0)*(Jinv10*Jinv10)*M11-(232.0/945.0)*Jinv00*M10*Jinv11-(232.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((64.0/63.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/63.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/63.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(368.0/189.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(368.0/189.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(368.0/189.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(368.0/189.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(1496.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(736.0/945.0)*Jinv00*M01*Jinv11-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(736.0/945.0)*M10*Jinv10*Jinv01-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11)*D;
  A[7][10]=(0.0)*D;
  A[7][11]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*Jinv00*M01*Jinv11+(2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][16]=(0.0)*D;
  A[7][17]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[7][20]=(0.0)*D;
  A[7][21]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[7][22]=(0.0)*D;
  A[7][23]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[7][24]=(0.0)*D;
  A[7][25]=((32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[7][26]=(0.0)*D;
  A[7][27]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[7][28]=(0.0)*D;
  A[7][29]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[8][0]=((107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv10+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11+(134.0/315.0)*Jinv00*M10*Jinv11+(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11-(736.0/945.0)*Jinv00*M10*Jinv11-(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*Jinv00*M10*Jinv10+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/126.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][9]=(0.0)*D;
  A[8][10]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][11]=(0.0)*D;
  A[8][12]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][15]=(0.0)*D;
  A[8][16]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][19]=(0.0)*D;
  A[8][20]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][21]=(0.0)*D;
  A[8][22]=((8.0/189.0)*(Jinv00*Jinv00)*M00-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11-(134.0/315.0)*Jinv00*M10*Jinv11-(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[8][23]=(0.0)*D;
  A[8][24]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[8][25]=(0.0)*D;
  A[8][26]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11+(64.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[8][27]=(0.0)*D;
  A[8][28]=(-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10*M11-(107.0/1890.0)*Jinv00*M10*Jinv11-(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[8][29]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=((107.0/1890.0)*(Jinv00*Jinv00)*M00+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*Jinv00*M10*Jinv10+(107.0/1890.0)*Jinv00*M01*Jinv10+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*(Jinv10*Jinv10)*M11+(107.0/1890.0)*Jinv00*M10*Jinv11+(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(232.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*Jinv00*M10*Jinv10-(232.0/945.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((442.0/945.0)*(Jinv00*Jinv00)*M00+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*Jinv00*M10*Jinv10+(442.0/945.0)*Jinv00*M01*Jinv10+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*(Jinv10*Jinv10)*M11+(134.0/315.0)*Jinv00*M10*Jinv11+(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(88.0/135.0)*(Jinv00*Jinv00)*M00-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*Jinv00*M10*Jinv10-(88.0/135.0)*Jinv00*M01*Jinv10-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*(Jinv10*Jinv10)*M11-(736.0/945.0)*Jinv00*M10*Jinv11-(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((47.0/126.0)*(Jinv00*Jinv00)*M00+(47.0/126.0)*Jinv00*M10*Jinv10+(47.0/126.0)*Jinv00*M01*Jinv10+(47.0/126.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][10]=(0.0)*D;
  A[9][11]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][12]=(0.0)*D;
  A[9][13]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][16]=(0.0)*D;
  A[9][17]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][20]=(0.0)*D;
  A[9][21]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][22]=(0.0)*D;
  A[9][23]=((8.0/189.0)*(Jinv00*Jinv00)*M00-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11-(134.0/315.0)*Jinv00*M10*Jinv11-(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[9][24]=(0.0)*D;
  A[9][25]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[9][26]=(0.0)*D;
  A[9][27]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11+(64.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[9][28]=(0.0)*D;
  A[9][29]=(-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*Jinv11*Jinv10*M11-(107.0/1890.0)*Jinv00*M10*Jinv11-(107.0/1890.0)*M01*Jinv10*Jinv01)*D;
  A[10][0]=((8.0/63.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M10*Jinv11+(8.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M10*Jinv11+(32.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=((32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(40.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[10][19]=(0.0)*D;
  A[10][20]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[10][21]=(0.0)*D;
  A[10][22]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[10][23]=(0.0)*D;
  A[10][24]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[10][25]=(0.0)*D;
  A[10][26]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[10][27]=(0.0)*D;
  A[10][28]=(-(232.0/945.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[10][29]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=((8.0/63.0)*(Jinv00*Jinv00)*M00-(88.0/135.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(496.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10-(88.0/135.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11+(8.0/63.0)*Jinv00*M01*Jinv10-(496.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01+(8.0/63.0)*(Jinv10*Jinv10)*M11+(8.0/63.0)*Jinv00*M10*Jinv11+(8.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/35.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/35.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/35.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/35.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/35.0)*Jinv00*M10*Jinv11+(32.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=((32.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1472.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1472.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(40.0/27.0)*Jinv00*M10*Jinv11-(40.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[11][20]=(0.0)*D;
  A[11][21]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[11][22]=(0.0)*D;
  A[11][23]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[11][24]=(0.0)*D;
  A[11][25]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/135.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/135.0)*M10*Jinv10*Jinv01+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[11][26]=(0.0)*D;
  A[11][27]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[11][28]=(0.0)*D;
  A[11][29]=(-(232.0/945.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv11-(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[12][0]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[12][13]=(0.0)*D;
  A[12][14]=(-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[12][15]=(0.0)*D;
  A[12][16]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[12][17]=(0.0)*D;
  A[12][18]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[12][19]=(0.0)*D;
  A[12][20]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[12][21]=(0.0)*D;
  A[12][22]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(16.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[12][23]=(0.0)*D;
  A[12][24]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[12][25]=(0.0)*D;
  A[12][26]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[12][27]=(0.0)*D;
  A[12][28]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[12][29]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1088.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(2176.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1088.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(256.0/105.0)*Jinv00*M01*Jinv10-(2176.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1088.0/945.0)*Jinv00*M10*Jinv11-(1088.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[13][14]=(0.0)*D;
  A[13][15]=(-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[13][16]=(0.0)*D;
  A[13][17]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[13][18]=(0.0)*D;
  A[13][19]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[13][20]=(0.0)*D;
  A[13][21]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[13][22]=(0.0)*D;
  A[13][23]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(16.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[13][24]=(0.0)*D;
  A[13][25]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[13][26]=(0.0)*D;
  A[13][27]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[13][28]=(0.0)*D;
  A[13][29]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][0]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*Jinv00*M01*Jinv11+(2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=(-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*Jinv00*M01*Jinv11-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[14][17]=(0.0)*D;
  A[14][18]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[14][19]=(0.0)*D;
  A[14][20]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01+(256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M10*Jinv11+(128.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[14][21]=(0.0)*D;
  A[14][22]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[14][23]=(0.0)*D;
  A[14][24]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[14][25]=(0.0)*D;
  A[14][26]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[14][27]=(0.0)*D;
  A[14][28]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[14][29]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(1216.0/945.0)*Jinv00*M01*Jinv11+(2432.0/945.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[15][12]=(0.0)*D;
  A[15][13]=(-(256.0/63.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/63.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/63.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/63.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*Jinv00*M01*Jinv11-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[15][20]=(0.0)*D;
  A[15][21]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01+(256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M10*Jinv11+(128.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[15][22]=(0.0)*D;
  A[15][23]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[15][24]=(0.0)*D;
  A[15][25]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[15][26]=(0.0)*D;
  A[15][27]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[15][28]=(0.0)*D;
  A[15][29]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[16][0]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=((32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*Jinv00*M01*Jinv11-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[16][17]=(0.0)*D;
  A[16][18]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[16][19]=(0.0)*D;
  A[16][20]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[16][21]=(0.0)*D;
  A[16][22]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M10*Jinv11+(776.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[16][23]=(0.0)*D;
  A[16][24]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[16][25]=(0.0)*D;
  A[16][26]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11-(416.0/945.0)*Jinv00*M10*Jinv11-(416.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[16][27]=(0.0)*D;
  A[16][28]=(-(8.0/189.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[16][29]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=((32.0/315.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11+(32.0/315.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01+(32.0/315.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=(-(128.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(1984.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(128.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(1984.0/945.0)*M00*(Jinv01*Jinv01)-(1984.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(1984.0/945.0)*M01*Jinv11*Jinv01-(128.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=((8.0/63.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(8.0/63.0)*Jinv00*M01*Jinv10+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*(Jinv10*Jinv10)*M11)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(64.0/315.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(256.0/105.0)*(Jinv00*Jinv00)*M00-(1216.0/945.0)*Jinv00*M01*Jinv11-(2432.0/945.0)*Jinv00*M00*Jinv01-(256.0/105.0)*Jinv00*M10*Jinv10-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*Jinv00*M01*Jinv10-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*(Jinv10*Jinv10)*M11-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((64.0/35.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(1984.0/945.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(64.0/35.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(1984.0/945.0)*M00*(Jinv01*Jinv01)+(1984.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/35.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(1984.0/945.0)*M01*Jinv11*Jinv01+(64.0/35.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[17][18]=(0.0)*D;
  A[17][19]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[17][20]=(0.0)*D;
  A[17][21]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[17][22]=(0.0)*D;
  A[17][23]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M10*Jinv11+(776.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[17][24]=(0.0)*D;
  A[17][25]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[17][26]=(0.0)*D;
  A[17][27]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(32.0/315.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11-(416.0/945.0)*Jinv00*M10*Jinv11-(416.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[17][28]=(0.0)*D;
  A[17][29]=(-(8.0/189.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M10*Jinv11+(64.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][0]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[18][3]=(0.0)*D;
  A[18][4]=((16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M10*Jinv11-(46.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][5]=(0.0)*D;
  A[18][6]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][13]=(0.0)*D;
  A[18][14]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((772.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*Jinv00*M01*Jinv11+(932.0/315.0)*M10*Jinv11*Jinv01+(932.0/315.0)*Jinv00*M00*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01+(932.0/315.0)*M00*(Jinv01*Jinv01)+(932.0/315.0)*(Jinv11*Jinv11)*M11+(772.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(932.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(466.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][19]=(0.0)*D;
  A[18][20]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[18][21]=(0.0)*D;
  A[18][22]=((124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][23]=(0.0)*D;
  A[18][24]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(1496.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[18][25]=(0.0)*D;
  A[18][26]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[18][27]=(0.0)*D;
  A[18][28]=((442.0/945.0)*M10*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M10*Jinv11+(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[18][29]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(442.0/945.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(482.0/945.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(442.0/945.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(482.0/945.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(344.0/945.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01-(688.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(344.0/945.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(688.0/945.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[19][4]=(0.0)*D;
  A[19][5]=((16.0/315.0)*(Jinv00*Jinv00)*M00-(46.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01-(92.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10-(46.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10-(92.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11-(46.0/315.0)*Jinv00*M10*Jinv11-(46.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[19][6]=(0.0)*D;
  A[19][7]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(16.0/189.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00-(40.0/27.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1744.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10-(40.0/27.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10-(1744.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(344.0/945.0)*Jinv00*M10*Jinv11-(344.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[19][12]=(0.0)*D;
  A[19][13]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(496.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01+(992.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(496.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(992.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(496.0/315.0)*Jinv00*M10*Jinv11+(496.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[19][14]=(0.0)*D;
  A[19][15]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[19][16]=(0.0)*D;
  A[19][17]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*Jinv00*M01*Jinv10-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((772.0/315.0)*(Jinv00*Jinv00)*M00+(466.0/315.0)*Jinv00*M01*Jinv11+(932.0/315.0)*M10*Jinv11*Jinv01+(932.0/315.0)*Jinv00*M00*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(466.0/315.0)*M10*Jinv10*Jinv01+(932.0/315.0)*M00*(Jinv01*Jinv01)+(932.0/315.0)*(Jinv11*Jinv11)*M11+(772.0/315.0)*Jinv00*M01*Jinv10+(932.0/315.0)*Jinv11*Jinv10*M11+(932.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*(Jinv10*Jinv10)*M11+(466.0/315.0)*Jinv00*M10*Jinv11+(466.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[19][20]=(0.0)*D;
  A[19][21]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[19][22]=(0.0)*D;
  A[19][23]=((124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[19][24]=(0.0)*D;
  A[19][25]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(88.0/189.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(88.0/189.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(1496.0/945.0)*Jinv00*M10*Jinv11-(1496.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[19][26]=(0.0)*D;
  A[19][27]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[19][28]=(0.0)*D;
  A[19][29]=((442.0/945.0)*M10*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M00*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M10*Jinv11+(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[20][0]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[20][1]=(0.0)*D;
  A[20][2]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[20][3]=(0.0)*D;
  A[20][4]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[20][5]=(0.0)*D;
  A[20][6]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[20][9]=(0.0)*D;
  A[20][10]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[20][11]=(0.0)*D;
  A[20][12]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[20][13]=(0.0)*D;
  A[20][14]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01+(256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M10*Jinv11+(128.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[20][15]=(0.0)*D;
  A[20][16]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[20][17]=(0.0)*D;
  A[20][18]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[20][19]=(0.0)*D;
  A[20][20]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[20][21]=(0.0)*D;
  A[20][22]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[20][23]=(0.0)*D;
  A[20][24]=((1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(2432.0/945.0)*Jinv00*M00*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[20][25]=(0.0)*D;
  A[20][26]=(-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2432.0/945.0)*Jinv00*M00*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[20][27]=(0.0)*D;
  A[20][28]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[20][29]=(0.0)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M01*Jinv11-(16.0/189.0)*M10*Jinv11*Jinv01-(32.0/189.0)*Jinv00*M00*Jinv01-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*M10*Jinv10*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv00*M01*Jinv10-(32.0/189.0)*Jinv11*Jinv10*M11-(16.0/189.0)*M01*Jinv11*Jinv01-(16.0/189.0)*(Jinv10*Jinv10)*M11-(16.0/189.0)*Jinv00*M10*Jinv11-(16.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[21][2]=(0.0)*D;
  A[21][3]=((128.0/945.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/945.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(128.0/945.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(-(32.0/315.0)*(Jinv00*Jinv00)*M00-(16.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv10-(16.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(32.0/315.0)*Jinv00*M01*Jinv10-(32.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*(Jinv10*Jinv10)*M11-(16.0/315.0)*Jinv00*M10*Jinv11-(16.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[21][6]=(0.0)*D;
  A[21][7]=((128.0/945.0)*(Jinv00*Jinv00)*M00-(64.0/189.0)*Jinv00*M01*Jinv11-(128.0/189.0)*Jinv00*M00*Jinv01+(128.0/945.0)*Jinv00*M10*Jinv10-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*Jinv00*M01*Jinv10-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*(Jinv10*Jinv10)*M11-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[21][8]=(0.0)*D;
  A[21][9]=(-(16.0/189.0)*(Jinv00*Jinv00)*M00-(16.0/189.0)*Jinv00*M10*Jinv10-(16.0/189.0)*Jinv00*M01*Jinv10-(16.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[21][10]=(0.0)*D;
  A[21][11]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/135.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(128.0/135.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/135.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/135.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/135.0)*Jinv00*M10*Jinv11+(64.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[21][12]=(0.0)*D;
  A[21][13]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00-(128.0/63.0)*Jinv00*M01*Jinv11-(256.0/63.0)*M10*Jinv11*Jinv01-(256.0/63.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10-(128.0/63.0)*M10*Jinv10*Jinv01-(256.0/63.0)*M00*(Jinv01*Jinv01)-(256.0/63.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10-(256.0/63.0)*Jinv11*Jinv10*M11-(256.0/63.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11-(128.0/63.0)*Jinv00*M10*Jinv11-(128.0/63.0)*M01*Jinv10*Jinv01)*D;
  A[21][14]=(0.0)*D;
  A[21][15]=(-(256.0/315.0)*(Jinv00*Jinv00)*M00+(128.0/105.0)*Jinv00*M01*Jinv11-(256.0/315.0)*M10*Jinv11*Jinv01+(256.0/105.0)*Jinv00*M00*Jinv01-(256.0/315.0)*Jinv00*M10*Jinv10+(128.0/105.0)*M10*Jinv10*Jinv01-(256.0/315.0)*M00*(Jinv01*Jinv01)-(256.0/315.0)*(Jinv11*Jinv11)*M11-(256.0/315.0)*Jinv00*M01*Jinv10+(256.0/105.0)*Jinv11*Jinv10*M11-(256.0/315.0)*M01*Jinv11*Jinv01-(256.0/315.0)*(Jinv10*Jinv10)*M11+(128.0/105.0)*Jinv00*M10*Jinv11+(128.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[21][16]=(0.0)*D;
  A[21][17]=((256.0/315.0)*(Jinv00*Jinv00)*M00+(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/189.0)*Jinv00*M00*Jinv01+(256.0/315.0)*Jinv00*M10*Jinv10+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*Jinv00*M01*Jinv10+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*(Jinv10*Jinv10)*M11+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[21][18]=(0.0)*D;
  A[21][19]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(176.0/105.0)*Jinv00*M01*Jinv11-(32.0/315.0)*M10*Jinv11*Jinv01-(352.0/105.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(176.0/105.0)*M10*Jinv10*Jinv01-(32.0/315.0)*M00*(Jinv01*Jinv01)-(32.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(352.0/105.0)*Jinv11*Jinv10*M11-(32.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(176.0/105.0)*Jinv00*M10*Jinv11-(176.0/105.0)*M01*Jinv10*Jinv01)*D;
  A[21][20]=(0.0)*D;
  A[21][21]=((256.0/45.0)*(Jinv00*Jinv00)*M00+(128.0/45.0)*Jinv00*M01*Jinv11+(256.0/45.0)*M10*Jinv11*Jinv01+(256.0/45.0)*Jinv00*M00*Jinv01+(256.0/45.0)*Jinv00*M10*Jinv10+(128.0/45.0)*M10*Jinv10*Jinv01+(256.0/45.0)*M00*(Jinv01*Jinv01)+(256.0/45.0)*(Jinv11*Jinv11)*M11+(256.0/45.0)*Jinv00*M01*Jinv10+(256.0/45.0)*Jinv11*Jinv10*M11+(256.0/45.0)*M01*Jinv11*Jinv01+(256.0/45.0)*(Jinv10*Jinv10)*M11+(128.0/45.0)*Jinv00*M10*Jinv11+(128.0/45.0)*M01*Jinv10*Jinv01)*D;
  A[21][22]=(0.0)*D;
  A[21][23]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[21][24]=(0.0)*D;
  A[21][25]=((1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(2432.0/945.0)*Jinv00*M00*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[21][26]=(0.0)*D;
  A[21][27]=(-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2432.0/945.0)*Jinv00*M00*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[21][28]=(0.0)*D;
  A[21][29]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[22][0]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[22][1]=(0.0)*D;
  A[22][2]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[22][3]=(0.0)*D;
  A[22][4]=((16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(124.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[22][5]=(0.0)*D;
  A[22][6]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[22][7]=(0.0)*D;
  A[22][8]=((8.0/189.0)*(Jinv00*Jinv00)*M00-(134.0/315.0)*Jinv00*M01*Jinv11-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10-(134.0/315.0)*M10*Jinv10*Jinv01+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[22][9]=(0.0)*D;
  A[22][10]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[22][11]=(0.0)*D;
  A[22][12]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(16.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[22][13]=(0.0)*D;
  A[22][14]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[22][15]=(0.0)*D;
  A[22][16]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[22][17]=(0.0)*D;
  A[22][18]=((124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[22][19]=(0.0)*D;
  A[22][20]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[22][21]=(0.0)*D;
  A[22][22]=((772.0/315.0)*(Jinv00*Jinv00)*M00+(34.0/35.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M10*Jinv11*Jinv01+(68.0/35.0)*Jinv00*M00*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(34.0/35.0)*M10*Jinv10*Jinv01+(772.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv11*Jinv11)*M11+(772.0/315.0)*Jinv00*M01*Jinv10+(68.0/35.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*(Jinv10*Jinv10)*M11+(34.0/35.0)*Jinv00*M10*Jinv11+(34.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[22][23]=(0.0)*D;
  A[22][24]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[22][25]=(0.0)*D;
  A[22][26]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M10*Jinv11+(776.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[22][27]=(0.0)*D;
  A[22][28]=((8.0/189.0)*M10*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M10*Jinv11-(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[22][29]=(0.0)*D;
  A[23][0]=(0.0)*D;
  A[23][1]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[23][2]=(0.0)*D;
  A[23][3]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[23][4]=(0.0)*D;
  A[23][5]=((16.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(124.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(16.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(124.0/315.0)*M00*(Jinv01*Jinv01)+(124.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(124.0/315.0)*M01*Jinv11*Jinv01+(16.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(-(64.0/945.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11+(16.0/21.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01-(64.0/945.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01+(16.0/21.0)*M00*(Jinv01*Jinv01)+(16.0/21.0)*(Jinv11*Jinv11)*M11-(64.0/945.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11+(16.0/21.0)*M01*Jinv11*Jinv01-(64.0/945.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[23][8]=(0.0)*D;
  A[23][9]=((8.0/189.0)*(Jinv00*Jinv00)*M00-(134.0/315.0)*Jinv00*M01*Jinv11-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10-(134.0/315.0)*M10*Jinv10*Jinv01+(8.0/189.0)*Jinv00*M01*Jinv10-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(-(16.0/105.0)*(Jinv00*Jinv00)*M00-(104.0/945.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01-(208.0/945.0)*Jinv00*M00*Jinv01-(16.0/105.0)*Jinv00*M10*Jinv10-(104.0/945.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11-(16.0/105.0)*Jinv00*M01*Jinv10-(208.0/945.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01-(16.0/105.0)*(Jinv10*Jinv10)*M11-(104.0/945.0)*Jinv00*M10*Jinv11-(104.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[23][12]=(0.0)*D;
  A[23][13]=((128.0/315.0)*(Jinv00*Jinv00)*M00+(16.0/35.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01+(32.0/35.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10+(16.0/35.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10+(32.0/35.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11+(16.0/35.0)*Jinv00*M10*Jinv11+(16.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[23][14]=(0.0)*D;
  A[23][15]=((128.0/315.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11-(128.0/45.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01+(128.0/315.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01-(128.0/45.0)*M00*(Jinv01*Jinv01)-(128.0/45.0)*(Jinv11*Jinv11)*M11+(128.0/315.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11-(128.0/45.0)*M01*Jinv11*Jinv01+(128.0/315.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[23][16]=(0.0)*D;
  A[23][17]=(-(208.0/315.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*Jinv00*M01*Jinv11-(16.0/21.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(208.0/315.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01-(16.0/21.0)*M00*(Jinv01*Jinv01)-(16.0/21.0)*(Jinv11*Jinv11)*M11-(208.0/315.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(16.0/21.0)*M01*Jinv11*Jinv01-(208.0/315.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[23][18]=(0.0)*D;
  A[23][19]=((124.0/315.0)*(Jinv00*Jinv00)*M00+(62.0/315.0)*Jinv00*M01*Jinv11+(16.0/315.0)*M10*Jinv11*Jinv01+(124.0/315.0)*Jinv00*M00*Jinv01+(124.0/315.0)*Jinv00*M10*Jinv10+(62.0/315.0)*M10*Jinv10*Jinv01+(16.0/315.0)*M00*(Jinv01*Jinv01)+(16.0/315.0)*(Jinv11*Jinv11)*M11+(124.0/315.0)*Jinv00*M01*Jinv10+(124.0/315.0)*Jinv11*Jinv10*M11+(16.0/315.0)*M01*Jinv11*Jinv01+(124.0/315.0)*(Jinv10*Jinv10)*M11+(62.0/315.0)*Jinv00*M10*Jinv11+(62.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[23][20]=(0.0)*D;
  A[23][21]=(-(128.0/45.0)*(Jinv00*Jinv00)*M00-(368.0/315.0)*Jinv00*M01*Jinv11+(128.0/315.0)*M10*Jinv11*Jinv01-(736.0/315.0)*Jinv00*M00*Jinv01-(128.0/45.0)*Jinv00*M10*Jinv10-(368.0/315.0)*M10*Jinv10*Jinv01+(128.0/315.0)*M00*(Jinv01*Jinv01)+(128.0/315.0)*(Jinv11*Jinv11)*M11-(128.0/45.0)*Jinv00*M01*Jinv10-(736.0/315.0)*Jinv11*Jinv10*M11+(128.0/315.0)*M01*Jinv11*Jinv01-(128.0/45.0)*(Jinv10*Jinv10)*M11-(368.0/315.0)*Jinv00*M10*Jinv11-(368.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[23][22]=(0.0)*D;
  A[23][23]=((772.0/315.0)*(Jinv00*Jinv00)*M00+(34.0/35.0)*Jinv00*M01*Jinv11+(772.0/315.0)*M10*Jinv11*Jinv01+(68.0/35.0)*Jinv00*M00*Jinv01+(772.0/315.0)*Jinv00*M10*Jinv10+(34.0/35.0)*M10*Jinv10*Jinv01+(772.0/315.0)*M00*(Jinv01*Jinv01)+(772.0/315.0)*(Jinv11*Jinv11)*M11+(772.0/315.0)*Jinv00*M01*Jinv10+(68.0/35.0)*Jinv11*Jinv10*M11+(772.0/315.0)*M01*Jinv11*Jinv01+(772.0/315.0)*(Jinv10*Jinv10)*M11+(34.0/35.0)*Jinv00*M10*Jinv11+(34.0/35.0)*M01*Jinv10*Jinv01)*D;
  A[23][24]=(0.0)*D;
  A[23][25]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[23][26]=(0.0)*D;
  A[23][27]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(8.0/27.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(8.0/27.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11+(776.0/945.0)*Jinv00*M10*Jinv11+(776.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[23][28]=(0.0)*D;
  A[23][29]=((8.0/189.0)*M10*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M10*Jinv11-(134.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[24][0]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[24][1]=(0.0)*D;
  A[24][2]=((32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[24][3]=(0.0)*D;
  A[24][4]=((8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[24][5]=(0.0)*D;
  A[24][6]=((32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[24][7]=(0.0)*D;
  A[24][8]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[24][9]=(0.0)*D;
  A[24][10]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[24][11]=(0.0)*D;
  A[24][12]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[24][13]=(0.0)*D;
  A[24][14]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[24][15]=(0.0)*D;
  A[24][16]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[24][17]=(0.0)*D;
  A[24][18]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[24][19]=(0.0)*D;
  A[24][20]=((1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(2432.0/945.0)*Jinv00*M00*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[24][21]=(0.0)*D;
  A[24][22]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[24][23]=(0.0)*D;
  A[24][24]=((1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[24][25]=(0.0)*D;
  A[24][26]=(-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[24][27]=(0.0)*D;
  A[24][28]=(-(88.0/135.0)*M10*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M10*Jinv11-(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[24][29]=(0.0)*D;
  A[25][0]=(0.0)*D;
  A[25][1]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00-(232.0/945.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(272.0/945.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10-(232.0/945.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(8.0/189.0)*Jinv00*M01*Jinv10-(272.0/945.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01-(8.0/189.0)*(Jinv10*Jinv10)*M11-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[25][2]=(0.0)*D;
  A[25][3]=((32.0/315.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[25][4]=(0.0)*D;
  A[25][5]=((8.0/189.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/189.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[25][6]=(0.0)*D;
  A[25][7]=((32.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01+(32.0/315.0)*M10*Jinv10*Jinv01+(64.0/315.0)*Jinv11*Jinv10*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[25][8]=(0.0)*D;
  A[25][9]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*Jinv00*M01*Jinv10+(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[25][10]=(0.0)*D;
  A[25][11]=((64.0/189.0)*(Jinv00*Jinv00)*M00+(736.0/945.0)*Jinv00*M01*Jinv11+(64.0/63.0)*M10*Jinv11*Jinv01+(64.0/63.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10+(736.0/945.0)*M10*Jinv10*Jinv01+(64.0/63.0)*M00*(Jinv01*Jinv01)+(64.0/63.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10+(64.0/63.0)*Jinv11*Jinv10*M11+(64.0/63.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/135.0)*Jinv00*M10*Jinv11+(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[25][12]=(0.0)*D;
  A[25][13]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[25][14]=(0.0)*D;
  A[25][15]=(-(64.0/189.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01-(128.0/189.0)*Jinv00*M00*Jinv01-(64.0/189.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11-(128.0/189.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv11-(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[25][16]=(0.0)*D;
  A[25][17]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[25][18]=(0.0)*D;
  A[25][19]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00-(1496.0/945.0)*Jinv00*M01*Jinv11-(368.0/189.0)*M10*Jinv11*Jinv01-(1936.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10-(1496.0/945.0)*M10*Jinv10*Jinv01-(368.0/189.0)*M00*(Jinv01*Jinv01)-(368.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10-(1936.0/945.0)*Jinv11*Jinv10*M11-(368.0/189.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(88.0/189.0)*Jinv00*M10*Jinv11-(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[25][20]=(0.0)*D;
  A[25][21]=((1216.0/945.0)*Jinv00*M01*Jinv11+(128.0/945.0)*M10*Jinv11*Jinv01+(2432.0/945.0)*Jinv00*M00*Jinv01+(1216.0/945.0)*M10*Jinv10*Jinv01+(128.0/945.0)*M00*(Jinv01*Jinv01)+(128.0/945.0)*(Jinv11*Jinv11)*M11+(2432.0/945.0)*Jinv11*Jinv10*M11+(128.0/945.0)*M01*Jinv11*Jinv01+(1216.0/945.0)*Jinv00*M10*Jinv11+(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[25][22]=(0.0)*D;
  A[25][23]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(8.0/27.0)*Jinv00*M01*Jinv11-(64.0/945.0)*M10*Jinv11*Jinv01+(16.0/27.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(8.0/27.0)*M10*Jinv10*Jinv01-(64.0/945.0)*M00*(Jinv01*Jinv01)-(64.0/945.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(16.0/27.0)*Jinv11*Jinv10*M11-(64.0/945.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(8.0/27.0)*Jinv00*M10*Jinv11+(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[25][24]=(0.0)*D;
  A[25][25]=((1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[25][26]=(0.0)*D;
  A[25][27]=(-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[25][28]=(0.0)*D;
  A[25][29]=(-(88.0/135.0)*M10*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M00*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M10*Jinv11-(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[26][0]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[26][1]=(0.0)*D;
  A[26][2]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[26][3]=(0.0)*D;
  A[26][4]=(-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[26][5]=(0.0)*D;
  A[26][6]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[26][7]=(0.0)*D;
  A[26][8]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00+(64.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10+(64.0/315.0)*M10*Jinv10*Jinv01-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[26][9]=(0.0)*D;
  A[26][10]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[26][11]=(0.0)*D;
  A[26][12]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[26][13]=(0.0)*D;
  A[26][14]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[26][15]=(0.0)*D;
  A[26][16]=((64.0/189.0)*(Jinv00*Jinv00)*M00-(416.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10-(416.0/945.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[26][17]=(0.0)*D;
  A[26][18]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[26][19]=(0.0)*D;
  A[26][20]=(-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2432.0/945.0)*Jinv00*M00*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[26][21]=(0.0)*D;
  A[26][22]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[26][23]=(0.0)*D;
  A[26][24]=(-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[26][25]=(0.0)*D;
  A[26][26]=((1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[26][27]=(0.0)*D;
  A[26][28]=((8.0/63.0)*M10*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[26][29]=(0.0)*D;
  A[27][0]=(0.0)*D;
  A[27][1]=((8.0/189.0)*(Jinv00*Jinv00)*M00+(8.0/189.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01+(16.0/189.0)*Jinv00*M00*Jinv01+(8.0/189.0)*Jinv00*M10*Jinv10+(8.0/189.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*Jinv00*M01*Jinv10+(16.0/189.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01+(8.0/189.0)*(Jinv10*Jinv10)*M11+(8.0/189.0)*Jinv00*M10*Jinv11+(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/315.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/315.0)*M00*(Jinv01*Jinv01)-(64.0/315.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/315.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[27][4]=(0.0)*D;
  A[27][5]=(-(8.0/189.0)*Jinv00*M01*Jinv11-(16.0/105.0)*M10*Jinv11*Jinv01-(16.0/189.0)*Jinv00*M00*Jinv01-(8.0/189.0)*M10*Jinv10*Jinv01-(16.0/105.0)*M00*(Jinv01*Jinv01)-(16.0/105.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*Jinv11*Jinv10*M11-(16.0/105.0)*M01*Jinv11*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv11-(8.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[27][6]=(0.0)*D;
  A[27][7]=(-(32.0/315.0)*Jinv00*M01*Jinv11-(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(32.0/315.0)*M10*Jinv10*Jinv01-(64.0/189.0)*M00*(Jinv01*Jinv01)-(64.0/189.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(64.0/189.0)*M01*Jinv11*Jinv01-(32.0/315.0)*Jinv00*M10*Jinv11-(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[27][8]=(0.0)*D;
  A[27][9]=(-(8.0/189.0)*(Jinv00*Jinv00)*M00+(64.0/315.0)*Jinv00*M01*Jinv11+(64.0/315.0)*Jinv00*M00*Jinv01-(8.0/189.0)*Jinv00*M10*Jinv10+(64.0/315.0)*M10*Jinv10*Jinv01-(8.0/189.0)*Jinv00*M01*Jinv10+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*(Jinv10*Jinv10)*M11)*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(-(64.0/189.0)*(Jinv00*Jinv00)*M00-(32.0/135.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(64.0/135.0)*Jinv00*M00*Jinv01-(64.0/189.0)*Jinv00*M10*Jinv10-(32.0/135.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/135.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(64.0/189.0)*(Jinv10*Jinv10)*M11-(32.0/135.0)*Jinv00*M10*Jinv11-(32.0/135.0)*M01*Jinv10*Jinv01)*D;
  A[27][12]=(0.0)*D;
  A[27][13]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[27][14]=(0.0)*D;
  A[27][15]=((64.0/189.0)*Jinv00*M01*Jinv11+(256.0/315.0)*M10*Jinv11*Jinv01+(128.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*M10*Jinv10*Jinv01+(256.0/315.0)*M00*(Jinv01*Jinv01)+(256.0/315.0)*(Jinv11*Jinv11)*M11+(128.0/189.0)*Jinv11*Jinv10*M11+(256.0/315.0)*M01*Jinv11*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv11+(64.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[27][16]=(0.0)*D;
  A[27][17]=((64.0/189.0)*(Jinv00*Jinv00)*M00-(416.0/945.0)*Jinv00*M01*Jinv11+(64.0/189.0)*M10*Jinv11*Jinv01-(64.0/189.0)*Jinv00*M00*Jinv01+(64.0/189.0)*Jinv00*M10*Jinv10-(416.0/945.0)*M10*Jinv10*Jinv01+(64.0/189.0)*M00*(Jinv01*Jinv01)+(64.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/189.0)*Jinv00*M01*Jinv10-(64.0/189.0)*Jinv11*Jinv10*M11+(64.0/189.0)*M01*Jinv11*Jinv01+(64.0/189.0)*(Jinv10*Jinv10)*M11+(32.0/315.0)*Jinv00*M10*Jinv11+(32.0/315.0)*M01*Jinv10*Jinv01)*D;
  A[27][18]=(0.0)*D;
  A[27][19]=((16.0/21.0)*(Jinv00*Jinv00)*M00+(88.0/189.0)*Jinv00*M01*Jinv11+(32.0/315.0)*M10*Jinv11*Jinv01+(176.0/189.0)*Jinv00*M00*Jinv01+(16.0/21.0)*Jinv00*M10*Jinv10+(88.0/189.0)*M10*Jinv10*Jinv01+(32.0/315.0)*M00*(Jinv01*Jinv01)+(32.0/315.0)*(Jinv11*Jinv11)*M11+(16.0/21.0)*Jinv00*M01*Jinv10+(176.0/189.0)*Jinv11*Jinv10*M11+(32.0/315.0)*M01*Jinv11*Jinv01+(16.0/21.0)*(Jinv10*Jinv10)*M11+(88.0/189.0)*Jinv00*M10*Jinv11+(88.0/189.0)*M01*Jinv10*Jinv01)*D;
  A[27][20]=(0.0)*D;
  A[27][21]=(-(1216.0/945.0)*Jinv00*M01*Jinv11-(256.0/105.0)*M10*Jinv11*Jinv01-(2432.0/945.0)*Jinv00*M00*Jinv01-(1216.0/945.0)*M10*Jinv10*Jinv01-(256.0/105.0)*M00*(Jinv01*Jinv01)-(256.0/105.0)*(Jinv11*Jinv11)*M11-(2432.0/945.0)*Jinv11*Jinv10*M11-(256.0/105.0)*M01*Jinv11*Jinv01-(1216.0/945.0)*Jinv00*M10*Jinv11-(1216.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[27][22]=(0.0)*D;
  A[27][23]=(-(16.0/21.0)*(Jinv00*Jinv00)*M00+(776.0/945.0)*Jinv00*M01*Jinv11-(208.0/315.0)*M10*Jinv11*Jinv01+(496.0/945.0)*Jinv00*M00*Jinv01-(16.0/21.0)*Jinv00*M10*Jinv10+(776.0/945.0)*M10*Jinv10*Jinv01-(208.0/315.0)*M00*(Jinv01*Jinv01)-(208.0/315.0)*(Jinv11*Jinv11)*M11-(16.0/21.0)*Jinv00*M01*Jinv10+(496.0/945.0)*Jinv11*Jinv10*M11-(208.0/315.0)*M01*Jinv11*Jinv01-(16.0/21.0)*(Jinv10*Jinv10)*M11-(8.0/27.0)*Jinv00*M10*Jinv11-(8.0/27.0)*M01*Jinv10*Jinv01)*D;
  A[27][24]=(0.0)*D;
  A[27][25]=(-(1984.0/945.0)*(Jinv00*Jinv00)*M00-(992.0/945.0)*Jinv00*M01*Jinv11-(128.0/945.0)*M10*Jinv11*Jinv01-(1984.0/945.0)*Jinv00*M00*Jinv01-(1984.0/945.0)*Jinv00*M10*Jinv10-(992.0/945.0)*M10*Jinv10*Jinv01-(128.0/945.0)*M00*(Jinv01*Jinv01)-(128.0/945.0)*(Jinv11*Jinv11)*M11-(1984.0/945.0)*Jinv00*M01*Jinv10-(1984.0/945.0)*Jinv11*Jinv10*M11-(128.0/945.0)*M01*Jinv11*Jinv01-(1984.0/945.0)*(Jinv10*Jinv10)*M11-(992.0/945.0)*Jinv00*M10*Jinv11-(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[27][26]=(0.0)*D;
  A[27][27]=((1984.0/945.0)*(Jinv00*Jinv00)*M00+(992.0/945.0)*Jinv00*M01*Jinv11+(64.0/35.0)*M10*Jinv11*Jinv01+(1984.0/945.0)*Jinv00*M00*Jinv01+(1984.0/945.0)*Jinv00*M10*Jinv10+(992.0/945.0)*M10*Jinv10*Jinv01+(64.0/35.0)*M00*(Jinv01*Jinv01)+(64.0/35.0)*(Jinv11*Jinv11)*M11+(1984.0/945.0)*Jinv00*M01*Jinv10+(1984.0/945.0)*Jinv11*Jinv10*M11+(64.0/35.0)*M01*Jinv11*Jinv01+(1984.0/945.0)*(Jinv10*Jinv10)*M11+(992.0/945.0)*Jinv00*M10*Jinv11+(992.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[27][28]=(0.0)*D;
  A[27][29]=((8.0/63.0)*M10*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M00*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M10*Jinv11+(736.0/945.0)*M01*Jinv10*Jinv01)*D;
  A[28][0]=((107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M10*Jinv10*Jinv01+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M01*Jinv11*Jinv01)*D;
  A[28][1]=(0.0)*D;
  A[28][2]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][3]=(0.0)*D;
  A[28][4]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][5]=(0.0)*D;
  A[28][6]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][7]=(0.0)*D;
  A[28][8]=(-(107.0/1890.0)*Jinv00*M01*Jinv11-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*M10*Jinv10*Jinv01-(107.0/1890.0)*Jinv11*Jinv10*M11)*D;
  A[28][9]=(0.0)*D;
  A[28][10]=(-(64.0/315.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[28][11]=(0.0)*D;
  A[28][12]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][13]=(0.0)*D;
  A[28][14]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][15]=(0.0)*D;
  A[28][16]=((64.0/315.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(64.0/315.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][17]=(0.0)*D;
  A[28][18]=((134.0/315.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M00*Jinv01+(134.0/315.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[28][19]=(0.0)*D;
  A[28][20]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][21]=(0.0)*D;
  A[28][22]=(-(134.0/315.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M00*Jinv01-(134.0/315.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[28][23]=(0.0)*D;
  A[28][24]=(-(736.0/945.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M00*Jinv01-(736.0/945.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01)*D;
  A[28][25]=(0.0)*D;
  A[28][26]=((736.0/945.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M00*Jinv01+(736.0/945.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01)*D;
  A[28][27]=(0.0)*D;
  A[28][28]=((47.0/126.0)*M10*Jinv11*Jinv01+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*M01*Jinv11*Jinv01)*D;
  A[28][29]=(0.0)*D;
  A[29][0]=(0.0)*D;
  A[29][1]=((107.0/1890.0)*Jinv00*M01*Jinv11+(107.0/1890.0)*M10*Jinv11*Jinv01+(107.0/1890.0)*Jinv00*M00*Jinv01+(107.0/1890.0)*M10*Jinv10*Jinv01+(107.0/1890.0)*M00*(Jinv01*Jinv01)+(107.0/1890.0)*(Jinv11*Jinv11)*M11+(107.0/1890.0)*Jinv11*Jinv10*M11+(107.0/1890.0)*M01*Jinv11*Jinv01)*D;
  A[29][2]=(0.0)*D;
  A[29][3]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][4]=(0.0)*D;
  A[29][5]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][6]=(0.0)*D;
  A[29][7]=((8.0/189.0)*M10*Jinv11*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][8]=(0.0)*D;
  A[29][9]=(-(107.0/1890.0)*Jinv00*M01*Jinv11-(107.0/1890.0)*Jinv00*M00*Jinv01-(107.0/1890.0)*M10*Jinv10*Jinv01-(107.0/1890.0)*Jinv11*Jinv10*M11)*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(-(64.0/315.0)*Jinv00*M01*Jinv11-(232.0/945.0)*M10*Jinv11*Jinv01-(64.0/315.0)*Jinv00*M00*Jinv01-(64.0/315.0)*M10*Jinv10*Jinv01-(232.0/945.0)*M00*(Jinv01*Jinv01)-(232.0/945.0)*(Jinv11*Jinv11)*M11-(64.0/315.0)*Jinv11*Jinv10*M11-(232.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[29][12]=(0.0)*D;
  A[29][13]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][14]=(0.0)*D;
  A[29][15]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][16]=(0.0)*D;
  A[29][17]=((64.0/315.0)*Jinv00*M01*Jinv11-(8.0/189.0)*M10*Jinv11*Jinv01+(64.0/315.0)*Jinv00*M00*Jinv01+(64.0/315.0)*M10*Jinv10*Jinv01-(8.0/189.0)*M00*(Jinv01*Jinv01)-(8.0/189.0)*(Jinv11*Jinv11)*M11+(64.0/315.0)*Jinv11*Jinv10*M11-(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][18]=(0.0)*D;
  A[29][19]=((134.0/315.0)*Jinv00*M01*Jinv11+(442.0/945.0)*M10*Jinv11*Jinv01+(134.0/315.0)*Jinv00*M00*Jinv01+(134.0/315.0)*M10*Jinv10*Jinv01+(442.0/945.0)*M00*(Jinv01*Jinv01)+(442.0/945.0)*(Jinv11*Jinv11)*M11+(134.0/315.0)*Jinv11*Jinv10*M11+(442.0/945.0)*M01*Jinv11*Jinv01)*D;
  A[29][20]=(0.0)*D;
  A[29][21]=(-(16.0/189.0)*M10*Jinv11*Jinv01-(16.0/189.0)*M00*(Jinv01*Jinv01)-(16.0/189.0)*(Jinv11*Jinv11)*M11-(16.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][22]=(0.0)*D;
  A[29][23]=(-(134.0/315.0)*Jinv00*M01*Jinv11+(8.0/189.0)*M10*Jinv11*Jinv01-(134.0/315.0)*Jinv00*M00*Jinv01-(134.0/315.0)*M10*Jinv10*Jinv01+(8.0/189.0)*M00*(Jinv01*Jinv01)+(8.0/189.0)*(Jinv11*Jinv11)*M11-(134.0/315.0)*Jinv11*Jinv10*M11+(8.0/189.0)*M01*Jinv11*Jinv01)*D;
  A[29][24]=(0.0)*D;
  A[29][25]=(-(736.0/945.0)*Jinv00*M01*Jinv11-(88.0/135.0)*M10*Jinv11*Jinv01-(736.0/945.0)*Jinv00*M00*Jinv01-(736.0/945.0)*M10*Jinv10*Jinv01-(88.0/135.0)*M00*(Jinv01*Jinv01)-(88.0/135.0)*(Jinv11*Jinv11)*M11-(736.0/945.0)*Jinv11*Jinv10*M11-(88.0/135.0)*M01*Jinv11*Jinv01)*D;
  A[29][26]=(0.0)*D;
  A[29][27]=((736.0/945.0)*Jinv00*M01*Jinv11+(8.0/63.0)*M10*Jinv11*Jinv01+(736.0/945.0)*Jinv00*M00*Jinv01+(736.0/945.0)*M10*Jinv10*Jinv01+(8.0/63.0)*M00*(Jinv01*Jinv01)+(8.0/63.0)*(Jinv11*Jinv11)*M11+(736.0/945.0)*Jinv11*Jinv10*M11+(8.0/63.0)*M01*Jinv11*Jinv01)*D;
  A[29][28]=(0.0)*D;
  A[29][29]=((47.0/126.0)*M10*Jinv11*Jinv01+(47.0/126.0)*M00*(Jinv01*Jinv01)+(47.0/126.0)*(Jinv11*Jinv11)*M11+(47.0/126.0)*M01*Jinv11*Jinv01)*D;
  int nbf = 30;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}


/* ------------- order 5 ---------------*/


 
using namespace std; 
  
void matrix_factory_vector_stiffness_2D_with_M_order5 (map<pair<int,int>,double>& matrix, 
         DofT<ptv,ptv_is_less>& dof, 
         int element, double M[2][2], double pp0[2], double pp1[2], double pp2[2]){
  
  double M00 = M[0][0]; double M10 = M[1][0]; 
  double M01 = M[0][1]; double M11 = M[1][1]; 
 
  
   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; 
  double x1 = pp1[0]; double y1 = pp1[1]; 
  double x2 = pp2[0]; double y2 = pp2[1]; 
  
  double G00 = x1 - x0; 
  double G01 = x2 - x0;  

  double G10 = y1 - y0; 
  double G11 = y2 - y0; 



  
  double D = fabs(G00*G11-G01*G10);  
 
  int    iidof[42];
  double idof0[3];
  idof0[0]=x0;  idof0[1]=y0;
  idof0[2] = 0.0;
  ptv ipdof0(3,idof0);
  iidof[0] = dof.insert_dof(element,0,ipdof0);

  double idof1[3];
  idof1[0]=x0;  idof1[1]=y0;
  idof1[2] = 1.0;
  ptv ipdof1(3,idof1);
  iidof[1] = dof.insert_dof(element,1,ipdof1);

  double idof2[3];
  idof2[0]=G00/5.0+x0;  idof2[1]=G10/5.0+y0;
  idof2[2] = 0.0;
  ptv ipdof2(3,idof2);
  iidof[2] = dof.insert_dof(element,2,ipdof2);

  double idof3[3];
  idof3[0]=G00/5.0+x0;  idof3[1]=G10/5.0+y0;
  idof3[2] = 1.0;
  ptv ipdof3(3,idof3);
  iidof[3] = dof.insert_dof(element,3,ipdof3);

  double idof4[3];
  idof4[0]=(2.0/5.0)*G00+x0;  idof4[1]=(2.0/5.0)*G10+y0;
  idof4[2] = 0.0;
  ptv ipdof4(3,idof4);
  iidof[4] = dof.insert_dof(element,4,ipdof4);

  double idof5[3];
  idof5[0]=(2.0/5.0)*G00+x0;  idof5[1]=(2.0/5.0)*G10+y0;
  idof5[2] = 1.0;
  ptv ipdof5(3,idof5);
  iidof[5] = dof.insert_dof(element,5,ipdof5);

  double idof6[3];
  idof6[0]=(3.0/5.0)*G00+x0;  idof6[1]=(3.0/5.0)*G10+y0;
  idof6[2] = 0.0;
  ptv ipdof6(3,idof6);
  iidof[6] = dof.insert_dof(element,6,ipdof6);

  double idof7[3];
  idof7[0]=(3.0/5.0)*G00+x0;  idof7[1]=(3.0/5.0)*G10+y0;
  idof7[2] = 1.0;
  ptv ipdof7(3,idof7);
  iidof[7] = dof.insert_dof(element,7,ipdof7);

  double idof8[3];
  idof8[0]=(4.0/5.0)*G00+x0;  idof8[1]=(4.0/5.0)*G10+y0;
  idof8[2] = 0.0;
  ptv ipdof8(3,idof8);
  iidof[8] = dof.insert_dof(element,8,ipdof8);

  double idof9[3];
  idof9[0]=(4.0/5.0)*G00+x0;  idof9[1]=(4.0/5.0)*G10+y0;
  idof9[2] = 1.0;
  ptv ipdof9(3,idof9);
  iidof[9] = dof.insert_dof(element,9,ipdof9);

  double idof10[3];
  idof10[0]=G00+x0;  idof10[1]=G10+y0;
  idof10[2] = 0.0;
  ptv ipdof10(3,idof10);
  iidof[10] = dof.insert_dof(element,10,ipdof10);

  double idof11[3];
  idof11[0]=G00+x0;  idof11[1]=G10+y0;
  idof11[2] = 1.0;
  ptv ipdof11(3,idof11);
  iidof[11] = dof.insert_dof(element,11,ipdof11);

  double idof12[3];
  idof12[0]=G01/5.0+x0;  idof12[1]=y0+G11/5.0;
  idof12[2] = 0.0;
  ptv ipdof12(3,idof12);
  iidof[12] = dof.insert_dof(element,12,ipdof12);

  double idof13[3];
  idof13[0]=G01/5.0+x0;  idof13[1]=y0+G11/5.0;
  idof13[2] = 1.0;
  ptv ipdof13(3,idof13);
  iidof[13] = dof.insert_dof(element,13,ipdof13);

  double idof14[3];
  idof14[0]=G01/5.0+G00/5.0+x0;  idof14[1]=G10/5.0+y0+G11/5.0;
  idof14[2] = 0.0;
  ptv ipdof14(3,idof14);
  iidof[14] = dof.insert_dof(element,14,ipdof14);

  double idof15[3];
  idof15[0]=G01/5.0+G00/5.0+x0;  idof15[1]=G10/5.0+y0+G11/5.0;
  idof15[2] = 1.0;
  ptv ipdof15(3,idof15);
  iidof[15] = dof.insert_dof(element,15,ipdof15);

  double idof16[3];
  idof16[0]=G01/5.0+(2.0/5.0)*G00+x0;  idof16[1]=(2.0/5.0)*G10+y0+G11/5.0;
  idof16[2] = 0.0;
  ptv ipdof16(3,idof16);
  iidof[16] = dof.insert_dof(element,16,ipdof16);

  double idof17[3];
  idof17[0]=G01/5.0+(2.0/5.0)*G00+x0;  idof17[1]=(2.0/5.0)*G10+y0+G11/5.0;
  idof17[2] = 1.0;
  ptv ipdof17(3,idof17);
  iidof[17] = dof.insert_dof(element,17,ipdof17);

  double idof18[3];
  idof18[0]=G01/5.0+(3.0/5.0)*G00+x0;  idof18[1]=(3.0/5.0)*G10+y0+G11/5.0;
  idof18[2] = 0.0;
  ptv ipdof18(3,idof18);
  iidof[18] = dof.insert_dof(element,18,ipdof18);

  double idof19[3];
  idof19[0]=G01/5.0+(3.0/5.0)*G00+x0;  idof19[1]=(3.0/5.0)*G10+y0+G11/5.0;
  idof19[2] = 1.0;
  ptv ipdof19(3,idof19);
  iidof[19] = dof.insert_dof(element,19,ipdof19);

  double idof20[3];
  idof20[0]=G01/5.0+(4.0/5.0)*G00+x0;  idof20[1]=(4.0/5.0)*G10+y0+G11/5.0;
  idof20[2] = 0.0;
  ptv ipdof20(3,idof20);
  iidof[20] = dof.insert_dof(element,20,ipdof20);

  double idof21[3];
  idof21[0]=G01/5.0+(4.0/5.0)*G00+x0;  idof21[1]=(4.0/5.0)*G10+y0+G11/5.0;
  idof21[2] = 1.0;
  ptv ipdof21(3,idof21);
  iidof[21] = dof.insert_dof(element,21,ipdof21);

  double idof22[3];
  idof22[0]=(2.0/5.0)*G01+x0;  idof22[1]=y0+(2.0/5.0)*G11;
  idof22[2] = 0.0;
  ptv ipdof22(3,idof22);
  iidof[22] = dof.insert_dof(element,22,ipdof22);

  double idof23[3];
  idof23[0]=(2.0/5.0)*G01+x0;  idof23[1]=y0+(2.0/5.0)*G11;
  idof23[2] = 1.0;
  ptv ipdof23(3,idof23);
  iidof[23] = dof.insert_dof(element,23,ipdof23);

  double idof24[3];
  idof24[0]=(2.0/5.0)*G01+G00/5.0+x0;  idof24[1]=G10/5.0+y0+(2.0/5.0)*G11;
  idof24[2] = 0.0;
  ptv ipdof24(3,idof24);
  iidof[24] = dof.insert_dof(element,24,ipdof24);

  double idof25[3];
  idof25[0]=(2.0/5.0)*G01+G00/5.0+x0;  idof25[1]=G10/5.0+y0+(2.0/5.0)*G11;
  idof25[2] = 1.0;
  ptv ipdof25(3,idof25);
  iidof[25] = dof.insert_dof(element,25,ipdof25);

  double idof26[3];
  idof26[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof26[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof26[2] = 0.0;
  ptv ipdof26(3,idof26);
  iidof[26] = dof.insert_dof(element,26,ipdof26);

  double idof27[3];
  idof27[0]=(2.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof27[1]=(2.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof27[2] = 1.0;
  ptv ipdof27(3,idof27);
  iidof[27] = dof.insert_dof(element,27,ipdof27);

  double idof28[3];
  idof28[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  idof28[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof28[2] = 0.0;
  ptv ipdof28(3,idof28);
  iidof[28] = dof.insert_dof(element,28,ipdof28);

  double idof29[3];
  idof29[0]=(2.0/5.0)*G01+(3.0/5.0)*G00+x0;  idof29[1]=(3.0/5.0)*G10+y0+(2.0/5.0)*G11;
  idof29[2] = 1.0;
  ptv ipdof29(3,idof29);
  iidof[29] = dof.insert_dof(element,29,ipdof29);

  double idof30[3];
  idof30[0]=(3.0/5.0)*G01+x0;  idof30[1]=y0+(3.0/5.0)*G11;
  idof30[2] = 0.0;
  ptv ipdof30(3,idof30);
  iidof[30] = dof.insert_dof(element,30,ipdof30);

  double idof31[3];
  idof31[0]=(3.0/5.0)*G01+x0;  idof31[1]=y0+(3.0/5.0)*G11;
  idof31[2] = 1.0;
  ptv ipdof31(3,idof31);
  iidof[31] = dof.insert_dof(element,31,ipdof31);

  double idof32[3];
  idof32[0]=(3.0/5.0)*G01+G00/5.0+x0;  idof32[1]=G10/5.0+y0+(3.0/5.0)*G11;
  idof32[2] = 0.0;
  ptv ipdof32(3,idof32);
  iidof[32] = dof.insert_dof(element,32,ipdof32);

  double idof33[3];
  idof33[0]=(3.0/5.0)*G01+G00/5.0+x0;  idof33[1]=G10/5.0+y0+(3.0/5.0)*G11;
  idof33[2] = 1.0;
  ptv ipdof33(3,idof33);
  iidof[33] = dof.insert_dof(element,33,ipdof33);

  double idof34[3];
  idof34[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof34[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  idof34[2] = 0.0;
  ptv ipdof34(3,idof34);
  iidof[34] = dof.insert_dof(element,34,ipdof34);

  double idof35[3];
  idof35[0]=(3.0/5.0)*G01+(2.0/5.0)*G00+x0;  idof35[1]=(2.0/5.0)*G10+y0+(3.0/5.0)*G11;
  idof35[2] = 1.0;
  ptv ipdof35(3,idof35);
  iidof[35] = dof.insert_dof(element,35,ipdof35);

  double idof36[3];
  idof36[0]=(4.0/5.0)*G01+x0;  idof36[1]=y0+(4.0/5.0)*G11;
  idof36[2] = 0.0;
  ptv ipdof36(3,idof36);
  iidof[36] = dof.insert_dof(element,36,ipdof36);

  double idof37[3];
  idof37[0]=(4.0/5.0)*G01+x0;  idof37[1]=y0+(4.0/5.0)*G11;
  idof37[2] = 1.0;
  ptv ipdof37(3,idof37);
  iidof[37] = dof.insert_dof(element,37,ipdof37);

  double idof38[3];
  idof38[0]=(4.0/5.0)*G01+G00/5.0+x0;  idof38[1]=G10/5.0+y0+(4.0/5.0)*G11;
  idof38[2] = 0.0;
  ptv ipdof38(3,idof38);
  iidof[38] = dof.insert_dof(element,38,ipdof38);

  double idof39[3];
  idof39[0]=(4.0/5.0)*G01+G00/5.0+x0;  idof39[1]=G10/5.0+y0+(4.0/5.0)*G11;
  idof39[2] = 1.0;
  ptv ipdof39(3,idof39);
  iidof[39] = dof.insert_dof(element,39,ipdof39);

  double idof40[3];
  idof40[0]=G01+x0;  idof40[1]=y0+G11;
  idof40[2] = 0.0;
  ptv ipdof40(3,idof40);
  iidof[40] = dof.insert_dof(element,40,ipdof40);

  double idof41[3];
  idof41[0]=G01+x0;  idof41[1]=y0+G11;
  idof41[2] = 1.0;
  ptv ipdof41(3,idof41);
  iidof[41] = dof.insert_dof(element,41,ipdof41);

 
  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;


  double A[42][42];
  A[0][0]=((16567.0/48384.0)*(Jinv01*Jinv01)*M00+(16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*M10*Jinv01*Jinv11+(16567.0/48384.0)*Jinv10*M10*Jinv00+(16567.0/24192.0)*Jinv01*Jinv00*M00+(16567.0/48384.0)*M01*Jinv00*Jinv11+(16567.0/48384.0)*Jinv10*Jinv01*M01+(16567.0/48384.0)*Jinv10*M10*Jinv01+(16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv01*M01*Jinv11+(16567.0/48384.0)*M10*Jinv00*Jinv11+(16567.0/24192.0)*Jinv10*Jinv11*M11+(16567.0/48384.0)*(Jinv11*Jinv11)*M11+(16567.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[0][1]=(0.0)*D;
  A[0][2]=((725.0/3584.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M10*Jinv01*Jinv11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00-(26875.0/41472.0)*M01*Jinv00*Jinv11+(725.0/3584.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv01*M01*Jinv11+(725.0/3584.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M10*Jinv01*Jinv11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00+(14375.0/24192.0)*M01*Jinv00*Jinv11-(575.0/36288.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv01*M01*Jinv11-(575.0/36288.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[0][5]=(0.0)*D;
  A[0][6]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M10*Jinv01*Jinv11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(130625.0/290304.0)*M01*Jinv00*Jinv11-(20225.0/290304.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv01*M01*Jinv11-(20225.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[0][7]=(0.0)*D;
  A[0][8]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M10*Jinv01*Jinv11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(29375.0/145152.0)*M01*Jinv00*Jinv11+(1975.0/48384.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv01*M01*Jinv11+(1975.0/48384.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv10*M10*Jinv00-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*M01*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*M10*Jinv01-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[0][11]=(0.0)*D;
  A[0][12]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M10*Jinv01*Jinv11+(725.0/3584.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00+(725.0/3584.0)*M01*Jinv00*Jinv11-(26875.0/41472.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv01*M01*Jinv11-(26875.0/41472.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/36288.0)*Jinv01*Jinv00*M00-(15625.0/72576.0)*M01*Jinv00*Jinv11-(15625.0/72576.0)*Jinv10*Jinv01*M01-(15625.0/72576.0)*Jinv10*M10*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*M10*Jinv00*Jinv11-(15625.0/36288.0)*Jinv10*Jinv11*M11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[0][19]=(0.0)*D;
  A[0][20]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[0][21]=(0.0)*D;
  A[0][22]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M10*Jinv01*Jinv11-(575.0/36288.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00-(575.0/36288.0)*M01*Jinv00*Jinv11+(14375.0/24192.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv01*M01*Jinv11+(14375.0/24192.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[0][23]=(0.0)*D;
  A[0][24]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[0][25]=(0.0)*D;
  A[0][26]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[0][27]=(0.0)*D;
  A[0][28]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[0][29]=(0.0)*D;
  A[0][30]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M10*Jinv01*Jinv11-(20225.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(20225.0/290304.0)*M01*Jinv00*Jinv11-(130625.0/290304.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv01*M01*Jinv11-(130625.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[0][31]=(0.0)*D;
  A[0][32]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[0][33]=(0.0)*D;
  A[0][34]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[0][35]=(0.0)*D;
  A[0][36]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1975.0/48384.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(1975.0/48384.0)*M01*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv01*M01*Jinv11+(29375.0/145152.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[0][37]=(0.0)*D;
  A[0][38]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[0][39]=(0.0)*D;
  A[0][40]=(-(5951.0/145152.0)*(Jinv01*Jinv01)*M00-(5951.0/145152.0)*M10*Jinv01*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*Jinv10*Jinv01*M01-(5951.0/145152.0)*Jinv01*M01*Jinv11-(5951.0/145152.0)*M10*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[0][41]=(0.0)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=((16567.0/48384.0)*(Jinv01*Jinv01)*M00+(16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*M10*Jinv01*Jinv11+(16567.0/48384.0)*Jinv10*M10*Jinv00+(16567.0/24192.0)*Jinv01*Jinv00*M00+(16567.0/48384.0)*M01*Jinv00*Jinv11+(16567.0/48384.0)*Jinv10*Jinv01*M01+(16567.0/48384.0)*Jinv10*M10*Jinv01+(16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv01*M01*Jinv11+(16567.0/48384.0)*M10*Jinv00*Jinv11+(16567.0/24192.0)*Jinv10*Jinv11*M11+(16567.0/48384.0)*(Jinv11*Jinv11)*M11+(16567.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[1][2]=(0.0)*D;
  A[1][3]=((725.0/3584.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M10*Jinv01*Jinv11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00-(26875.0/41472.0)*M01*Jinv00*Jinv11+(725.0/3584.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv01*M01*Jinv11+(725.0/3584.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[1][4]=(0.0)*D;
  A[1][5]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M10*Jinv01*Jinv11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00+(14375.0/24192.0)*M01*Jinv00*Jinv11-(575.0/36288.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv01*M01*Jinv11-(575.0/36288.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M10*Jinv01*Jinv11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(130625.0/290304.0)*M01*Jinv00*Jinv11-(20225.0/290304.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv01*M01*Jinv11-(20225.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[1][8]=(0.0)*D;
  A[1][9]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M10*Jinv01*Jinv11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(29375.0/145152.0)*M01*Jinv00*Jinv11+(1975.0/48384.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv01*M01*Jinv11+(1975.0/48384.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[1][10]=(0.0)*D;
  A[1][11]=(-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv10*M10*Jinv00-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*M01*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*M10*Jinv01-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M10*Jinv01*Jinv11+(725.0/3584.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00+(725.0/3584.0)*M01*Jinv00*Jinv11-(26875.0/41472.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv01*M01*Jinv11-(26875.0/41472.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/36288.0)*Jinv01*Jinv00*M00-(15625.0/72576.0)*M01*Jinv00*Jinv11-(15625.0/72576.0)*Jinv10*Jinv01*M01-(15625.0/72576.0)*Jinv10*M10*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*M10*Jinv00*Jinv11-(15625.0/36288.0)*Jinv10*Jinv11*M11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[1][20]=(0.0)*D;
  A[1][21]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[1][22]=(0.0)*D;
  A[1][23]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M10*Jinv01*Jinv11-(575.0/36288.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00-(575.0/36288.0)*M01*Jinv00*Jinv11+(14375.0/24192.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv01*M01*Jinv11+(14375.0/24192.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[1][24]=(0.0)*D;
  A[1][25]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[1][26]=(0.0)*D;
  A[1][27]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[1][28]=(0.0)*D;
  A[1][29]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[1][30]=(0.0)*D;
  A[1][31]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M10*Jinv01*Jinv11-(20225.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(20225.0/290304.0)*M01*Jinv00*Jinv11-(130625.0/290304.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv01*M01*Jinv11-(130625.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[1][32]=(0.0)*D;
  A[1][33]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[1][34]=(0.0)*D;
  A[1][35]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[1][36]=(0.0)*D;
  A[1][37]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1975.0/48384.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(1975.0/48384.0)*M01*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv01*M01*Jinv11+(29375.0/145152.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[1][38]=(0.0)*D;
  A[1][39]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[1][40]=(0.0)*D;
  A[1][41]=(-(5951.0/145152.0)*(Jinv01*Jinv01)*M00-(5951.0/145152.0)*M10*Jinv01*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*Jinv10*Jinv01*M01-(5951.0/145152.0)*Jinv01*M01*Jinv11-(5951.0/145152.0)*M10*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[2][0]=((725.0/3584.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M10*Jinv01*Jinv11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00+(725.0/3584.0)*M01*Jinv00*Jinv11-(26875.0/41472.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv01*M01*Jinv11-(26875.0/41472.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[2][1]=(0.0)*D;
  A[2][2]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(29375.0/20736.0)*Jinv01*Jinv00*M00+(29375.0/41472.0)*M01*Jinv00*Jinv11+(29375.0/41472.0)*Jinv10*Jinv01*M01+(29375.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(29375.0/41472.0)*M10*Jinv00*Jinv11+(29375.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(70625.0/41472.0)*M01*Jinv00*Jinv11-(15625.0/41472.0)*Jinv10*Jinv01*M01-(70625.0/41472.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[2][5]=(0.0)*D;
  A[2][6]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(94375.0/72576.0)*M01*Jinv00*Jinv11+(10625.0/18144.0)*Jinv10*Jinv01*M01+(94375.0/72576.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(10625.0/18144.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[2][7]=(0.0)*D;
  A[2][8]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(68125.0/72576.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(194375.0/290304.0)*M01*Jinv00*Jinv11-(78125.0/290304.0)*Jinv10*Jinv01*M01-(194375.0/290304.0)*Jinv10*M10*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(78125.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=((29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*M01*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[2][11]=(0.0)*D;
  A[2][12]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00+(6875.0/3456.0)*Jinv01*Jinv00*M00+(6875.0/6912.0)*M01*Jinv00*Jinv11+(6875.0/6912.0)*Jinv10*Jinv01*M01+(6875.0/6912.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11+(6875.0/6912.0)*M10*Jinv00*Jinv11+(6875.0/3456.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M10*Jinv01*Jinv11+(8125.0/16128.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(409375.0/145152.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M10*Jinv01*Jinv11+(14375.0/290304.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(115625.0/96768.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M10*Jinv01*Jinv11-(625.0/1344.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(71875.0/72576.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[2][19]=(0.0)*D;
  A[2][20]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M10*Jinv01*Jinv11+(14375.0/72576.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/145152.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[2][21]=(0.0)*D;
  A[2][22]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[2][23]=(0.0)*D;
  A[2][24]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M10*Jinv01*Jinv11+(4375.0/20736.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(3125.0/2304.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[2][25]=(0.0)*D;
  A[2][26]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M10*Jinv01*Jinv11-(79375.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(40625.0/96768.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[2][27]=(0.0)*D;
  A[2][28]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M10*Jinv01*Jinv11+(8125.0/72576.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/18144.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[2][29]=(0.0)*D;
  A[2][30]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[2][31]=(0.0)*D;
  A[2][32]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(96875.0/145152.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[2][33]=(0.0)*D;
  A[2][34]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[2][35]=(0.0)*D;
  A[2][36]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[2][37]=(0.0)*D;
  A[2][38]=((6875.0/48384.0)*(Jinv01*Jinv01)*M00+(6875.0/48384.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[2][39]=(0.0)*D;
  A[2][40]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[2][41]=(0.0)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=((725.0/3584.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*M10*Jinv01*Jinv11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00+(725.0/3584.0)*M01*Jinv00*Jinv11-(26875.0/41472.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00+(725.0/3584.0)*Jinv01*M01*Jinv11-(26875.0/41472.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[3][2]=(0.0)*D;
  A[3][3]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(29375.0/20736.0)*Jinv01*Jinv00*M00+(29375.0/41472.0)*M01*Jinv00*Jinv11+(29375.0/41472.0)*Jinv10*Jinv01*M01+(29375.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(29375.0/41472.0)*M10*Jinv00*Jinv11+(29375.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[3][4]=(0.0)*D;
  A[3][5]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(70625.0/41472.0)*M01*Jinv00*Jinv11-(15625.0/41472.0)*Jinv10*Jinv01*M01-(70625.0/41472.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(94375.0/72576.0)*M01*Jinv00*Jinv11+(10625.0/18144.0)*Jinv10*Jinv01*M01+(94375.0/72576.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(10625.0/18144.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[3][8]=(0.0)*D;
  A[3][9]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(68125.0/72576.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(194375.0/290304.0)*M01*Jinv00*Jinv11-(78125.0/290304.0)*Jinv10*Jinv01*M01-(194375.0/290304.0)*Jinv10*M10*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(78125.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=((29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*M01*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00+(6875.0/3456.0)*Jinv01*Jinv00*M00+(6875.0/6912.0)*M01*Jinv00*Jinv11+(6875.0/6912.0)*Jinv10*Jinv01*M01+(6875.0/6912.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11+(6875.0/6912.0)*M10*Jinv00*Jinv11+(6875.0/3456.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M10*Jinv01*Jinv11+(8125.0/16128.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(409375.0/145152.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M10*Jinv01*Jinv11+(14375.0/290304.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(115625.0/96768.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M10*Jinv01*Jinv11-(625.0/1344.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(71875.0/72576.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[3][20]=(0.0)*D;
  A[3][21]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M10*Jinv01*Jinv11+(14375.0/72576.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/145152.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[3][22]=(0.0)*D;
  A[3][23]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[3][24]=(0.0)*D;
  A[3][25]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M10*Jinv01*Jinv11+(4375.0/20736.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(3125.0/2304.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[3][26]=(0.0)*D;
  A[3][27]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M10*Jinv01*Jinv11-(79375.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(40625.0/96768.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[3][28]=(0.0)*D;
  A[3][29]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M10*Jinv01*Jinv11+(8125.0/72576.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/18144.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[3][30]=(0.0)*D;
  A[3][31]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[3][32]=(0.0)*D;
  A[3][33]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(96875.0/145152.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[3][34]=(0.0)*D;
  A[3][35]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[3][36]=(0.0)*D;
  A[3][37]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[3][38]=(0.0)*D;
  A[3][39]=((6875.0/48384.0)*(Jinv01*Jinv01)*M00+(6875.0/48384.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[3][40]=(0.0)*D;
  A[3][41]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[4][0]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M10*Jinv01*Jinv11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00-(575.0/36288.0)*M01*Jinv00*Jinv11+(14375.0/24192.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv01*M01*Jinv11+(14375.0/24192.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[4][1]=(0.0)*D;
  A[4][2]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(15625.0/41472.0)*M01*Jinv00*Jinv11-(70625.0/41472.0)*Jinv10*Jinv01*M01-(15625.0/41472.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(70625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=((10625.0/3456.0)*(Jinv01*Jinv01)*M00+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M10*Jinv01*Jinv11+(11875.0/2688.0)*Jinv10*M10*Jinv00+(4375.0/1152.0)*Jinv01*Jinv00*M00+(4375.0/2304.0)*M01*Jinv00*Jinv11+(4375.0/2304.0)*Jinv10*Jinv01*M01+(4375.0/2304.0)*Jinv10*M10*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(10625.0/3456.0)*Jinv01*M01*Jinv11+(4375.0/2304.0)*M10*Jinv00*Jinv11+(4375.0/1152.0)*Jinv10*Jinv11*M11+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv10*M01*Jinv00)*D;
  A[4][5]=(0.0)*D;
  A[4][6]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(574375.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(726875.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/10752.0)*Jinv10*Jinv01*M01-(726875.0/290304.0)*Jinv10*M10*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(15625.0/10752.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[4][7]=(0.0)*D;
  A[4][8]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(6875.0/10368.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(6875.0/10368.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=(-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*M01*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[4][19]=(0.0)*D;
  A[4][20]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[4][21]=(0.0)*D;
  A[4][22]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[4][23]=(0.0)*D;
  A[4][24]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[4][25]=(0.0)*D;
  A[4][26]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[4][27]=(0.0)*D;
  A[4][28]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[4][29]=(0.0)*D;
  A[4][30]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[4][31]=(0.0)*D;
  A[4][32]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[4][33]=(0.0)*D;
  A[4][34]=(-(14375.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/48384.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[4][35]=(0.0)*D;
  A[4][36]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[4][37]=(0.0)*D;
  A[4][38]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[4][39]=(0.0)*D;
  A[4][40]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[4][41]=(0.0)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*M10*Jinv01*Jinv11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00-(575.0/36288.0)*M01*Jinv00*Jinv11+(14375.0/24192.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00-(575.0/36288.0)*Jinv01*M01*Jinv11+(14375.0/24192.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[5][2]=(0.0)*D;
  A[5][3]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(15625.0/41472.0)*M01*Jinv00*Jinv11-(70625.0/41472.0)*Jinv10*Jinv01*M01-(15625.0/41472.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(70625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[5][4]=(0.0)*D;
  A[5][5]=((10625.0/3456.0)*(Jinv01*Jinv01)*M00+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M10*Jinv01*Jinv11+(11875.0/2688.0)*Jinv10*M10*Jinv00+(4375.0/1152.0)*Jinv01*Jinv00*M00+(4375.0/2304.0)*M01*Jinv00*Jinv11+(4375.0/2304.0)*Jinv10*Jinv01*M01+(4375.0/2304.0)*Jinv10*M10*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(10625.0/3456.0)*Jinv01*M01*Jinv11+(4375.0/2304.0)*M10*Jinv00*Jinv11+(4375.0/1152.0)*Jinv10*Jinv11*M11+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv10*M01*Jinv00)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(574375.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(726875.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/10752.0)*Jinv10*Jinv01*M01-(726875.0/290304.0)*Jinv10*M10*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(15625.0/10752.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[5][8]=(0.0)*D;
  A[5][9]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(6875.0/10368.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(6875.0/10368.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[5][10]=(0.0)*D;
  A[5][11]=(-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*M01*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[5][20]=(0.0)*D;
  A[5][21]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[5][22]=(0.0)*D;
  A[5][23]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[5][24]=(0.0)*D;
  A[5][25]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[5][26]=(0.0)*D;
  A[5][27]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[5][28]=(0.0)*D;
  A[5][29]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[5][30]=(0.0)*D;
  A[5][31]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[5][32]=(0.0)*D;
  A[5][33]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[5][34]=(0.0)*D;
  A[5][35]=(-(14375.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/48384.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[5][36]=(0.0)*D;
  A[5][37]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[5][38]=(0.0)*D;
  A[5][39]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[5][40]=(0.0)*D;
  A[5][41]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[6][0]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M10*Jinv01*Jinv11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(20225.0/290304.0)*M01*Jinv00*Jinv11-(130625.0/290304.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv01*M01*Jinv11-(130625.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[6][1]=(0.0)*D;
  A[6][2]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(10625.0/18144.0)*M01*Jinv00*Jinv11+(94375.0/72576.0)*Jinv10*Jinv01*M01+(10625.0/18144.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(94375.0/72576.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(574375.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/10752.0)*M01*Jinv00*Jinv11-(726875.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/10752.0)*Jinv10*M10*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(726875.0/290304.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[6][5]=(0.0)*D;
  A[6][6]=((89375.0/24192.0)*(Jinv01*Jinv01)*M00+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M10*Jinv01*Jinv11+(11875.0/2688.0)*Jinv10*M10*Jinv00+(40625.0/8064.0)*Jinv01*Jinv00*M00+(40625.0/16128.0)*M01*Jinv00*Jinv11+(40625.0/16128.0)*Jinv10*Jinv01*M01+(40625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(89375.0/24192.0)*Jinv01*M01*Jinv11+(40625.0/16128.0)*M10*Jinv00*Jinv11+(40625.0/8064.0)*Jinv10*Jinv11*M11+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv10*M01*Jinv00)*D;
  A[6][7]=(0.0)*D;
  A[6][8]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(318125.0/145152.0)*M01*Jinv00*Jinv11-(41875.0/48384.0)*Jinv10*Jinv01*M01-(318125.0/145152.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(41875.0/48384.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[6][9]=(0.0)*D;
  A[6][10]=((14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*M01*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[6][11]=(0.0)*D;
  A[6][12]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[6][15]=(0.0)*D;
  A[6][16]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[6][19]=(0.0)*D;
  A[6][20]=((625.0/448.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[6][21]=(0.0)*D;
  A[6][22]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[6][23]=(0.0)*D;
  A[6][24]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[6][25]=(0.0)*D;
  A[6][26]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[6][27]=(0.0)*D;
  A[6][28]=((19375.0/72576.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/72576.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[6][29]=(0.0)*D;
  A[6][30]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(38125.0/145152.0)*Jinv01*Jinv00*M00+(38125.0/290304.0)*M01*Jinv00*Jinv11+(38125.0/290304.0)*Jinv10*Jinv01*M01+(38125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(38125.0/290304.0)*M10*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[6][31]=(0.0)*D;
  A[6][32]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[6][33]=(0.0)*D;
  A[6][34]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[6][35]=(0.0)*D;
  A[6][36]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[6][37]=(0.0)*D;
  A[6][38]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11)*D;
  A[6][39]=(0.0)*D;
  A[6][40]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[6][41]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*M10*Jinv01*Jinv11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(20225.0/290304.0)*M01*Jinv00*Jinv11-(130625.0/290304.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(20225.0/290304.0)*Jinv01*M01*Jinv11-(130625.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[7][2]=(0.0)*D;
  A[7][3]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(10625.0/18144.0)*M01*Jinv00*Jinv11+(94375.0/72576.0)*Jinv10*Jinv01*M01+(10625.0/18144.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(94375.0/72576.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[7][4]=(0.0)*D;
  A[7][5]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(574375.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(574375.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/10752.0)*M01*Jinv00*Jinv11-(726875.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/10752.0)*Jinv10*M10*Jinv01-(574375.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(726875.0/290304.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(574375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=((89375.0/24192.0)*(Jinv01*Jinv01)*M00+(11875.0/2688.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M10*Jinv01*Jinv11+(11875.0/2688.0)*Jinv10*M10*Jinv00+(40625.0/8064.0)*Jinv01*Jinv00*M00+(40625.0/16128.0)*M01*Jinv00*Jinv11+(40625.0/16128.0)*Jinv10*Jinv01*M01+(40625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/2688.0)*(Jinv00*Jinv00)*M00+(89375.0/24192.0)*Jinv01*M01*Jinv11+(40625.0/16128.0)*M10*Jinv00*Jinv11+(40625.0/8064.0)*Jinv10*Jinv11*M11+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(11875.0/2688.0)*Jinv10*M01*Jinv00)*D;
  A[7][8]=(0.0)*D;
  A[7][9]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(318125.0/145152.0)*M01*Jinv00*Jinv11-(41875.0/48384.0)*Jinv10*Jinv01*M01-(318125.0/145152.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(41875.0/48384.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[7][10]=(0.0)*D;
  A[7][11]=((14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*M01*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[7][16]=(0.0)*D;
  A[7][17]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[7][20]=(0.0)*D;
  A[7][21]=((625.0/448.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[7][22]=(0.0)*D;
  A[7][23]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[7][24]=(0.0)*D;
  A[7][25]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[7][26]=(0.0)*D;
  A[7][27]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[7][28]=(0.0)*D;
  A[7][29]=((19375.0/72576.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/72576.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[7][30]=(0.0)*D;
  A[7][31]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(38125.0/145152.0)*Jinv01*Jinv00*M00+(38125.0/290304.0)*M01*Jinv00*Jinv11+(38125.0/290304.0)*Jinv10*Jinv01*M01+(38125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(38125.0/290304.0)*M10*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[7][32]=(0.0)*D;
  A[7][33]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[7][34]=(0.0)*D;
  A[7][35]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[7][36]=(0.0)*D;
  A[7][37]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[7][38]=(0.0)*D;
  A[7][39]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11)*D;
  A[7][40]=(0.0)*D;
  A[7][41]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[8][0]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M10*Jinv01*Jinv11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(1975.0/48384.0)*M01*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv01*M01*Jinv11+(29375.0/145152.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[8][1]=(0.0)*D;
  A[8][2]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(68125.0/72576.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(78125.0/290304.0)*M01*Jinv00*Jinv11-(194375.0/290304.0)*Jinv10*Jinv01*M01-(78125.0/290304.0)*Jinv10*M10*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(194375.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/10368.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(6875.0/10368.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(41875.0/48384.0)*M01*Jinv00*Jinv11-(318125.0/145152.0)*Jinv10*Jinv01*M01-(41875.0/48384.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(318125.0/145152.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[8][7]=(0.0)*D;
  A[8][8]=((53125.0/20736.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/20736.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[8][9]=(0.0)*D;
  A[8][10]=(-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*M01*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[8][11]=(0.0)*D;
  A[8][12]=((14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[8][15]=(0.0)*D;
  A[8][16]=((14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=((8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv10*M10*Jinv00+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[8][19]=(0.0)*D;
  A[8][20]=(-(53125.0/20736.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/20736.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[8][21]=(0.0)*D;
  A[8][22]=((8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[8][23]=(0.0)*D;
  A[8][24]=(-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv10*M10*Jinv00+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[8][25]=(0.0)*D;
  A[8][26]=((4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[8][27]=(0.0)*D;
  A[8][28]=((625.0/448.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[8][29]=(0.0)*D;
  A[8][30]=((6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[8][31]=(0.0)*D;
  A[8][32]=(-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[8][33]=(0.0)*D;
  A[8][34]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[8][35]=(0.0)*D;
  A[8][36]=(-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11)*D;
  A[8][37]=(0.0)*D;
  A[8][38]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[8][39]=(0.0)*D;
  A[8][40]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[8][41]=(0.0)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*M10*Jinv01*Jinv11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(1975.0/48384.0)*M01*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1975.0/48384.0)*Jinv01*M01*Jinv11+(29375.0/145152.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[9][2]=(0.0)*D;
  A[9][3]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(68125.0/72576.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(68125.0/72576.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(78125.0/290304.0)*M01*Jinv00*Jinv11-(194375.0/290304.0)*Jinv10*Jinv01*M01-(78125.0/290304.0)*Jinv10*M10*Jinv01-(68125.0/72576.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(194375.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(68125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(11875.0/6048.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(11875.0/6048.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/10368.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(6875.0/10368.0)*Jinv10*M10*Jinv01+(11875.0/6048.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(11875.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(745625.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(745625.0/290304.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(41875.0/48384.0)*M01*Jinv00*Jinv11-(318125.0/145152.0)*Jinv10*Jinv01*M01-(41875.0/48384.0)*Jinv10*M10*Jinv01-(745625.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(318125.0/145152.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(745625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[9][8]=(0.0)*D;
  A[9][9]=((53125.0/20736.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/20736.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[9][10]=(0.0)*D;
  A[9][11]=(-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*M01*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[9][12]=(0.0)*D;
  A[9][13]=((14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[9][16]=(0.0)*D;
  A[9][17]=((14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=((8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv10*M10*Jinv00+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[9][20]=(0.0)*D;
  A[9][21]=(-(53125.0/20736.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/20736.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[9][22]=(0.0)*D;
  A[9][23]=((8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[9][24]=(0.0)*D;
  A[9][25]=(-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv10*M10*Jinv00+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[9][26]=(0.0)*D;
  A[9][27]=((4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[9][28]=(0.0)*D;
  A[9][29]=((625.0/448.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[9][30]=(0.0)*D;
  A[9][31]=((6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[9][32]=(0.0)*D;
  A[9][33]=(-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[9][34]=(0.0)*D;
  A[9][35]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[9][36]=(0.0)*D;
  A[9][37]=(-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11)*D;
  A[9][38]=(0.0)*D;
  A[9][39]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[9][40]=(0.0)*D;
  A[9][41]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[10][0]=(-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv10*M10*Jinv00-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*Jinv10*Jinv01*M01-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*M10*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=((29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1675.0/10368.0)*M10*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(575.0/1512.0)*M10*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[10][5]=(0.0)*D;
  A[10][6]=((14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(6325.0/10368.0)*M10*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=(-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(123425.0/145152.0)*M10*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=((16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*Jinv10*M10*Jinv00+(16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[10][11]=(0.0)*D;
  A[10][12]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[10][19]=(0.0)*D;
  A[10][20]=((725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv10*M10*Jinv00+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(123425.0/145152.0)*M10*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[10][21]=(0.0)*D;
  A[10][22]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[10][23]=(0.0)*D;
  A[10][24]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[10][25]=(0.0)*D;
  A[10][26]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[10][27]=(0.0)*D;
  A[10][28]=(-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv10*M10*Jinv00-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(6325.0/10368.0)*M10*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[10][29]=(0.0)*D;
  A[10][30]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[10][31]=(0.0)*D;
  A[10][32]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[10][33]=(0.0)*D;
  A[10][34]=(-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv10*M10*Jinv00+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00+(575.0/1512.0)*M10*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[10][35]=(0.0)*D;
  A[10][36]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[10][37]=(0.0)*D;
  A[10][38]=((1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv10*M10*Jinv00-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1675.0/10368.0)*M10*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[10][39]=(0.0)*D;
  A[10][40]=((5951.0/145152.0)*Jinv01*Jinv00*M00+(5951.0/145152.0)*Jinv10*Jinv01*M01+(5951.0/145152.0)*M10*Jinv00*Jinv11+(5951.0/145152.0)*Jinv10*Jinv11*M11)*D;
  A[10][41]=(0.0)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(-(5951.0/145152.0)*(Jinv10*Jinv10)*M11-(5951.0/145152.0)*Jinv10*M10*Jinv00-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*Jinv10*Jinv01*M01-(5951.0/145152.0)*(Jinv00*Jinv00)*M00-(5951.0/145152.0)*M10*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[11][2]=(0.0)*D;
  A[11][3]=((29375.0/145152.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*Jinv10*M10*Jinv00+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*(Jinv00*Jinv00)*M00+(1675.0/10368.0)*M10*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-(130625.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*Jinv10*M10*Jinv00-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*(Jinv00*Jinv00)*M00-(575.0/1512.0)*M10*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=((14375.0/24192.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*Jinv10*M10*Jinv00+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*(Jinv00*Jinv00)*M00+(6325.0/10368.0)*M10*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=(-(26875.0/41472.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*Jinv10*M10*Jinv00-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*(Jinv00*Jinv00)*M00-(123425.0/145152.0)*M10*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[11][10]=(0.0)*D;
  A[11][11]=((16567.0/48384.0)*(Jinv10*Jinv10)*M11+(16567.0/48384.0)*Jinv10*M10*Jinv00+(16567.0/48384.0)*(Jinv00*Jinv00)*M00+(16567.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[11][20]=(0.0)*D;
  A[11][21]=((725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv10*M10*Jinv00+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(123425.0/145152.0)*M10*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[11][22]=(0.0)*D;
  A[11][23]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[11][24]=(0.0)*D;
  A[11][25]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[11][26]=(0.0)*D;
  A[11][27]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[11][28]=(0.0)*D;
  A[11][29]=(-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv10*M10*Jinv00-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(6325.0/10368.0)*M10*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[11][30]=(0.0)*D;
  A[11][31]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[11][32]=(0.0)*D;
  A[11][33]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[11][34]=(0.0)*D;
  A[11][35]=(-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv10*M10*Jinv00+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00+(575.0/1512.0)*M10*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[11][36]=(0.0)*D;
  A[11][37]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[11][38]=(0.0)*D;
  A[11][39]=((1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv10*M10*Jinv00-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1675.0/10368.0)*M10*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[11][40]=(0.0)*D;
  A[11][41]=((5951.0/145152.0)*Jinv01*Jinv00*M00+(5951.0/145152.0)*Jinv10*Jinv01*M01+(5951.0/145152.0)*M10*Jinv00*Jinv11+(5951.0/145152.0)*Jinv10*Jinv11*M11)*D;
  A[12][0]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M10*Jinv01*Jinv11+(725.0/3584.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00-(26875.0/41472.0)*M01*Jinv00*Jinv11+(725.0/3584.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv01*M01*Jinv11+(725.0/3584.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00+(6875.0/3456.0)*Jinv01*Jinv00*M00+(6875.0/6912.0)*M01*Jinv00*Jinv11+(6875.0/6912.0)*Jinv10*Jinv01*M01+(6875.0/6912.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11+(6875.0/6912.0)*M10*Jinv00*Jinv11+(6875.0/3456.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=((14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(29375.0/20736.0)*Jinv01*Jinv00*M00+(29375.0/41472.0)*M01*Jinv00*Jinv11+(29375.0/41472.0)*Jinv10*Jinv01*M01+(29375.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(29375.0/41472.0)*M10*Jinv00*Jinv11+(29375.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[12][13]=(0.0)*D;
  A[12][14]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M10*Jinv01*Jinv11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00+(8125.0/16128.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[12][15]=(0.0)*D;
  A[12][16]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M10*Jinv01*Jinv11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(4375.0/20736.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[12][17]=(0.0)*D;
  A[12][18]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M10*Jinv01*Jinv11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(6875.0/48384.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[12][19]=(0.0)*D;
  A[12][20]=((6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[12][21]=(0.0)*D;
  A[12][22]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(15625.0/41472.0)*M01*Jinv00*Jinv11-(70625.0/41472.0)*Jinv10*Jinv01*M01-(15625.0/41472.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(70625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[12][23]=(0.0)*D;
  A[12][24]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M10*Jinv01*Jinv11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(14375.0/290304.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[12][25]=(0.0)*D;
  A[12][26]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M10*Jinv01*Jinv11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(79375.0/290304.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[12][27]=(0.0)*D;
  A[12][28]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[12][29]=(0.0)*D;
  A[12][30]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(10625.0/18144.0)*M01*Jinv00*Jinv11+(94375.0/72576.0)*Jinv10*Jinv01*M01+(10625.0/18144.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(94375.0/72576.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[12][31]=(0.0)*D;
  A[12][32]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M10*Jinv01*Jinv11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/1344.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[12][33]=(0.0)*D;
  A[12][34]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(8125.0/72576.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[12][35]=(0.0)*D;
  A[12][36]=(-(68125.0/72576.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(78125.0/290304.0)*M01*Jinv00*Jinv11-(194375.0/290304.0)*Jinv10*Jinv01*M01-(78125.0/290304.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(68125.0/72576.0)*Jinv01*M01*Jinv11-(194375.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[12][37]=(0.0)*D;
  A[12][38]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(14375.0/72576.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[12][39]=(0.0)*D;
  A[12][40]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1675.0/10368.0)*M10*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[12][41]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*(Jinv10*Jinv10)*M11-(26875.0/41472.0)*M10*Jinv01*Jinv11+(725.0/3584.0)*Jinv10*M10*Jinv00-(16175.0/36288.0)*Jinv01*Jinv00*M00-(26875.0/41472.0)*M01*Jinv00*Jinv11+(725.0/3584.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00-(26875.0/41472.0)*Jinv01*M01*Jinv11+(725.0/3584.0)*M10*Jinv00*Jinv11-(16175.0/36288.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00+(6875.0/3456.0)*Jinv01*Jinv00*M00+(6875.0/6912.0)*M01*Jinv00*Jinv11+(6875.0/6912.0)*Jinv10*Jinv01*M01+(6875.0/6912.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11+(6875.0/6912.0)*M10*Jinv00*Jinv11+(6875.0/3456.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=((14375.0/72576.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[13][12]=(0.0)*D;
  A[13][13]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(29375.0/20736.0)*Jinv01*Jinv00*M00+(29375.0/41472.0)*M01*Jinv00*Jinv11+(29375.0/41472.0)*Jinv10*Jinv01*M01+(29375.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(29375.0/41472.0)*M10*Jinv00*Jinv11+(29375.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[13][14]=(0.0)*D;
  A[13][15]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M10*Jinv01*Jinv11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00+(8125.0/16128.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[13][16]=(0.0)*D;
  A[13][17]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M10*Jinv01*Jinv11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(4375.0/20736.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[13][18]=(0.0)*D;
  A[13][19]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M10*Jinv01*Jinv11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(6875.0/48384.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[13][20]=(0.0)*D;
  A[13][21]=((6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[13][22]=(0.0)*D;
  A[13][23]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(15625.0/41472.0)*M01*Jinv00*Jinv11-(70625.0/41472.0)*Jinv10*Jinv01*M01-(15625.0/41472.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(70625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[13][24]=(0.0)*D;
  A[13][25]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M10*Jinv01*Jinv11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(14375.0/290304.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[13][26]=(0.0)*D;
  A[13][27]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M10*Jinv01*Jinv11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(79375.0/290304.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[13][28]=(0.0)*D;
  A[13][29]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[13][30]=(0.0)*D;
  A[13][31]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(10625.0/18144.0)*M01*Jinv00*Jinv11+(94375.0/72576.0)*Jinv10*Jinv01*M01+(10625.0/18144.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(94375.0/72576.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[13][32]=(0.0)*D;
  A[13][33]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M10*Jinv01*Jinv11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/1344.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[13][34]=(0.0)*D;
  A[13][35]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(8125.0/72576.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[13][36]=(0.0)*D;
  A[13][37]=(-(68125.0/72576.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(78125.0/290304.0)*M01*Jinv00*Jinv11-(194375.0/290304.0)*Jinv10*Jinv01*M01-(78125.0/290304.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(68125.0/72576.0)*Jinv01*M01*Jinv11-(194375.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[13][38]=(0.0)*D;
  A[13][39]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(14375.0/72576.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[13][40]=(0.0)*D;
  A[13][41]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1675.0/10368.0)*M10*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[14][0]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/36288.0)*Jinv01*Jinv00*M00-(15625.0/72576.0)*M01*Jinv00*Jinv11-(15625.0/72576.0)*Jinv10*Jinv01*M01-(15625.0/72576.0)*Jinv10*M10*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*M10*Jinv00*Jinv11-(15625.0/36288.0)*Jinv10*Jinv11*M11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M10*Jinv01*Jinv11+(8125.0/16128.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(409375.0/145152.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[14][9]=(0.0)*D;
  A[14][10]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M10*Jinv01*Jinv11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00+(8125.0/16128.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[14][13]=(0.0)*D;
  A[14][14]=((128125.0/18144.0)*(Jinv01*Jinv01)*M00+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M10*Jinv01*Jinv11+(128125.0/18144.0)*Jinv10*M10*Jinv00+(3125.0/504.0)*Jinv01*Jinv00*M00+(3125.0/1008.0)*M01*Jinv00*Jinv11+(3125.0/1008.0)*Jinv10*Jinv01*M01+(3125.0/1008.0)*Jinv10*M10*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(128125.0/18144.0)*Jinv01*M01*Jinv11+(3125.0/1008.0)*M10*Jinv00*Jinv11+(3125.0/504.0)*Jinv10*Jinv11*M11+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[14][15]=(0.0)*D;
  A[14][16]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[14][17]=(0.0)*D;
  A[14][18]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/1134.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv10*M01*Jinv00)*D;
  A[14][19]=(0.0)*D;
  A[14][20]=(-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[14][21]=(0.0)*D;
  A[14][22]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[14][23]=(0.0)*D;
  A[14][24]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[14][25]=(0.0)*D;
  A[14][26]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00+(53125.0/18144.0)*Jinv01*Jinv00*M00+(53125.0/36288.0)*M01*Jinv00*Jinv11+(53125.0/36288.0)*Jinv10*Jinv01*M01+(53125.0/36288.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11+(53125.0/36288.0)*M10*Jinv00*Jinv11+(53125.0/18144.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[14][27]=(0.0)*D;
  A[14][28]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[14][29]=(0.0)*D;
  A[14][30]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[14][31]=(0.0)*D;
  A[14][32]=((3125.0/1134.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/1134.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[14][33]=(0.0)*D;
  A[14][34]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[14][35]=(0.0)*D;
  A[14][36]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11)*D;
  A[14][37]=(0.0)*D;
  A[14][38]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[14][39]=(0.0)*D;
  A[14][40]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[14][41]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/36288.0)*Jinv01*Jinv00*M00-(15625.0/72576.0)*M01*Jinv00*Jinv11-(15625.0/72576.0)*Jinv10*Jinv01*M01-(15625.0/72576.0)*Jinv10*M10*Jinv01-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*M10*Jinv00*Jinv11-(15625.0/36288.0)*Jinv10*Jinv11*M11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*M10*Jinv01*Jinv11+(8125.0/16128.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00-(409375.0/145152.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[15][12]=(0.0)*D;
  A[15][13]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*M10*Jinv01*Jinv11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(168125.0/72576.0)*Jinv01*Jinv00*M00-(168125.0/145152.0)*M01*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv01*M01-(168125.0/145152.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00+(8125.0/16128.0)*Jinv01*M01*Jinv11-(168125.0/145152.0)*M10*Jinv00*Jinv11-(168125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[15][14]=(0.0)*D;
  A[15][15]=((128125.0/18144.0)*(Jinv01*Jinv01)*M00+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M10*Jinv01*Jinv11+(128125.0/18144.0)*Jinv10*M10*Jinv00+(3125.0/504.0)*Jinv01*Jinv00*M00+(3125.0/1008.0)*M01*Jinv00*Jinv11+(3125.0/1008.0)*Jinv10*Jinv01*M01+(3125.0/1008.0)*Jinv10*M10*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(128125.0/18144.0)*Jinv01*M01*Jinv11+(3125.0/1008.0)*M10*Jinv00*Jinv11+(3125.0/504.0)*Jinv10*Jinv11*M11+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[15][16]=(0.0)*D;
  A[15][17]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/1134.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv10*M01*Jinv00)*D;
  A[15][20]=(0.0)*D;
  A[15][21]=(-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[15][22]=(0.0)*D;
  A[15][23]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[15][24]=(0.0)*D;
  A[15][25]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[15][26]=(0.0)*D;
  A[15][27]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00+(53125.0/18144.0)*Jinv01*Jinv00*M00+(53125.0/36288.0)*M01*Jinv00*Jinv11+(53125.0/36288.0)*Jinv10*Jinv01*M01+(53125.0/36288.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11+(53125.0/36288.0)*M10*Jinv00*Jinv11+(53125.0/18144.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[15][28]=(0.0)*D;
  A[15][29]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[15][30]=(0.0)*D;
  A[15][31]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[15][32]=(0.0)*D;
  A[15][33]=((3125.0/1134.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/1134.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[15][34]=(0.0)*D;
  A[15][35]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[15][36]=(0.0)*D;
  A[15][37]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11)*D;
  A[15][38]=(0.0)*D;
  A[15][39]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[15][40]=(0.0)*D;
  A[15][41]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[16][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M10*Jinv01*Jinv11+(14375.0/290304.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(115625.0/96768.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=((14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M10*Jinv01*Jinv11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(4375.0/20736.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[16][13]=(0.0)*D;
  A[16][14]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[16][15]=(0.0)*D;
  A[16][16]=((209375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/3456.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/3456.0)*Jinv10*M10*Jinv00+(34375.0/3456.0)*Jinv01*Jinv00*M00+(34375.0/6912.0)*M01*Jinv00*Jinv11+(34375.0/6912.0)*Jinv10*Jinv01*M01+(34375.0/6912.0)*Jinv10*M10*Jinv01+(34375.0/3456.0)*(Jinv00*Jinv00)*M00+(209375.0/24192.0)*Jinv01*M01*Jinv11+(34375.0/6912.0)*M10*Jinv00*Jinv11+(34375.0/3456.0)*Jinv10*Jinv11*M11+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[16][17]=(0.0)*D;
  A[16][18]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[16][19]=(0.0)*D;
  A[16][20]=((3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[16][21]=(0.0)*D;
  A[16][22]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[16][23]=(0.0)*D;
  A[16][24]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00+(246875.0/48384.0)*Jinv01*Jinv00*M00+(246875.0/96768.0)*M01*Jinv00*Jinv11+(246875.0/96768.0)*Jinv10*Jinv01*M01+(246875.0/96768.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11+(246875.0/96768.0)*M10*Jinv00*Jinv11+(246875.0/48384.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[16][25]=(0.0)*D;
  A[16][26]=(-(40625.0/6912.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/6912.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[16][27]=(0.0)*D;
  A[16][28]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[16][29]=(0.0)*D;
  A[16][30]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[16][31]=(0.0)*D;
  A[16][32]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11-(3125.0/36288.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[16][33]=(0.0)*D;
  A[16][34]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[16][35]=(0.0)*D;
  A[16][36]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*M10*Jinv01*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*Jinv01*M01*Jinv11+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[16][37]=(0.0)*D;
  A[16][38]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*M10*Jinv01*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*Jinv01*M01*Jinv11-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[16][39]=(0.0)*D;
  A[16][40]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[16][41]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*M10*Jinv01*Jinv11+(14375.0/290304.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(115625.0/96768.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(625.0/145152.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(625.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(625.0/145152.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=((14375.0/290304.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[17][12]=(0.0)*D;
  A[17][13]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*M10*Jinv01*Jinv11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(4375.0/20736.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[17][14]=(0.0)*D;
  A[17][15]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[17][16]=(0.0)*D;
  A[17][17]=((209375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/3456.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/3456.0)*Jinv10*M10*Jinv00+(34375.0/3456.0)*Jinv01*Jinv00*M00+(34375.0/6912.0)*M01*Jinv00*Jinv11+(34375.0/6912.0)*Jinv10*Jinv01*M01+(34375.0/6912.0)*Jinv10*M10*Jinv01+(34375.0/3456.0)*(Jinv00*Jinv00)*M00+(209375.0/24192.0)*Jinv01*M01*Jinv11+(34375.0/6912.0)*M10*Jinv00*Jinv11+(34375.0/3456.0)*Jinv10*Jinv11*M11+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[17][18]=(0.0)*D;
  A[17][19]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[17][20]=(0.0)*D;
  A[17][21]=((3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[17][22]=(0.0)*D;
  A[17][23]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[17][24]=(0.0)*D;
  A[17][25]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00+(246875.0/48384.0)*Jinv01*Jinv00*M00+(246875.0/96768.0)*M01*Jinv00*Jinv11+(246875.0/96768.0)*Jinv10*Jinv01*M01+(246875.0/96768.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11+(246875.0/96768.0)*M10*Jinv00*Jinv11+(246875.0/48384.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[17][26]=(0.0)*D;
  A[17][27]=(-(40625.0/6912.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/6912.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[17][28]=(0.0)*D;
  A[17][29]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[17][30]=(0.0)*D;
  A[17][31]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[17][32]=(0.0)*D;
  A[17][33]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11-(3125.0/36288.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[17][34]=(0.0)*D;
  A[17][35]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[17][36]=(0.0)*D;
  A[17][37]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*M10*Jinv01*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*Jinv01*M01*Jinv11+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[17][38]=(0.0)*D;
  A[17][39]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*M10*Jinv01*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*Jinv01*M01*Jinv11-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[17][40]=(0.0)*D;
  A[17][41]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[18][0]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M10*Jinv01*Jinv11-(625.0/1344.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(71875.0/72576.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[18][3]=(0.0)*D;
  A[18][4]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[18][5]=(0.0)*D;
  A[18][6]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=((8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv10*M10*Jinv00+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M10*Jinv01*Jinv11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(6875.0/48384.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[18][13]=(0.0)*D;
  A[18][14]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/1134.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv10*M01*Jinv00)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[18][17]=(0.0)*D;
  A[18][18]=((71875.0/9072.0)*(Jinv01*Jinv01)*M00+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(71875.0/9072.0)*M10*Jinv01*Jinv11+(128125.0/18144.0)*Jinv10*M10*Jinv00+(71875.0/9072.0)*Jinv01*Jinv00*M00+(71875.0/18144.0)*M01*Jinv00*Jinv11+(71875.0/18144.0)*Jinv10*Jinv01*M01+(71875.0/18144.0)*Jinv10*M10*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(71875.0/9072.0)*Jinv01*M01*Jinv11+(71875.0/18144.0)*M10*Jinv00*Jinv11+(71875.0/9072.0)*Jinv10*Jinv11*M11+(71875.0/9072.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[18][19]=(0.0)*D;
  A[18][20]=(-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[18][21]=(0.0)*D;
  A[18][22]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[18][23]=(0.0)*D;
  A[18][24]=(-(3125.0/36288.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/36288.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[18][25]=(0.0)*D;
  A[18][26]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[18][27]=(0.0)*D;
  A[18][28]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[18][29]=(0.0)*D;
  A[18][30]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[18][31]=(0.0)*D;
  A[18][32]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00-(3125.0/4536.0)*Jinv01*Jinv00*M00-(3125.0/9072.0)*M01*Jinv00*Jinv11-(3125.0/9072.0)*Jinv10*Jinv01*M01-(3125.0/9072.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11-(3125.0/9072.0)*M10*Jinv00*Jinv11-(3125.0/4536.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[18][33]=(0.0)*D;
  A[18][34]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[18][35]=(0.0)*D;
  A[18][36]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[18][37]=(0.0)*D;
  A[18][38]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[18][39]=(0.0)*D;
  A[18][40]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[18][41]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*M10*Jinv01*Jinv11-(625.0/1344.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*(Jinv00*Jinv00)*M00-(71875.0/72576.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/1344.0)*Jinv10*M01*Jinv00)*D;
  A[19][4]=(0.0)*D;
  A[19][5]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(49375.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[19][6]=(0.0)*D;
  A[19][7]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00-(44375.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11-(44375.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(44375.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11-(44375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=((8125.0/16128.0)*(Jinv10*Jinv10)*M11+(8125.0/16128.0)*Jinv10*M10*Jinv00+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*(Jinv00*Jinv00)*M00+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*Jinv10*M01*Jinv00)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(-(15625.0/72576.0)*(Jinv10*Jinv10)*M11-(15625.0/72576.0)*Jinv10*M10*Jinv00-(15625.0/72576.0)*(Jinv00*Jinv00)*M00-(15625.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[19][12]=(0.0)*D;
  A[19][13]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*M10*Jinv01*Jinv11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(6875.0/48384.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[19][14]=(0.0)*D;
  A[19][15]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/1134.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/1134.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/1134.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/1134.0)*Jinv10*M01*Jinv00)*D;
  A[19][16]=(0.0)*D;
  A[19][17]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(21875.0/3456.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(21875.0/3456.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(21875.0/3456.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(21875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[19][18]=(0.0)*D;
  A[19][19]=((71875.0/9072.0)*(Jinv01*Jinv01)*M00+(128125.0/18144.0)*(Jinv10*Jinv10)*M11+(71875.0/9072.0)*M10*Jinv01*Jinv11+(128125.0/18144.0)*Jinv10*M10*Jinv00+(71875.0/9072.0)*Jinv01*Jinv00*M00+(71875.0/18144.0)*M01*Jinv00*Jinv11+(71875.0/18144.0)*Jinv10*Jinv01*M01+(71875.0/18144.0)*Jinv10*M10*Jinv01+(128125.0/18144.0)*(Jinv00*Jinv00)*M00+(71875.0/9072.0)*Jinv01*M01*Jinv11+(71875.0/18144.0)*M10*Jinv00*Jinv11+(71875.0/9072.0)*Jinv10*Jinv11*M11+(71875.0/9072.0)*(Jinv11*Jinv11)*M11+(128125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[19][20]=(0.0)*D;
  A[19][21]=(-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[19][22]=(0.0)*D;
  A[19][23]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[19][24]=(0.0)*D;
  A[19][25]=(-(3125.0/36288.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/36288.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[19][26]=(0.0)*D;
  A[19][27]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[19][28]=(0.0)*D;
  A[19][29]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[19][30]=(0.0)*D;
  A[19][31]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[19][32]=(0.0)*D;
  A[19][33]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00-(3125.0/4536.0)*Jinv01*Jinv00*M00-(3125.0/9072.0)*M01*Jinv00*Jinv11-(3125.0/9072.0)*Jinv10*Jinv01*M01-(3125.0/9072.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11-(3125.0/9072.0)*M10*Jinv00*Jinv11-(3125.0/4536.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[19][34]=(0.0)*D;
  A[19][35]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[19][36]=(0.0)*D;
  A[19][37]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[19][38]=(0.0)*D;
  A[19][39]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[19][40]=(0.0)*D;
  A[19][41]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[20][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[20][1]=(0.0)*D;
  A[20][2]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M10*Jinv01*Jinv11+(14375.0/72576.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/145152.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[20][3]=(0.0)*D;
  A[20][4]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[20][5]=(0.0)*D;
  A[20][6]=((625.0/448.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(-(53125.0/20736.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/20736.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[20][9]=(0.0)*D;
  A[20][10]=((725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv10*M10*Jinv00+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*M01*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[20][11]=(0.0)*D;
  A[20][12]=((6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[20][13]=(0.0)*D;
  A[20][14]=(-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[20][15]=(0.0)*D;
  A[20][16]=((3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[20][17]=(0.0)*D;
  A[20][18]=(-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[20][19]=(0.0)*D;
  A[20][20]=((53125.0/20736.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/20736.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[20][21]=(0.0)*D;
  A[20][22]=((38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[20][23]=(0.0)*D;
  A[20][24]=(-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[20][25]=(0.0)*D;
  A[20][26]=((115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[20][27]=(0.0)*D;
  A[20][28]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00-(25625.0/48384.0)*M01*Jinv00*Jinv11+(115625.0/145152.0)*Jinv10*Jinv01*M01-(25625.0/48384.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11+(115625.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[20][29]=(0.0)*D;
  A[20][30]=((3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[20][31]=(0.0)*D;
  A[20][32]=(-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[20][33]=(0.0)*D;
  A[20][34]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00+(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/1296.0)*Jinv10*Jinv01*M01+(625.0/2688.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/1296.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[20][35]=(0.0)*D;
  A[20][36]=((49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[20][37]=(0.0)*D;
  A[20][38]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00+(3125.0/12096.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11+(10625.0/32256.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11+(10625.0/32256.0)*M10*Jinv00*Jinv11+(3125.0/12096.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[20][39]=(0.0)*D;
  A[20][40]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*M10*Jinv01*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv01*M01*Jinv11-(1675.0/10368.0)*M10*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[20][41]=(0.0)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[21][2]=(0.0)*D;
  A[21][3]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*M10*Jinv01*Jinv11+(14375.0/72576.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/145152.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11+(14375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00-(104375.0/290304.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11-(104375.0/290304.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(104375.0/290304.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11-(104375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[21][6]=(0.0)*D;
  A[21][7]=((625.0/448.0)*(Jinv01*Jinv01)*M00+(11875.0/41472.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11+(11875.0/41472.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(11875.0/41472.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11+(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[21][8]=(0.0)*D;
  A[21][9]=(-(53125.0/20736.0)*(Jinv01*Jinv01)*M00-(11875.0/41472.0)*(Jinv10*Jinv10)*M11-(53125.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/41472.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(11875.0/41472.0)*(Jinv00*Jinv00)*M00-(53125.0/20736.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(53125.0/20736.0)*(Jinv11*Jinv11)*M11-(11875.0/41472.0)*Jinv10*M01*Jinv00)*D;
  A[21][10]=(0.0)*D;
  A[21][11]=((725.0/3584.0)*(Jinv10*Jinv10)*M11+(725.0/3584.0)*Jinv10*M10*Jinv00+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*M01*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*(Jinv00*Jinv00)*M00+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*Jinv10*M01*Jinv00)*D;
  A[21][12]=(0.0)*D;
  A[21][13]=((6875.0/48384.0)*(Jinv10*Jinv10)*M11+(6875.0/48384.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[21][14]=(0.0)*D;
  A[21][15]=(-(96875.0/145152.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[21][16]=(0.0)*D;
  A[21][17]=((3125.0/2304.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*Jinv10*M01*Jinv00)*D;
  A[21][18]=(0.0)*D;
  A[21][19]=(-(409375.0/145152.0)*(Jinv10*Jinv10)*M11-(409375.0/145152.0)*Jinv10*M10*Jinv00-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*(Jinv00*Jinv00)*M00-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[21][20]=(0.0)*D;
  A[21][21]=((53125.0/20736.0)*(Jinv01*Jinv01)*M00+(6875.0/3456.0)*(Jinv10*Jinv10)*M11+(53125.0/20736.0)*M10*Jinv01*Jinv11+(6875.0/3456.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(6875.0/3456.0)*(Jinv00*Jinv00)*M00+(53125.0/20736.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(53125.0/20736.0)*(Jinv11*Jinv11)*M11+(6875.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[21][22]=(0.0)*D;
  A[21][23]=((38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[21][24]=(0.0)*D;
  A[21][25]=(-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[21][26]=(0.0)*D;
  A[21][27]=((115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[21][28]=(0.0)*D;
  A[21][29]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00-(25625.0/48384.0)*M01*Jinv00*Jinv11+(115625.0/145152.0)*Jinv10*Jinv01*M01-(25625.0/48384.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11+(115625.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[21][30]=(0.0)*D;
  A[21][31]=((3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[21][32]=(0.0)*D;
  A[21][33]=(-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[21][34]=(0.0)*D;
  A[21][35]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00+(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/1296.0)*Jinv10*Jinv01*M01+(625.0/2688.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/1296.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[21][36]=(0.0)*D;
  A[21][37]=((49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[21][38]=(0.0)*D;
  A[21][39]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00+(3125.0/12096.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11+(10625.0/32256.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11+(10625.0/32256.0)*M10*Jinv00*Jinv11+(3125.0/12096.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[21][40]=(0.0)*D;
  A[21][41]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*M10*Jinv01*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*Jinv10*Jinv01*M01+(1975.0/48384.0)*Jinv01*M01*Jinv11-(1675.0/10368.0)*M10*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[22][0]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M10*Jinv01*Jinv11-(575.0/36288.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00+(14375.0/24192.0)*M01*Jinv00*Jinv11-(575.0/36288.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv01*M01*Jinv11-(575.0/36288.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[22][1]=(0.0)*D;
  A[22][2]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[22][3]=(0.0)*D;
  A[22][4]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[22][5]=(0.0)*D;
  A[22][6]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[22][7]=(0.0)*D;
  A[22][8]=((8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[22][9]=(0.0)*D;
  A[22][10]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[22][11]=(0.0)*D;
  A[22][12]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(70625.0/41472.0)*M01*Jinv00*Jinv11-(15625.0/41472.0)*Jinv10*Jinv01*M01-(70625.0/41472.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[22][13]=(0.0)*D;
  A[22][14]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[22][15]=(0.0)*D;
  A[22][16]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[22][17]=(0.0)*D;
  A[22][18]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[22][19]=(0.0)*D;
  A[22][20]=((38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[22][21]=(0.0)*D;
  A[22][22]=((11875.0/2688.0)*(Jinv01*Jinv01)*M00+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M10*Jinv01*Jinv11+(10625.0/3456.0)*Jinv10*M10*Jinv00+(4375.0/1152.0)*Jinv01*Jinv00*M00+(4375.0/2304.0)*M01*Jinv00*Jinv11+(4375.0/2304.0)*Jinv10*Jinv01*M01+(4375.0/2304.0)*Jinv10*M10*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(11875.0/2688.0)*Jinv01*M01*Jinv11+(4375.0/2304.0)*M10*Jinv00*Jinv11+(4375.0/1152.0)*Jinv10*Jinv11*M11+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[22][23]=(0.0)*D;
  A[22][24]=((625.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[22][25]=(0.0)*D;
  A[22][26]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[22][27]=(0.0)*D;
  A[22][28]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(14375.0/48384.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[22][29]=(0.0)*D;
  A[22][30]=(-(574375.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/10752.0)*M01*Jinv00*Jinv11-(726875.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/10752.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(574375.0/145152.0)*Jinv01*M01*Jinv11-(726875.0/290304.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[22][31]=(0.0)*D;
  A[22][32]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[22][33]=(0.0)*D;
  A[22][34]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[22][35]=(0.0)*D;
  A[22][36]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/10368.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(6875.0/10368.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[22][37]=(0.0)*D;
  A[22][38]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[22][39]=(0.0)*D;
  A[22][40]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*M10*Jinv01*Jinv11-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv01*M01*Jinv11-(575.0/1512.0)*M10*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[22][41]=(0.0)*D;
  A[23][0]=(0.0)*D;
  A[23][1]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*(Jinv10*Jinv10)*M11+(14375.0/24192.0)*M10*Jinv01*Jinv11-(575.0/36288.0)*Jinv10*M10*Jinv00+(41975.0/72576.0)*Jinv01*Jinv00*M00+(14375.0/24192.0)*M01*Jinv00*Jinv11-(575.0/36288.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00+(14375.0/24192.0)*Jinv01*M01*Jinv11-(575.0/36288.0)*M10*Jinv00*Jinv11+(41975.0/72576.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[23][2]=(0.0)*D;
  A[23][3]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00-(168125.0/145152.0)*Jinv01*Jinv00*M00-(168125.0/290304.0)*M01*Jinv00*Jinv11-(168125.0/290304.0)*Jinv10*Jinv01*M01-(168125.0/290304.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11-(168125.0/290304.0)*M10*Jinv00*Jinv11-(168125.0/145152.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[23][4]=(0.0)*D;
  A[23][5]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[23][8]=(0.0)*D;
  A[23][9]=((8125.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[23][12]=(0.0)*D;
  A[23][13]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/6912.0)*Jinv01*Jinv00*M00-(70625.0/41472.0)*M01*Jinv00*Jinv11-(15625.0/41472.0)*Jinv10*Jinv01*M01-(70625.0/41472.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/6912.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[23][14]=(0.0)*D;
  A[23][15]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00+(49375.0/12096.0)*Jinv01*Jinv00*M00+(49375.0/24192.0)*M01*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv01*M01+(49375.0/24192.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11+(49375.0/24192.0)*M10*Jinv00*Jinv11+(49375.0/12096.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[23][16]=(0.0)*D;
  A[23][17]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[23][18]=(0.0)*D;
  A[23][19]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[23][20]=(0.0)*D;
  A[23][21]=((38125.0/290304.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[23][22]=(0.0)*D;
  A[23][23]=((11875.0/2688.0)*(Jinv01*Jinv01)*M00+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M10*Jinv01*Jinv11+(10625.0/3456.0)*Jinv10*M10*Jinv00+(4375.0/1152.0)*Jinv01*Jinv00*M00+(4375.0/2304.0)*M01*Jinv00*Jinv11+(4375.0/2304.0)*Jinv10*Jinv01*M01+(4375.0/2304.0)*Jinv10*M10*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(11875.0/2688.0)*Jinv01*M01*Jinv11+(4375.0/2304.0)*M10*Jinv00*Jinv11+(4375.0/1152.0)*Jinv10*Jinv11*M11+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[23][24]=(0.0)*D;
  A[23][25]=((625.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[23][26]=(0.0)*D;
  A[23][27]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[23][28]=(0.0)*D;
  A[23][29]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(14375.0/48384.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[23][30]=(0.0)*D;
  A[23][31]=(-(574375.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/10752.0)*M01*Jinv00*Jinv11-(726875.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/10752.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(574375.0/145152.0)*Jinv01*M01*Jinv11-(726875.0/290304.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[23][32]=(0.0)*D;
  A[23][33]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[23][34]=(0.0)*D;
  A[23][35]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[23][36]=(0.0)*D;
  A[23][37]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/10368.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(6875.0/10368.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[23][38]=(0.0)*D;
  A[23][39]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[23][40]=(0.0)*D;
  A[23][41]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*M10*Jinv01*Jinv11-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv01*M01*Jinv11-(575.0/1512.0)*M10*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[24][0]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[24][1]=(0.0)*D;
  A[24][2]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M10*Jinv01*Jinv11+(4375.0/20736.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(3125.0/2304.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[24][3]=(0.0)*D;
  A[24][4]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[24][5]=(0.0)*D;
  A[24][6]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[24][7]=(0.0)*D;
  A[24][8]=(-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv10*M10*Jinv00+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[24][9]=(0.0)*D;
  A[24][10]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[24][11]=(0.0)*D;
  A[24][12]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M10*Jinv01*Jinv11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(14375.0/290304.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[24][13]=(0.0)*D;
  A[24][14]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[24][15]=(0.0)*D;
  A[24][16]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00+(246875.0/48384.0)*Jinv01*Jinv00*M00+(246875.0/96768.0)*M01*Jinv00*Jinv11+(246875.0/96768.0)*Jinv10*Jinv01*M01+(246875.0/96768.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11+(246875.0/96768.0)*M10*Jinv00*Jinv11+(246875.0/48384.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[24][17]=(0.0)*D;
  A[24][18]=(-(3125.0/36288.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/36288.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[24][19]=(0.0)*D;
  A[24][20]=(-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[24][21]=(0.0)*D;
  A[24][22]=((625.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[24][23]=(0.0)*D;
  A[24][24]=((34375.0/3456.0)*(Jinv01*Jinv01)*M00+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/3456.0)*M10*Jinv01*Jinv11+(209375.0/24192.0)*Jinv10*M10*Jinv00+(34375.0/3456.0)*Jinv01*Jinv00*M00+(34375.0/6912.0)*M01*Jinv00*Jinv11+(34375.0/6912.0)*Jinv10*Jinv01*M01+(34375.0/6912.0)*Jinv10*M10*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/3456.0)*Jinv01*M01*Jinv11+(34375.0/6912.0)*M10*Jinv00*Jinv11+(34375.0/3456.0)*Jinv10*Jinv11*M11+(34375.0/3456.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[24][25]=(0.0)*D;
  A[24][26]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(40625.0/6912.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv10*M01*Jinv00)*D;
  A[24][27]=(0.0)*D;
  A[24][28]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[24][29]=(0.0)*D;
  A[24][30]=((625.0/145152.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[24][31]=(0.0)*D;
  A[24][32]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[24][33]=(0.0)*D;
  A[24][34]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[24][35]=(0.0)*D;
  A[24][36]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[24][37]=(0.0)*D;
  A[24][38]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11)*D;
  A[24][39]=(0.0)*D;
  A[24][40]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[24][41]=(0.0)*D;
  A[25][0]=(0.0)*D;
  A[25][1]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/145152.0)*Jinv01*Jinv00*M00-(15625.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/290304.0)*Jinv10*Jinv01*M01-(15625.0/290304.0)*Jinv10*M10*Jinv01-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*M10*Jinv00*Jinv11-(15625.0/145152.0)*Jinv10*Jinv11*M11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[25][2]=(0.0)*D;
  A[25][3]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*(Jinv10*Jinv10)*M11+(3125.0/2304.0)*M10*Jinv01*Jinv11+(4375.0/20736.0)*Jinv10*M10*Jinv00+(8125.0/5184.0)*Jinv01*Jinv00*M00+(8125.0/10368.0)*M01*Jinv00*Jinv11+(8125.0/10368.0)*Jinv10*Jinv01*M01+(8125.0/10368.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00+(3125.0/2304.0)*Jinv01*M01*Jinv11+(8125.0/10368.0)*M10*Jinv00*Jinv11+(8125.0/5184.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[25][4]=(0.0)*D;
  A[25][5]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/48384.0)*Jinv01*Jinv00*M00-(45625.0/96768.0)*M01*Jinv00*Jinv11-(45625.0/96768.0)*Jinv10*Jinv01*M01-(45625.0/96768.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11-(45625.0/96768.0)*M10*Jinv00*Jinv11-(45625.0/48384.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[25][6]=(0.0)*D;
  A[25][7]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[25][8]=(0.0)*D;
  A[25][9]=(-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*Jinv10*M10*Jinv00+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[25][10]=(0.0)*D;
  A[25][11]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[25][12]=(0.0)*D;
  A[25][13]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*(Jinv10*Jinv10)*M11+(14375.0/290304.0)*M10*Jinv01*Jinv11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(180625.0/145152.0)*Jinv01*Jinv00*M00+(180625.0/290304.0)*M01*Jinv00*Jinv11+(180625.0/290304.0)*Jinv10*Jinv01*M01+(180625.0/290304.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(14375.0/290304.0)*Jinv01*M01*Jinv11+(180625.0/290304.0)*M10*Jinv00*Jinv11+(180625.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[25][14]=(0.0)*D;
  A[25][15]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00-(221875.0/36288.0)*Jinv01*Jinv00*M00-(221875.0/72576.0)*M01*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv01*M01-(221875.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(221875.0/72576.0)*M10*Jinv00*Jinv11-(221875.0/36288.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[25][16]=(0.0)*D;
  A[25][17]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00+(246875.0/48384.0)*Jinv01*Jinv00*M00+(246875.0/96768.0)*M01*Jinv00*Jinv11+(246875.0/96768.0)*Jinv10*Jinv01*M01+(246875.0/96768.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11+(246875.0/96768.0)*M10*Jinv00*Jinv11+(246875.0/48384.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[25][18]=(0.0)*D;
  A[25][19]=(-(3125.0/36288.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11-(3125.0/36288.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00-(3125.0/36288.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/36288.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[25][20]=(0.0)*D;
  A[25][21]=(-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[25][22]=(0.0)*D;
  A[25][23]=((625.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(233125.0/48384.0)*Jinv01*Jinv00*M00-(233125.0/96768.0)*M01*Jinv00*Jinv11-(233125.0/96768.0)*Jinv10*Jinv01*M01-(233125.0/96768.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11-(233125.0/96768.0)*M10*Jinv00*Jinv11-(233125.0/48384.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[25][24]=(0.0)*D;
  A[25][25]=((34375.0/3456.0)*(Jinv01*Jinv01)*M00+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/3456.0)*M10*Jinv01*Jinv11+(209375.0/24192.0)*Jinv10*M10*Jinv00+(34375.0/3456.0)*Jinv01*Jinv00*M00+(34375.0/6912.0)*M01*Jinv00*Jinv11+(34375.0/6912.0)*Jinv10*Jinv01*M01+(34375.0/6912.0)*Jinv10*M10*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/3456.0)*Jinv01*M01*Jinv11+(34375.0/6912.0)*M10*Jinv00*Jinv11+(34375.0/3456.0)*Jinv10*Jinv11*M11+(34375.0/3456.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[25][26]=(0.0)*D;
  A[25][27]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(40625.0/6912.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv10*M01*Jinv00)*D;
  A[25][28]=(0.0)*D;
  A[25][29]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[25][30]=(0.0)*D;
  A[25][31]=((625.0/145152.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[25][32]=(0.0)*D;
  A[25][33]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[25][34]=(0.0)*D;
  A[25][35]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[25][36]=(0.0)*D;
  A[25][37]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[25][38]=(0.0)*D;
  A[25][39]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11)*D;
  A[25][40]=(0.0)*D;
  A[25][41]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[26][0]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[26][1]=(0.0)*D;
  A[26][2]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M10*Jinv01*Jinv11-(79375.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(40625.0/96768.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[26][3]=(0.0)*D;
  A[26][4]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[26][5]=(0.0)*D;
  A[26][6]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[26][7]=(0.0)*D;
  A[26][8]=((4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[26][9]=(0.0)*D;
  A[26][10]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[26][11]=(0.0)*D;
  A[26][12]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M10*Jinv01*Jinv11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(79375.0/290304.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[26][13]=(0.0)*D;
  A[26][14]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00+(53125.0/18144.0)*Jinv01*Jinv00*M00+(53125.0/36288.0)*M01*Jinv00*Jinv11+(53125.0/36288.0)*Jinv10*Jinv01*M01+(53125.0/36288.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11+(53125.0/36288.0)*M10*Jinv00*Jinv11+(53125.0/18144.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[26][15]=(0.0)*D;
  A[26][16]=(-(40625.0/6912.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/6912.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[26][17]=(0.0)*D;
  A[26][18]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[26][19]=(0.0)*D;
  A[26][20]=((115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[26][21]=(0.0)*D;
  A[26][22]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[26][23]=(0.0)*D;
  A[26][24]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(40625.0/6912.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv10*M01*Jinv00)*D;
  A[26][25]=(0.0)*D;
  A[26][26]=((209375.0/24192.0)*(Jinv01*Jinv01)*M00+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M10*Jinv01*Jinv11+(209375.0/24192.0)*Jinv10*M10*Jinv00+(59375.0/8064.0)*Jinv01*Jinv00*M00+(59375.0/16128.0)*M01*Jinv00*Jinv11+(59375.0/16128.0)*Jinv10*Jinv01*M01+(59375.0/16128.0)*Jinv10*M10*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(209375.0/24192.0)*Jinv01*M01*Jinv11+(59375.0/16128.0)*M10*Jinv00*Jinv11+(59375.0/8064.0)*Jinv10*Jinv11*M11+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[26][27]=(0.0)*D;
  A[26][28]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[26][29]=(0.0)*D;
  A[26][30]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[26][31]=(0.0)*D;
  A[26][32]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[26][33]=(0.0)*D;
  A[26][34]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[26][35]=(0.0)*D;
  A[26][36]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11)*D;
  A[26][37]=(0.0)*D;
  A[26][38]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[26][39]=(0.0)*D;
  A[26][40]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[26][41]=(0.0)*D;
  A[27][0]=(0.0)*D;
  A[27][1]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*(Jinv10*Jinv10)*M11-(40625.0/96768.0)*M10*Jinv01*Jinv11-(79375.0/290304.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*(Jinv00*Jinv00)*M00-(40625.0/96768.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11-(79375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[27][4]=(0.0)*D;
  A[27][5]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(11875.0/36288.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(11875.0/36288.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(11875.0/36288.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(11875.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[27][6]=(0.0)*D;
  A[27][7]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(23125.0/72576.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(23125.0/72576.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01-(23125.0/72576.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(23125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[27][8]=(0.0)*D;
  A[27][9]=((4375.0/20736.0)*(Jinv10*Jinv10)*M11+(4375.0/20736.0)*Jinv10*M10*Jinv00-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(-(15625.0/290304.0)*(Jinv10*Jinv10)*M11-(15625.0/290304.0)*Jinv10*M10*Jinv00-(15625.0/290304.0)*(Jinv00*Jinv00)*M00-(15625.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[27][12]=(0.0)*D;
  A[27][13]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*(Jinv10*Jinv10)*M11-(79375.0/290304.0)*M10*Jinv01*Jinv11-(40625.0/96768.0)*Jinv10*M10*Jinv00-(14375.0/20736.0)*Jinv01*Jinv00*M00-(14375.0/41472.0)*M01*Jinv00*Jinv11-(14375.0/41472.0)*Jinv10*Jinv01*M01-(14375.0/41472.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*(Jinv00*Jinv00)*M00-(79375.0/290304.0)*Jinv01*M01*Jinv11-(14375.0/41472.0)*M10*Jinv00*Jinv11-(14375.0/20736.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11-(40625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[27][14]=(0.0)*D;
  A[27][15]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00+(34375.0/24192.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11+(34375.0/24192.0)*Jinv10*M10*Jinv00+(53125.0/18144.0)*Jinv01*Jinv00*M00+(53125.0/36288.0)*M01*Jinv00*Jinv11+(53125.0/36288.0)*Jinv10*Jinv01*M01+(53125.0/36288.0)*Jinv10*M10*Jinv01+(34375.0/24192.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11+(53125.0/36288.0)*M10*Jinv00*Jinv11+(53125.0/18144.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11+(34375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[27][16]=(0.0)*D;
  A[27][17]=(-(40625.0/6912.0)*(Jinv01*Jinv01)*M00-(3125.0/8064.0)*(Jinv10*Jinv10)*M11-(40625.0/6912.0)*M10*Jinv01*Jinv11-(3125.0/8064.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(3125.0/8064.0)*(Jinv00*Jinv00)*M00-(40625.0/6912.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(40625.0/6912.0)*(Jinv11*Jinv11)*M11-(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[27][18]=(0.0)*D;
  A[27][19]=(-(146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/1728.0)*(Jinv10*Jinv10)*M11-(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/1728.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/1728.0)*(Jinv00*Jinv00)*M00-(146875.0/72576.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/1728.0)*Jinv10*M01*Jinv00)*D;
  A[27][20]=(0.0)*D;
  A[27][21]=((115625.0/96768.0)*(Jinv10*Jinv10)*M11+(115625.0/96768.0)*Jinv10*M10*Jinv00+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*(Jinv00*Jinv00)*M00+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[27][22]=(0.0)*D;
  A[27][23]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(10625.0/8064.0)*Jinv01*Jinv00*M00+(10625.0/16128.0)*M01*Jinv00*Jinv11+(10625.0/16128.0)*Jinv10*Jinv01*M01+(10625.0/16128.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11+(10625.0/16128.0)*M10*Jinv00*Jinv11+(10625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[27][24]=(0.0)*D;
  A[27][25]=(-(3125.0/8064.0)*(Jinv01*Jinv01)*M00-(40625.0/6912.0)*(Jinv10*Jinv10)*M11-(3125.0/8064.0)*M10*Jinv01*Jinv11-(40625.0/6912.0)*Jinv10*M10*Jinv00-(40625.0/6912.0)*Jinv01*Jinv00*M00-(40625.0/13824.0)*M01*Jinv00*Jinv11-(40625.0/13824.0)*Jinv10*Jinv01*M01-(40625.0/13824.0)*Jinv10*M10*Jinv01-(40625.0/6912.0)*(Jinv00*Jinv00)*M00-(3125.0/8064.0)*Jinv01*M01*Jinv11-(40625.0/13824.0)*M10*Jinv00*Jinv11-(40625.0/6912.0)*Jinv10*Jinv11*M11-(3125.0/8064.0)*(Jinv11*Jinv11)*M11-(40625.0/6912.0)*Jinv10*M01*Jinv00)*D;
  A[27][26]=(0.0)*D;
  A[27][27]=((209375.0/24192.0)*(Jinv01*Jinv01)*M00+(209375.0/24192.0)*(Jinv10*Jinv10)*M11+(209375.0/24192.0)*M10*Jinv01*Jinv11+(209375.0/24192.0)*Jinv10*M10*Jinv00+(59375.0/8064.0)*Jinv01*Jinv00*M00+(59375.0/16128.0)*M01*Jinv00*Jinv11+(59375.0/16128.0)*Jinv10*Jinv01*M01+(59375.0/16128.0)*Jinv10*M10*Jinv01+(209375.0/24192.0)*(Jinv00*Jinv00)*M00+(209375.0/24192.0)*Jinv01*M01*Jinv11+(59375.0/16128.0)*M10*Jinv00*Jinv11+(59375.0/8064.0)*Jinv10*Jinv11*M11+(209375.0/24192.0)*(Jinv11*Jinv11)*M11+(209375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[27][28]=(0.0)*D;
  A[27][29]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[27][30]=(0.0)*D;
  A[27][31]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[27][32]=(0.0)*D;
  A[27][33]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[27][34]=(0.0)*D;
  A[27][35]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[27][36]=(0.0)*D;
  A[27][37]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11)*D;
  A[27][38]=(0.0)*D;
  A[27][39]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[27][40]=(0.0)*D;
  A[27][41]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[28][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[28][1]=(0.0)*D;
  A[28][2]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M10*Jinv01*Jinv11+(8125.0/72576.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/18144.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[28][3]=(0.0)*D;
  A[28][4]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[28][5]=(0.0)*D;
  A[28][6]=((19375.0/72576.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/72576.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[28][7]=(0.0)*D;
  A[28][8]=((625.0/448.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[28][9]=(0.0)*D;
  A[28][10]=(-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv10*M10*Jinv00-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*M01*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[28][11]=(0.0)*D;
  A[28][12]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[28][13]=(0.0)*D;
  A[28][14]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[28][15]=(0.0)*D;
  A[28][16]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[28][17]=(0.0)*D;
  A[28][18]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[28][19]=(0.0)*D;
  A[28][20]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(115625.0/145152.0)*M01*Jinv00*Jinv11-(25625.0/48384.0)*Jinv10*Jinv01*M01+(115625.0/145152.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(25625.0/48384.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[28][21]=(0.0)*D;
  A[28][22]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(14375.0/48384.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[28][23]=(0.0)*D;
  A[28][24]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[28][25]=(0.0)*D;
  A[28][26]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[28][27]=(0.0)*D;
  A[28][28]=((89375.0/24192.0)*(Jinv01*Jinv01)*M00+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M10*Jinv01*Jinv11+(10625.0/3456.0)*Jinv10*M10*Jinv00+(8125.0/3456.0)*Jinv01*Jinv00*M00+(8125.0/6912.0)*M01*Jinv00*Jinv11+(8125.0/6912.0)*Jinv10*Jinv01*M01+(8125.0/6912.0)*Jinv10*M10*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(89375.0/24192.0)*Jinv01*M01*Jinv11+(8125.0/6912.0)*M10*Jinv00*Jinv11+(8125.0/3456.0)*Jinv10*Jinv11*M11+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[28][29]=(0.0)*D;
  A[28][30]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[28][31]=(0.0)*D;
  A[28][32]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[28][33]=(0.0)*D;
  A[28][34]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00+(625.0/1792.0)*Jinv01*Jinv00*M00-(101875.0/290304.0)*M01*Jinv00*Jinv11+(203125.0/290304.0)*Jinv10*Jinv01*M01-(101875.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11+(203125.0/290304.0)*M10*Jinv00*Jinv11+(625.0/1792.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[28][35]=(0.0)*D;
  A[28][36]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[28][37]=(0.0)*D;
  A[28][38]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00+(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/1296.0)*Jinv10*Jinv01*M01+(625.0/2688.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/1296.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[28][39]=(0.0)*D;
  A[28][40]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*M10*Jinv01*Jinv11+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv01*M01*Jinv11+(575.0/1512.0)*M10*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[28][41]=(0.0)*D;
  A[29][0]=(0.0)*D;
  A[29][1]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[29][2]=(0.0)*D;
  A[29][3]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*M10*Jinv01*Jinv11+(8125.0/72576.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/18144.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11+(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[29][4]=(0.0)*D;
  A[29][5]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(8125.0/72576.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(8125.0/72576.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(8125.0/72576.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(8125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[29][6]=(0.0)*D;
  A[29][7]=((19375.0/72576.0)*(Jinv01*Jinv01)*M00+(625.0/6048.0)*(Jinv10*Jinv10)*M11+(19375.0/72576.0)*M10*Jinv01*Jinv11+(625.0/6048.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(625.0/6048.0)*(Jinv00*Jinv00)*M00+(19375.0/72576.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(19375.0/72576.0)*(Jinv11*Jinv11)*M11+(625.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[29][8]=(0.0)*D;
  A[29][9]=((625.0/448.0)*(Jinv01*Jinv01)*M00-(14375.0/290304.0)*(Jinv10*Jinv10)*M11+(625.0/448.0)*M10*Jinv01*Jinv11-(14375.0/290304.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01-(14375.0/290304.0)*(Jinv00*Jinv00)*M00+(625.0/448.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11+(625.0/448.0)*(Jinv11*Jinv11)*M11-(14375.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(-(575.0/36288.0)*(Jinv10*Jinv10)*M11-(575.0/36288.0)*Jinv10*M10*Jinv00-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*M01*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*(Jinv00*Jinv00)*M00-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[29][12]=(0.0)*D;
  A[29][13]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11+(38125.0/290304.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11+(38125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[29][14]=(0.0)*D;
  A[29][15]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00-(3125.0/9072.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11-(3125.0/9072.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/9072.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11-(3125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[29][16]=(0.0)*D;
  A[29][17]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00+(3125.0/8064.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11+(3125.0/8064.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(3125.0/8064.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11+(3125.0/8064.0)*Jinv10*M01*Jinv00)*D;
  A[29][18]=(0.0)*D;
  A[29][19]=(-(71875.0/18144.0)*(Jinv01*Jinv01)*M00+(53125.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/18144.0)*M10*Jinv01*Jinv11+(53125.0/72576.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01+(53125.0/72576.0)*(Jinv00*Jinv00)*M00-(71875.0/18144.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11-(71875.0/18144.0)*(Jinv11*Jinv11)*M11+(53125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[29][20]=(0.0)*D;
  A[29][21]=(-(625.0/448.0)*(Jinv01*Jinv01)*M00-(263125.0/290304.0)*(Jinv10*Jinv10)*M11-(625.0/448.0)*M10*Jinv01*Jinv11-(263125.0/290304.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(115625.0/145152.0)*M01*Jinv00*Jinv11-(25625.0/48384.0)*Jinv10*Jinv01*M01+(115625.0/145152.0)*Jinv10*M10*Jinv01-(263125.0/290304.0)*(Jinv00*Jinv00)*M00-(625.0/448.0)*Jinv01*M01*Jinv11-(25625.0/48384.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(625.0/448.0)*(Jinv11*Jinv11)*M11-(263125.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[29][22]=(0.0)*D;
  A[29][23]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(14375.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(14375.0/48384.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(14375.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(14375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[29][24]=(0.0)*D;
  A[29][25]=((3125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/72576.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[29][26]=(0.0)*D;
  A[29][27]=((146875.0/145152.0)*(Jinv01*Jinv01)*M00-(184375.0/48384.0)*(Jinv10*Jinv10)*M11+(146875.0/145152.0)*M10*Jinv01*Jinv11-(184375.0/48384.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01-(184375.0/48384.0)*(Jinv00*Jinv00)*M00+(146875.0/145152.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11+(146875.0/145152.0)*(Jinv11*Jinv11)*M11-(184375.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[29][28]=(0.0)*D;
  A[29][29]=((89375.0/24192.0)*(Jinv01*Jinv01)*M00+(10625.0/3456.0)*(Jinv10*Jinv10)*M11+(89375.0/24192.0)*M10*Jinv01*Jinv11+(10625.0/3456.0)*Jinv10*M10*Jinv00+(8125.0/3456.0)*Jinv01*Jinv00*M00+(8125.0/6912.0)*M01*Jinv00*Jinv11+(8125.0/6912.0)*Jinv10*Jinv01*M01+(8125.0/6912.0)*Jinv10*M10*Jinv01+(10625.0/3456.0)*(Jinv00*Jinv00)*M00+(89375.0/24192.0)*Jinv01*M01*Jinv11+(8125.0/6912.0)*M10*Jinv00*Jinv11+(8125.0/3456.0)*Jinv10*Jinv11*M11+(89375.0/24192.0)*(Jinv11*Jinv11)*M11+(10625.0/3456.0)*Jinv10*M01*Jinv00)*D;
  A[29][30]=(0.0)*D;
  A[29][31]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[29][32]=(0.0)*D;
  A[29][33]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[29][34]=(0.0)*D;
  A[29][35]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00+(625.0/1792.0)*Jinv01*Jinv00*M00-(101875.0/290304.0)*M01*Jinv00*Jinv11+(203125.0/290304.0)*Jinv10*Jinv01*M01-(101875.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11+(203125.0/290304.0)*M10*Jinv00*Jinv11+(625.0/1792.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[29][36]=(0.0)*D;
  A[29][37]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[29][38]=(0.0)*D;
  A[29][39]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00+(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/1296.0)*Jinv10*Jinv01*M01+(625.0/2688.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/1296.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[29][40]=(0.0)*D;
  A[29][41]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*M10*Jinv01*Jinv11+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*Jinv10*Jinv01*M01-(20225.0/290304.0)*Jinv01*M01*Jinv11+(575.0/1512.0)*M10*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[30][0]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M10*Jinv01*Jinv11-(20225.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(130625.0/290304.0)*M01*Jinv00*Jinv11-(20225.0/290304.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv01*M01*Jinv11-(20225.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[30][1]=(0.0)*D;
  A[30][2]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[30][3]=(0.0)*D;
  A[30][4]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[30][5]=(0.0)*D;
  A[30][6]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(38125.0/145152.0)*Jinv01*Jinv00*M00+(38125.0/290304.0)*M01*Jinv00*Jinv11+(38125.0/290304.0)*Jinv10*Jinv01*M01+(38125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(38125.0/290304.0)*M10*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[30][7]=(0.0)*D;
  A[30][8]=((6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[30][9]=(0.0)*D;
  A[30][10]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[30][11]=(0.0)*D;
  A[30][12]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(94375.0/72576.0)*M01*Jinv00*Jinv11+(10625.0/18144.0)*Jinv10*Jinv01*M01+(94375.0/72576.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(10625.0/18144.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[30][13]=(0.0)*D;
  A[30][14]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[30][15]=(0.0)*D;
  A[30][16]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[30][17]=(0.0)*D;
  A[30][18]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[30][19]=(0.0)*D;
  A[30][20]=((3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[30][21]=(0.0)*D;
  A[30][22]=(-(574375.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(726875.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/10752.0)*Jinv10*Jinv01*M01-(726875.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(574375.0/145152.0)*Jinv01*M01*Jinv11-(15625.0/10752.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[30][23]=(0.0)*D;
  A[30][24]=((625.0/145152.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[30][25]=(0.0)*D;
  A[30][26]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[30][27]=(0.0)*D;
  A[30][28]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[30][29]=(0.0)*D;
  A[30][30]=((11875.0/2688.0)*(Jinv01*Jinv01)*M00+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M10*Jinv01*Jinv11+(89375.0/24192.0)*Jinv10*M10*Jinv00+(40625.0/8064.0)*Jinv01*Jinv00*M00+(40625.0/16128.0)*M01*Jinv00*Jinv11+(40625.0/16128.0)*Jinv10*Jinv01*M01+(40625.0/16128.0)*Jinv10*M10*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(11875.0/2688.0)*Jinv01*M01*Jinv11+(40625.0/16128.0)*M10*Jinv00*Jinv11+(40625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[30][31]=(0.0)*D;
  A[30][32]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[30][33]=(0.0)*D;
  A[30][34]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(19375.0/72576.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[30][35]=(0.0)*D;
  A[30][36]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(41875.0/48384.0)*M01*Jinv00*Jinv11-(318125.0/145152.0)*Jinv10*Jinv01*M01-(41875.0/48384.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(318125.0/145152.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[30][37]=(0.0)*D;
  A[30][38]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[30][39]=(0.0)*D;
  A[30][40]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*M10*Jinv01*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv01*M01*Jinv11+(6325.0/10368.0)*M10*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11)*D;
  A[30][41]=(0.0)*D;
  A[31][0]=(0.0)*D;
  A[31][1]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(130625.0/290304.0)*M10*Jinv01*Jinv11-(20225.0/290304.0)*Jinv10*M10*Jinv00-(10775.0/20736.0)*Jinv01*Jinv00*M00-(130625.0/290304.0)*M01*Jinv00*Jinv11-(20225.0/290304.0)*Jinv10*Jinv01*M01-(130625.0/290304.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00-(130625.0/290304.0)*Jinv01*M01*Jinv11-(20225.0/290304.0)*M10*Jinv00*Jinv11-(10775.0/20736.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[31][2]=(0.0)*D;
  A[31][3]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/48384.0)*Jinv01*Jinv00*M00+(29375.0/96768.0)*M01*Jinv00*Jinv11+(29375.0/96768.0)*Jinv10*Jinv01*M01+(29375.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/96768.0)*M10*Jinv00*Jinv11+(29375.0/48384.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[31][4]=(0.0)*D;
  A[31][5]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(625.0/6912.0)*Jinv01*Jinv00*M00+(625.0/13824.0)*M01*Jinv00*Jinv11+(625.0/13824.0)*Jinv10*Jinv01*M01+(625.0/13824.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11+(625.0/13824.0)*M10*Jinv00*Jinv11+(625.0/6912.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[31][6]=(0.0)*D;
  A[31][7]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00+(38125.0/145152.0)*Jinv01*Jinv00*M00+(38125.0/290304.0)*M01*Jinv00*Jinv11+(38125.0/290304.0)*Jinv10*Jinv01*M01+(38125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11+(38125.0/290304.0)*M10*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[31][8]=(0.0)*D;
  A[31][9]=((6875.0/96768.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[31][10]=(0.0)*D;
  A[31][11]=(-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[31][12]=(0.0)*D;
  A[31][13]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00+(45625.0/24192.0)*Jinv01*Jinv00*M00+(94375.0/72576.0)*M01*Jinv00*Jinv11+(10625.0/18144.0)*Jinv10*Jinv01*M01+(94375.0/72576.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(10625.0/18144.0)*M10*Jinv00*Jinv11+(45625.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[31][14]=(0.0)*D;
  A[31][15]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/336.0)*Jinv01*Jinv00*M00-(625.0/672.0)*M01*Jinv00*Jinv11-(625.0/672.0)*Jinv10*Jinv01*M01-(625.0/672.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11-(625.0/672.0)*M10*Jinv00*Jinv11-(625.0/336.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[31][16]=(0.0)*D;
  A[31][17]=((11875.0/36288.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(11875.0/36288.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00-(6875.0/10368.0)*Jinv01*Jinv00*M00-(6875.0/20736.0)*M01*Jinv00*Jinv11-(6875.0/20736.0)*Jinv10*Jinv01*M01-(6875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(11875.0/36288.0)*Jinv01*M01*Jinv11-(6875.0/20736.0)*M10*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv11*M11+(11875.0/36288.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[31][18]=(0.0)*D;
  A[31][19]=((625.0/18144.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(625.0/18144.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(625.0/18144.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11+(625.0/18144.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[31][20]=(0.0)*D;
  A[31][21]=((3125.0/18144.0)*(Jinv10*Jinv10)*M11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[31][22]=(0.0)*D;
  A[31][23]=(-(574375.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(574375.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00-(574375.0/145152.0)*Jinv01*Jinv00*M00-(726875.0/290304.0)*M01*Jinv00*Jinv11-(15625.0/10752.0)*Jinv10*Jinv01*M01-(726875.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(574375.0/145152.0)*Jinv01*M01*Jinv11-(15625.0/10752.0)*M10*Jinv00*Jinv11-(574375.0/145152.0)*Jinv10*Jinv11*M11-(574375.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[31][24]=(0.0)*D;
  A[31][25]=((625.0/145152.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(625.0/145152.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(700625.0/145152.0)*Jinv01*Jinv00*M00+(700625.0/290304.0)*M01*Jinv00*Jinv11+(700625.0/290304.0)*Jinv10*Jinv01*M01+(700625.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(625.0/145152.0)*Jinv01*M01*Jinv11+(700625.0/290304.0)*M10*Jinv00*Jinv11+(700625.0/145152.0)*Jinv10*Jinv11*M11+(625.0/145152.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[31][26]=(0.0)*D;
  A[31][27]=(-(23125.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(23125.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(44375.0/145152.0)*Jinv01*Jinv00*M00+(44375.0/290304.0)*M01*Jinv00*Jinv11+(44375.0/290304.0)*Jinv10*Jinv01*M01+(44375.0/290304.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(23125.0/72576.0)*Jinv01*M01*Jinv11+(44375.0/290304.0)*M10*Jinv00*Jinv11+(44375.0/145152.0)*Jinv10*Jinv11*M11-(23125.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[31][28]=(0.0)*D;
  A[31][29]=(-(625.0/36288.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(625.0/36288.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(625.0/36288.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(625.0/36288.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[31][30]=(0.0)*D;
  A[31][31]=((11875.0/2688.0)*(Jinv01*Jinv01)*M00+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(11875.0/2688.0)*M10*Jinv01*Jinv11+(89375.0/24192.0)*Jinv10*M10*Jinv00+(40625.0/8064.0)*Jinv01*Jinv00*M00+(40625.0/16128.0)*M01*Jinv00*Jinv11+(40625.0/16128.0)*Jinv10*Jinv01*M01+(40625.0/16128.0)*Jinv10*M10*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(11875.0/2688.0)*Jinv01*M01*Jinv11+(40625.0/16128.0)*M10*Jinv00*Jinv11+(40625.0/8064.0)*Jinv10*Jinv11*M11+(11875.0/2688.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[31][32]=(0.0)*D;
  A[31][33]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[31][34]=(0.0)*D;
  A[31][35]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(19375.0/72576.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[31][36]=(0.0)*D;
  A[31][37]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(41875.0/48384.0)*M01*Jinv00*Jinv11-(318125.0/145152.0)*Jinv10*Jinv01*M01-(41875.0/48384.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(318125.0/145152.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[31][38]=(0.0)*D;
  A[31][39]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[31][40]=(0.0)*D;
  A[31][41]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*M10*Jinv01*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*Jinv10*Jinv01*M01+(14375.0/24192.0)*Jinv01*M01*Jinv11+(6325.0/10368.0)*M10*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11)*D;
  A[32][0]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[32][1]=(0.0)*D;
  A[32][2]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(96875.0/145152.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[32][3]=(0.0)*D;
  A[32][4]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[32][5]=(0.0)*D;
  A[32][6]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[32][7]=(0.0)*D;
  A[32][8]=(-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[32][9]=(0.0)*D;
  A[32][10]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[32][11]=(0.0)*D;
  A[32][12]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M10*Jinv01*Jinv11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/1344.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][13]=(0.0)*D;
  A[32][14]=((3125.0/1134.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/1134.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[32][15]=(0.0)*D;
  A[32][16]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11-(3125.0/36288.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[32][17]=(0.0)*D;
  A[32][18]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00-(3125.0/4536.0)*Jinv01*Jinv00*M00-(3125.0/9072.0)*M01*Jinv00*Jinv11-(3125.0/9072.0)*Jinv10*Jinv01*M01-(3125.0/9072.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11-(3125.0/9072.0)*M10*Jinv00*Jinv11-(3125.0/4536.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[32][19]=(0.0)*D;
  A[32][20]=(-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][21]=(0.0)*D;
  A[32][22]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][23]=(0.0)*D;
  A[32][24]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][25]=(0.0)*D;
  A[32][26]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][27]=(0.0)*D;
  A[32][28]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[32][29]=(0.0)*D;
  A[32][30]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[32][31]=(0.0)*D;
  A[32][32]=((128125.0/18144.0)*(Jinv01*Jinv01)*M00+(71875.0/9072.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M10*Jinv01*Jinv11+(71875.0/9072.0)*Jinv10*M10*Jinv00+(71875.0/9072.0)*Jinv01*Jinv00*M00+(71875.0/18144.0)*M01*Jinv00*Jinv11+(71875.0/18144.0)*Jinv10*Jinv01*M01+(71875.0/18144.0)*Jinv10*M10*Jinv01+(71875.0/9072.0)*(Jinv00*Jinv00)*M00+(128125.0/18144.0)*Jinv01*M01*Jinv11+(71875.0/18144.0)*M10*Jinv00*Jinv11+(71875.0/9072.0)*Jinv10*Jinv11*M11+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(71875.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[32][33]=(0.0)*D;
  A[32][34]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[32][35]=(0.0)*D;
  A[32][36]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*M10*Jinv01*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*Jinv01*M01*Jinv11+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11)*D;
  A[32][37]=(0.0)*D;
  A[32][38]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*M10*Jinv01*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*Jinv01*M01*Jinv11-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[32][39]=(0.0)*D;
  A[32][40]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[32][41]=(0.0)*D;
  A[33][0]=(0.0)*D;
  A[33][1]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/72576.0)*Jinv01*Jinv00*M00+(15625.0/145152.0)*M01*Jinv00*Jinv11+(15625.0/145152.0)*Jinv10*Jinv01*M01+(15625.0/145152.0)*Jinv10*M10*Jinv01+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*M10*Jinv00*Jinv11+(15625.0/72576.0)*Jinv10*Jinv11*M11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[33][2]=(0.0)*D;
  A[33][3]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(96875.0/145152.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv10*M10*Jinv00-(29375.0/36288.0)*Jinv01*Jinv00*M00-(29375.0/72576.0)*M01*Jinv00*Jinv11-(29375.0/72576.0)*Jinv10*Jinv01*M01-(29375.0/72576.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00-(96875.0/145152.0)*Jinv01*M01*Jinv11-(29375.0/72576.0)*M10*Jinv00*Jinv11-(29375.0/36288.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[33][4]=(0.0)*D;
  A[33][5]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00+(625.0/3024.0)*Jinv01*Jinv00*M00+(625.0/6048.0)*M01*Jinv00*Jinv11+(625.0/6048.0)*Jinv10*Jinv01*M01+(625.0/6048.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/6048.0)*M10*Jinv00*Jinv11+(625.0/3024.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[33][6]=(0.0)*D;
  A[33][7]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(625.0/18144.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(625.0/18144.0)*Jinv10*M10*Jinv00-(625.0/4536.0)*Jinv01*Jinv00*M00-(625.0/9072.0)*M01*Jinv00*Jinv11-(625.0/9072.0)*Jinv10*Jinv01*M01-(625.0/9072.0)*Jinv10*M10*Jinv01+(625.0/18144.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11-(625.0/9072.0)*M10*Jinv00*Jinv11-(625.0/4536.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(625.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[33][8]=(0.0)*D;
  A[33][9]=(-(6875.0/48384.0)*(Jinv10*Jinv10)*M11-(6875.0/48384.0)*Jinv10*M10*Jinv00+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*(Jinv00*Jinv00)*M00+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[33][10]=(0.0)*D;
  A[33][11]=((15625.0/145152.0)*(Jinv10*Jinv10)*M11+(15625.0/145152.0)*Jinv10*M10*Jinv00+(15625.0/145152.0)*(Jinv00*Jinv00)*M00+(15625.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[33][12]=(0.0)*D;
  A[33][13]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(625.0/1344.0)*M10*Jinv01*Jinv11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(105625.0/72576.0)*Jinv01*Jinv00*M00-(105625.0/145152.0)*M01*Jinv00*Jinv11-(105625.0/145152.0)*Jinv10*Jinv01*M01-(105625.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(625.0/1344.0)*Jinv01*M01*Jinv11-(105625.0/145152.0)*M10*Jinv00*Jinv11-(105625.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][14]=(0.0)*D;
  A[33][15]=((3125.0/1134.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/1134.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00+(3125.0/1134.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(3125.0/2268.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/1134.0)*Jinv01*M01*Jinv11+(3125.0/2268.0)*M10*Jinv00*Jinv11+(3125.0/1134.0)*Jinv10*Jinv11*M11+(3125.0/1134.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[33][16]=(0.0)*D;
  A[33][17]=((34375.0/24192.0)*(Jinv01*Jinv01)*M00-(3125.0/36288.0)*(Jinv10*Jinv10)*M11+(34375.0/24192.0)*M10*Jinv01*Jinv11-(3125.0/36288.0)*Jinv10*M10*Jinv00-(3125.0/36288.0)*Jinv01*Jinv00*M00-(3125.0/72576.0)*M01*Jinv00*Jinv11-(3125.0/72576.0)*Jinv10*Jinv01*M01-(3125.0/72576.0)*Jinv10*M10*Jinv01-(3125.0/36288.0)*(Jinv00*Jinv00)*M00+(34375.0/24192.0)*Jinv01*M01*Jinv11-(3125.0/72576.0)*M10*Jinv00*Jinv11-(3125.0/36288.0)*Jinv10*Jinv11*M11+(34375.0/24192.0)*(Jinv11*Jinv11)*M11-(3125.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[33][18]=(0.0)*D;
  A[33][19]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/3024.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/3024.0)*Jinv10*M10*Jinv00-(3125.0/4536.0)*Jinv01*Jinv00*M00-(3125.0/9072.0)*M01*Jinv00*Jinv11-(3125.0/9072.0)*Jinv10*Jinv01*M01-(3125.0/9072.0)*Jinv10*M10*Jinv01+(3125.0/3024.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11-(3125.0/9072.0)*M10*Jinv00*Jinv11-(3125.0/4536.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/3024.0)*Jinv10*M01*Jinv00)*D;
  A[33][20]=(0.0)*D;
  A[33][21]=(-(71875.0/72576.0)*(Jinv10*Jinv10)*M11-(71875.0/72576.0)*Jinv10*M10*Jinv00-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*(Jinv00*Jinv00)*M00-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][22]=(0.0)*D;
  A[33][23]=((49375.0/72576.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11+(49375.0/72576.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(116875.0/36288.0)*Jinv01*Jinv00*M00+(116875.0/72576.0)*M01*Jinv00*Jinv11+(116875.0/72576.0)*Jinv10*Jinv01*M01+(116875.0/72576.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00+(49375.0/72576.0)*Jinv01*M01*Jinv11+(116875.0/72576.0)*M10*Jinv00*Jinv11+(116875.0/36288.0)*Jinv10*Jinv11*M11+(49375.0/72576.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][24]=(0.0)*D;
  A[33][25]=(-(21875.0/3456.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(21875.0/3456.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00-(59375.0/9072.0)*Jinv01*Jinv00*M00-(59375.0/18144.0)*M01*Jinv00*Jinv11-(59375.0/18144.0)*Jinv10*Jinv01*M01-(59375.0/18144.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(21875.0/3456.0)*Jinv01*M01*Jinv11-(59375.0/18144.0)*M10*Jinv00*Jinv11-(59375.0/9072.0)*Jinv10*Jinv11*M11-(21875.0/3456.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][26]=(0.0)*D;
  A[33][27]=(-(3125.0/1728.0)*(Jinv01*Jinv01)*M00-(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/1728.0)*M10*Jinv01*Jinv11-(146875.0/72576.0)*Jinv10*M10*Jinv00+(90625.0/36288.0)*Jinv01*Jinv00*M00+(90625.0/72576.0)*M01*Jinv00*Jinv11+(90625.0/72576.0)*Jinv10*Jinv01*M01+(90625.0/72576.0)*Jinv10*M10*Jinv01-(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/1728.0)*Jinv01*M01*Jinv11+(90625.0/72576.0)*M10*Jinv00*Jinv11+(90625.0/36288.0)*Jinv10*Jinv11*M11-(3125.0/1728.0)*(Jinv11*Jinv11)*M11-(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][28]=(0.0)*D;
  A[33][29]=(-(3125.0/6048.0)*(Jinv01*Jinv01)*M00+(146875.0/72576.0)*(Jinv10*Jinv10)*M11-(3125.0/6048.0)*M10*Jinv01*Jinv11+(146875.0/72576.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01+(146875.0/72576.0)*(Jinv00*Jinv00)*M00-(3125.0/6048.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11-(3125.0/6048.0)*(Jinv11*Jinv11)*M11+(146875.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[33][30]=(0.0)*D;
  A[33][31]=(-(44375.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11-(44375.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(6875.0/1296.0)*Jinv01*Jinv00*M00-(6875.0/2592.0)*M01*Jinv00*Jinv11-(6875.0/2592.0)*Jinv10*Jinv01*M01-(6875.0/2592.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00-(44375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/2592.0)*M10*Jinv00*Jinv11-(6875.0/1296.0)*Jinv10*Jinv11*M11-(44375.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[33][32]=(0.0)*D;
  A[33][33]=((128125.0/18144.0)*(Jinv01*Jinv01)*M00+(71875.0/9072.0)*(Jinv10*Jinv10)*M11+(128125.0/18144.0)*M10*Jinv01*Jinv11+(71875.0/9072.0)*Jinv10*M10*Jinv00+(71875.0/9072.0)*Jinv01*Jinv00*M00+(71875.0/18144.0)*M01*Jinv00*Jinv11+(71875.0/18144.0)*Jinv10*Jinv01*M01+(71875.0/18144.0)*Jinv10*M10*Jinv01+(71875.0/9072.0)*(Jinv00*Jinv00)*M00+(128125.0/18144.0)*Jinv01*M01*Jinv11+(71875.0/18144.0)*M10*Jinv00*Jinv11+(71875.0/9072.0)*Jinv10*Jinv11*M11+(128125.0/18144.0)*(Jinv11*Jinv11)*M11+(71875.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[33][34]=(0.0)*D;
  A[33][35]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[33][36]=(0.0)*D;
  A[33][37]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*M10*Jinv01*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*Jinv01*M01*Jinv11+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11)*D;
  A[33][38]=(0.0)*D;
  A[33][39]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*M10*Jinv01*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*Jinv01*M01*Jinv11-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[33][40]=(0.0)*D;
  A[33][41]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[34][0]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[34][1]=(0.0)*D;
  A[34][2]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[34][3]=(0.0)*D;
  A[34][4]=(-(14375.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/48384.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[34][5]=(0.0)*D;
  A[34][6]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[34][7]=(0.0)*D;
  A[34][8]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[34][9]=(0.0)*D;
  A[34][10]=(-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv10*M10*Jinv00+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*M01*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[34][11]=(0.0)*D;
  A[34][12]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(8125.0/72576.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[34][13]=(0.0)*D;
  A[34][14]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[34][15]=(0.0)*D;
  A[34][16]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[34][17]=(0.0)*D;
  A[34][18]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[34][19]=(0.0)*D;
  A[34][20]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00-(625.0/1296.0)*M01*Jinv00*Jinv11+(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/1296.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/2688.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[34][21]=(0.0)*D;
  A[34][22]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[34][23]=(0.0)*D;
  A[34][24]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[34][25]=(0.0)*D;
  A[34][26]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[34][27]=(0.0)*D;
  A[34][28]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00+(625.0/1792.0)*Jinv01*Jinv00*M00+(203125.0/290304.0)*M01*Jinv00*Jinv11-(101875.0/290304.0)*Jinv10*Jinv01*M01+(203125.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(101875.0/290304.0)*M10*Jinv00*Jinv11+(625.0/1792.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[34][29]=(0.0)*D;
  A[34][30]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(19375.0/72576.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[34][31]=(0.0)*D;
  A[34][32]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[34][33]=(0.0)*D;
  A[34][34]=((10625.0/3456.0)*(Jinv01*Jinv01)*M00+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M10*Jinv01*Jinv11+(89375.0/24192.0)*Jinv10*M10*Jinv00+(8125.0/3456.0)*Jinv01*Jinv00*M00+(8125.0/6912.0)*M01*Jinv00*Jinv11+(8125.0/6912.0)*Jinv10*Jinv01*M01+(8125.0/6912.0)*Jinv10*M10*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(10625.0/3456.0)*Jinv01*M01*Jinv11+(8125.0/6912.0)*M10*Jinv00*Jinv11+(8125.0/3456.0)*Jinv10*Jinv11*M11+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[34][35]=(0.0)*D;
  A[34][36]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[34][37]=(0.0)*D;
  A[34][38]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00-(25625.0/48384.0)*M01*Jinv00*Jinv11+(115625.0/145152.0)*Jinv10*Jinv01*M01-(25625.0/48384.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11+(115625.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[34][39]=(0.0)*D;
  A[34][40]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*M10*Jinv01*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv01*M01*Jinv11-(6325.0/10368.0)*M10*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11)*D;
  A[34][41]=(0.0)*D;
  A[35][0]=(0.0)*D;
  A[35][1]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*(Jinv10*Jinv10)*M11-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv10*M10*Jinv00-(175.0/2304.0)*Jinv01*Jinv00*M00-(175.0/4608.0)*M01*Jinv00*Jinv11-(175.0/4608.0)*Jinv10*Jinv01*M01-(175.0/4608.0)*Jinv10*M10*Jinv01-(175.0/4608.0)*(Jinv00*Jinv00)*M00-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*M10*Jinv00*Jinv11-(175.0/2304.0)*Jinv10*Jinv11*M11-(175.0/4608.0)*(Jinv11*Jinv11)*M11-(175.0/4608.0)*Jinv10*M01*Jinv00)*D;
  A[35][2]=(0.0)*D;
  A[35][3]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11+(38125.0/290304.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00+(29375.0/145152.0)*Jinv01*Jinv00*M00+(29375.0/290304.0)*M01*Jinv00*Jinv11+(29375.0/290304.0)*Jinv10*Jinv01*M01+(29375.0/290304.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00+(38125.0/290304.0)*Jinv01*M01*Jinv11+(29375.0/290304.0)*M10*Jinv00*Jinv11+(29375.0/145152.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[35][4]=(0.0)*D;
  A[35][5]=(-(14375.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(14375.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(14375.0/48384.0)*Jinv01*Jinv00*M00-(14375.0/96768.0)*M01*Jinv00*Jinv11-(14375.0/96768.0)*Jinv10*Jinv01*M01-(14375.0/96768.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(14375.0/48384.0)*Jinv01*M01*Jinv11-(14375.0/96768.0)*M10*Jinv00*Jinv11-(14375.0/48384.0)*Jinv10*Jinv11*M11-(14375.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[35][6]=(0.0)*D;
  A[35][7]=(-(10625.0/48384.0)*(Jinv01*Jinv01)*M00-(625.0/36288.0)*(Jinv10*Jinv10)*M11-(10625.0/48384.0)*M10*Jinv01*Jinv11-(625.0/36288.0)*Jinv10*M10*Jinv00-(18125.0/145152.0)*Jinv01*Jinv00*M00-(18125.0/290304.0)*M01*Jinv00*Jinv11-(18125.0/290304.0)*Jinv10*Jinv01*M01-(18125.0/290304.0)*Jinv10*M10*Jinv01-(625.0/36288.0)*(Jinv00*Jinv00)*M00-(10625.0/48384.0)*Jinv01*M01*Jinv11-(18125.0/290304.0)*M10*Jinv00*Jinv11-(18125.0/145152.0)*Jinv10*Jinv11*M11-(10625.0/48384.0)*(Jinv11*Jinv11)*M11-(625.0/36288.0)*Jinv10*M01*Jinv00)*D;
  A[35][8]=(0.0)*D;
  A[35][9]=(-(8125.0/9072.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*(Jinv10*Jinv10)*M11-(8125.0/9072.0)*M10*Jinv01*Jinv11+(6875.0/96768.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*(Jinv00*Jinv00)*M00-(8125.0/9072.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11-(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(6875.0/96768.0)*Jinv10*M01*Jinv00)*D;
  A[35][10]=(0.0)*D;
  A[35][11]=(-(20225.0/290304.0)*(Jinv10*Jinv10)*M11-(20225.0/290304.0)*Jinv10*M10*Jinv00+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*M01*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*(Jinv00*Jinv00)*M00+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*Jinv10*M01*Jinv00)*D;
  A[35][12]=(0.0)*D;
  A[35][13]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*(Jinv10*Jinv10)*M11+(8125.0/72576.0)*M10*Jinv01*Jinv11+(3125.0/18144.0)*Jinv10*M10*Jinv00+(6875.0/24192.0)*Jinv01*Jinv00*M00+(6875.0/48384.0)*M01*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv01*M01+(6875.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*(Jinv00*Jinv00)*M00+(8125.0/72576.0)*Jinv01*M01*Jinv11+(6875.0/48384.0)*M10*Jinv00*Jinv11+(6875.0/24192.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11+(3125.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[35][14]=(0.0)*D;
  A[35][15]=(-(3125.0/9072.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11-(3125.0/9072.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00-(8125.0/9072.0)*Jinv01*Jinv00*M00-(8125.0/18144.0)*M01*Jinv00*Jinv11-(8125.0/18144.0)*Jinv10*Jinv01*M01-(8125.0/18144.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00-(3125.0/9072.0)*Jinv01*M01*Jinv11-(8125.0/18144.0)*M10*Jinv00*Jinv11-(8125.0/9072.0)*Jinv10*Jinv11*M11-(3125.0/9072.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[35][16]=(0.0)*D;
  A[35][17]=((3125.0/3024.0)*(Jinv01*Jinv01)*M00+(3125.0/72576.0)*(Jinv10*Jinv10)*M11+(3125.0/3024.0)*M10*Jinv01*Jinv11+(3125.0/72576.0)*Jinv10*M10*Jinv00+(18125.0/24192.0)*Jinv01*Jinv00*M00+(18125.0/48384.0)*M01*Jinv00*Jinv11+(18125.0/48384.0)*Jinv10*Jinv01*M01+(18125.0/48384.0)*Jinv10*M10*Jinv01+(3125.0/72576.0)*(Jinv00*Jinv00)*M00+(3125.0/3024.0)*Jinv01*M01*Jinv11+(18125.0/48384.0)*M10*Jinv00*Jinv11+(18125.0/24192.0)*Jinv10*Jinv11*M11+(3125.0/3024.0)*(Jinv11*Jinv11)*M11+(3125.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[35][18]=(0.0)*D;
  A[35][19]=((146875.0/72576.0)*(Jinv01*Jinv01)*M00-(3125.0/6048.0)*(Jinv10*Jinv10)*M11+(146875.0/72576.0)*M10*Jinv01*Jinv11-(3125.0/6048.0)*Jinv10*M10*Jinv00+(625.0/756.0)*Jinv01*Jinv00*M00+(625.0/1512.0)*M01*Jinv00*Jinv11+(625.0/1512.0)*Jinv10*Jinv01*M01+(625.0/1512.0)*Jinv10*M10*Jinv01-(3125.0/6048.0)*(Jinv00*Jinv00)*M00+(146875.0/72576.0)*Jinv01*M01*Jinv11+(625.0/1512.0)*M10*Jinv00*Jinv11+(625.0/756.0)*Jinv10*Jinv11*M11+(146875.0/72576.0)*(Jinv11*Jinv11)*M11-(3125.0/6048.0)*Jinv10*M01*Jinv00)*D;
  A[35][20]=(0.0)*D;
  A[35][21]=((8125.0/9072.0)*(Jinv01*Jinv01)*M00+(59375.0/72576.0)*(Jinv10*Jinv10)*M11+(8125.0/9072.0)*M10*Jinv01*Jinv11+(59375.0/72576.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00-(625.0/1296.0)*M01*Jinv00*Jinv11+(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/1296.0)*Jinv10*M10*Jinv01+(59375.0/72576.0)*(Jinv00*Jinv00)*M00+(8125.0/9072.0)*Jinv01*M01*Jinv11+(625.0/2688.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(8125.0/9072.0)*(Jinv11*Jinv11)*M11+(59375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[35][22]=(0.0)*D;
  A[35][23]=(-(8125.0/72576.0)*(Jinv01*Jinv01)*M00-(10625.0/48384.0)*(Jinv10*Jinv10)*M11-(8125.0/72576.0)*M10*Jinv01*Jinv11-(10625.0/48384.0)*Jinv10*M10*Jinv00-(45625.0/145152.0)*Jinv01*Jinv00*M00-(45625.0/290304.0)*M01*Jinv00*Jinv11-(45625.0/290304.0)*Jinv10*Jinv01*M01-(45625.0/290304.0)*Jinv10*M10*Jinv01-(10625.0/48384.0)*(Jinv00*Jinv00)*M00-(8125.0/72576.0)*Jinv01*M01*Jinv11-(45625.0/290304.0)*M10*Jinv00*Jinv11-(45625.0/145152.0)*Jinv10*Jinv11*M11-(8125.0/72576.0)*(Jinv11*Jinv11)*M11-(10625.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[35][24]=(0.0)*D;
  A[35][25]=((3125.0/8064.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11+(3125.0/8064.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00+(11875.0/6912.0)*Jinv01*Jinv00*M00+(11875.0/13824.0)*M01*Jinv00*Jinv11+(11875.0/13824.0)*Jinv10*Jinv01*M01+(11875.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00+(3125.0/8064.0)*Jinv01*M01*Jinv11+(11875.0/13824.0)*M10*Jinv00*Jinv11+(11875.0/6912.0)*Jinv10*Jinv11*M11+(3125.0/8064.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[35][26]=(0.0)*D;
  A[35][27]=(-(184375.0/48384.0)*(Jinv01*Jinv01)*M00+(146875.0/145152.0)*(Jinv10*Jinv10)*M11-(184375.0/48384.0)*M10*Jinv01*Jinv11+(146875.0/145152.0)*Jinv10*M10*Jinv00-(19375.0/6912.0)*Jinv01*Jinv00*M00-(19375.0/13824.0)*M01*Jinv00*Jinv11-(19375.0/13824.0)*Jinv10*Jinv01*M01-(19375.0/13824.0)*Jinv10*M10*Jinv01+(146875.0/145152.0)*(Jinv00*Jinv00)*M00-(184375.0/48384.0)*Jinv01*M01*Jinv11-(19375.0/13824.0)*M10*Jinv00*Jinv11-(19375.0/6912.0)*Jinv10*Jinv11*M11-(184375.0/48384.0)*(Jinv11*Jinv11)*M11+(146875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[35][28]=(0.0)*D;
  A[35][29]=(-(261875.0/145152.0)*(Jinv01*Jinv01)*M00-(261875.0/145152.0)*(Jinv10*Jinv10)*M11-(261875.0/145152.0)*M10*Jinv01*Jinv11-(261875.0/145152.0)*Jinv10*M10*Jinv00+(625.0/1792.0)*Jinv01*Jinv00*M00+(203125.0/290304.0)*M01*Jinv00*Jinv11-(101875.0/290304.0)*Jinv10*Jinv01*M01+(203125.0/290304.0)*Jinv10*M10*Jinv01-(261875.0/145152.0)*(Jinv00*Jinv00)*M00-(261875.0/145152.0)*Jinv01*M01*Jinv11-(101875.0/290304.0)*M10*Jinv00*Jinv11+(625.0/1792.0)*Jinv10*Jinv11*M11-(261875.0/145152.0)*(Jinv11*Jinv11)*M11-(261875.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[35][30]=(0.0)*D;
  A[35][31]=((625.0/6048.0)*(Jinv01*Jinv01)*M00+(19375.0/72576.0)*(Jinv10*Jinv10)*M11+(625.0/6048.0)*M10*Jinv01*Jinv11+(19375.0/72576.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(19375.0/145152.0)*M01*Jinv00*Jinv11+(19375.0/145152.0)*Jinv10*Jinv01*M01+(19375.0/145152.0)*Jinv10*M10*Jinv01+(19375.0/72576.0)*(Jinv00*Jinv00)*M00+(625.0/6048.0)*Jinv01*M01*Jinv11+(19375.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11+(625.0/6048.0)*(Jinv11*Jinv11)*M11+(19375.0/72576.0)*Jinv10*M01*Jinv00)*D;
  A[35][32]=(0.0)*D;
  A[35][33]=((53125.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/18144.0)*(Jinv10*Jinv10)*M11+(53125.0/72576.0)*M10*Jinv01*Jinv11-(71875.0/18144.0)*Jinv10*M10*Jinv00-(11875.0/4536.0)*Jinv01*Jinv00*M00-(11875.0/9072.0)*M01*Jinv00*Jinv11-(11875.0/9072.0)*Jinv10*Jinv01*M01-(11875.0/9072.0)*Jinv10*M10*Jinv01-(71875.0/18144.0)*(Jinv00*Jinv00)*M00+(53125.0/72576.0)*Jinv01*M01*Jinv11-(11875.0/9072.0)*M10*Jinv00*Jinv11-(11875.0/4536.0)*Jinv10*Jinv11*M11+(53125.0/72576.0)*(Jinv11*Jinv11)*M11-(71875.0/18144.0)*Jinv10*M01*Jinv00)*D;
  A[35][34]=(0.0)*D;
  A[35][35]=((10625.0/3456.0)*(Jinv01*Jinv01)*M00+(89375.0/24192.0)*(Jinv10*Jinv10)*M11+(10625.0/3456.0)*M10*Jinv01*Jinv11+(89375.0/24192.0)*Jinv10*M10*Jinv00+(8125.0/3456.0)*Jinv01*Jinv00*M00+(8125.0/6912.0)*M01*Jinv00*Jinv11+(8125.0/6912.0)*Jinv10*Jinv01*M01+(8125.0/6912.0)*Jinv10*M10*Jinv01+(89375.0/24192.0)*(Jinv00*Jinv00)*M00+(10625.0/3456.0)*Jinv01*M01*Jinv11+(8125.0/6912.0)*M10*Jinv00*Jinv11+(8125.0/3456.0)*Jinv10*Jinv11*M11+(10625.0/3456.0)*(Jinv11*Jinv11)*M11+(89375.0/24192.0)*Jinv10*M01*Jinv00)*D;
  A[35][36]=(0.0)*D;
  A[35][37]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[35][38]=(0.0)*D;
  A[35][39]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00-(25625.0/48384.0)*M01*Jinv00*Jinv11+(115625.0/145152.0)*Jinv10*Jinv01*M01-(25625.0/48384.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11+(115625.0/145152.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[35][40]=(0.0)*D;
  A[35][41]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*M10*Jinv01*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*Jinv10*Jinv01*M01-(575.0/36288.0)*Jinv01*M01*Jinv11-(6325.0/10368.0)*M10*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][0]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1975.0/48384.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(29375.0/145152.0)*M01*Jinv00*Jinv11+(1975.0/48384.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1975.0/48384.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[36][1]=(0.0)*D;
  A[36][2]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][3]=(0.0)*D;
  A[36][4]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][5]=(0.0)*D;
  A[36][6]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][7]=(0.0)*D;
  A[36][8]=(-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11)*D;
  A[36][9]=(0.0)*D;
  A[36][10]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[36][11]=(0.0)*D;
  A[36][12]=(-(68125.0/72576.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(194375.0/290304.0)*M01*Jinv00*Jinv11-(78125.0/290304.0)*Jinv10*Jinv01*M01-(194375.0/290304.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(68125.0/72576.0)*Jinv01*M01*Jinv11-(78125.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[36][13]=(0.0)*D;
  A[36][14]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][15]=(0.0)*D;
  A[36][16]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*M10*Jinv01*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*Jinv01*M01*Jinv11+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][17]=(0.0)*D;
  A[36][18]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][19]=(0.0)*D;
  A[36][20]=((49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[36][21]=(0.0)*D;
  A[36][22]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(6875.0/10368.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(6875.0/10368.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[36][23]=(0.0)*D;
  A[36][24]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][25]=(0.0)*D;
  A[36][26]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][27]=(0.0)*D;
  A[36][28]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[36][29]=(0.0)*D;
  A[36][30]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(318125.0/145152.0)*M01*Jinv00*Jinv11-(41875.0/48384.0)*Jinv10*Jinv01*M01-(318125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(41875.0/48384.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[36][31]=(0.0)*D;
  A[36][32]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*M10*Jinv01*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*Jinv01*M01*Jinv11+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][33]=(0.0)*D;
  A[36][34]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[36][35]=(0.0)*D;
  A[36][36]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(53125.0/20736.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[36][37]=(0.0)*D;
  A[36][38]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(53125.0/20736.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[36][39]=(0.0)*D;
  A[36][40]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*M10*Jinv01*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv01*M01*Jinv11-(123425.0/145152.0)*M10*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11)*D;
  A[36][41]=(0.0)*D;
  A[37][0]=(0.0)*D;
  A[37][1]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*(Jinv10*Jinv10)*M11+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1975.0/48384.0)*Jinv10*M10*Jinv00+(8825.0/36288.0)*Jinv01*Jinv00*M00+(29375.0/145152.0)*M01*Jinv00*Jinv11+(1975.0/48384.0)*Jinv10*Jinv01*M01+(29375.0/145152.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1975.0/48384.0)*M10*Jinv00*Jinv11+(8825.0/36288.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[37][2]=(0.0)*D;
  A[37][3]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(14375.0/72576.0)*M10*Jinv01*Jinv11-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01+(14375.0/72576.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][4]=(0.0)*D;
  A[37][5]=((8125.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/72576.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(8125.0/72576.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(8125.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][6]=(0.0)*D;
  A[37][7]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00+(6875.0/96768.0)*M10*Jinv01*Jinv11-(625.0/10368.0)*Jinv01*Jinv00*M00-(625.0/20736.0)*M01*Jinv00*Jinv11-(625.0/20736.0)*Jinv10*Jinv01*M01-(625.0/20736.0)*Jinv10*M10*Jinv01+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/20736.0)*M10*Jinv00*Jinv11-(625.0/10368.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][8]=(0.0)*D;
  A[37][9]=(-(6875.0/48384.0)*Jinv01*Jinv00*M00-(6875.0/96768.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01-(6875.0/96768.0)*Jinv10*M10*Jinv01-(6875.0/96768.0)*M10*Jinv00*Jinv11-(6875.0/48384.0)*Jinv10*Jinv11*M11)*D;
  A[37][10]=(0.0)*D;
  A[37][11]=(-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[37][12]=(0.0)*D;
  A[37][13]=(-(68125.0/72576.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(68125.0/72576.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00-(68125.0/72576.0)*Jinv01*Jinv00*M00-(194375.0/290304.0)*M01*Jinv00*Jinv11-(78125.0/290304.0)*Jinv10*Jinv01*M01-(194375.0/290304.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(68125.0/72576.0)*Jinv01*M01*Jinv11-(78125.0/290304.0)*M10*Jinv00*Jinv11-(68125.0/72576.0)*Jinv10*Jinv11*M11-(68125.0/72576.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[37][14]=(0.0)*D;
  A[37][15]=(-(625.0/1344.0)*(Jinv01*Jinv01)*M00-(625.0/1344.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/1344.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(625.0/1344.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][16]=(0.0)*D;
  A[37][17]=(-(79375.0/290304.0)*(Jinv01*Jinv01)*M00-(79375.0/290304.0)*M10*Jinv01*Jinv11+(10625.0/72576.0)*Jinv01*Jinv00*M00+(10625.0/145152.0)*M01*Jinv00*Jinv11+(10625.0/145152.0)*Jinv10*Jinv01*M01+(10625.0/145152.0)*Jinv10*M10*Jinv01-(79375.0/290304.0)*Jinv01*M01*Jinv11+(10625.0/145152.0)*M10*Jinv00*Jinv11+(10625.0/72576.0)*Jinv10*Jinv11*M11-(79375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][18]=(0.0)*D;
  A[37][19]=(-(6875.0/48384.0)*(Jinv01*Jinv01)*M00-(6875.0/48384.0)*M10*Jinv01*Jinv11+(38125.0/72576.0)*Jinv01*Jinv00*M00+(38125.0/145152.0)*M01*Jinv00*Jinv11+(38125.0/145152.0)*Jinv10*Jinv01*M01+(38125.0/145152.0)*Jinv10*M10*Jinv01-(6875.0/48384.0)*Jinv01*M01*Jinv11+(38125.0/145152.0)*M10*Jinv00*Jinv11+(38125.0/72576.0)*Jinv10*Jinv11*M11-(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][20]=(0.0)*D;
  A[37][21]=((49375.0/145152.0)*(Jinv10*Jinv10)*M11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[37][22]=(0.0)*D;
  A[37][23]=((11875.0/6048.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(11875.0/6048.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00+(49375.0/24192.0)*Jinv01*Jinv00*M00+(3125.0/2268.0)*M01*Jinv00*Jinv11+(6875.0/10368.0)*Jinv10*Jinv01*M01+(3125.0/2268.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(11875.0/6048.0)*Jinv01*M01*Jinv11+(6875.0/10368.0)*M10*Jinv00*Jinv11+(49375.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/6048.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[37][24]=(0.0)*D;
  A[37][25]=((14375.0/290304.0)*(Jinv01*Jinv01)*M00+(14375.0/290304.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(14375.0/290304.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][26]=(0.0)*D;
  A[37][27]=((4375.0/20736.0)*(Jinv01*Jinv01)*M00+(4375.0/20736.0)*M10*Jinv01*Jinv11-(11875.0/10368.0)*Jinv01*Jinv00*M00-(11875.0/20736.0)*M01*Jinv00*Jinv11-(11875.0/20736.0)*Jinv10*Jinv01*M01-(11875.0/20736.0)*Jinv10*M10*Jinv01+(4375.0/20736.0)*Jinv01*M01*Jinv11-(11875.0/20736.0)*M10*Jinv00*Jinv11-(11875.0/10368.0)*Jinv10*Jinv11*M11+(4375.0/20736.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][28]=(0.0)*D;
  A[37][29]=((6875.0/96768.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(6875.0/96768.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(625.0/1344.0)*Jinv01*Jinv00*M00-(625.0/2688.0)*M01*Jinv00*Jinv11-(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/2688.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(6875.0/96768.0)*Jinv01*M01*Jinv11-(625.0/2688.0)*M10*Jinv00*Jinv11-(625.0/1344.0)*Jinv10*Jinv11*M11+(6875.0/96768.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[37][30]=(0.0)*D;
  A[37][31]=(-(745625.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(745625.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00-(221875.0/72576.0)*Jinv01*Jinv00*M00-(318125.0/145152.0)*M01*Jinv00*Jinv11-(41875.0/48384.0)*Jinv10*Jinv01*M01-(318125.0/145152.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(745625.0/290304.0)*Jinv01*M01*Jinv11-(41875.0/48384.0)*M10*Jinv00*Jinv11-(221875.0/72576.0)*Jinv10*Jinv11*M11-(745625.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[37][32]=(0.0)*D;
  A[37][33]=((8125.0/16128.0)*(Jinv01*Jinv01)*M00+(8125.0/16128.0)*M10*Jinv01*Jinv11+(120625.0/36288.0)*Jinv01*Jinv00*M00+(120625.0/72576.0)*M01*Jinv00*Jinv11+(120625.0/72576.0)*Jinv10*Jinv01*M01+(120625.0/72576.0)*Jinv10*M10*Jinv01+(8125.0/16128.0)*Jinv01*M01*Jinv11+(120625.0/72576.0)*M10*Jinv00*Jinv11+(120625.0/36288.0)*Jinv10*Jinv11*M11+(8125.0/16128.0)*(Jinv11*Jinv11)*M11)*D;
  A[37][34]=(0.0)*D;
  A[37][35]=(-(14375.0/290304.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11-(14375.0/290304.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(25625.0/24192.0)*Jinv01*Jinv00*M00+(25625.0/48384.0)*M01*Jinv00*Jinv11+(25625.0/48384.0)*Jinv10*Jinv01*M01+(25625.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00-(14375.0/290304.0)*Jinv01*M01*Jinv11+(25625.0/48384.0)*M10*Jinv00*Jinv11+(25625.0/24192.0)*Jinv10*Jinv11*M11-(14375.0/290304.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[37][36]=(0.0)*D;
  A[37][37]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(53125.0/20736.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[37][38]=(0.0)*D;
  A[37][39]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(53125.0/20736.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[37][40]=(0.0)*D;
  A[37][41]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*M10*Jinv01*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*Jinv10*Jinv01*M01-(26875.0/41472.0)*Jinv01*M01*Jinv11-(123425.0/145152.0)*M10*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][0]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[38][1]=(0.0)*D;
  A[38][2]=((6875.0/48384.0)*(Jinv01*Jinv01)*M00+(6875.0/48384.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][3]=(0.0)*D;
  A[38][4]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][5]=(0.0)*D;
  A[38][6]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][7]=(0.0)*D;
  A[38][8]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][9]=(0.0)*D;
  A[38][10]=((1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv10*M10*Jinv00-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*M01*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[38][11]=(0.0)*D;
  A[38][12]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(14375.0/72576.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[38][13]=(0.0)*D;
  A[38][14]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][15]=(0.0)*D;
  A[38][16]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*M10*Jinv01*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*Jinv01*M01*Jinv11-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][17]=(0.0)*D;
  A[38][18]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][19]=(0.0)*D;
  A[38][20]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00+(3125.0/12096.0)*Jinv01*Jinv00*M00+(10625.0/32256.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01+(10625.0/32256.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11+(3125.0/12096.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[38][21]=(0.0)*D;
  A[38][22]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[38][23]=(0.0)*D;
  A[38][24]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][25]=(0.0)*D;
  A[38][26]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][27]=(0.0)*D;
  A[38][28]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00-(625.0/1296.0)*M01*Jinv00*Jinv11+(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/1296.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(625.0/2688.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[38][29]=(0.0)*D;
  A[38][30]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[38][31]=(0.0)*D;
  A[38][32]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*M10*Jinv01*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*Jinv01*M01*Jinv11-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][33]=(0.0)*D;
  A[38][34]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(115625.0/145152.0)*M01*Jinv00*Jinv11-(25625.0/48384.0)*Jinv10*Jinv01*M01+(115625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(25625.0/48384.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[38][35]=(0.0)*D;
  A[38][36]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(53125.0/20736.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[38][37]=(0.0)*D;
  A[38][38]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(53125.0/20736.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[38][39]=(0.0)*D;
  A[38][40]=((725.0/3584.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*M10*Jinv01*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv01*M01*Jinv11+(123425.0/145152.0)*M10*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11)*D;
  A[38][41]=(0.0)*D;
  A[39][0]=(0.0)*D;
  A[39][1]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*(Jinv10*Jinv10)*M11-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv10*M10*Jinv00-(1975.0/24192.0)*Jinv01*Jinv00*M00-(1975.0/48384.0)*M01*Jinv00*Jinv11-(1975.0/48384.0)*Jinv10*Jinv01*M01-(1975.0/48384.0)*Jinv10*M10*Jinv01-(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*M10*Jinv00*Jinv11-(1975.0/24192.0)*Jinv10*Jinv11*M11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11-(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[39][2]=(0.0)*D;
  A[39][3]=((6875.0/48384.0)*(Jinv01*Jinv01)*M00+(6875.0/48384.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(6875.0/48384.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(6875.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][4]=(0.0)*D;
  A[39][5]=((38125.0/290304.0)*(Jinv01*Jinv01)*M00+(38125.0/290304.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(38125.0/290304.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(38125.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][6]=(0.0)*D;
  A[39][7]=((3125.0/18144.0)*(Jinv01*Jinv01)*M00+(3125.0/18144.0)*M10*Jinv01*Jinv11+(625.0/10368.0)*Jinv01*Jinv00*M00+(625.0/20736.0)*M01*Jinv00*Jinv11+(625.0/20736.0)*Jinv10*Jinv01*M01+(625.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/18144.0)*Jinv01*M01*Jinv11+(625.0/20736.0)*M10*Jinv00*Jinv11+(625.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/18144.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][8]=(0.0)*D;
  A[39][9]=((49375.0/145152.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*M10*Jinv01*Jinv11+(6875.0/48384.0)*Jinv01*Jinv00*M00+(6875.0/96768.0)*M01*Jinv00*Jinv11+(6875.0/96768.0)*Jinv10*Jinv01*M01+(6875.0/96768.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*Jinv01*M01*Jinv11+(6875.0/96768.0)*M10*Jinv00*Jinv11+(6875.0/48384.0)*Jinv10*Jinv11*M11+(49375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][10]=(0.0)*D;
  A[39][11]=((1975.0/48384.0)*(Jinv10*Jinv10)*M11+(1975.0/48384.0)*Jinv10*M10*Jinv00-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*M01*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*(Jinv00*Jinv00)*M00-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*Jinv10*M01*Jinv00)*D;
  A[39][12]=(0.0)*D;
  A[39][13]=((14375.0/72576.0)*(Jinv01*Jinv01)*M00+(49375.0/145152.0)*(Jinv10*Jinv10)*M11+(14375.0/72576.0)*M10*Jinv01*Jinv11+(49375.0/145152.0)*Jinv10*M10*Jinv00+(78125.0/145152.0)*Jinv01*Jinv00*M00+(78125.0/290304.0)*M01*Jinv00*Jinv11+(78125.0/290304.0)*Jinv10*Jinv01*M01+(78125.0/290304.0)*Jinv10*M10*Jinv01+(49375.0/145152.0)*(Jinv00*Jinv00)*M00+(14375.0/72576.0)*Jinv01*M01*Jinv11+(78125.0/290304.0)*M10*Jinv00*Jinv11+(78125.0/145152.0)*Jinv10*Jinv11*M11+(14375.0/72576.0)*(Jinv11*Jinv11)*M11+(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[39][14]=(0.0)*D;
  A[39][15]=(-(96875.0/145152.0)*(Jinv01*Jinv01)*M00-(96875.0/145152.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(96875.0/145152.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(96875.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][16]=(0.0)*D;
  A[39][17]=(-(40625.0/96768.0)*(Jinv01*Jinv01)*M00-(40625.0/96768.0)*M10*Jinv01*Jinv11-(10625.0/72576.0)*Jinv01*Jinv00*M00-(10625.0/145152.0)*M01*Jinv00*Jinv11-(10625.0/145152.0)*Jinv10*Jinv01*M01-(10625.0/145152.0)*Jinv10*M10*Jinv01-(40625.0/96768.0)*Jinv01*M01*Jinv11-(10625.0/145152.0)*M10*Jinv00*Jinv11-(10625.0/72576.0)*Jinv10*Jinv11*M11-(40625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][18]=(0.0)*D;
  A[39][19]=(-(71875.0/72576.0)*(Jinv01*Jinv01)*M00-(71875.0/72576.0)*M10*Jinv01*Jinv11-(38125.0/72576.0)*Jinv01*Jinv00*M00-(38125.0/145152.0)*M01*Jinv00*Jinv11-(38125.0/145152.0)*Jinv10*Jinv01*M01-(38125.0/145152.0)*Jinv10*M10*Jinv01-(71875.0/72576.0)*Jinv01*M01*Jinv11-(38125.0/145152.0)*M10*Jinv00*Jinv11-(38125.0/72576.0)*Jinv10*Jinv11*M11-(71875.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][20]=(0.0)*D;
  A[39][21]=(-(49375.0/145152.0)*(Jinv01*Jinv01)*M00-(49375.0/145152.0)*(Jinv10*Jinv10)*M11-(49375.0/145152.0)*M10*Jinv01*Jinv11-(49375.0/145152.0)*Jinv10*M10*Jinv00+(3125.0/12096.0)*Jinv01*Jinv00*M00+(10625.0/32256.0)*M01*Jinv00*Jinv11-(6875.0/96768.0)*Jinv10*Jinv01*M01+(10625.0/32256.0)*Jinv10*M10*Jinv01-(49375.0/145152.0)*(Jinv00*Jinv00)*M00-(49375.0/145152.0)*Jinv01*M01*Jinv11-(6875.0/96768.0)*M10*Jinv00*Jinv11+(3125.0/12096.0)*Jinv10*Jinv11*M11-(49375.0/145152.0)*(Jinv11*Jinv11)*M11-(49375.0/145152.0)*Jinv10*M01*Jinv00)*D;
  A[39][22]=(0.0)*D;
  A[39][23]=(-(104375.0/290304.0)*(Jinv01*Jinv01)*M00-(8125.0/9072.0)*(Jinv10*Jinv10)*M11-(104375.0/290304.0)*M10*Jinv01*Jinv11-(8125.0/9072.0)*Jinv10*M10*Jinv00-(6875.0/5184.0)*Jinv01*Jinv00*M00-(6875.0/10368.0)*M01*Jinv00*Jinv11-(6875.0/10368.0)*Jinv10*Jinv01*M01-(6875.0/10368.0)*Jinv10*M10*Jinv01-(8125.0/9072.0)*(Jinv00*Jinv00)*M00-(104375.0/290304.0)*Jinv01*M01*Jinv11-(6875.0/10368.0)*M10*Jinv00*Jinv11-(6875.0/5184.0)*Jinv10*Jinv11*M11-(104375.0/290304.0)*(Jinv11*Jinv11)*M11-(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[39][24]=(0.0)*D;
  A[39][25]=((3125.0/2304.0)*(Jinv01*Jinv01)*M00+(3125.0/2304.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(3125.0/2304.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(3125.0/2304.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][26]=(0.0)*D;
  A[39][27]=((115625.0/96768.0)*(Jinv01*Jinv01)*M00+(115625.0/96768.0)*M10*Jinv01*Jinv11+(11875.0/10368.0)*Jinv01*Jinv00*M00+(11875.0/20736.0)*M01*Jinv00*Jinv11+(11875.0/20736.0)*Jinv10*Jinv01*M01+(11875.0/20736.0)*Jinv10*M10*Jinv01+(115625.0/96768.0)*Jinv01*M01*Jinv11+(11875.0/20736.0)*M10*Jinv00*Jinv11+(11875.0/10368.0)*Jinv10*Jinv11*M11+(115625.0/96768.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][28]=(0.0)*D;
  A[39][29]=((59375.0/72576.0)*(Jinv01*Jinv01)*M00+(8125.0/9072.0)*(Jinv10*Jinv10)*M11+(59375.0/72576.0)*M10*Jinv01*Jinv11+(8125.0/9072.0)*Jinv10*M10*Jinv00-(18125.0/72576.0)*Jinv01*Jinv00*M00-(625.0/1296.0)*M01*Jinv00*Jinv11+(625.0/2688.0)*Jinv10*Jinv01*M01-(625.0/1296.0)*Jinv10*M10*Jinv01+(8125.0/9072.0)*(Jinv00*Jinv00)*M00+(59375.0/72576.0)*Jinv01*M01*Jinv11+(625.0/2688.0)*M10*Jinv00*Jinv11-(18125.0/72576.0)*Jinv10*Jinv11*M11+(59375.0/72576.0)*(Jinv11*Jinv11)*M11+(8125.0/9072.0)*Jinv10*M01*Jinv00)*D;
  A[39][30]=(0.0)*D;
  A[39][31]=((11875.0/41472.0)*(Jinv01*Jinv01)*M00+(625.0/448.0)*(Jinv10*Jinv10)*M11+(11875.0/41472.0)*M10*Jinv01*Jinv11+(625.0/448.0)*Jinv10*M10*Jinv00+(41875.0/24192.0)*Jinv01*Jinv00*M00+(41875.0/48384.0)*M01*Jinv00*Jinv11+(41875.0/48384.0)*Jinv10*Jinv01*M01+(41875.0/48384.0)*Jinv10*M10*Jinv01+(625.0/448.0)*(Jinv00*Jinv00)*M00+(11875.0/41472.0)*Jinv01*M01*Jinv11+(41875.0/48384.0)*M10*Jinv00*Jinv11+(41875.0/24192.0)*Jinv10*Jinv11*M11+(11875.0/41472.0)*(Jinv11*Jinv11)*M11+(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[39][32]=(0.0)*D;
  A[39][33]=(-(409375.0/145152.0)*(Jinv01*Jinv01)*M00-(409375.0/145152.0)*M10*Jinv01*Jinv11-(120625.0/36288.0)*Jinv01*Jinv00*M00-(120625.0/72576.0)*M01*Jinv00*Jinv11-(120625.0/72576.0)*Jinv10*Jinv01*M01-(120625.0/72576.0)*Jinv10*M10*Jinv01-(409375.0/145152.0)*Jinv01*M01*Jinv11-(120625.0/72576.0)*M10*Jinv00*Jinv11-(120625.0/36288.0)*Jinv10*Jinv11*M11-(409375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[39][34]=(0.0)*D;
  A[39][35]=(-(263125.0/290304.0)*(Jinv01*Jinv01)*M00-(625.0/448.0)*(Jinv10*Jinv10)*M11-(263125.0/290304.0)*M10*Jinv01*Jinv11-(625.0/448.0)*Jinv10*M10*Jinv00+(19375.0/72576.0)*Jinv01*Jinv00*M00+(115625.0/145152.0)*M01*Jinv00*Jinv11-(25625.0/48384.0)*Jinv10*Jinv01*M01+(115625.0/145152.0)*Jinv10*M10*Jinv01-(625.0/448.0)*(Jinv00*Jinv00)*M00-(263125.0/290304.0)*Jinv01*M01*Jinv11-(25625.0/48384.0)*M10*Jinv00*Jinv11+(19375.0/72576.0)*Jinv10*Jinv11*M11-(263125.0/290304.0)*(Jinv11*Jinv11)*M11-(625.0/448.0)*Jinv10*M01*Jinv00)*D;
  A[39][36]=(0.0)*D;
  A[39][37]=(-(11875.0/41472.0)*(Jinv01*Jinv01)*M00-(53125.0/20736.0)*(Jinv10*Jinv10)*M11-(11875.0/41472.0)*M10*Jinv01*Jinv11-(53125.0/20736.0)*Jinv10*M10*Jinv00-(53125.0/20736.0)*Jinv01*Jinv00*M00-(53125.0/41472.0)*M01*Jinv00*Jinv11-(53125.0/41472.0)*Jinv10*Jinv01*M01-(53125.0/41472.0)*Jinv10*M10*Jinv01-(53125.0/20736.0)*(Jinv00*Jinv00)*M00-(11875.0/41472.0)*Jinv01*M01*Jinv11-(53125.0/41472.0)*M10*Jinv00*Jinv11-(53125.0/20736.0)*Jinv10*Jinv11*M11-(11875.0/41472.0)*(Jinv11*Jinv11)*M11-(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[39][38]=(0.0)*D;
  A[39][39]=((6875.0/3456.0)*(Jinv01*Jinv01)*M00+(53125.0/20736.0)*(Jinv10*Jinv10)*M11+(6875.0/3456.0)*M10*Jinv01*Jinv11+(53125.0/20736.0)*Jinv10*M10*Jinv00+(53125.0/20736.0)*Jinv01*Jinv00*M00+(53125.0/41472.0)*M01*Jinv00*Jinv11+(53125.0/41472.0)*Jinv10*Jinv01*M01+(53125.0/41472.0)*Jinv10*M10*Jinv01+(53125.0/20736.0)*(Jinv00*Jinv00)*M00+(6875.0/3456.0)*Jinv01*M01*Jinv11+(53125.0/41472.0)*M10*Jinv00*Jinv11+(53125.0/20736.0)*Jinv10*Jinv11*M11+(6875.0/3456.0)*(Jinv11*Jinv11)*M11+(53125.0/20736.0)*Jinv10*M01*Jinv00)*D;
  A[39][40]=(0.0)*D;
  A[39][41]=((725.0/3584.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*M10*Jinv01*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*Jinv10*Jinv01*M01+(725.0/3584.0)*Jinv01*M01*Jinv11+(123425.0/145152.0)*M10*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][0]=(-(5951.0/145152.0)*(Jinv01*Jinv01)*M00-(5951.0/145152.0)*M10*Jinv01*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*M01*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*M10*Jinv01-(5951.0/145152.0)*Jinv01*M01*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][1]=(0.0)*D;
  A[40][2]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][3]=(0.0)*D;
  A[40][4]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][5]=(0.0)*D;
  A[40][6]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][7]=(0.0)*D;
  A[40][8]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][9]=(0.0)*D;
  A[40][10]=((5951.0/145152.0)*Jinv01*Jinv00*M00+(5951.0/145152.0)*M01*Jinv00*Jinv11+(5951.0/145152.0)*Jinv10*M10*Jinv01+(5951.0/145152.0)*Jinv10*Jinv11*M11)*D;
  A[40][11]=(0.0)*D;
  A[40][12]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*M01*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][13]=(0.0)*D;
  A[40][14]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][15]=(0.0)*D;
  A[40][16]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][17]=(0.0)*D;
  A[40][18]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][19]=(0.0)*D;
  A[40][20]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*M10*Jinv01*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*M01*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*Jinv01*M01*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][21]=(0.0)*D;
  A[40][22]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*M10*Jinv01*Jinv11-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*M01*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*Jinv01*M01*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][23]=(0.0)*D;
  A[40][24]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][25]=(0.0)*D;
  A[40][26]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][27]=(0.0)*D;
  A[40][28]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*M10*Jinv01*Jinv11+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*M01*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*Jinv01*M01*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][29]=(0.0)*D;
  A[40][30]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*M10*Jinv01*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*M01*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*Jinv01*M01*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][31]=(0.0)*D;
  A[40][32]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][33]=(0.0)*D;
  A[40][34]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*M10*Jinv01*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*M01*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*Jinv01*M01*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][35]=(0.0)*D;
  A[40][36]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*M10*Jinv01*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*M01*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*Jinv01*M01*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][37]=(0.0)*D;
  A[40][38]=((725.0/3584.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*M10*Jinv01*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*M01*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*Jinv01*M01*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][39]=(0.0)*D;
  A[40][40]=((16567.0/48384.0)*(Jinv01*Jinv01)*M00+(16567.0/48384.0)*M10*Jinv01*Jinv11+(16567.0/48384.0)*Jinv01*M01*Jinv11+(16567.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[40][41]=(0.0)*D;
  A[41][0]=(0.0)*D;
  A[41][1]=(-(5951.0/145152.0)*(Jinv01*Jinv01)*M00-(5951.0/145152.0)*M10*Jinv01*Jinv11-(5951.0/145152.0)*Jinv01*Jinv00*M00-(5951.0/145152.0)*M01*Jinv00*Jinv11-(5951.0/145152.0)*Jinv10*M10*Jinv01-(5951.0/145152.0)*Jinv01*M01*Jinv11-(5951.0/145152.0)*Jinv10*Jinv11*M11-(5951.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][2]=(0.0)*D;
  A[41][3]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][4]=(0.0)*D;
  A[41][5]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][6]=(0.0)*D;
  A[41][7]=(-(175.0/4608.0)*(Jinv01*Jinv01)*M00-(175.0/4608.0)*M10*Jinv01*Jinv11-(175.0/4608.0)*Jinv01*M01*Jinv11-(175.0/4608.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][8]=(0.0)*D;
  A[41][9]=(-(1975.0/48384.0)*(Jinv01*Jinv01)*M00-(1975.0/48384.0)*M10*Jinv01*Jinv11-(1975.0/48384.0)*Jinv01*M01*Jinv11-(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][10]=(0.0)*D;
  A[41][11]=((5951.0/145152.0)*Jinv01*Jinv00*M00+(5951.0/145152.0)*M01*Jinv00*Jinv11+(5951.0/145152.0)*Jinv10*M10*Jinv01+(5951.0/145152.0)*Jinv10*Jinv11*M11)*D;
  A[41][12]=(0.0)*D;
  A[41][13]=((29375.0/145152.0)*(Jinv01*Jinv01)*M00+(29375.0/145152.0)*M10*Jinv01*Jinv11+(1675.0/10368.0)*Jinv01*Jinv00*M00+(1675.0/10368.0)*M01*Jinv00*Jinv11+(1675.0/10368.0)*Jinv10*M10*Jinv01+(29375.0/145152.0)*Jinv01*M01*Jinv11+(1675.0/10368.0)*Jinv10*Jinv11*M11+(29375.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][14]=(0.0)*D;
  A[41][15]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][16]=(0.0)*D;
  A[41][17]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][18]=(0.0)*D;
  A[41][19]=((15625.0/145152.0)*(Jinv01*Jinv01)*M00+(15625.0/145152.0)*M10*Jinv01*Jinv11+(15625.0/145152.0)*Jinv01*M01*Jinv11+(15625.0/145152.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][20]=(0.0)*D;
  A[41][21]=((1975.0/48384.0)*(Jinv01*Jinv01)*M00+(1975.0/48384.0)*M10*Jinv01*Jinv11-(1675.0/10368.0)*Jinv01*Jinv00*M00-(1675.0/10368.0)*M01*Jinv00*Jinv11-(1675.0/10368.0)*Jinv10*M10*Jinv01+(1975.0/48384.0)*Jinv01*M01*Jinv11-(1675.0/10368.0)*Jinv10*Jinv11*M11+(1975.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][22]=(0.0)*D;
  A[41][23]=(-(130625.0/290304.0)*(Jinv01*Jinv01)*M00-(130625.0/290304.0)*M10*Jinv01*Jinv11-(575.0/1512.0)*Jinv01*Jinv00*M00-(575.0/1512.0)*M01*Jinv00*Jinv11-(575.0/1512.0)*Jinv10*M10*Jinv01-(130625.0/290304.0)*Jinv01*M01*Jinv11-(575.0/1512.0)*Jinv10*Jinv11*M11-(130625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][24]=(0.0)*D;
  A[41][25]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][26]=(0.0)*D;
  A[41][27]=(-(15625.0/290304.0)*(Jinv01*Jinv01)*M00-(15625.0/290304.0)*M10*Jinv01*Jinv11-(15625.0/290304.0)*Jinv01*M01*Jinv11-(15625.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][28]=(0.0)*D;
  A[41][29]=(-(20225.0/290304.0)*(Jinv01*Jinv01)*M00-(20225.0/290304.0)*M10*Jinv01*Jinv11+(575.0/1512.0)*Jinv01*Jinv00*M00+(575.0/1512.0)*M01*Jinv00*Jinv11+(575.0/1512.0)*Jinv10*M10*Jinv01-(20225.0/290304.0)*Jinv01*M01*Jinv11+(575.0/1512.0)*Jinv10*Jinv11*M11-(20225.0/290304.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][30]=(0.0)*D;
  A[41][31]=((14375.0/24192.0)*(Jinv01*Jinv01)*M00+(14375.0/24192.0)*M10*Jinv01*Jinv11+(6325.0/10368.0)*Jinv01*Jinv00*M00+(6325.0/10368.0)*M01*Jinv00*Jinv11+(6325.0/10368.0)*Jinv10*M10*Jinv01+(14375.0/24192.0)*Jinv01*M01*Jinv11+(6325.0/10368.0)*Jinv10*Jinv11*M11+(14375.0/24192.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][32]=(0.0)*D;
  A[41][33]=(-(15625.0/72576.0)*(Jinv01*Jinv01)*M00-(15625.0/72576.0)*M10*Jinv01*Jinv11-(15625.0/72576.0)*Jinv01*M01*Jinv11-(15625.0/72576.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][34]=(0.0)*D;
  A[41][35]=(-(575.0/36288.0)*(Jinv01*Jinv01)*M00-(575.0/36288.0)*M10*Jinv01*Jinv11-(6325.0/10368.0)*Jinv01*Jinv00*M00-(6325.0/10368.0)*M01*Jinv00*Jinv11-(6325.0/10368.0)*Jinv10*M10*Jinv01-(575.0/36288.0)*Jinv01*M01*Jinv11-(6325.0/10368.0)*Jinv10*Jinv11*M11-(575.0/36288.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][36]=(0.0)*D;
  A[41][37]=(-(26875.0/41472.0)*(Jinv01*Jinv01)*M00-(26875.0/41472.0)*M10*Jinv01*Jinv11-(123425.0/145152.0)*Jinv01*Jinv00*M00-(123425.0/145152.0)*M01*Jinv00*Jinv11-(123425.0/145152.0)*Jinv10*M10*Jinv01-(26875.0/41472.0)*Jinv01*M01*Jinv11-(123425.0/145152.0)*Jinv10*Jinv11*M11-(26875.0/41472.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][38]=(0.0)*D;
  A[41][39]=((725.0/3584.0)*(Jinv01*Jinv01)*M00+(725.0/3584.0)*M10*Jinv01*Jinv11+(123425.0/145152.0)*Jinv01*Jinv00*M00+(123425.0/145152.0)*M01*Jinv00*Jinv11+(123425.0/145152.0)*Jinv10*M10*Jinv01+(725.0/3584.0)*Jinv01*M01*Jinv11+(123425.0/145152.0)*Jinv10*Jinv11*M11+(725.0/3584.0)*(Jinv11*Jinv11)*M11)*D;
  A[41][40]=(0.0)*D;
  A[41][41]=((16567.0/48384.0)*(Jinv01*Jinv01)*M00+(16567.0/48384.0)*M10*Jinv01*Jinv11+(16567.0/48384.0)*Jinv01*M01*Jinv11+(16567.0/48384.0)*(Jinv11*Jinv11)*M11)*D;
  int nbf = 42;  

  pair<int,int> index; 
  for (int i=0; i< nbf; i++) {
    index.first = iidof[i]; 
    for (int j=0; j< nbf; j++) {
      index.second = iidof[j]; 
      matrix[index] += A[i][j];   
    }
  }

}
